(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       150,          7]
NotebookDataLength[   1031313,      18030]
NotebookOptionsPosition[   1019520,      17745]
NotebookOutlinePosition[   1025833,      17890]
CellTagsIndexPosition[   1025790,      17887]
WindowTitle->CDF InfoKit - Mandelbrot & Julia Sets
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Mandelbrot and Julia Fractal Sets", "Title",
 CellChangeTimes->{{3.505532082070176*^9, 3.505532085805726*^9}, 
   3.5060529709731083`*^9, {3.5091016870663614`*^9, 3.5091016974062586`*^9}, {
   3.512834681017666*^9, 3.512834682387842*^9}, {3.512834743916793*^9, 
   3.512834762259749*^9}, 3.512835489471404*^9, {3.512835899143688*^9, 
   3.512835901824376*^9}, {3.513346276729426*^9, 3.513346283242709*^9}, {
   3.5142078619962435`*^9, 3.5142078773827815`*^9}, {3.514210102934333*^9, 
   3.5142101177528152`*^9}, {3.5142178925899262`*^9, 3.5142178940089264`*^9}}],

Cell["History and Introductory Concepts", "Subtitle",
 CellChangeTimes->{{3.5060522445714755`*^9, 3.5060522487928977`*^9}, {
  3.506052314204438*^9, 3.5060523167156897`*^9}, {3.506054280360431*^9, 
  3.5060542931544313`*^9}, {3.5140474872034655`*^9, 3.5140474879725094`*^9}}],

Cell["Eric Weisstein", "Author",
 CellChangeTimes->{{3.5060998848828917`*^9, 3.5060998961527395`*^9}, {
   3.5061001078985205`*^9, 3.5061001346125207`*^9}, 3.509101374025586*^9, {
   3.5091014085318303`*^9, 3.50910141061287*^9}}],

Cell["\<\
The introduction of fractal objects in mathematics and physics by Benoit \
Mandelbrot revolutionized the descriptive methods we use to model the \
geometry of nature. Nowadays fractals find applications in computer graphics, \
physics, biology, medicine, engineering, and many other fields. Recursive \
geometric and algebraic algorithms are at the heart of fractal generation. In \
this article we summarize basic information on two well-known fractals: the \
Julia and Mandelbrot sets. For these and a few other fractals, the methods of \
description, construction, and visualization are reviewed along with some \
history and useful references.\
\>", "Abstract",
 CellChangeTimes->{
  3.509101346509835*^9, {3.509122892428677*^9, 3.5091229620160413`*^9}, {
   3.50912660758853*^9, 3.5091266121689434`*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["\<\
A fractal is an object or quantity that displays self-similarity, in a \
somewhat technical sense, on all scales. The object need not exhibit exactly \
the same structure at all scales, but the same \"type\" of structures must \
appear on all scales. A plot of the quantity on a log-log graph versus scale \
then gives a straight line, whose slope is said to be the fractal dimension. \
The prototypical example for a fractal is the length of a coastline measured \
with different length rulers. The shorter the ruler, the longer the length \
measured, a paradox known as the coastline paradox.\
\>", "Text",
 CellChangeTimes->{{3.505533636400078*^9, 3.5055336382482624`*^9}, {
  3.5147402314296865`*^9, 3.5147402326200438`*^9}}],

Cell["\<\
Determining the length of a country's coastline is not as simple as it first \
appears, as first considered by L. F. Richardson (1881-1953) and sometimes \
known as the Richardson effect (Mandelbrot 1983, p. 28). In fact, the answer \
depends on the length of the ruler you use for the measurements. A shorter \
ruler measures more of the sinuosity of bays and inlets than a larger one, so \
the estimated length continues to increase as the ruler length decreases.\
\>", "Text",
 CellChangeTimes->{{3.5060527980358167`*^9, 3.5060527992269354`*^9}}],

Cell["\<\
Plotting the length of the ruler versus the measured length of the coastline \
on a log-log plot gives a straight line, the slope of which is the fractal \
dimension of the coastline (and will be a number between 1 and 2).\
\>", "Text",
 CellChangeTimes->{{3.5091267872029915`*^9, 3.509126789471986*^9}}],

Cell["\<\
In the interactive Demonstration below the fractal curves are generated from \
an initial curve (often a regular polygon) and one or more replacement \
curves. Repeatedly, each line is replaced by a properly scaled copy of one of \
the replacement curves. The buttons show the first iteration of the \
replacement curve used. To see the initial curve, set the number of steps to \
0.\
\>", "Text",
 CellChangeTimes->{{3.5091024539288096`*^9, 3.5091024573674974`*^9}, {
  3.5116278128081245`*^9, 3.511627813554865*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"Curve", ",", "Flat"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Curve", "/:", 
   RowBox[{"r_", " ", "c_Curve"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r", " ", "#1"}], "&"}], ")"}], "/@", "c"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"simplify", "[", "c_Curve", "]"}], ":=", 
   RowBox[{"c", "//.", "\[VeryThinSpace]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Curve", "[", 
        RowBox[{
         RowBox[{"Turn", "[", "r1_", "]"}], ",", 
         RowBox[{"Turn", "[", "r2_", "]"}]}], "]"}], "\[RuleDelayed]", 
       RowBox[{"Curve", "[", 
        RowBox[{"Turn", "[", 
         RowBox[{"r1", "+", "r2"}], "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Curve", "[", 
        RowBox[{"Turn", "[", 
         RowBox[{"z_", "/;", 
          RowBox[{"z", "\[Equal]", "0.0"}]}], "]"}], "]"}], "\[RuleDelayed]", 
       
       RowBox[{"Curve", "[", "]"}]}]}], "}"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Iterate", "[", 
    RowBox[{"c_Curve", ",", "template_Curve"}], "]"}], ":=", 
   RowBox[{"c", "/.", "\[VeryThinSpace]", 
    RowBox[{
     RowBox[{"Move", "[", "l_", "]"}], "\[RuleDelayed]", 
     RowBox[{"l", " ", "template"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Iterate", "[", 
    RowBox[{"c_Curve", ",", 
     RowBox[{"template", ":", 
      RowBox[{"{", "__Curve", "}"}]}]}], "]"}], ":=", 
   RowBox[{"c", "/.", "\[VeryThinSpace]", 
    RowBox[{
     RowBox[{"Move", "[", 
      RowBox[{"l_", ",", 
       RowBox[{"n_", ":", "1"}]}], "]"}], "\[RuleDelayed]", 
     RowBox[{"l", " ", 
      RowBox[{
      "template", "\[LeftDoubleBracket]", "n", 
       "\[RightDoubleBracket]"}]}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Move", "/:", 
   RowBox[{"l_", " ", 
    RowBox[{"Move", "[", 
     RowBox[{"l1_", ",", "args___"}], "]"}]}], ":=", 
   RowBox[{"Move", "[", 
    RowBox[{
     RowBox[{"l", " ", "l1"}], ",", "args"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Turn", "/:", 
   RowBox[{"l_", " ", 
    RowBox[{"Turn", "[", "a_", "]"}]}], ":=", 
   RowBox[{"Turn", "[", "a", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Fractal", "[", 
    RowBox[{"c_Curve", ",", "t_", ",", 
     RowBox[{"n_Integer", "?", "NonNegative"}]}], "]"}], ":=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tt", "=", 
       RowBox[{"Fixup", "[", "t", "]"}]}], "}"}], ",", 
     RowBox[{"Nest", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Iterate", "[", 
         RowBox[{"#1", ",", "tt"}], "]"}], "&"}], ",", "c", ",", "n"}], 
      "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"NextState", "[", 
    RowBox[{
     RowBox[{"s", "[", 
      RowBox[{"xy_", ",", "a_"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"l_", ",", "___"}], "]"}]}], "]"}], ":=", 
   RowBox[{"s", "[", 
    RowBox[{
     RowBox[{"xy", "+", 
      RowBox[{"l", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Cos", "[", "a", "]"}], ",", 
         RowBox[{"Sin", "[", "a", "]"}]}], "}"}]}]}], ",", "a"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"NextState", "[", 
    RowBox[{
     RowBox[{"s", "[", 
      RowBox[{"xy_", ",", "a_"}], "]"}], ",", 
     RowBox[{"Turn", "[", "da_", "]"}]}], "]"}], ":=", 
   RowBox[{"s", "[", 
    RowBox[{"xy", ",", 
     RowBox[{"a", "+", 
      RowBox[{"da", " ", "\[Degree]"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CurveToStates", "[", "c_Curve", "]"}], ":=", 
   RowBox[{"FoldList", "[", 
    RowBox[{"NextState", ",", 
     RowBox[{"s", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0.0", ",", "0.0"}], "}"}], ",", "0.0"}], "]"}], ",", 
     RowBox[{"List", "@@", "c"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"RemoveDuplicates", "[", "l_List", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "pairs", "}"}], ",", 
     RowBox[{
      RowBox[{"pairs", "=", 
       RowBox[{"Partition", "[", 
        RowBox[{"l", ",", "2", ",", "1"}], "]"}]}], ";", 
      RowBox[{"pairs", "=", 
       RowBox[{"Select", "[", 
        RowBox[{"pairs", ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "=!=", 
           RowBox[{
           "#1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
          "&"}]}], "]"}]}], ";", 
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"First", "/@", "pairs"}], ",", 
        RowBox[{"Last", "[", "l", "]"}]}], "]"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"StatesToLine", "[", "st_List", "]"}], ":=", 
   RowBox[{"Line", "[", 
    RowBox[{"RemoveDuplicates", "[", 
     RowBox[{"First", "/@", "st"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"EndPoint", "[", "c_Curve", "]"}], ":=", 
   RowBox[{
    RowBox[{"Last", "[", 
     RowBox[{"CurveToStates", "[", "c", "]"}], "]"}], "\[LeftDoubleBracket]", 
    "1", "\[RightDoubleBracket]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"simplify", "[", "c_Curve", "]"}], ":=", 
   RowBox[{"c", "//.", "\[VeryThinSpace]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Curve", "[", 
        RowBox[{
         RowBox[{"Turn", "[", "r1_", "]"}], ",", 
         RowBox[{"Turn", "[", "r2_", "]"}]}], "]"}], "\[RuleDelayed]", 
       RowBox[{"Curve", "[", 
        RowBox[{"Turn", "[", 
         RowBox[{"r1", "+", "r2"}], "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Curve", "[", 
        RowBox[{"Turn", "[", 
         RowBox[{"z_", "/;", 
          RowBox[{"z", "\[Equal]", "0.0"}]}], "]"}], "]"}], "\[RuleDelayed]", 
       
       RowBox[{"Curve", "[", "]"}]}]}], "}"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"Fixup", ",", "Listable"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Fixup", "[", "t_Curve", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"excess", ",", "rot", ",", 
       RowBox[{"tt", "=", "t"}]}], "}"}], ",", 
     RowBox[{
      RowBox[{"rot", "=", 
       RowBox[{"Chop", "[", 
        FractionBox[
         RowBox[{"ArcTan", "@@", 
          RowBox[{"EndPoint", "[", "tt", "]"}]}], "\[Degree]"], "]"}]}], ";", 
      
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"rot", "\[NotEqual]", "0.0"}], ",", 
        RowBox[{"PrependTo", "[", 
         RowBox[{"tt", ",", 
          RowBox[{"Turn", "[", 
           RowBox[{"-", "rot"}], "]"}]}], "]"}]}], "]"}], ";", 
      RowBox[{"rot", "=", 
       RowBox[{"Plus", "@@", 
        RowBox[{"First", "/@", 
         RowBox[{"Cases", "[", 
          RowBox[{"tt", ",", "_Turn"}], "]"}]}]}]}], ";", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"rot", "\[NotEqual]", "0.0"}], ",", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"tt", ",", 
          RowBox[{"Turn", "[", 
           RowBox[{"-", "rot"}], "]"}]}], "]"}]}], "]"}], ";", 
      RowBox[{"simplify", "[", "tt", "]"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Curve", "/:", 
    RowBox[{"Graphics", "[", 
     RowBox[{"c_Curve", ",", 
      RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"thick", ",", "gc"}], "}"}], ",", 
      RowBox[{
       RowBox[{"thick", "=", 
        RowBox[{"Thickness", "/.", "\[VeryThinSpace]", 
         RowBox[{"Flatten", "[", 
          RowBox[{"{", "opts", "}"}], "]"}]}]}], ";", 
       RowBox[{"gc", "=", 
        RowBox[{"StatesToLine", "[", 
         RowBox[{"CurveToStates", "[", "c", "]"}], "]"}]}], ";", 
       RowBox[{"gc", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"NumericQ", "[", "thick", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Thickness", "[", "thick", "]"}], ",", "gc"}], "}"}], ",", 
          RowBox[{"{", "gc", "}"}]}], "]"}]}], ";", 
       RowBox[{"Graphics", "[", 
        RowBox[{"gc", ",", 
         RowBox[{"{", 
          RowBox[{"opts", ",", 
           RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "}"}]}], 
        "]"}]}]}], "]"}]}], ";"}], "\n", 
  RowBox[{"(*", "Examples", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Gon", "[", "n_", "]"}], ":=", 
   RowBox[{"TurnCurve", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      FractionBox["360.0", "n"], ",", 
      RowBox[{"{", 
       RowBox[{"n", "-", "1"}], "}"}]}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TurnCurve", "[", "l_List", "]"}], ":=", 
   RowBox[{"Append", "[", 
    RowBox[{
     RowBox[{"Apply", "[", 
      RowBox[{"Curve", ",", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Move", "[", "1", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"Length", "[", "l", "]"}], "}"}]}], "]"}], ",", 
          RowBox[{"Turn", "/@", "l"}]}], "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"Move", "[", "1", "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ht1", "=", 
   RowBox[{"Curve", "[", 
    RowBox[{
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "2"}], "]"}], ",", 
     RowBox[{"Turn", "[", 
      RowBox[{"-", "60"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "1"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "1"}], "]"}], ",", 
     RowBox[{"Turn", "[", 
      RowBox[{"-", "120"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "1"}], "]"}], ",", 
     RowBox[{"Turn", "[", 
      RowBox[{"-", "60"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "2"}], "]"}], ",", 
     RowBox[{"Turn", "[", "120", "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "2"}], "]"}], ",", 
     RowBox[{"Turn", "[", "60", "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "1"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ht2", "=", 
   RowBox[{
    RowBox[{"Reverse", "[", "ht1", "]"}], "/.", "\[VeryThinSpace]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Turn", "[", "a_", "]"}], "\[RuleDelayed]", 
       RowBox[{"Turn", "[", 
        RowBox[{"-", "a"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Move", "[", 
        RowBox[{"d_", ",", "i_"}], "]"}], "\[RuleDelayed]", 
       RowBox[{"Move", "[", 
        RowBox[{"d", ",", 
         RowBox[{"3", "-", "i"}]}], "]"}]}]}], "}"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sql", "=", 
   RowBox[{"Curve", "[", 
    RowBox[{
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "2"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "1"}], "]"}], ",", 
     RowBox[{"Turn", "[", 
      RowBox[{"-", "90"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "1"}], "]"}], ",", 
     RowBox[{"Turn", "[", 
      RowBox[{"-", "90"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "2"}], "]"}], ",", 
     RowBox[{"Turn", "[", "90", "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "1"}], "]"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sqr", "=", 
   RowBox[{
    RowBox[{"Reverse", "[", "sql", "]"}], "/.", "\[VeryThinSpace]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Turn", "[", "a_", "]"}], "\[RuleDelayed]", 
       RowBox[{"Turn", "[", 
        RowBox[{"-", "a"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Move", "[", 
        RowBox[{"d_", ",", "i_"}], "]"}], "\[RuleDelayed]", 
       RowBox[{"Move", "[", 
        RowBox[{"d", ",", 
         RowBox[{"3", "-", "i"}]}], "]"}]}]}], "}"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"mb1", "=", 
   RowBox[{"Curve", "[", 
    RowBox[{
     RowBox[{"Turn", "[", "60", "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "2"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "4"}], "]"}], ",", 
     RowBox[{"Turn", "[", 
      RowBox[{"-", "60"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "4"}], "]"}], ",", 
     RowBox[{"Turn", "[", 
      RowBox[{"-", "60"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "4"}], "]"}], ",", 
     RowBox[{"Turn", "[", 
      RowBox[{"-", "90"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{
       SqrtBox["3.0"], ",", "3"}], "]"}], ",", 
     RowBox[{"Turn", "[", "150", "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "2"}], "]"}], ",", 
     RowBox[{"Move", "[", 
      RowBox[{"1", ",", "4"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"flip", "[", "1", "]"}], "=", "2"}], ";", 
  RowBox[{
   RowBox[{"flip", "[", "2", "]"}], "=", "1"}], ";", 
  RowBox[{
   RowBox[{"flip", "[", "3", "]"}], "=", "4"}], ";", 
  RowBox[{
   RowBox[{"flip", "[", "4", "]"}], "=", "3"}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rev", "[", "1", "]"}], "=", "3"}], ";", 
   RowBox[{
    RowBox[{"rev", "[", "3", "]"}], "=", "1"}], ";", 
   RowBox[{
    RowBox[{"rev", "[", "2", "]"}], "=", "4"}], ";", 
   RowBox[{
    RowBox[{"rev", "[", "4", "]"}], "=", "2"}], ";"}], "\[IndentingNewLine]", 
  
  RowBox[{"(*", "flipped", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mb2", "=", 
    RowBox[{"mb1", "/.", "\[VeryThinSpace]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Turn", "[", "a_", "]"}], "\[RuleDelayed]", 
        RowBox[{"Turn", "[", 
         RowBox[{"-", "a"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Move", "[", 
         RowBox[{"d_", ",", "n_"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"Move", "[", 
         RowBox[{"d", ",", 
          RowBox[{"flip", "[", "n", "]"}]}], "]"}]}]}], "}"}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "reversed", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mb3", "=", 
    RowBox[{
     RowBox[{"Reverse", "[", "mb1", "]"}], "/.", "\[VeryThinSpace]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Turn", "[", "a_", "]"}], "\[RuleDelayed]", 
        RowBox[{"Turn", "[", 
         RowBox[{"-", "a"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Move", "[", 
         RowBox[{"d_", ",", "n_"}], "]"}], "\[RuleDelayed]", 
        RowBox[{"Move", "[", 
         RowBox[{"d", ",", 
          RowBox[{"rev", "[", "n", "]"}]}], "]"}]}]}], "}"}]}]}], ";"}], "\n", 
  RowBox[{"(*", 
   RowBox[{"flipped", " ", "and", " ", "reversed"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mb4", "=", 
   RowBox[{
    RowBox[{"Reverse", "[", "mb2", "]"}], "/.", "\[VeryThinSpace]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"Turn", "[", "a_", "]"}], "\[RuleDelayed]", 
       RowBox[{"Turn", "[", 
        RowBox[{"-", "a"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"Move", "[", 
        RowBox[{"d_", ",", "n_"}], "]"}], "\[RuleDelayed]", 
       RowBox[{"Move", "[", 
        RowBox[{"d", ",", 
         RowBox[{"rev", "[", "n", "]"}]}], "]"}]}]}], "}"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"examples", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Gon", "[", "3", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"TurnCurve", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "60"}], ",", "120", ",", 
           RowBox[{"-", "60"}]}], "}"}], "]"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Curve", "[", 
        RowBox[{"Move", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"ht1", ",", "ht2"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"mb1", ",", 
       RowBox[{"{", 
        RowBox[{"mb1", ",", "mb2", ",", "mb3", ",", "mb4"}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Curve", "[", 
        RowBox[{"Move", "[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"sql", ",", "sqr"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Gon", "[", "4", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"TurnCurve", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "90"}], ",", "90", ",", "90", ",", "0", ",", 
           RowBox[{"-", "90"}], ",", 
           RowBox[{"-", "90"}], ",", "90"}], "}"}], "]"}], "}"}]}], "}"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"Fractal", "[", 
      RowBox[{
       RowBox[{"ex", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"ex", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", "n"}], "]"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"400", ",", "400"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "3", ",", "\"\<iterations\>\""}], "}"}], ",", 
     RowBox[{
      RowBox[{"Range", "[", "6", "]"}], "-", "1"}], ",", "Setter"}], "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ex", ",", 
       RowBox[{"examples", "[", 
        RowBox[{"[", "3", "]"}], "]"}], ",", 
       RowBox[{"Column", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<replacement\>\"", ",", "\"\<curves\>\""}], "}"}], "]"}],
        ",", 
       RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], ",", 
     RowBox[{"Thread", "[", 
      RowBox[{"examples", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{
            RowBox[{"Fractal", "[", 
             RowBox[{
              RowBox[{"#", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", 
              RowBox[{"#", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "1"}], "]"}], ",", 
            RowBox[{"ImageSize", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"65", ",", "65"}], "}"}]}]}], "]"}], "&"}], "/@", 
         "examples"}], ")"}]}], "]"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "SetterBar"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AppearanceElements", "\[Rule]", "None"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.36861375779963*^9, 3.36861376157734*^9}, {
   3.36861383800974*^9, 3.36861388922054*^9}, {3.36861412752693*^9, 
   3.36861421934246*^9}, {3.36861435784369*^9, 3.36861436118668*^9}, {
   3.36861444708481*^9, 3.36861446917823*^9}, {3.3686145662151*^9, 
   3.36861464629436*^9}, {3.36861473890533*^9, 3.36861474283954*^9}, {
   3.36861477887194*^9, 3.36861481098669*^9}, {3.36861499850759*^9, 
   3.36861507796971*^9}, {3.36861513355786*^9, 3.36861513584993*^9}, {
   3.36861517899638*^9, 3.36861519294773*^9}, {3.36861545762174*^9, 
   3.36861547277396*^9}, {3.36861553996177*^9, 3.36861556345122*^9}, {
   3.36861560446576*^9, 3.36861561028156*^9}, {3.36861565477591*^9, 
   3.36861565954167*^9}, {3.36879128602122*^9, 3.36879129289798*^9}, {
   3.36879259008935*^9, 3.36879260349904*^9}, {3.36879277601194*^9, 
   3.36879277649644*^9}, {3.36879283186998*^9, 3.36879283551154*^9}, {
   3.36879295854303*^9, 3.36879299455224*^9}, {3.36879569255917*^9, 
   3.3687957042747*^9}, {3.36879578664369*^9, 3.36879579304945*^9}, {
   3.36880773592983*^9, 3.36880773877368*^9}, {3.3787313814411573`*^9, 
   3.3787313902536573`*^9}, {3.3787317798786573`*^9, 
   3.3787317811911573`*^9}, {3.378731856113033*^9, 3.3787318864411573`*^9}, {
   3.3790906261752586`*^9, 3.379090670956222*^9}, {3.38072711715625*^9, 
   3.38072711790625*^9}, {3.38072725009375*^9, 3.380727250578125*^9}, {
   3.3864476567284393`*^9, 3.386447656806565*^9}, {3.5060526196959844`*^9, 
   3.506052636847699*^9}, 3.5114651428458643`*^9, {3.511474500432088*^9, 
   3.5114745700520697`*^9}, {3.511474617858804*^9, 3.5114746290484443`*^9}, {
   3.5114746819804716`*^9, 3.5114747178515234`*^9}, 3.511488970135708*^9, {
   3.5141223837266254`*^9, 3.514122416638916*^9}, {3.514297995850761*^9, 
   3.5142983222117305`*^9}, {3.514298396020629*^9, 3.514298420560587*^9}, 
   3.5142993057061243`*^9, {3.514299355520286*^9, 3.514299449661641*^9}},
 CellID->1388044557],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`ex$$ = {
     $CellContext`Curve[
      $CellContext`Turn[60], 
      $CellContext`Move[1, 2], 
      $CellContext`Move[1, 4], 
      $CellContext`Turn[-60], 
      $CellContext`Move[1, 4], 
      $CellContext`Turn[-60], 
      $CellContext`Move[1, 4], 
      $CellContext`Turn[-90], 
      $CellContext`Move[1.7320508075688772`, 3], 
      $CellContext`Turn[150], 
      $CellContext`Move[1, 2], 
      $CellContext`Move[1, 4]], {
      $CellContext`Curve[
       $CellContext`Turn[60], 
       $CellContext`Move[1, 2], 
       $CellContext`Move[1, 4], 
       $CellContext`Turn[-60], 
       $CellContext`Move[1, 4], 
       $CellContext`Turn[-60], 
       $CellContext`Move[1, 4], 
       $CellContext`Turn[-90], 
       $CellContext`Move[1.7320508075688772`, 3], 
       $CellContext`Turn[150], 
       $CellContext`Move[1, 2], 
       $CellContext`Move[1, 4]], 
      $CellContext`Curve[
       $CellContext`Turn[-60], 
       $CellContext`Move[1, 1], 
       $CellContext`Move[1, 3], 
       $CellContext`Turn[60], 
       $CellContext`Move[1, 3], 
       $CellContext`Turn[60], 
       $CellContext`Move[1, 3], 
       $CellContext`Turn[90], 
       $CellContext`Move[1.7320508075688772`, 4], 
       $CellContext`Turn[-150], 
       $CellContext`Move[1, 1], 
       $CellContext`Move[1, 3]], 
      $CellContext`Curve[
       $CellContext`Move[1, 2], 
       $CellContext`Move[1, 4], 
       $CellContext`Turn[-150], 
       $CellContext`Move[1.7320508075688772`, 1], 
       $CellContext`Turn[90], 
       $CellContext`Move[1, 2], 
       $CellContext`Turn[60], 
       $CellContext`Move[1, 2], 
       $CellContext`Turn[60], 
       $CellContext`Move[1, 2], 
       $CellContext`Move[1, 4], 
       $CellContext`Turn[-60]], 
      $CellContext`Curve[
       $CellContext`Move[1, 1], 
       $CellContext`Move[1, 3], 
       $CellContext`Turn[150], 
       $CellContext`Move[1.7320508075688772`, 2], 
       $CellContext`Turn[-90], 
       $CellContext`Move[1, 1], 
       $CellContext`Turn[-60], 
       $CellContext`Move[1, 1], 
       $CellContext`Turn[-60], 
       $CellContext`Move[1, 1], 
       $CellContext`Move[1, 3], 
       $CellContext`Turn[60]]}}, $CellContext`n$$ = 3, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n$$], 3, "iterations"}, {0, 1, 2, 3, 4, 5}}, {{
       Hold[$CellContext`ex$$], {
        $CellContext`Curve[
         $CellContext`Turn[60], 
         $CellContext`Move[1, 2], 
         $CellContext`Move[1, 4], 
         $CellContext`Turn[-60], 
         $CellContext`Move[1, 4], 
         $CellContext`Turn[-60], 
         $CellContext`Move[1, 4], 
         $CellContext`Turn[-90], 
         $CellContext`Move[1.7320508075688772`, 3], 
         $CellContext`Turn[150], 
         $CellContext`Move[1, 2], 
         $CellContext`Move[1, 4]], {
         $CellContext`Curve[
          $CellContext`Turn[60], 
          $CellContext`Move[1, 2], 
          $CellContext`Move[1, 4], 
          $CellContext`Turn[-60], 
          $CellContext`Move[1, 4], 
          $CellContext`Turn[-60], 
          $CellContext`Move[1, 4], 
          $CellContext`Turn[-90], 
          $CellContext`Move[1.7320508075688772`, 3], 
          $CellContext`Turn[150], 
          $CellContext`Move[1, 2], 
          $CellContext`Move[1, 4]], 
         $CellContext`Curve[
          $CellContext`Turn[-60], 
          $CellContext`Move[1, 1], 
          $CellContext`Move[1, 3], 
          $CellContext`Turn[60], 
          $CellContext`Move[1, 3], 
          $CellContext`Turn[60], 
          $CellContext`Move[1, 3], 
          $CellContext`Turn[90], 
          $CellContext`Move[1.7320508075688772`, 4], 
          $CellContext`Turn[-150], 
          $CellContext`Move[1, 1], 
          $CellContext`Move[1, 3]], 
         $CellContext`Curve[
          $CellContext`Move[1, 2], 
          $CellContext`Move[1, 4], 
          $CellContext`Turn[-150], 
          $CellContext`Move[1.7320508075688772`, 1], 
          $CellContext`Turn[90], 
          $CellContext`Move[1, 2], 
          $CellContext`Turn[60], 
          $CellContext`Move[1, 2], 
          $CellContext`Turn[60], 
          $CellContext`Move[1, 2], 
          $CellContext`Move[1, 4], 
          $CellContext`Turn[-60]], 
         $CellContext`Curve[
          $CellContext`Move[1, 1], 
          $CellContext`Move[1, 3], 
          $CellContext`Turn[150], 
          $CellContext`Move[1.7320508075688772`, 2], 
          $CellContext`Turn[-90], 
          $CellContext`Move[1, 1], 
          $CellContext`Turn[-60], 
          $CellContext`Move[1, 1], 
          $CellContext`Turn[-60], 
          $CellContext`Move[1, 1], 
          $CellContext`Move[1, 3], 
          $CellContext`Turn[60]]}}, 
       Column[{"replacement", "curves"}], ControlType -> SetterBar}, {{
         $CellContext`Curve[
          $CellContext`Move[1], 
          $CellContext`Turn[120.], 
          $CellContext`Move[1], 
          $CellContext`Turn[120.], 
          $CellContext`Move[1]], {
          $CellContext`Curve[
           $CellContext`Move[1], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1], 
           $CellContext`Turn[120], 
           $CellContext`Move[1], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1]]}} -> Graphics[{
          
          Line[{{0., 0.}, {1., 0.}, {1.5, -0.8660254037844386}, {2., 0.}, {3.,
            0.}, {2.5, 0.8660254037844387}, {3., 1.7320508075688772`}, {2., 
           1.7320508075688774`}, {1.4999999999999998`, 2.598076211353316}, {
           1.0000000000000002`, 1.7320508075688772`}, {2.220446049250313*^-16,
            1.7320508075688765`}, {0.5000000000000011, 0.8660254037844384}, {
           2.275957200481571*^-15, -8.881784197001252*^-16}}]}, {
         ImageSize -> {65, 65}, AspectRatio -> Automatic}], {
         $CellContext`Curve[
          $CellContext`Move[1, 1]], {
          $CellContext`Curve[
           $CellContext`Move[1, 2], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1, 1], 
           $CellContext`Move[1, 1], 
           $CellContext`Turn[-120], 
           $CellContext`Move[1, 1], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1, 2], 
           $CellContext`Turn[120], 
           $CellContext`Move[1, 2], 
           $CellContext`Turn[60], 
           $CellContext`Move[1, 1]], 
          $CellContext`Curve[
           $CellContext`Move[1, 2], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1, 1], 
           $CellContext`Turn[-120], 
           $CellContext`Move[1, 1], 
           $CellContext`Turn[60], 
           $CellContext`Move[1, 2], 
           $CellContext`Turn[120], 
           $CellContext`Move[1, 2], 
           $CellContext`Move[1, 2], 
           $CellContext`Turn[60], 
           $CellContext`Move[1, 1]]}} -> Graphics[{
          
          Line[{{0., 0.}, {0.18898223650461357`, 0.9819805060619657}, {
           1.1338934190276817`, 1.3093073414159544`}, {2.0788046015507495`, 
           1.636634176769943}, {1.8898223650461363`, 0.6546536707079773}, {
           0.9449111825230684, 0.32732683535398827`}, {
           1.700840128541523, -0.3273268353539887}, {2.645751311064591, 
           0.}}]}, {ImageSize -> {65, 65}, AspectRatio -> Automatic}], {
         $CellContext`Curve[
          $CellContext`Turn[60], 
          $CellContext`Move[1, 2], 
          $CellContext`Move[1, 4], 
          $CellContext`Turn[-60], 
          $CellContext`Move[1, 4], 
          $CellContext`Turn[-60], 
          $CellContext`Move[1, 4], 
          $CellContext`Turn[-90], 
          $CellContext`Move[1.7320508075688772`, 3], 
          $CellContext`Turn[150], 
          $CellContext`Move[1, 2], 
          $CellContext`Move[1, 4]], {
          $CellContext`Curve[
           $CellContext`Turn[60], 
           $CellContext`Move[1, 2], 
           $CellContext`Move[1, 4], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1, 4], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1, 4], 
           $CellContext`Turn[-90], 
           $CellContext`Move[1.7320508075688772`, 3], 
           $CellContext`Turn[150], 
           $CellContext`Move[1, 2], 
           $CellContext`Move[1, 4]], 
          $CellContext`Curve[
           $CellContext`Turn[-60], 
           $CellContext`Move[1, 1], 
           $CellContext`Move[1, 3], 
           $CellContext`Turn[60], 
           $CellContext`Move[1, 3], 
           $CellContext`Turn[60], 
           $CellContext`Move[1, 3], 
           $CellContext`Turn[90], 
           $CellContext`Move[1.7320508075688772`, 4], 
           $CellContext`Turn[-150], 
           $CellContext`Move[1, 1], 
           $CellContext`Move[1, 3]], 
          $CellContext`Curve[
           $CellContext`Move[1, 2], 
           $CellContext`Move[1, 4], 
           $CellContext`Turn[-150], 
           $CellContext`Move[1.7320508075688772`, 1], 
           $CellContext`Turn[90], 
           $CellContext`Move[1, 2], 
           $CellContext`Turn[60], 
           $CellContext`Move[1, 2], 
           $CellContext`Turn[60], 
           $CellContext`Move[1, 2], 
           $CellContext`Move[1, 4], 
           $CellContext`Turn[-60]], 
          $CellContext`Curve[
           $CellContext`Move[1, 1], 
           $CellContext`Move[1, 3], 
           $CellContext`Turn[150], 
           $CellContext`Move[1.7320508075688772`, 2], 
           $CellContext`Turn[-90], 
           $CellContext`Move[1, 1], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1, 1], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1, 1], 
           $CellContext`Move[1, 3], 
           $CellContext`Turn[60]]}} -> Graphics[{
          Line[CompressedData["
1:eJxTTMoPSmViYGAwAmIQjR18sEcTcEDlsjis8ol4UbXtNUwdlP/b/s9/ELhv
vw5F/oP9Gqg8xM4f9g2WTnp3TrA4MKHo53Zghpr/St/8Ik+QoAMrVD9MngfM
f2APk2eDyteDzROB6mdwQOVzwPkQ+wTQ+CJwPguYz+Mg4uzbvdpeAq5+Jdh+
abh6VL4YmnoJNPOl4P6B8GXg/mWE8hug6iHOV0DjKzq8huqHyaPql3OoQwlP
CYclKOEt5DATJT4kHFZA9YOj67+gwwuo+RA+O1Q/N9Q+Dod5UPMYoXyI+Is9
TNDwOgAxfz8svLZA1O+HhdcmFL6Yww409RDznu6BqYfwH+6B+QfCv7UHFn4Q
/qU9jNDwgPCP7IGF9zyof2Hhuwzqflj4rUThKzqsRgkfJah5B2wAEIbLHg==

           "]]}, {ImageSize -> {65, 65}, AspectRatio -> Automatic}], {
         $CellContext`Curve[
          $CellContext`Move[1, 1]], {
          $CellContext`Curve[
           $CellContext`Move[1, 2], 
           $CellContext`Move[1, 1], 
           $CellContext`Turn[-90], 
           $CellContext`Move[1, 1], 
           $CellContext`Turn[-90], 
           $CellContext`Move[1, 2], 
           $CellContext`Turn[90], 
           $CellContext`Move[1, 1]], 
          $CellContext`Curve[
           $CellContext`Move[1, 2], 
           $CellContext`Turn[-90], 
           $CellContext`Move[1, 1], 
           $CellContext`Turn[90], 
           $CellContext`Move[1, 2], 
           $CellContext`Turn[90], 
           $CellContext`Move[1, 2], 
           $CellContext`Move[1, 1]]}} -> Graphics[{
          
          Line[{{0., 0.}, {0.44721359549995804`, 0.8944271909999159}, {
           0.8944271909999161, 1.7888543819998317`}, {1.788854381999832, 
           1.3416407864998736`}, {1.341640786499874, 0.44721359549995776`}, {
           2.23606797749979, -2.220446049250313*^-16}}]}, {
         ImageSize -> {65, 65}, AspectRatio -> Automatic}], {
         $CellContext`Curve[
          $CellContext`Move[1], 
          $CellContext`Turn[90.], 
          $CellContext`Move[1], 
          $CellContext`Turn[90.], 
          $CellContext`Move[1], 
          $CellContext`Turn[90.], 
          $CellContext`Move[1]], {
          $CellContext`Curve[
           $CellContext`Move[1], 
           $CellContext`Turn[-90], 
           $CellContext`Move[1], 
           $CellContext`Turn[90], 
           $CellContext`Move[1], 
           $CellContext`Turn[90], 
           $CellContext`Move[1], 
           $CellContext`Turn[0], 
           $CellContext`Move[1], 
           $CellContext`Turn[-90], 
           $CellContext`Move[1], 
           $CellContext`Turn[-90], 
           $CellContext`Move[1], 
           $CellContext`Turn[90], 
           $CellContext`Move[1]]}} -> Graphics[{
          Line[CompressedData["
1:eJxTTMoPSmViYGBQBGIQjR18sMfO/7AfKuCAnQ8HMHmoPg4cfBgQwMGHqRfB
wYfZI4DG58DB50BTj87HJQ7jo9sr4vAfAuxh6v+h8Dkc/oC57+H8vyh8mPk7
9sD4TYvUg/3mHdoDUw+JI1g4czgwo/Bh7jixB+aOX1DzYe74AeWjuuPCHpg7
HC9O1lT3v7wH5g4Anl9vBQ==
           "]]}, {
         ImageSize -> {65, 65}, AspectRatio -> Automatic}]}}}, 
    Typeset`size$$ = {400., {198., 202.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`n$1966$$ = 0, $CellContext`ex$1967$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`ex$$ = {
          $CellContext`Curve[
           $CellContext`Turn[60], 
           $CellContext`Move[1, 2], 
           $CellContext`Move[1, 4], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1, 4], 
           $CellContext`Turn[-60], 
           $CellContext`Move[1, 4], 
           $CellContext`Turn[-90], 
           $CellContext`Move[1.7320508075688772`, 3], 
           $CellContext`Turn[150], 
           $CellContext`Move[1, 2], 
           $CellContext`Move[1, 4]], {
           $CellContext`Curve[
            $CellContext`Turn[60], 
            $CellContext`Move[1, 2], 
            $CellContext`Move[1, 4], 
            $CellContext`Turn[-60], 
            $CellContext`Move[1, 4], 
            $CellContext`Turn[-60], 
            $CellContext`Move[1, 4], 
            $CellContext`Turn[-90], 
            $CellContext`Move[1.7320508075688772`, 3], 
            $CellContext`Turn[150], 
            $CellContext`Move[1, 2], 
            $CellContext`Move[1, 4]], 
           $CellContext`Curve[
            $CellContext`Turn[-60], 
            $CellContext`Move[1, 1], 
            $CellContext`Move[1, 3], 
            $CellContext`Turn[60], 
            $CellContext`Move[1, 3], 
            $CellContext`Turn[60], 
            $CellContext`Move[1, 3], 
            $CellContext`Turn[90], 
            $CellContext`Move[1.7320508075688772`, 4], 
            $CellContext`Turn[-150], 
            $CellContext`Move[1, 1], 
            $CellContext`Move[1, 3]], 
           $CellContext`Curve[
            $CellContext`Move[1, 2], 
            $CellContext`Move[1, 4], 
            $CellContext`Turn[-150], 
            $CellContext`Move[1.7320508075688772`, 1], 
            $CellContext`Turn[90], 
            $CellContext`Move[1, 2], 
            $CellContext`Turn[60], 
            $CellContext`Move[1, 2], 
            $CellContext`Turn[60], 
            $CellContext`Move[1, 2], 
            $CellContext`Move[1, 4], 
            $CellContext`Turn[-60]], 
           $CellContext`Curve[
            $CellContext`Move[1, 1], 
            $CellContext`Move[1, 3], 
            $CellContext`Turn[150], 
            $CellContext`Move[1.7320508075688772`, 2], 
            $CellContext`Turn[-90], 
            $CellContext`Move[1, 1], 
            $CellContext`Turn[-60], 
            $CellContext`Move[1, 1], 
            $CellContext`Turn[-60], 
            $CellContext`Move[1, 1], 
            $CellContext`Move[1, 3], 
            $CellContext`Turn[60]]}}, $CellContext`n$$ = 3}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n$$, $CellContext`n$1966$$, 0], 
        Hold[$CellContext`ex$$, $CellContext`ex$1967$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics[
        $CellContext`Fractal[
         Part[$CellContext`ex$$, 1], 
         Part[$CellContext`ex$$, 2], $CellContext`n$$], 
        ImageSize -> {400, 400}], 
      "Specifications" :> {{{$CellContext`n$$, 3, "iterations"}, {0, 1, 2, 3, 
         4, 5}, ControlType -> Setter}, {{$CellContext`ex$$, {
           $CellContext`Curve[
            $CellContext`Turn[60], 
            $CellContext`Move[1, 2], 
            $CellContext`Move[1, 4], 
            $CellContext`Turn[-60], 
            $CellContext`Move[1, 4], 
            $CellContext`Turn[-60], 
            $CellContext`Move[1, 4], 
            $CellContext`Turn[-90], 
            $CellContext`Move[1.7320508075688772`, 3], 
            $CellContext`Turn[150], 
            $CellContext`Move[1, 2], 
            $CellContext`Move[1, 4]], {
            $CellContext`Curve[
             $CellContext`Turn[60], 
             $CellContext`Move[1, 2], 
             $CellContext`Move[1, 4], 
             $CellContext`Turn[-60], 
             $CellContext`Move[1, 4], 
             $CellContext`Turn[-60], 
             $CellContext`Move[1, 4], 
             $CellContext`Turn[-90], 
             $CellContext`Move[1.7320508075688772`, 3], 
             $CellContext`Turn[150], 
             $CellContext`Move[1, 2], 
             $CellContext`Move[1, 4]], 
            $CellContext`Curve[
             $CellContext`Turn[-60], 
             $CellContext`Move[1, 1], 
             $CellContext`Move[1, 3], 
             $CellContext`Turn[60], 
             $CellContext`Move[1, 3], 
             $CellContext`Turn[60], 
             $CellContext`Move[1, 3], 
             $CellContext`Turn[90], 
             $CellContext`Move[1.7320508075688772`, 4], 
             $CellContext`Turn[-150], 
             $CellContext`Move[1, 1], 
             $CellContext`Move[1, 3]], 
            $CellContext`Curve[
             $CellContext`Move[1, 2], 
             $CellContext`Move[1, 4], 
             $CellContext`Turn[-150], 
             $CellContext`Move[1.7320508075688772`, 1], 
             $CellContext`Turn[90], 
             $CellContext`Move[1, 2], 
             $CellContext`Turn[60], 
             $CellContext`Move[1, 2], 
             $CellContext`Turn[60], 
             $CellContext`Move[1, 2], 
             $CellContext`Move[1, 4], 
             $CellContext`Turn[-60]], 
            $CellContext`Curve[
             $CellContext`Move[1, 1], 
             $CellContext`Move[1, 3], 
             $CellContext`Turn[150], 
             $CellContext`Move[1.7320508075688772`, 2], 
             $CellContext`Turn[-90], 
             $CellContext`Move[1, 1], 
             $CellContext`Turn[-60], 
             $CellContext`Move[1, 1], 
             $CellContext`Turn[-60], 
             $CellContext`Move[1, 1], 
             $CellContext`Move[1, 3], 
             $CellContext`Turn[60]]}}, 
          Column[{"replacement", "curves"}], ControlType -> SetterBar}, {{
            $CellContext`Curve[
             $CellContext`Move[1], 
             $CellContext`Turn[120.], 
             $CellContext`Move[1], 
             $CellContext`Turn[120.], 
             $CellContext`Move[1]], {
             $CellContext`Curve[
              $CellContext`Move[1], 
              $CellContext`Turn[-60], 
              $CellContext`Move[1], 
              $CellContext`Turn[120], 
              $CellContext`Move[1], 
              $CellContext`Turn[-60], 
              $CellContext`Move[1]]}} -> Graphics[{
             
             Line[{{0., 0.}, {1., 0.}, {1.5, -0.8660254037844386}, {2., 0.}, {
              3., 0.}, {2.5, 0.8660254037844387}, {3., 1.7320508075688772`}, {
              2., 1.7320508075688774`}, {1.4999999999999998`, 
              2.598076211353316}, {1.0000000000000002`, 
              1.7320508075688772`}, {2.220446049250313*^-16, 
              1.7320508075688765`}, {0.5000000000000011, 
              0.8660254037844384}, {
              2.275957200481571*^-15, -8.881784197001252*^-16}}]}, {
            ImageSize -> {65, 65}, AspectRatio -> Automatic}], {
            $CellContext`Curve[
             $CellContext`Move[1, 1]], {
             $CellContext`Curve[
              $CellContext`Move[1, 2], 
              $CellContext`Turn[-60], 
              $CellContext`Move[1, 1], 
              $CellContext`Move[1, 1], 
              $CellContext`Turn[-120], 
              $CellContext`Move[1, 1], 
              $CellContext`Turn[-60], 
              $CellContext`Move[1, 2], 
              $CellContext`Turn[120], 
              $CellContext`Move[1, 2], 
              $CellContext`Turn[60], 
              $CellContext`Move[1, 1]], 
             $CellContext`Curve[
              $CellContext`Move[1, 2], 
              $CellContext`Turn[-60], 
              $CellContext`Move[1, 1], 
              $CellContext`Turn[-120], 
              $CellContext`Move[1, 1], 
              $CellContext`Turn[60], 
              $CellContext`Move[1, 2], 
              $CellContext`Turn[120], 
              $CellContext`Move[1, 2], 
              $CellContext`Move[1, 2], 
              $CellContext`Turn[60], 
              $CellContext`Move[1, 1]]}} -> Graphics[{
             
             Line[{{0., 0.}, {0.18898223650461357`, 0.9819805060619657}, {
              1.1338934190276817`, 1.3093073414159544`}, {2.0788046015507495`,
               1.636634176769943}, {1.8898223650461363`, 
              0.6546536707079773}, {0.9449111825230684, 
              0.32732683535398827`}, {
              1.700840128541523, -0.3273268353539887}, {2.645751311064591, 
              0.}}]}, {ImageSize -> {65, 65}, AspectRatio -> Automatic}], {
            $CellContext`Curve[
             $CellContext`Turn[60], 
             $CellContext`Move[1, 2], 
             $CellContext`Move[1, 4], 
             $CellContext`Turn[-60], 
             $CellContext`Move[1, 4], 
             $CellContext`Turn[-60], 
             $CellContext`Move[1, 4], 
             $CellContext`Turn[-90], 
             $CellContext`Move[1.7320508075688772`, 3], 
             $CellContext`Turn[150], 
             $CellContext`Move[1, 2], 
             $CellContext`Move[1, 4]], {
             $CellContext`Curve[
              $CellContext`Turn[60], 
              $CellContext`Move[1, 2], 
              $CellContext`Move[1, 4], 
              $CellContext`Turn[-60], 
              $CellContext`Move[1, 4], 
              $CellContext`Turn[-60], 
              $CellContext`Move[1, 4], 
              $CellContext`Turn[-90], 
              $CellContext`Move[1.7320508075688772`, 3], 
              $CellContext`Turn[150], 
              $CellContext`Move[1, 2], 
              $CellContext`Move[1, 4]], 
             $CellContext`Curve[
              $CellContext`Turn[-60], 
              $CellContext`Move[1, 1], 
              $CellContext`Move[1, 3], 
              $CellContext`Turn[60], 
              $CellContext`Move[1, 3], 
              $CellContext`Turn[60], 
              $CellContext`Move[1, 3], 
              $CellContext`Turn[90], 
              $CellContext`Move[1.7320508075688772`, 4], 
              $CellContext`Turn[-150], 
              $CellContext`Move[1, 1], 
              $CellContext`Move[1, 3]], 
             $CellContext`Curve[
              $CellContext`Move[1, 2], 
              $CellContext`Move[1, 4], 
              $CellContext`Turn[-150], 
              $CellContext`Move[1.7320508075688772`, 1], 
              $CellContext`Turn[90], 
              $CellContext`Move[1, 2], 
              $CellContext`Turn[60], 
              $CellContext`Move[1, 2], 
              $CellContext`Turn[60], 
              $CellContext`Move[1, 2], 
              $CellContext`Move[1, 4], 
              $CellContext`Turn[-60]], 
             $CellContext`Curve[
              $CellContext`Move[1, 1], 
              $CellContext`Move[1, 3], 
              $CellContext`Turn[150], 
              $CellContext`Move[1.7320508075688772`, 2], 
              $CellContext`Turn[-90], 
              $CellContext`Move[1, 1], 
              $CellContext`Turn[-60], 
              $CellContext`Move[1, 1], 
              $CellContext`Turn[-60], 
              $CellContext`Move[1, 1], 
              $CellContext`Move[1, 3], 
              $CellContext`Turn[60]]}} -> Graphics[{
             Line[CompressedData["
1:eJxTTMoPSmViYGAwAmIQjR18sEcTcEDlsjis8ol4UbXtNUwdlP/b/s9/ELhv
vw5F/oP9Gqg8xM4f9g2WTnp3TrA4MKHo53Zghpr/St/8Ik+QoAMrVD9MngfM
f2APk2eDyteDzROB6mdwQOVzwPkQ+wTQ+CJwPguYz+Mg4uzbvdpeAq5+Jdh+
abh6VL4YmnoJNPOl4P6B8GXg/mWE8hug6iHOV0DjKzq8huqHyaPql3OoQwlP
CYclKOEt5DATJT4kHFZA9YOj67+gwwuo+RA+O1Q/N9Q+Dod5UPMYoXyI+Is9
TNDwOgAxfz8svLZA1O+HhdcmFL6Yww409RDznu6BqYfwH+6B+QfCv7UHFn4Q
/qU9jNDwgPCP7IGF9zyof2Hhuwzqflj4rUThKzqsRgkfJah5B2wAEIbLHg==

              "]]}, {ImageSize -> {65, 65}, AspectRatio -> Automatic}], {
            $CellContext`Curve[
             $CellContext`Move[1, 1]], {
             $CellContext`Curve[
              $CellContext`Move[1, 2], 
              $CellContext`Move[1, 1], 
              $CellContext`Turn[-90], 
              $CellContext`Move[1, 1], 
              $CellContext`Turn[-90], 
              $CellContext`Move[1, 2], 
              $CellContext`Turn[90], 
              $CellContext`Move[1, 1]], 
             $CellContext`Curve[
              $CellContext`Move[1, 2], 
              $CellContext`Turn[-90], 
              $CellContext`Move[1, 1], 
              $CellContext`Turn[90], 
              $CellContext`Move[1, 2], 
              $CellContext`Turn[90], 
              $CellContext`Move[1, 2], 
              $CellContext`Move[1, 1]]}} -> Graphics[{
             
             Line[{{0., 0.}, {0.44721359549995804`, 0.8944271909999159}, {
              0.8944271909999161, 1.7888543819998317`}, {1.788854381999832, 
              1.3416407864998736`}, {1.341640786499874, 
              0.44721359549995776`}, {
              2.23606797749979, -2.220446049250313*^-16}}]}, {
            ImageSize -> {65, 65}, AspectRatio -> Automatic}], {
            $CellContext`Curve[
             $CellContext`Move[1], 
             $CellContext`Turn[90.], 
             $CellContext`Move[1], 
             $CellContext`Turn[90.], 
             $CellContext`Move[1], 
             $CellContext`Turn[90.], 
             $CellContext`Move[1]], {
             $CellContext`Curve[
              $CellContext`Move[1], 
              $CellContext`Turn[-90], 
              $CellContext`Move[1], 
              $CellContext`Turn[90], 
              $CellContext`Move[1], 
              $CellContext`Turn[90], 
              $CellContext`Move[1], 
              $CellContext`Turn[0], 
              $CellContext`Move[1], 
              $CellContext`Turn[-90], 
              $CellContext`Move[1], 
              $CellContext`Turn[-90], 
              $CellContext`Move[1], 
              $CellContext`Turn[90], 
              $CellContext`Move[1]]}} -> Graphics[{
             Line[CompressedData["
1:eJxTTMoPSmViYGBQBGIQjR18sMfO/7AfKuCAnQ8HMHmoPg4cfBgQwMGHqRfB
wYfZI4DG58DB50BTj87HJQ7jo9sr4vAfAuxh6v+h8Dkc/oC57+H8vyh8mPk7
9sD4TYvUg/3mHdoDUw+JI1g4czgwo/Bh7jixB+aOX1DzYe74AeWjuuPCHpg7
HC9O1lT3v7wH5g4Anl9vBQ==
              "]]}, {
            ImageSize -> {65, 65}, AspectRatio -> Automatic}]}, ControlType -> 
         SetterBar}}, "Options" :> {AppearanceElements -> None}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{464., {274., 281.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`Fractal[
         Pattern[$CellContext`c, 
          Blank[$CellContext`Curve]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         PatternTest[
          Pattern[$CellContext`n, 
           Blank[Integer]], NonNegative]] := 
       With[{$CellContext`tt = $CellContext`Fixup[$CellContext`t]}, 
         Nest[$CellContext`Iterate[#, $CellContext`tt]& , $CellContext`c, \
$CellContext`n]], Attributes[$CellContext`Curve] = {Flat}, 
       UpSetDelayed[Pattern[$CellContext`c, 
          Blank[$CellContext`Curve]] Pattern[$CellContext`r, 
          Blank[]], 
        Map[$CellContext`r #& , $CellContext`c]], 
       UpSetDelayed[
        Graphics[
         Pattern[$CellContext`c, 
          Blank[$CellContext`Curve]], 
         PatternTest[
          Pattern[$CellContext`opts, 
           BlankNullSequence[]], OptionQ]], 
        Module[{$CellContext`thick, $CellContext`gc}, $CellContext`thick = 
          ReplaceAll[Thickness, 
            
            Flatten[{$CellContext`opts}]]; $CellContext`gc = \
$CellContext`StatesToLine[
            $CellContext`CurveToStates[$CellContext`c]]; $CellContext`gc = 
          If[
            NumericQ[$CellContext`thick], {
             
             Thickness[$CellContext`thick], $CellContext`gc}, \
{$CellContext`gc}]; 
         Graphics[$CellContext`gc, {$CellContext`opts, AspectRatio -> 
            Automatic}]]], $CellContext`StatesToLine[
         Pattern[$CellContext`st, 
          Blank[List]]] := Line[
         $CellContext`RemoveDuplicates[
          Map[First, $CellContext`st]]], $CellContext`RemoveDuplicates[
         Pattern[$CellContext`l, 
          Blank[List]]] := 
       Module[{$CellContext`pairs}, $CellContext`pairs = 
          Partition[$CellContext`l, 2, 1]; $CellContext`pairs = 
          Select[$CellContext`pairs, Part[#, 1] =!= Part[#, 2]& ]; Append[
           Map[First, $CellContext`pairs], 
           Last[$CellContext`l]]], $CellContext`CurveToStates[
         Pattern[$CellContext`c, 
          Blank[$CellContext`Curve]]] := FoldList[$CellContext`NextState, 
         $CellContext`s[{0., 0.}, 0.], 
         Apply[List, $CellContext`c]], $CellContext`NextState[
         $CellContext`s[
          Pattern[$CellContext`xy, 
           Blank[]], 
          Pattern[$CellContext`a, 
           Blank[]]], 
         $CellContext`Move[
          Pattern[$CellContext`l, 
           Blank[]], 
          
          BlankNullSequence[]]] := $CellContext`s[$CellContext`xy + \
$CellContext`l {
            Cos[$CellContext`a], 
            Sin[$CellContext`a]}, $CellContext`a], $CellContext`NextState[
         $CellContext`s[
          Pattern[$CellContext`xy, 
           Blank[]], 
          Pattern[$CellContext`a, 
           Blank[]]], 
         $CellContext`Turn[
          Pattern[$CellContext`da, 
           
           Blank[]]]] := $CellContext`s[$CellContext`xy, $CellContext`a + \
$CellContext`da Degree], 
       UpSetDelayed[$CellContext`Move[
          Pattern[$CellContext`l1, 
           Blank[]], 
          Pattern[$CellContext`args, 
           BlankNullSequence[]]] Pattern[$CellContext`l, 
          Blank[]], 
        $CellContext`Move[$CellContext`l $CellContext`l1, $CellContext`args]], 
       UpSetDelayed[Pattern[$CellContext`l, 
          Blank[]] $CellContext`Turn[
          Pattern[$CellContext`a, 
           Blank[]]], 
        $CellContext`Turn[$CellContext`a]], 
       Attributes[$CellContext`Fixup] = {Listable}, $CellContext`Fixup[
         Pattern[$CellContext`t, 
          Blank[$CellContext`Curve]]] := 
       Module[{$CellContext`excess, $CellContext`rot, $CellContext`tt = \
$CellContext`t}, $CellContext`rot = Chop[Apply[ArcTan, 
              $CellContext`EndPoint[$CellContext`tt]]/Degree]; 
         If[$CellContext`rot != 0., 
           PrependTo[$CellContext`tt, 
            $CellContext`Turn[-$CellContext`rot]]]; $CellContext`rot = 
          Apply[Plus, 
            Map[First, 
             Cases[$CellContext`tt, 
              Blank[$CellContext`Turn]]]]; If[$CellContext`rot != 0., 
           AppendTo[$CellContext`tt, 
            $CellContext`Turn[-$CellContext`rot]]]; \
$CellContext`simplify[$CellContext`tt]], $CellContext`EndPoint[
         Pattern[$CellContext`c, 
          Blank[$CellContext`Curve]]] := Part[
         Last[
          $CellContext`CurveToStates[$CellContext`c]], 
         1], $CellContext`simplify[
         Pattern[$CellContext`c, 
          Blank[$CellContext`Curve]]] := 
       ReplaceRepeated[$CellContext`c, {$CellContext`Curve[
            $CellContext`Turn[
             Pattern[$CellContext`r1, 
              Blank[]]], 
            $CellContext`Turn[
             Pattern[$CellContext`r2, 
              Blank[]]]] :> $CellContext`Curve[
            $CellContext`Turn[$CellContext`r1 + $CellContext`r2]], \
$CellContext`Curve[
            $CellContext`Turn[
             Condition[
              Pattern[$CellContext`z, 
               Blank[]], $CellContext`z == 
              0.]]] :> $CellContext`Curve[]}], $CellContext`Iterate[
         Pattern[$CellContext`c, 
          Blank[$CellContext`Curve]], 
         Pattern[$CellContext`template, 
          Blank[$CellContext`Curve]]] := 
       ReplaceAll[$CellContext`c, $CellContext`Move[
           Pattern[$CellContext`l, 
            
            Blank[]]] :> $CellContext`l $CellContext`template], \
$CellContext`Iterate[
         Pattern[$CellContext`c, 
          Blank[$CellContext`Curve]], 
         Pattern[$CellContext`template, {
           BlankSequence[$CellContext`Curve]}]] := 
       ReplaceAll[$CellContext`c, $CellContext`Move[
           Pattern[$CellContext`l, 
            Blank[]], 
           Optional[
            Pattern[$CellContext`n, 
             Blank[]], 1]] :> $CellContext`l 
          Part[$CellContext`template, $CellContext`n]]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.514746796276824*^9}]
}, {2}]],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel",
  FontWeight->"Plain"],
 StyleBox["\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 ButtonBox["Based on the \[OpenCurlyDoubleQuote]Fractal Curves\
\[CloseCurlyDoubleQuote] interactive applet by Roman E. Maeder.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/FractalCurves/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/FractalCurves/"],
 " \[LineSeparator]Select the number of iterations or choose the replacement \
curve."
}], "FigureCaption",
 CellChangeTimes->{{3.509219656680394*^9, 3.509219694547472*^9}, {
   3.509220005381826*^9, 3.509220038615546*^9}, 3.512834113264539*^9}],

Cell["\<\
Another way to generate a fractal is to iterate branching. Such a process can \
be seen abundantly in natural flora. An example is given in the interactive \
Demonstration below. Drag the magenta and cyan circular locators at the \
intersection of crosshairs to bend the tree. This is a binary tree, which \
means it has two branches at each fork and one or two leaves at the end of \
each branch. One can create interesting patterns by simply changing the \
bending angles. Some patterns will look like real trees and others will look \
much more mathematical. You can also go through the growth stages (\
\[OpenCurlyDoubleQuote]generations\[CloseCurlyDoubleQuote] control), switch \
the crosshair on and off (\[OpenCurlyDoubleQuote]crosshair\
\[CloseCurlyDoubleQuote] control) and stylize the tree (\
\[OpenCurlyDoubleQuote]thickness ratio\[CloseCurlyDoubleQuote] and \
\[OpenCurlyDoubleQuote]tree color\[CloseCurlyDoubleQuote] controls). \
\>", "Text",
 CellChangeTimes->{
  3.506053650327431*^9, {3.509102495225067*^9, 3.509102509816985*^9}, {
   3.50912322590427*^9, 3.509123229247485*^9}, {3.509126811459193*^9, 
   3.509126811981041*^9}, {3.511488121585173*^9, 3.5114881293816195`*^9}, {
   3.5114883970309277`*^9, 3.511488437438239*^9}, {3.5116308324225655`*^9, 
   3.511630836199992*^9}, 3.5147390264082885`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"color1", "=", 
      RowBox[{"RGBColor", "[", 
       FractionBox[
        RowBox[{"{", 
         RowBox[{"123", ",", "20", ",", "0"}], "}"}], "255."], "]"}]}], ",", 
     RowBox[{"color2", "=", 
      RowBox[{"RGBColor", "[", 
       FractionBox[
        RowBox[{"{", 
         RowBox[{"255", ",", "114", ",", "17"}], "}"}], "255."], "]"}]}]}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"m1", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Reverse", "[", "pt1", "]"}], ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], "pt1"}]}], "}"}]}], ",", 
         RowBox[{"m2", "=", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Reverse", "[", "pt2", "]"}], ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1"}], "}"}], "pt2"}]}], "}"}]}]}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dynamic", "[", 
              RowBox[{"If", "[", 
               RowBox[{"bx", ",", "color1", ",", "White"}], "]"}], "]"}], ",", 
             RowBox[{"Dashing", "[", 
              RowBox[{"{", 
               RowBox[{"0.03", ",", "0.008"}], "}"}], "]"}], ",", 
             RowBox[{"Thickness", "[", ".005", "]"}], ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    "pt1", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"-", "5"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    "pt1", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", "5"}], "}"}]}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", "5"}], ",", 
                    RowBox[{
                    "pt1", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"5", ",", 
                    RowBox[{
                    "pt1", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "}"}]}], "}"}]}], "}"}], 
              "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Dynamic", "[", 
              RowBox[{"If", "[", 
               RowBox[{"bx", ",", "color2", ",", "White"}], "]"}], "]"}], ",", 
             RowBox[{"Dashing", "[", 
              RowBox[{"{", 
               RowBox[{"0.03", ",", "0.008"}], "}"}], "]"}], ",", 
             RowBox[{"Thickness", "[", ".005", "]"}], ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    "pt2", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"-", "5"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    "pt2", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", "5"}], "}"}]}], "}"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", "5"}], ",", 
                    RowBox[{
                    "pt2", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"5", ",", 
                    RowBox[{
                    "pt2", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "}"}]}], "}"}]}], "}"}], 
              "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"MapIndexed", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"ColorData", "[", "col", "]"}], "[", 
                 RowBox[{"#2", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
                RowBox[{"Thickness", "[", 
                 RowBox[{"0.01", 
                  RowBox[{"th", "^", 
                   RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], "]"}], ",", 
                RowBox[{"Line", "[", "#", "]"}]}], "}"}], "&"}], ",", 
             RowBox[{"NestList", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Flatten", "[", 
                 RowBox[{
                  RowBox[{"Map", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "+", 
                    RowBox[{"m1", ".", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "-", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "+", 
                    RowBox[{"m2", ".", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"#", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "-", 
                    RowBox[{"#", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}]}]}], "}"}]}], 
                    "}"}], "&"}], ",", "#"}], "]"}], ",", "1"}], "]"}], "&"}],
                ",", 
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"0", ",", 
                    RowBox[{"-", "1"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"0", ",", "0"}], "}"}]}], "}"}], "}"}], ",", 
               "gen"}], "]"}]}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "5"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"400", ",", "400"}], "}"}]}]}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"gen", ",", "10", ",", "\"\<generations\>\""}], "}"}], 
              ",", 
              RowBox[{"Range", "[", 
               RowBox[{"3", ",", "10"}], "]"}], ",", "Setter"}], "}"}], "]"}],
            ",", 
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"bx", ",", "True", ",", "\"\<crosshair\>\""}], "}"}], 
              ",", 
              RowBox[{"{", 
               RowBox[{"True", ",", "False"}], "}"}]}], "}"}], "]"}], ",", 
           RowBox[{"Button", "[", 
            RowBox[{"\"\<reset\>\"", ",", 
             RowBox[{
              RowBox[{"gen", "=", "10"}], ";", 
              RowBox[{"th", "=", "0.904"}], ";", 
              RowBox[{"pt1", "=", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.13"}], ",", "0.86"}], "}"}]}], ";", 
              RowBox[{"pt2", "=", 
               RowBox[{"{", 
                RowBox[{"0.485", ",", "0.47"}], "}"}]}]}], ",", 
             RowBox[{"ImageSize", "\[Rule]", "All"}], ",", 
             RowBox[{"ContentPadding", "\[Rule]", "False"}], ",", 
             RowBox[{"BaseStyle", "\[Rule]", "\"\<Manipulate\>\""}]}], 
            "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"th", ",", "0.904", ",", "\"\<thickness ratio\>\""}], 
               "}"}], ",", "0.01", ",", "1.2", ",", 
              RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Control", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"col", ",", "2", ",", "\"\<tree color\>\""}], "}"}], 
              ",", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"#", "\[Rule]", 
                  RowBox[{"Show", "[", 
                   RowBox[{
                    RowBox[{"ColorData", "[", 
                    RowBox[{"#", ",", "\"\<Image\>\""}], "]"}], ",", 
                    RowBox[{"ImageSize", "\[Rule]", "100"}]}], "]"}]}], ")"}],
                 "&"}], "/@", 
               RowBox[{"{", 
                RowBox[{
                "2", ",", "5", ",", "7", ",", "8", ",", "11", ",", "16", ",", 
                 "57"}], "}"}]}], ",", "PopupMenu"}], "}"}], "]"}], ",", 
           "SpanFromLeft"}], "}"}]}], "}"}], ",", 
       RowBox[{"Alignment", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"Left", ",", "Baseline", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", "Right"}], "}"}]}], 
         "}"}]}], ",", 
       RowBox[{"Spacings", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"3", ",", "1"}], "}"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pt1", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.13"}], ",", "0.86"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}], ",", "Locator", ",", 
       RowBox[{"Appearance", "\[Rule]", 
        RowBox[{"Graphics", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"color1", ",", 
            RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "15"}]}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pt2", ",", 
         RowBox[{"{", 
          RowBox[{"0.485", ",", "0.47"}], "}"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "3"}], ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}], ",", "Locator", ",", 
       RowBox[{"Appearance", "\[Rule]", 
        RowBox[{"Graphics", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"color2", ",", 
            RowBox[{"Disk", "[", "]"}]}], "}"}], ",", 
          RowBox[{"ImageSize", "\[Rule]", "15"}]}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"AppearanceElements", "\[Rule]", "None"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5142996403234415`*^9, 3.514299656049241*^9}, {
  3.5142997136009912`*^9, 3.514299726673875*^9}, {3.5142997941025076`*^9, 
  3.514299896898929*^9}, {3.514300024000729*^9, 3.5143002343490133`*^9}, {
  3.514300292523389*^9, 3.514300304379465*^9}, {3.5143003765421295`*^9, 
  3.5143003860903907`*^9}, {3.514304183825185*^9, 3.5143042263381853`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`bx$$ = True, $CellContext`col$$ = 
    2, $CellContext`gen$$ = 10, $CellContext`pt1$$ = {-0.13, 
    0.86}, $CellContext`pt2$$ = {0.485, 0.47}, $CellContext`th$$ = 0.904, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`gen$$], 10, "generations"}, {3, 4, 5, 6, 7, 8, 9, 
      10}}, {{
       Hold[$CellContext`bx$$], True, "crosshair"}, {True, False}}, {{
       Hold[$CellContext`th$$], 0.904, "thickness ratio"}, 0.01, 1.2}, {{
       Hold[$CellContext`col$$], 2, "tree color"}, {2 -> Graphics[{{
           RGBColor[
           0.8588235294117647, 0.00784313725490196, 0.00784313725490196], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{1, 0}, 
            Offset[{-1, -1}, {2, 1}]]}, {
           RGBColor[1., 0.26666666666666666`, 0.], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{2, 0}, 
            Offset[{-1, -1}, {3, 1}]]}, {
           RGBColor[1., 0.4549019607843137, 0.2549019607843137], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{3, 0}, 
            Offset[{-1, -1}, {4, 1}]]}, {
           RGBColor[
           0.4823529411764706, 0.18823529411764706`, 0.03529411764705882], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{4, 0}, 
            Offset[{-1, -1}, {5, 1}]]}, {
           RGBColor[1., 0.8784313725490196, 0.5058823529411764], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{5, 0}, 
            Offset[{-1, -1}, {6, 1}]]}, {
           RGBColor[
           0.7019607843137254, 0.7450980392156863, 0.8235294117647058], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{6, 0}, 
            Offset[{-1, -1}, {7, 1}]]}, {
           RGBColor[
           0.20784313725490197`, 0.23921568627450981`, 0.3215686274509804], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{7, 0}, 
            Offset[{-1, -1}, {8, 1}]]}, {
           RGBColor[
           0.08627450980392157, 0.1411764705882353, 0.28627450980392155`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{8, 0}, 
            Offset[{-1, -1}, {9, 1}]]}, {
           RGBColor[
           0.33725490196078434`, 0.403921568627451, 0.6235294117647059], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{9, 0}, 
            Offset[{-1, -1}, {10, 1}]]}}, {
         ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
          PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 5 -> 
       Graphics[{{
           RGBColor[
           0.4588235294117647, 0.1411764705882353, 0.1411764705882353], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{1, 0}, 
            Offset[{-1, -1}, {2, 1}]]}, {
           RGBColor[
           0.6274509803921569, 0.23137254901960785`, 0.23137254901960785`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{2, 0}, 
            Offset[{-1, -1}, {3, 1}]]}, {
           RGBColor[
           0.3803921568627451, 0.2784313725490196, 0.20784313725490197`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{3, 0}, 
            Offset[{-1, -1}, {4, 1}]]}, {
           RGBColor[
           0.5882352941176471, 0.44313725490196076`, 0.33725490196078434`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{4, 0}, 
            Offset[{-1, -1}, {5, 1}]]}, {
           RGBColor[
           0.592156862745098, 0.4196078431372549, 0.2823529411764706], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{5, 0}, 
            Offset[{-1, -1}, {6, 1}]]}, {
           RGBColor[
           0.8235294117647058, 0.5019607843137255, 0.09411764705882353], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{6, 0}, 
            Offset[{-1, -1}, {7, 1}]]}, {
           RGBColor[
           0.9764705882352941, 0.6901960784313725, 0.3215686274509804], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{7, 0}, 
            Offset[{-1, -1}, {8, 1}]]}, {
           RGBColor[
           0.396078431372549, 0.396078431372549, 0.17647058823529413`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{8, 0}, 
            Offset[{-1, -1}, {9, 1}]]}, {
           RGBColor[
           0.41568627450980394`, 0.41568627450980394`, 0.3058823529411765], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{9, 0}, 
            Offset[{-1, -1}, {10, 1}]]}, {
           RGBColor[
           0.6313725490196078, 0.6313725490196078, 0.24705882352941178`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{10, 0}, 
            Offset[{-1, -1}, {11, 1}]]}}, {
         ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
          PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 7 -> 
       Graphics[{{
           RGBColor[
           0.5019607843137255, 0.4980392156862745, 0.4980392156862745], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{1, 0}, 
            Offset[{-1, -1}, {2, 1}]]}, {
           RGBColor[
           0.796078431372549, 0.5137254901960784, 0.4980392156862745], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{2, 0}, 
            Offset[{-1, -1}, {3, 1}]]}, {
           RGBColor[
           0.40784313725490196`, 0.24313725490196078`, 0.20784313725490197`], 
           
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{3, 0}, 
            Offset[{-1, -1}, {4, 1}]]}, {
           RGBColor[
           0.803921568627451, 0.6862745098039216, 0.6039215686274509], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{4, 0}, 
            Offset[{-1, -1}, {5, 1}]]}, {
           RGBColor[0.28627450980392155`, 0.23921568627450981`, 0.2], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{5, 0}, 
            Offset[{-1, -1}, {6, 1}]]}, {
           RGBColor[
           0.7568627450980392, 0.7058823529411765, 0.5764705882352941], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{6, 0}, 
            Offset[{-1, -1}, {7, 1}]]}, {
           RGBColor[
           0.6980392156862745, 0.7254901960784313, 0.5647058823529412], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{7, 0}, 
            Offset[{-1, -1}, {8, 1}]]}, {
           RGBColor[
           0.4588235294117647, 0.5764705882352941, 0.5058823529411764], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{8, 0}, 
            Offset[{-1, -1}, {9, 1}]]}, {
           RGBColor[
           0.5725490196078431, 0.6313725490196078, 0.6705882352941176], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{9, 0}, 
            Offset[{-1, -1}, {10, 1}]]}, {
           RGBColor[
           0.3411764705882353, 0.34509803921568627`, 0.34901960784313724`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{10, 0}, 
            Offset[{-1, -1}, {11, 1}]]}, {
           RGBColor[
           0.2627450980392157, 0.3411764705882353, 0.4470588235294118], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{11, 0}, 
            Offset[{-1, -1}, {12, 1}]]}}, {
         ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
          PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 8 -> 
       Graphics[{{
           RGBColor[
           0.611764705882353, 0.2980392156862745, 0.29411764705882354`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{1, 0}, 
            Offset[{-1, -1}, {2, 1}]]}, {
           RGBColor[1., 0.8549019607843137, 0.8274509803921568], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{2, 0}, 
            Offset[{-1, -1}, {3, 1}]]}, {
           RGBColor[
           0.8588235294117647, 0.5607843137254902, 0.4588235294117647], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{3, 0}, 
            Offset[{-1, -1}, {4, 1}]]}, {
           RGBColor[
           0.6549019607843137, 0.2980392156862745, 0.08235294117647059], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{4, 0}, 
            Offset[{-1, -1}, {5, 1}]]}, {
           RGBColor[
           0.8705882352941177, 0.9254901960784314, 0.21568627450980393`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{5, 0}, 
            Offset[{-1, -1}, {6, 1}]]}, {
           RGBColor[
           0.5019607843137255, 0.6862745098039216, 0.03529411764705882], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{6, 0}, 
            Offset[{-1, -1}, {7, 1}]]}, {
           RGBColor[
           0.21568627450980393`, 0.36470588235294116`, 0.16470588235294117`], 
           
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{7, 0}, 
            Offset[{-1, -1}, {8, 1}]]}, {
           RGBColor[
           0.24313725490196078`, 0.3176470588235294, 0.30980392156862746`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{8, 0}, 
            Offset[{-1, -1}, {9, 1}]]}, {
           RGBColor[
           0.6862745098039216, 0.19215686274509805`, 0.24705882352941178`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{9, 0}, 
            Offset[{-1, -1}, {10, 1}]]}}, {
         ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
          PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 11 -> 
       Graphics[{{
           RGBColor[
           0.6588235294117647, 0.3411764705882353, 0.32941176470588235`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{1, 0}, 
            Offset[{-1, -1}, {2, 1}]]}, {
           RGBColor[
           0.8823529411764706, 0.28627450980392155`, 0.20392156862745098`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{2, 0}, 
            Offset[{-1, -1}, {3, 1}]]}, {
           RGBColor[
           0.8901960784313725, 0.788235294117647, 0.6509803921568628], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{3, 0}, 
            Offset[{-1, -1}, {4, 1}]]}, {
           RGBColor[
           0.6666666666666666, 0.5058823529411764, 0.19607843137254902`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{4, 0}, 
            Offset[{-1, -1}, {5, 1}]]}, {
           RGBColor[
           0.6666666666666666, 0.6980392156862745, 0.403921568627451], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{5, 0}, 
            Offset[{-1, -1}, {6, 1}]]}, {
           RGBColor[
           0.5843137254901961, 0.7725490196078432, 0.3411764705882353], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{6, 0}, 
            Offset[{-1, -1}, {7, 1}]]}, {
           RGBColor[
           0.7137254901960784, 0.7607843137254902, 0.9176470588235294], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{7, 0}, 
            Offset[{-1, -1}, {8, 1}]]}, {
           RGBColor[
           0.6549019607843137, 0.6509803921568628, 0.8156862745098039], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{8, 0}, 
            Offset[{-1, -1}, {9, 1}]]}}, {
         ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
          PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 16 -> 
       Graphics[{{
           RGBColor[
           0.4549019607843137, 0.050980392156862744`, 0.023529411764705882`], 
           
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{1, 0}, 
            Offset[{-1, -1}, {2, 1}]]}, {
           RGBColor[0.6784313725490196, 0.3137254901960784, 0.], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{2, 0}, 
            Offset[{-1, -1}, {3, 1}]]}, {
           RGBColor[
           0.9058823529411765, 0.6392156862745098, 0.07058823529411765], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{3, 0}, 
            Offset[{-1, -1}, {4, 1}]]}, {
           RGBColor[
           0.16470588235294117`, 0.41568627450980394`, 0.11764705882352941`], 
           
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{4, 0}, 
            Offset[{-1, -1}, {5, 1}]]}, {
           RGBColor[0.8549019607843137, 0.9607843137254902, 1.], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{5, 0}, 
            Offset[{-1, -1}, {6, 1}]]}, {
           RGBColor[
           0.12156862745098039`, 0.5098039215686274, 0.7333333333333333], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{6, 0}, 
            Offset[{-1, -1}, {7, 1}]]}, {
           RGBColor[
           0.6392156862745098, 0.5607843137254902, 0.7529411764705882], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{7, 0}, 
            Offset[{-1, -1}, {8, 1}]]}, {
           RGBColor[
           0.1450980392156863, 0.11372549019607843`, 0.16470588235294117`], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{8, 0}, 
            Offset[{-1, -1}, {9, 1}]]}, {
           RGBColor[0.9411764705882353, 0., 0.00784313725490196], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{9, 0}, 
            Offset[{-1, -1}, {10, 1}]]}}, {
         ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
          PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 57 -> 
       Graphics[{{
           RGBColor[0.339361, 0.306752, 0.0416419], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{1, 0}, 
            Offset[{-1, -1}, {2, 1}]]}, {
           RGBColor[0.76817, 0.891402, 0.871962], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{2, 0}, 
            Offset[{-1, -1}, {3, 1}]]}, {
           RGBColor[0.610864, 0.327443, 0.219913], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{3, 0}, 
            Offset[{-1, -1}, {4, 1}]]}, {
           RGBColor[0.909773, 0.932128, 0.699825], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{4, 0}, 
            Offset[{-1, -1}, {5, 1}]]}, {
           RGBColor[0.418616, 0.48278, 0.719463], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{5, 0}, 
            Offset[{-1, -1}, {6, 1}]]}, {
           GrayLevel[0.642527], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{6, 0}, 
            Offset[{-1, -1}, {7, 1}]]}, {
           RGBColor[0.814481, 0.554788, 0.334264], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{7, 0}, 
            Offset[{-1, -1}, {8, 1}]]}, {
           RGBColor[0.832578, 0.811261, 0.567498], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{8, 0}, 
            Offset[{-1, -1}, {9, 1}]]}, {
           RGBColor[0.696834, 0.400534, 0.293294], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{9, 0}, 
            Offset[{-1, -1}, {10, 1}]]}, {
           RGBColor[0.592264, 0.649119, 0.873304], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{10, 0}, 
            Offset[{-1, -1}, {11, 1}]]}, {
           RGBColor[0.380087, 0.377371, 0.298589], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{11, 0}, 
            Offset[{-1, -1}, {12, 1}]]}, {
           RGBColor[0.986908, 1, 0.771313], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{12, 0}, 
            Offset[{-1, -1}, {13, 1}]]}, {
           RGBColor[0.367086, 0.40798, 0.547509], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{13, 0}, 
            Offset[{-1, -1}, {14, 1}]]}, {
           RGBColor[0.266972, 0.247196, 0.155093], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{14, 0}, 
            Offset[{-1, -1}, {15, 1}]]}, {
           RGBColor[0.52784, 0.214603, 0.157061], 
           EdgeForm[
            Opacity[0.1]], 
           Rectangle[{15, 0}, 
            Offset[{-1, -1}, {16, 1}]]}}, {
         ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
          PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}]}}, {
      Hold[
       Grid[{{
          Manipulate`Place[1], 
          Manipulate`Place[2], 
          Button[
          "reset", $CellContext`gen$$ = 10; $CellContext`th$$ = 
            0.904; $CellContext`pt1$$ = {-0.13, 0.86}; $CellContext`pt2$$ = {
             0.485, 0.47}, ImageSize -> All, ContentPadding -> False, 
           BaseStyle -> "Manipulate"]}, {
          Manipulate`Place[3], 
          Manipulate`Place[4], SpanFromLeft}}, 
        Alignment -> {Left, Baseline, {{1, 3} -> Right}}, 
        Spacings -> {3, 1}]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`pt1$$], {-0.13, 0.86}}, {-3, -1}, {3, 3}}, {{
       Hold[$CellContext`pt2$$], {0.485, 0.47}}, {-3, -1}, {3, 3}}}, 
    Typeset`size$$ = {400., {198., 202.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`gen$2368$$ = 0, $CellContext`bx$2369$$ = 
    False, $CellContext`th$2370$$ = 0, $CellContext`col$2371$$ = 
    False, $CellContext`pt1$2372$$ = {0, 0}, $CellContext`pt2$2373$$ = {0, 
    0}}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`bx$$ = True, $CellContext`col$$ = 
        2, $CellContext`gen$$ = 
        10, $CellContext`pt1$$ = {-0.13, 0.86}, $CellContext`pt2$$ = {0.485, 
         0.47}, $CellContext`th$$ = 0.904}, "ControllerVariables" :> {
        Hold[$CellContext`gen$$, $CellContext`gen$2368$$, 0], 
        Hold[$CellContext`bx$$, $CellContext`bx$2369$$, False], 
        Hold[$CellContext`th$$, $CellContext`th$2370$$, 0], 
        Hold[$CellContext`col$$, $CellContext`col$2371$$, False], 
        Hold[$CellContext`pt1$$, $CellContext`pt1$2372$$, {0, 0}], 
        Hold[$CellContext`pt2$$, $CellContext`pt2$2373$$, {0, 0}]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Module[{$CellContext`m1$ = {
           
           Reverse[$CellContext`pt1$$], {-1, 
            1} $CellContext`pt1$$}, $CellContext`m2$ = {
           Reverse[$CellContext`pt2$$], {-1, 1} $CellContext`pt2$$}}, 
        Graphics[{{
           Dynamic[
            If[$CellContext`bx$$, 
             RGBColor[{0.4823529411764706, 0.0784313725490196, 0.}], White]], 
           
           Dashing[{0.03, 0.008}], 
           Thickness[0.005], 
           Line[{{{
               Part[$CellContext`pt1$$, 1], -5}, {
               Part[$CellContext`pt1$$, 1], 5}}, {{-5, 
               Part[$CellContext`pt1$$, 2]}, {5, 
               Part[$CellContext`pt1$$, 2]}}}]}, {
           Dynamic[
            If[$CellContext`bx$$, 
             RGBColor[{1., 0.44705882352941173`, 0.06666666666666667}], 
             White]], 
           Dashing[{0.03, 0.008}], 
           Thickness[0.005], 
           Line[{{{
               Part[$CellContext`pt2$$, 1], -5}, {
               Part[$CellContext`pt2$$, 1], 5}}, {{-5, 
               Part[$CellContext`pt2$$, 2]}, {5, 
               Part[$CellContext`pt2$$, 2]}}}]}, 
          MapIndexed[{
            ColorData[$CellContext`col$$][
             Part[#2, 1]], 
            Thickness[0.01 $CellContext`th$$^Part[#2, 1]], 
            Line[#]}& , 
           NestList[Flatten[
             Map[{{
                Part[#, 2], Part[#, 2] + 
                Dot[$CellContext`m1$, Part[#, 2] - Part[#, 1]]}, {
                Part[#, 2], Part[#, 2] + 
                Dot[$CellContext`m2$, Part[#, 2] - Part[#, 1]]}}& , #], 
             1]& , {{{0, -1}, {0, 0}}}, $CellContext`gen$$]]}, 
         PlotRange -> {{-3, 3}, {-1, 5}}, ImageSize -> {400, 400}]], 
      "Specifications" :> {{{$CellContext`gen$$, 10, "generations"}, {3, 4, 5,
          6, 7, 8, 9, 10}, ControlType -> Setter, ControlPlacement -> 
         1}, {{$CellContext`bx$$, True, "crosshair"}, {True, False}, 
         ControlPlacement -> 
         2}, {{$CellContext`th$$, 0.904, "thickness ratio"}, 0.01, 1.2, 
         ImageSize -> Small, ControlPlacement -> 
         3}, {{$CellContext`col$$, 2, "tree color"}, {2 -> Graphics[{{
              RGBColor[
              0.8588235294117647, 0.00784313725490196, 0.00784313725490196], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{1, 0}, 
               Offset[{-1, -1}, {2, 1}]]}, {
              RGBColor[1., 0.26666666666666666`, 0.], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{2, 0}, 
               Offset[{-1, -1}, {3, 1}]]}, {
              RGBColor[1., 0.4549019607843137, 0.2549019607843137], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{3, 0}, 
               Offset[{-1, -1}, {4, 1}]]}, {
              RGBColor[
              0.4823529411764706, 0.18823529411764706`, 0.03529411764705882], 
              
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{4, 0}, 
               Offset[{-1, -1}, {5, 1}]]}, {
              RGBColor[1., 0.8784313725490196, 0.5058823529411764], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{5, 0}, 
               Offset[{-1, -1}, {6, 1}]]}, {
              RGBColor[
              0.7019607843137254, 0.7450980392156863, 0.8235294117647058], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{6, 0}, 
               Offset[{-1, -1}, {7, 1}]]}, {
              RGBColor[
              0.20784313725490197`, 0.23921568627450981`, 0.3215686274509804], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{7, 0}, 
               Offset[{-1, -1}, {8, 1}]]}, {
              RGBColor[
              0.08627450980392157, 0.1411764705882353, 0.28627450980392155`], 
              
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{8, 0}, 
               Offset[{-1, -1}, {9, 1}]]}, {
              RGBColor[
              0.33725490196078434`, 0.403921568627451, 0.6235294117647059], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{9, 0}, 
               Offset[{-1, -1}, {10, 1}]]}}, {
            ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
             PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 5 -> 
          Graphics[{{
              RGBColor[
              0.4588235294117647, 0.1411764705882353, 0.1411764705882353], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{1, 0}, 
               Offset[{-1, -1}, {2, 1}]]}, {
              RGBColor[
              0.6274509803921569, 0.23137254901960785`, 0.23137254901960785`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{2, 0}, 
               Offset[{-1, -1}, {3, 1}]]}, {
              RGBColor[
              0.3803921568627451, 0.2784313725490196, 0.20784313725490197`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{3, 0}, 
               Offset[{-1, -1}, {4, 1}]]}, {
              RGBColor[
              0.5882352941176471, 0.44313725490196076`, 0.33725490196078434`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{4, 0}, 
               Offset[{-1, -1}, {5, 1}]]}, {
              RGBColor[
              0.592156862745098, 0.4196078431372549, 0.2823529411764706], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{5, 0}, 
               Offset[{-1, -1}, {6, 1}]]}, {
              RGBColor[
              0.8235294117647058, 0.5019607843137255, 0.09411764705882353], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{6, 0}, 
               Offset[{-1, -1}, {7, 1}]]}, {
              RGBColor[
              0.9764705882352941, 0.6901960784313725, 0.3215686274509804], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{7, 0}, 
               Offset[{-1, -1}, {8, 1}]]}, {
              RGBColor[
              0.396078431372549, 0.396078431372549, 0.17647058823529413`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{8, 0}, 
               Offset[{-1, -1}, {9, 1}]]}, {
              RGBColor[
              0.41568627450980394`, 0.41568627450980394`, 0.3058823529411765], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{9, 0}, 
               Offset[{-1, -1}, {10, 1}]]}, {
              RGBColor[
              0.6313725490196078, 0.6313725490196078, 0.24705882352941178`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{10, 0}, 
               Offset[{-1, -1}, {11, 1}]]}}, {
            ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
             PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 7 -> 
          Graphics[{{
              RGBColor[
              0.5019607843137255, 0.4980392156862745, 0.4980392156862745], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{1, 0}, 
               Offset[{-1, -1}, {2, 1}]]}, {
              RGBColor[
              0.796078431372549, 0.5137254901960784, 0.4980392156862745], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{2, 0}, 
               Offset[{-1, -1}, {3, 1}]]}, {
              RGBColor[
              0.40784313725490196`, 0.24313725490196078`, 
               0.20784313725490197`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{3, 0}, 
               Offset[{-1, -1}, {4, 1}]]}, {
              RGBColor[
              0.803921568627451, 0.6862745098039216, 0.6039215686274509], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{4, 0}, 
               Offset[{-1, -1}, {5, 1}]]}, {
              RGBColor[0.28627450980392155`, 0.23921568627450981`, 0.2], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{5, 0}, 
               Offset[{-1, -1}, {6, 1}]]}, {
              RGBColor[
              0.7568627450980392, 0.7058823529411765, 0.5764705882352941], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{6, 0}, 
               Offset[{-1, -1}, {7, 1}]]}, {
              RGBColor[
              0.6980392156862745, 0.7254901960784313, 0.5647058823529412], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{7, 0}, 
               Offset[{-1, -1}, {8, 1}]]}, {
              RGBColor[
              0.4588235294117647, 0.5764705882352941, 0.5058823529411764], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{8, 0}, 
               Offset[{-1, -1}, {9, 1}]]}, {
              RGBColor[
              0.5725490196078431, 0.6313725490196078, 0.6705882352941176], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{9, 0}, 
               Offset[{-1, -1}, {10, 1}]]}, {
              RGBColor[
              0.3411764705882353, 0.34509803921568627`, 0.34901960784313724`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{10, 0}, 
               Offset[{-1, -1}, {11, 1}]]}, {
              RGBColor[
              0.2627450980392157, 0.3411764705882353, 0.4470588235294118], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{11, 0}, 
               Offset[{-1, -1}, {12, 1}]]}}, {
            ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
             PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 8 -> 
          Graphics[{{
              RGBColor[
              0.611764705882353, 0.2980392156862745, 0.29411764705882354`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{1, 0}, 
               Offset[{-1, -1}, {2, 1}]]}, {
              RGBColor[1., 0.8549019607843137, 0.8274509803921568], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{2, 0}, 
               Offset[{-1, -1}, {3, 1}]]}, {
              RGBColor[
              0.8588235294117647, 0.5607843137254902, 0.4588235294117647], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{3, 0}, 
               Offset[{-1, -1}, {4, 1}]]}, {
              RGBColor[
              0.6549019607843137, 0.2980392156862745, 0.08235294117647059], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{4, 0}, 
               Offset[{-1, -1}, {5, 1}]]}, {
              RGBColor[
              0.8705882352941177, 0.9254901960784314, 0.21568627450980393`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{5, 0}, 
               Offset[{-1, -1}, {6, 1}]]}, {
              RGBColor[
              0.5019607843137255, 0.6862745098039216, 0.03529411764705882], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{6, 0}, 
               Offset[{-1, -1}, {7, 1}]]}, {
              RGBColor[
              0.21568627450980393`, 0.36470588235294116`, 
               0.16470588235294117`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{7, 0}, 
               Offset[{-1, -1}, {8, 1}]]}, {
              RGBColor[
              0.24313725490196078`, 0.3176470588235294, 0.30980392156862746`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{8, 0}, 
               Offset[{-1, -1}, {9, 1}]]}, {
              RGBColor[
              0.6862745098039216, 0.19215686274509805`, 0.24705882352941178`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{9, 0}, 
               Offset[{-1, -1}, {10, 1}]]}}, {
            ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
             PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 11 -> 
          Graphics[{{
              RGBColor[
              0.6588235294117647, 0.3411764705882353, 0.32941176470588235`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{1, 0}, 
               Offset[{-1, -1}, {2, 1}]]}, {
              RGBColor[
              0.8823529411764706, 0.28627450980392155`, 0.20392156862745098`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{2, 0}, 
               Offset[{-1, -1}, {3, 1}]]}, {
              RGBColor[
              0.8901960784313725, 0.788235294117647, 0.6509803921568628], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{3, 0}, 
               Offset[{-1, -1}, {4, 1}]]}, {
              RGBColor[
              0.6666666666666666, 0.5058823529411764, 0.19607843137254902`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{4, 0}, 
               Offset[{-1, -1}, {5, 1}]]}, {
              RGBColor[
              0.6666666666666666, 0.6980392156862745, 0.403921568627451], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{5, 0}, 
               Offset[{-1, -1}, {6, 1}]]}, {
              RGBColor[
              0.5843137254901961, 0.7725490196078432, 0.3411764705882353], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{6, 0}, 
               Offset[{-1, -1}, {7, 1}]]}, {
              RGBColor[
              0.7137254901960784, 0.7607843137254902, 0.9176470588235294], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{7, 0}, 
               Offset[{-1, -1}, {8, 1}]]}, {
              RGBColor[
              0.6549019607843137, 0.6509803921568628, 0.8156862745098039], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{8, 0}, 
               Offset[{-1, -1}, {9, 1}]]}}, {
            ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
             PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 16 -> 
          Graphics[{{
              RGBColor[
              0.4549019607843137, 0.050980392156862744`, 
               0.023529411764705882`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{1, 0}, 
               Offset[{-1, -1}, {2, 1}]]}, {
              RGBColor[0.6784313725490196, 0.3137254901960784, 0.], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{2, 0}, 
               Offset[{-1, -1}, {3, 1}]]}, {
              RGBColor[
              0.9058823529411765, 0.6392156862745098, 0.07058823529411765], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{3, 0}, 
               Offset[{-1, -1}, {4, 1}]]}, {
              RGBColor[
              0.16470588235294117`, 0.41568627450980394`, 
               0.11764705882352941`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{4, 0}, 
               Offset[{-1, -1}, {5, 1}]]}, {
              RGBColor[0.8549019607843137, 0.9607843137254902, 1.], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{5, 0}, 
               Offset[{-1, -1}, {6, 1}]]}, {
              RGBColor[
              0.12156862745098039`, 0.5098039215686274, 0.7333333333333333], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{6, 0}, 
               Offset[{-1, -1}, {7, 1}]]}, {
              RGBColor[
              0.6392156862745098, 0.5607843137254902, 0.7529411764705882], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{7, 0}, 
               Offset[{-1, -1}, {8, 1}]]}, {
              RGBColor[
              0.1450980392156863, 0.11372549019607843`, 0.16470588235294117`], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{8, 0}, 
               Offset[{-1, -1}, {9, 1}]]}, {
              RGBColor[0.9411764705882353, 0., 0.00784313725490196], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{9, 0}, 
               Offset[{-1, -1}, {10, 1}]]}}, {
            ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
             PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}], 57 -> 
          Graphics[{{
              RGBColor[0.339361, 0.306752, 0.0416419], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{1, 0}, 
               Offset[{-1, -1}, {2, 1}]]}, {
              RGBColor[0.76817, 0.891402, 0.871962], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{2, 0}, 
               Offset[{-1, -1}, {3, 1}]]}, {
              RGBColor[0.610864, 0.327443, 0.219913], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{3, 0}, 
               Offset[{-1, -1}, {4, 1}]]}, {
              RGBColor[0.909773, 0.932128, 0.699825], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{4, 0}, 
               Offset[{-1, -1}, {5, 1}]]}, {
              RGBColor[0.418616, 0.48278, 0.719463], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{5, 0}, 
               Offset[{-1, -1}, {6, 1}]]}, {
              GrayLevel[0.642527], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{6, 0}, 
               Offset[{-1, -1}, {7, 1}]]}, {
              RGBColor[0.814481, 0.554788, 0.334264], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{7, 0}, 
               Offset[{-1, -1}, {8, 1}]]}, {
              RGBColor[0.832578, 0.811261, 0.567498], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{8, 0}, 
               Offset[{-1, -1}, {9, 1}]]}, {
              RGBColor[0.696834, 0.400534, 0.293294], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{9, 0}, 
               Offset[{-1, -1}, {10, 1}]]}, {
              RGBColor[0.592264, 0.649119, 0.873304], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{10, 0}, 
               Offset[{-1, -1}, {11, 1}]]}, {
              RGBColor[0.380087, 0.377371, 0.298589], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{11, 0}, 
               Offset[{-1, -1}, {12, 1}]]}, {
              RGBColor[0.986908, 1, 0.771313], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{12, 0}, 
               Offset[{-1, -1}, {13, 1}]]}, {
              RGBColor[0.367086, 0.40798, 0.547509], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{13, 0}, 
               Offset[{-1, -1}, {14, 1}]]}, {
              RGBColor[0.266972, 0.247196, 0.155093], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{14, 0}, 
               Offset[{-1, -1}, {15, 1}]]}, {
              RGBColor[0.52784, 0.214603, 0.157061], 
              EdgeForm[
               Opacity[0.1]], 
              Rectangle[{15, 0}, 
               Offset[{-1, -1}, {16, 1}]]}}, {
            ImageSize -> 100, ImageSize -> 250, ContentSelectable -> False, 
             PlotRangePadding -> None, AspectRatio -> Rational[1, 10]}]}, 
         ControlType -> PopupMenu, ControlPlacement -> 4}, 
        Grid[{{
           Manipulate`Place[1], 
           Manipulate`Place[2], 
           Button[
           "reset", $CellContext`gen$$ = 10; $CellContext`th$$ = 
             0.904; $CellContext`pt1$$ = {-0.13, 0.86}; $CellContext`pt2$$ = {
              0.485, 0.47}, ImageSize -> All, ContentPadding -> False, 
            BaseStyle -> "Manipulate"]}, {
           Manipulate`Place[3], 
           Manipulate`Place[4], SpanFromLeft}}, 
         Alignment -> {Left, Baseline, {{1, 3} -> Right}}, 
         Spacings -> {3, 1}], {{$CellContext`pt1$$, {-0.13, 
          0.86}}, {-3, -1}, {3, 3}, ControlType -> Locator, Appearance -> 
         Graphics[{
            RGBColor[{0.4823529411764706, 0.0784313725490196, 0.}], 
            Disk[{0, 0}]}, ImageSize -> 15]}, {{$CellContext`pt2$$, {0.485, 
          0.47}}, {-3, -1}, {3, 3}, ControlType -> Locator, Appearance -> 
         Graphics[{
            RGBColor[{1., 0.44705882352941173`, 0.06666666666666667}], 
            Disk[{0, 0}]}, ImageSize -> 15]}}, 
      "Options" :> {AppearanceElements -> None}, "DefaultOptions" :> {}],
     ImageSizeCache->{459., {258., 265.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5147468148966856`*^9}]
}, {2}]],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel",
  FontWeight->"Plain"],
 StyleBox["\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 ButtonBox["Based on an interactive applet by Theodore Gray.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/TreeBender/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/TreeBender/"],
 " Bend the tree by dragging the circles, \[LineSeparator]choose the number \
of generations, or change the tree's thickness or color."
}], "FigureCaption",
 CellChangeTimes->{{3.509219656680394*^9, 3.509219694547472*^9}, {
   3.509220005381826*^9, 3.509220038615546*^9}, 3.512834279957816*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Julia S",
 StyleBox["e",
  FontColor->RGBColor[
   0.07290760662241551, 0.42914473182269014`, 0.5300068665598535]],
 "t"
}], "Section",
 TaggingRules:>{"HTML" -> "JuliaSet"}],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", 
    RowBox[{"(", "z", ")"}]}], TraditionalForm]], "InlineFormula"],
 " be a ",
 "rational function"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{"R", 
   RowBox[{"(", "z", ")"}], "\[Congruent]", 
   FractionBox[
    RowBox[{"P", 
     RowBox[{"(", "z", ")"}]}], 
    RowBox[{"Q", 
     RowBox[{"(", "z", ")"}]}]], ","}], TraditionalForm]], "EquationNumbered",
 TaggingRules:>{"Punctuation" -> ","}],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "\[Element]", 
    SuperscriptBox["\[DoubleStruckCapitalC]", "*"]}], TraditionalForm]], 
  "InlineFormula"],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[DoubleStruckCapitalC]", "*"], TraditionalForm]], 
  "InlineFormula"],
 " is the ",
 "Riemann sphere",
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[DoubleStruckCapitalC]", "\[Union]", 
    RowBox[{"{", "\[Infinity]", "}"}]}], TraditionalForm]], "InlineFormula"],
 ", and ",
 Cell[BoxData[
  FormBox["P", TraditionalForm]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]], "InlineFormula"],
 " are ",
 "polynomials",
 " without common divisors. The \[OpenCurlyDoubleQuote]filled\[Hyphen]in\
\[CloseCurlyDoubleQuote] Julia set ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["J", "R"], TraditionalForm]], "InlineFormula"],
 " is the set of points ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]], "InlineFormula"],
 " which do not approach infinity after ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", 
    RowBox[{"(", "z", ")"}]}], TraditionalForm]], "InlineFormula"],
 " is repeatedly applied (corresponding to a ",
 "strange attractor",
 "). The true Julia set ",
 Cell[BoxData[
  FormBox["J", TraditionalForm]], "InlineFormula"],
 " is the boundary of the filled\[Hyphen]in set (the set of \
\[OpenCurlyDoubleQuote]exceptional points\[CloseCurlyDoubleQuote]). There are \
two types of Julia sets: connected sets (",
 "Fatou set",
 ") and ",
 "Cantor sets",
 " (",
 "Fatou dust",
 ")."
}], "Text"],

Cell["Quadratic Julia sets are generated by the quadratic mapping", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["z", 
    RowBox[{"n", "+", "1"}]], "\[LongEqual]", 
   SubsuperscriptBox["z", "n", "2"], "+", "c"}], 
  TraditionalForm]], "EquationNumbered"],

Cell[TextData[{
 "for fixed ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineFormula"],
 ". For almost every ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineFormula"],
 ", this transformation generates a ",
 "fractal",
 "."
}], "Text",
 CellChangeTimes->{{3.505752058138624*^9, 3.505752195173781*^9}, {
   3.5060341090123987`*^9, 3.5060341098804855`*^9}, {3.5060397136508484`*^9, 
   3.506039713726856*^9}, 3.506039758584341*^9, {3.5060400558886747`*^9, 
   3.506040055893675*^9}, {3.509123363351025*^9, 3.50912337388059*^9}, {
   3.509981510577512*^9, 3.509981511791391*^9}}],

Cell[BoxData[
 DynamicBox[ToBoxes[
   ImportString[
   "/9j/4AAQSkZJRgABAQAAAQABAAD/\
2wBDAAYEBQYFBAYGBQYHBwYIChAKCgkJChQODwwQFxQYGBcU\n\
FhYaHSUfGhsjHBYWICwgIyYnKSopGR8tMC0oMCUoKSj/2wBDAQcHBwoIChMKChMoGhYaKCgoKCgo\n\
KCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCj/wAARCAD6AwgDASIA\n\
AhEBAxEB/8QAHwAAAQUBAQEBAQEAAAAAAAAAAAECAwQFBgcICQoL/8QAtRAAAgEDAwIEAwUFBAQA\n\
AAF9AQIDAAQRBRIhMUEGE1FhByJxFDKBkaEII0KxwRVS0fAkM2JyggkKFhcYGRolJicoKSo0NTY3\n\
ODk6Q0RFRkdISUpTVFVWV1hZWmNkZWZnaGlqc3R1dnd4eXqDhIWGh4iJipKTlJWWl5iZmqKjpKWm\n\
p6ipqrKztLW2t7i5usLDxMXGx8jJytLT1NXW19jZ2uHi4+Tl5ufo6erx8vP09fb3+Pn6/8QAHwEA\n\
AwEBAQEBAQEBAQAAAAAAAAECAwQFBgcICQoL/8QAtREAAgECBAQDBAcFBAQAAQJ3AAECAxEEBSEx\n\
BhJBUQdhcRMiMoEIFEKRobHBCSMzUvAVYnLRChYkNOEl8RcYGRomJygpKjU2Nzg5OkNERUZHSElK\n\
U1RVVldYWVpjZGVmZ2hpanN0dXZ3eHl6goOEhYaHiImKkpOUlZaXmJmaoqOkpaanqKmqsrO0tba3\n\
uLm6wsPExcbHyMnK0tPU1dbX2Nna4uPk5ebn6Onq8vP09fb3+Pn6/9oADAMBAAIRAxEAPwD2HUtQ\n\
u01G5VbiUKJGAAc8c1Euo3h/5eJf++zTdUX/AImd1/10b+dQqua+KlOfM/ee76vv6nekrFxdQvP+\n\
fiX/AL7NSLf3f/PeT/vo1VVakVaanPu/vf8AmKyLS311/wA95P8Avo08X11/z2k/76NVlWpVWtFO\n\
fd/exWRYW9uf+ez/APfRqRby4/56v/30arqvpXK+LfGMGjF7SyCz3+Of7sX19T7V0UYVasuWDbfq\n\
ROUYq7Og17xXBoUAe9uXMjfciRiXb8M9PevLNb8ca5qtzvW7ltYV+5FDIRj6nua5+7uJ7+6kubqR\n\
pJXOSzH/ADxTo4q+iwuEVFXk7s4KlZz0WxpR+INaP/MUvf8Av83+NWY9e1k/8xK8/wC/zf41Ss7O\n\
S4lWOFCzH0rr9J0KK2w8+2WX6fKv+NVicXTw697fsTTpynsRaW+vXQDy6ldxRHuZWyfoM109rdXk\n\
MYRbu5bHd5WJP61n6jfWml2puL6URp0A6sx9AO9cFq3ivUNWY22nxtbQscfKcuw9z2/CvJ5sTjnd\n\
e7H8P+CdXuUfNnoep+LotLH+l6lJv/55o5ZvyzXO3nxQus7dPhnb/amkI/QGuLGmQ20TT6hcKoHL\n\
YP8AM/8A66j/ALXggXNlYoqHpLctt3fQcn9K2hToQW7m/Wy/P/MlynLyOjfx14su/wDVXTx/9clP\n\
9c1EuueLpCWOo3+SefmIrNg129aQ4W2KKcEFXUD8cf0rVh19ocHUdPkSI9JYX3qR61bxE1pTgvvJ\n\
5E/ikyNtd8VocNqV/n/eNSReMPFNsF/4mk5VT0kwc/XPNdFp72WpRlrG4SXHVQcMPqOtSy6cCMMg\n\
I9xXNLM5RfLUpGioJ6xkZFv8SPEMX/Hx5Uw/4Ep/nWtafFAkAXltdRnuYpNw/UiqNxo1u5OYgD6r\n\
wazZ/D6HOxiPYjNCxuDqfHFx+/8AR/oHs6sdnc7mz8eafd9NSkgb0mLLW1Dqctwu63vPMX1STP8A\n\
WvHJ9BlXO0BvpVIWt3ZvuiaaFuuUJX9RWiw1Ct/Bq/j/AMMxe1nH4onuLXd5/wA95f8Avs1E15ef\n\
8/Ev/fZryiy8Wa3ZABpxcRjtMuf1rcs/iDGSFv8AT2T1eF8/of8AGuerl2Jjs7+jLjiIM7Zr69/5\n\
+Zv++zULX99/z8zf99mqen6/pGpELbXkYkP/ACzk+RvyNaTwe1edUhVg7SuvvN4uL2MXVZdTnHmW\n\
9/cpKB93zWCt7deK5W51jWY5Gje/vEdDgqZm4/Wu8eCsjWNIS9jyPknUEK/9D7V14HMZ4d8lXWP4\n\
oyrUFU1jucafEGtxSq6and7lIIzKxH86+ivDN3LfeHtOup8ebNAjvjpkjmvnC5tnjlaOVCsinDL6\n\
f/Wr6J8GjHhXSh/07J/KvpW4ySlE4qd02ma8nEbEehrzNtSvN7f6RL1/vmvTJf8AVv8AQ15Wy/vG\n\
+prwc5lJOFnbf9DuoJalpdRvP+fiX/vs09dQvP8An4l/77NVVWpFWvGU5/zP73/mb2RaW/u/+e8n\n\
/fRqQX11/wA95P8Avo1WVaeBVqc+7+9k2RZF9df89pP++jUi3t1/z2f/AL6NVlWpFX1rRTn3f3sL\n\
IsLe3J/5av8A99GpFvLj/nq//fRquq1xfinxzBYNJaaSFuLkZVps/JGfb+8f0roo061aXLBv7zOc\n\
owV2dTr/AIqh0K3El7cOZG+5CjZdvwz0968u13x1rWq3G6O6ltIFPyRxSEH8T3Nc3cTT3lw891I8\n\
sznLOxyTTo4q+hw2EVFXk7s4alZz0WxpJ4g1o/8AMTvP+/zf41Zj17WeP+Jnef8Af5v8azY4ulWo\n\
4vSuwxuX013V++pXf/f5v8atQazrMjhUv7tmPAAlbn9aZpWkTXrZA2Rjq5HH4etW9T1nTfDSmC2T\n\
7TfH7yg9P949vpXLVxKg+SC5pdv8+xpCDa5m7I2tPGrYEl9qVyqjnYJj+pzxTb7x5aWDeWdQnnde\n\
NsLFsfjnFea6jq2p63KBPK3lk/LDHkL+Xeq0tta6ft/tG5SKRukSjfIf+Aj+tc8sPKo+bET+S/q7\n\
NFUS0po7q4+KF6Tizt5SPWWY/wAhVB/iP4lcEJLFHk8EBiR+tcvBe2isv/EsvpE7liqn/vnrW1p1\n\
9ocz+XJG9rJ0xOpAH49KGqNJXUG/x/X9B3nLd2LY+IHij/n8H/fJ/wAasw/EjxEjL5phkUdR8wJ/\n\
HNXToVtIiusYKHkFDwfxqrN4fjx8hZf1rn+v4R6Si1/Xky/ZVejL9t8UbocXdpKPeKYn9DWxafEW\n\
wuGCyXN1bk/89AcfmCa4qfQnXO3a36VnT6W0ZO5GHuRVxjg8RpCdn6tfmS5Vobo9js9cW+TdZ6is\n\
w/2Jc/1qdru8H/LeX/vo14V9keMh4yykdGU4rRsdf1rTyBFeSOg/gl+cfrUVMrn/AMu5/fcqOJXV\n\
HsDXl5/z8S/99n/Gomvb3/n4l/77NcDa/EG4QBb3T45PVo3Kn8sGtuy8aaLdYEsktq57Spx+YzXn\n\
1MFiobp/J3/U2jWpvqb7X17/AM/M3/fZqJr++/5+pv8Avs0ttc2d6M2d1BOP+mbg094PauKSqLRt\n\
/ibJozL+41GYAxX9zHIvTEjYP1GawZNV1eO5EUl9dK47ea2CPUc11bwe1U7rT47oBJF5zww6rXVg\n\
8wqYZ2lrH+tjKrRVRaaM9dtyTbxEnJ2jJ/CmX7FbKdlOCEJBFSQDEMY9FA/So7//AI8p/wDcNfR1\n\
X+7k12f5GC3OMW9uv+e0n/fRp4vLn/ns/wD30az9Rv7PTLfzr+4SGPtuPLfQdTXDav8AEVsvHpFq\n\
AP4Zpu//AAH/AOvXz1ChXrfBf7zedSENz0t76aNC8k5RB1LOQP51gah4/wBMsSVN9JcOP4YMt+uc\n\
V5BqWqahqj7r66llHUKThR+FVVhNerSy1rWpNv0OaWJ/lR6Pf/FS4PGn2j4/vTSHP5D/ABrAvPiD\n\
4luul95C8jES4/nk1ziwVKsHtXdDDU4bL82YyqyfUtP4j1yRyzape5P/AE2Yf1pR4g1v/oKXv/f5\n\
v8ariD2p4grexndk39v61/0E73/v83+NKNf1r/oJ3n/f5v8AGoRBS+TTC5N/wkGtf9BS8/7/ADf4\n\
0n/CQa3/ANBO8/7/ADf41F5NHk0BclPiDWv+gnef9/m/xpP+Eg1v/oJ3n/f5v8ai8mmmGgLk3/CQ\n\
63/0FLz/AL/N/jVi38YeIrbHlarc8DA3Nu/nVAw+1MMPtSaT3Gm0dNb/ABJ8RwgB54psDHzoc/oR\n\
Wra/FW9DAXVkGXuY5SD+RrgjDTTDWEsNSluvz/zLVWS6nq1t8UbCQgTpew+p+8B+RzWxZeN9KvMe\n\
Xqaox/hlJQ/rXhxhppiNc88upvaTXzLWIkt0fRcOoNOoaC5EinkFJM/1p5ubj/no/wD30a+c4Jbi\n\
2bdbzSRN6oxX+Vblh4x12ywBeGZB/DMN3/165KmWVV8E7/eaxxMeqPbjdXH/AD1f/vo0hurj/nq/\n\
/fRrzSz+JbjAvtOVh3aKTB/Ij+tdJpvjTQ74qv2k28h/hnXb+vSuKphcTT3T+TubRq05bHSm7uP+\n\
er/99Gmm7uf+er/99Gmxsk0YeF0kQ9GQgj8xQVrjcp9397NdAN5c/wDPV/8Avo003lz/AM9n/wC+\n\
jQVphSpc59397HZCm9uf+ez/APfRphvbr/ntJ/30aQrTCtS5z7v73/mOyLNheXLXsKtNIQXGfmPr\n\
RTNPX/Tof98fzor1ctlJwld9f0Matroo6mM6nc/9dG/nUSrVnUh/xMrn/rof51EoryJL3n6v82bd\n\
BVWpFFCrUirTSECrUqrSEqiM8jBUUZLE4AFeZeN/GJ1BZdO0slbTO2SYHmUeg/2f512YbDTry5Y/\n\
eZ1KigrsveNvGmwvp+hyo2RiW6Q5x/sof6/lXniqXYliSScknvSxx+1W4o6+moYeFCPLE86dRzd2\n\
NjixWvpOlTXsg2DbGPvORwP8T7VZ0XR3uiJJgyQjvjlvp/jXZW0CxoqRoEQdFA4FcWNzFUf3dPWX\n\
5f8AB/pmtGg5e9LYg0/T4bRNsCY9WPVvrVbxFrttoNupkXzblx+7hBwT7n0FT6/q0OiaeZ5Bvlb5\n\
Y488sf8ACvMIY7jWL+S5u3LMxy7Ht7CvPw2H9tevXfurr3/r/gI3qT5fchuPYXuvXjXV/KSvdsfK\n\
o/uqK1VjgsbaSQARQopZ2J5IHqau21sNqqq4ReFX0rnvFF4Jbo2kWGt7YeZNjoz9k/OrdeWLlyR9\n\
2C/L+uguRU1d6syNQvHupEklU725gtwAdg/vHPBbH4Cobcp5b3Mjs8+7ZG6/MC46omepwcFuMZ4x\n\
1ovJNPiicXVzh2TzJZCM5b0CjkjtUthr8lpeWb6Xp9w95AyMFePaFUgg5x67un0p1G4xbitlp2/r\n\
zKpw5pJPqWtNtNQhU3Osab5LvOBbI7kOoxyVTke+TmuqtjHYC3luMyabdLhsc+VJ0J+h9Kq69p2t\n\
Xzrqqo/nTlI/LYqqwJ/EeemfWn28rW1vPDNGZrRv9ZGjBiv+2vqPWuPCVo4ind6vqv0T7rp5+TOj\n\
FUnSnZbdC7qnhsQyCayJikX5lKEj8j2os/E+pac/lanCLyEHBYjbIB9Rwf8APNR6bq82loscx+26\n\
YeFkQ5MY9v8ACtRpNM1JD9muIZc/wE4b8jzXS3Upq1Re0h36r57r0ZzK0vhdmaVhruj6io8u6WCU\n\
/wDLOf5D+Z4P4GtB7MMu5RuU9CORXD3vh6NsmPK/hkVnf2Le27H7NOyA/wBxytT9WwtXWE+XyY/a\n\
VI7q/oegSWntVZ7TP8Oa4mSLWwMtqcoA9Z//AK9Vp4bpiDd60R2GJif6il9QprX2i/EPbP8AlOyu\n\
NNhPMsSDPc8frWdPoto4+Vth9mBrk3sNOVS0t0Je+XmAFQyRaZGDsFu3oAS/9a0jel/DnL7tPxZL\n\
tLdI6Kfw5IQWgZJF/I/4frS2mp65ohVYp5RED/qpRvQ+3P8ASuXg8tJQYIZoeCd6OYz9cE/0rotL\n\
1y7iwlzm9tuhR1AkA9j0b6da61iJSXLNKXk1Z/qvyM+RLVaHaaJ43s72QQanELKU9JN2Yz9T1X8f\n\
zrq2iDKGXBVhkEHII9RXnT6NY6tZ/aNJkXryvofQjtVTSNU1LwxdeWyM9sT88D9CPVT2Ncc8LRxD\n\
ao+7JfZf6Gqqyh8eq7nY+IdGF5F5sKgXSD5T/eHoa9S8JqV8M6YCrKRbpkMMEcVxGk31rrFkl1ZN\n\
lTwyH7yH0Ir0TTBjT7ceiCtcrlUi5UJ7L8B1VF2mieT/AFbfQ15gw/eN9TXp8n+rb6GvNSv7xvqa\n\
yzlaw+f6F0Oo1VxUirSqtPAzXjpGwAVIq0qr6VKq1okIaq0TyxW0Dz3MixQxjczscACqms6tZ6LZ\n\
tcX0gUY+RB95z6AV5B4l8QXfiC73zEx2yn93ADwvufU134TBSxDvtHuY1ayh6mx4t8az6k0lppZa\n\
CxzguOHlH9B7da5GOOnRx5q1HHX0dKjCjHlgjz5zc3djI4qsxx+tSRR9OKuWts8zqkaFnPQCtG0t\n\
WSQRxZ4xXUaPoPCy3o4PKxZ/n/hV7R9IS0AkkAef17L9P8a53x14j2CTStOc+YeLiVT0H9we/r+V\n\
eXUxc8RP2OH+b/y/r0OmNJQXPU+4i8V+K/K36dopAK/K86dF/wBlf8a5bTtNa5cySEqmcs555/qa\n\
fpOn+c+WBCD7xFdNFCqpkgJEgz7KKmtWhgo+ypayf9a/5DjF1XzS2Of1a+/sxYrPTEAu5wdrNyVX\n\
u7H0Hp7VzKsouSsUrKn3ri6P32B9+2T0UYqe5me/ubidDh7pyiE87Il5P9OO5qO3tuZGuEJjgyUh\n\
U9W/vO3c/Sk4yi0pu76/12XbuNNW0LNuV81pHhR492xIxvKZ7knjGK7i30uG5vJ9LugHdV8y2l7s\n\
mM49+P0zXJaVapcW0Ujx3SySIsjPKCpcjJwo9MfnXQtPIrWyeZsnhUNbTj/lovUfiOn0rNL2iSTt\n\
vb9H9617oufuPYci6n4dnxaS5iJ/1TjMb/h2P0xXWaJrthq+Inxa3p48lzwx/wBk9/p1plrd2viC\n\
0cFFS6UYmhP8x7VzOr6I0bMQpZOxxyPrWS5Kz9jilyzXXv6/1qGsFzU9V2O7mssE8VSlswcgrXH6\n\
Z4h1TSMRlvtVsOBHLzj6HqK6Oz8Z6XcDF2ktq/8AtLuX8xXNXyurDZXXkaQxEZeQ2fS4XzmPB9Rx\n\
WfPoyk/I35iuhGr6PL9zUbXpn5pAP51WudW0iIHdqNseM/K4b+VTSli6OkG/x/UJKnLexy82iyA8\n\
KDn0NUJtLkUEmNgB3xitu/8AFmkwg+SZrhvREwPzNYkviu+nP+g6aFX+87E169HEYu15wVvPQ5pU\n\
6fR/qVDaSRsHjLIw6MpwR+Nadn4i1yxwI72SRB/BMA4/Xn9azG1vWdv76WxUY6FN38s0yDWZpG/f\n\
QWF0GOAISY2rb29OrpOKfzT/AE/UnklHVM7nTPH0bYTV7No2/wCetvyPxU8j8zXY6bdWepIs1jcR\n\
zoeflPI+o6j8a8ss4bDVTst5Gt7k9ILgYJ+h70z+z73Sr1JYjJBKp4dDj9a46uCw9V2g+WXZ/wBf\n\
k2axq1Iq8ldH1LH/AKtfoKyvF9zLZ+F9Uubdgs0Vu7ISM4IFaVqSbaItySgz+VZPjcbvCOrj1tn/\n\
AJV6qXRkt6XPmC6uLnULgz3s0k8p/ic5/wD1UqQVYih9q0bTTZpvuoQPVuBVTqU6MbyaSOdKU3pq\n\
ZqQ+1WI7ckgAdeldFbaREmDIS59OgrTgt0jGI0VR7DFeTWzulHSmnL8F/mdMcJJ/E7HMQ6XcPgiI\n\
ge/H86uxaJKT87oB7HJ/lXRJF7VMsXtXBPOMRL4Ul8r/AJmywtNb6mDHoSZ+eUkey4/rU6aDB3eT\n\
8MVuLFUyxe1YvH4qX23+H+RXsaa6GCugW396X8x/hTj4etzja8o/I/0roFi9qeyLGMyFVHqxxTWL\n\
xP8AO/6+QOnT7HON4biK/JK4b1K5FRHwwxPFwuPdMf1rbm1nSbfPm6jagjqBICfyFUJPGOhxsALl\n\
34zlY2/wrqp18c9m38v+AZunR6mY3hq7yMGE/wDAjx+lVpNBvkJ/0diOeQQf61pDx5pP/PG7/wC+\n\
B/jTh480n/njd/8AfA/xrrjXx63hf5f8EzdOi+pz0thPFkyQyoAMkshFQGI+ldpF4y0KQ4Ny6cZ+\n\
aJsfyq7HqmhXoH+mWTljwHZQcn61f9oVo/HSf4/5E+wi9pHnZi9qaYvavSjoemXKZihjK46xN/hV\n\
KfwpbN/qpZY/rgirjmtF/EmhPDT6Hn5iphhrs5/Cc4JMU8bjnAYEGs2fw/qEX/LuW90YGuiGOw89\n\
pr8vzM3RqLoc2YvamNF7VsS2M8Z+eCVfqhquYuo9K6YyjL4Xczaa3MtoajaKtRovao2hqgK1jfXu\n\
nSb7G5mgbr8jEA/UdDXVaV8RNStiq6jDFeR92A2P+Y4/SuaaE+lQtD7VjVw9Or8cblRqSjsz2DR/\n\
GGjaqQiXH2ac8CO4+Un6HofzroClfPTQkVpaN4g1TRW/0O4byu8T/Mh/Dt+FeZWylPWk/k/8zphi\n\
v5ke4FaYUrltA8eaff4i1ECyn/vMcxt+Pb8a65CksYkidXRuQynIP4149bDzpO01Y6ozjLZhYL/p\n\
sP8AvD+dFTWS/wClxf7w/nRXflytGXr+hFXczdRH/ExuP+uh/nUSirOoj/iYXH++aiVa8qS95+r/\n\
ADNlsKq1LwqlmIVQMknoBQi15j4+8Vi/ZtN0yQ/ZUJWaVTxKR2B/u/z+ldWGw0q8+WPzM6lRQV2R\n\
eOPFx1NmsdNcrYjh3HBl/wDsf51yMaZIojjzVqOPsK+oo0Y0Y8kDzZzc3dixJXR6Jo/nBZrgERdV\n\
X+9/9anaLowZVmul4PKoe/ufaupij6V5GYZly3pUXr1f+R00cP8AamLDGAAAMAcAVPPLFZ2stxcM\n\
EijXczegqSKOuF+I2s+bMukWzZVCGuCO7dl/Dr9fpXmYTDuvUUfvOmpNQjc5zV7+fxDrBmIYR52x\n\
Rn+Ff8fWt2wtBDEsa9B1Pqaz9Astqecw5PC/1NdPaQdK7MxrpyWHp/DH8/8AgfmY0Y6c8t2UtVvI\n\
9I0uS6fBf7sSn+Jz0H9a4K5ga302NpOZp5Q0hJ5JPP8A9f8AGtnV7n+29cxGc2Fn8q46Oe5/E8fQ\n\
VF4ji229iCPmaUtn6D/69aUoexUaX2pav0s7L9Qb5m5dEZWn3FuLqGe+AlFvnCMuV/HHUV3/AICn\n\
s9ct5bu5s2jUOMAjAcL0HPOOBxXnVrGqp5+yIk5Bklk2xgnIUYGSSa73w5cavb6ZDDqkaxsi7UCr\n\
jjtXhZ+4xppxtz3tvrb9fM9fKXPmd78v6/oavjewjuYhqDzTKsoMCQq2FfHJJH4YrjpL4BAIRseI\n\
5WROmD/CR71seJ7h77RBYPGxKMWRlOOvrWf4O8GW/wDZdxc38zy6gwIhZmJEfHGKqhjsJhMHBud2\n\
911v18rfp6k1sJXxGIlpZdPQyku3Nw7W2I5cBnCNxg9CVNTo9ldIWu7fYVGTNbZK+h469a0fDvw9\n\
jSzvDrM0tzPMSVETEMx7YNMt9MhtH+yW4FkS/wAkYm3+W5BOGPs25cdPzr0MJmFOvKSoNtLr/X5N\n\
HHiMJOjFOp16FWOxSVD9i1S4dTzhJh/Kq1xaTQqzSXl5tHdpsAVNex2Er7b+OO0uwMNuGFY+zD+t\n\
Yt1HaLIyWwguHUZJ3F0jA7sTkAf5FdalUk939y/PY5tEARZlPkxPLETt8x3ZlJz29efwqxaWkjtK\n\
PskYSAAyyMABFntz1Pt71SvNQfSoBcXitMuf3UBHEjEFeecjAJOO3yj1xq+HreCGzku9T0zb56Ar\n\
Cx+XcAMEj1wQayxNepRjdXtdL73byt+Rvh6EartfWz/BENxsgJEi2xA/vKFIH9aqxslxKDJMUg+Z\n\
isfBcBSSAfTA5Paqt14hin1IW9pbM8zkhkKkKo9SQc0zUtUgt5nWNJ5LgIyeXtA3HGPm9vb9K00T\n\
Se/9fIy5JNXSNr+w/EVzZw6hpVhb7JURomMituUjOc5xjPatHSdMKT2tumz7XgI0iSFw0nJJ596u\n\
eGr/AFjWvDUWmrm3ZI1iV1GCoAA4qrax3un3ghezmtWt5t0EjyLlwOrsAenqa83CYmdStOnWaTTd\n\
rdu/5dO53YmjGFJSprR73/I3VD2y2+vaUuAPlu4B0JHDAiumkhsfEGmCeDLRk49Gjb0+vSuT0/WI\n\
rO9u/NQpaTtmeEjLQt/eA7r9P58VZtLpvD+ofarYifTLj76o2QRnqD7dvyrsqU3Ustn9l/8Att/y\n\
ZwqVvTr/AJ/5kNrNe+F9Z8yEkqT8yn7sq/419E6JcpeaRZ3EWfLliV1z1wRXkWrWMGraests6ujj\n\
fFIOxr1TwnG8XhnTI5F2OtugZc9Diu/AYhVr8699aPzREocj02ZqSfcb6GvOWX9431NejP8Acb6V\n\
56wzI31NcubrWHz/AENaPUaozUqrQq1KoryUjYFWsXxR4ktNAtyGKy3rDMcA7+59BVTxf4st9Fie\n\
2tGWXUiMBRyIvdv8K8luJ5r25kuLqRpZpDlnbqTXrYLAOr79T4fz/wCAc1avy6R3J9U1K71e9a5v\n\
ZS8jHgdlHoB2FQxR06OPvVmOPivoIxUVZHA23qxI46tRpyKWOPPStjStLkuiGb5YQeW9fpU1KkaU\n\
XObshxi5OyK+n2Mt3JsiXgdWPQV2Gl6fHZx7UGXP3nPepbS2jgjEcShVH61alkitbaW4nYJFEpZm\n\
PYCvnMVjp4p8kNI/n6/5HfSoqmrvcwvGOuDRdPCQkfbZwRGP7o7tXmdlbvcTZOWdzkk9z6mp9Yvn\n\
1nV5ryQEK5win+FR0FbOjWmyISEfM3A+lenBRwGHc3v+vRf15nPJutOy2LlnbBEVEHA/U+tQ+Lpf\n\
sfh+RV4e4YQj6Hk/oK2rSDpxXKeOLj7Tq8FjH92AZbH94/8A1q8rAwlXxClLXqzpqtQhZHPW0Di4\n\
S3jYL5lqByoPBc5x78D8QKmfSredrfeZY7GRWb92+GkOO5HOR6Vp67ataf2bdKOFzC314I/kay9S\n\
na0edVJKNi6ix2JPOPxz+dd85upLnWz/AM7f5P0Mo+6rEq3cD3EoSaeK3tYlMMeCwcIOSD149ada\n\
3ct1aJIVdbaT95CZPkYc9VHoazYNTMMsrRKQ0oJKheUQ9/YHmrNpZXF7bNf3txMY5IfKt0jJMhA4\n\
ARemDnk9s1jyTp6wV46aW1W23zvf5m141F7zs+/f+kbdn5l5slsZTHfRjICthmHqPX3HatBfFF5b\n\
Yi1azMuODIvysfw6VT/sc2jCO5lKN9pe3WVWB8qVQp6jjHO0kd1/Gp5tRurHdDrNu0wXgTxAEke4\n\
rarUjVSTipfg/k+vpv6mEYuOzsOm1fQ7o/PJLbuf70Z/pxVRoLC5Gba+tXPoX2n9aSSbSLlS6XNq\n\
D1IlARv1rHvX0iLmSa1fJ6I+4n8BmijXdP3UpLyav/l+YShza6GudAnkz5ao2PSRT/WkHhyYcy+X\n\
Gvclgf5VzzC1Qb1s72OM/wDLRmWJT9N2DiiOO0lhaYee9vnaCJwNx6YyRj9a6vrDeikl8v8Agmfs\n\
12/E6CS20qwGZ7iFnHPzuMfkOaoz6tbTDZZxzXTDgBE2oPxPFU1htbdEddHuXzyH+WYH34OP0pXu\n\
ZZU2xWF0ABx522JB+tcNVe0d5Xl6tJfdc2jotNCnPMzzJ9t2EE/LbRZwf95u/wBBV6zzIwBUIkUe\n\
/wCVSPmJyB6DAUk+1ZsfkLI7TmO6nkUquxtsa4H8JPYHHPc1r6fZWmoIv2fUI7m7ltwJZFkysZLq\n\
oTkc8tz3xmnNqKjDv5af167lQje8ux0Gm6XFew29sxKvcW/2i0foRgkYPvgA/Wuh8NamLiVNL1Zc\n\
XaHYjsPv47H3/nXNJevBFYgMI3ty3kyNxyD8yH3DD8RWrfG31lUvbEhblSDJEDhlP+ehqKsVJWnr\n\
B9ez6P0fUmLttv8AmfRsIxEg/wBkVmeLYzL4Z1NFxlrdwM/StG2z9miz12DP5VU8QDOh3w/6Yt/K\n\
vVqScIOS6L9BJXdmeE2Wmxw4LDe/qRwK00jqSOKrMcXtXx1WpUry5qjuzsjGMFaJCkVTpFU6RVOk\n\
VCgDZXSKp0ipmoXtnpcHnX9xHCnYMeW+g6muN1Xx8T8mj2pH/TWcc/goP867KGDqVvgRnOrGO7O3\n\
lMVvEZZ5EijHVnYAD8653UPGuk2qsLUvdyjjCKQv5mvO725vdUm8y+uJJn7bjwPoOgq1aaNNJhiu\n\
xfVuK9WOXUaMeevL9F/mczryk7QRpX/jXVrsMlsI7VD/AHBlh+JrDne9vnzdTzTE/wB9ia6C20eJ\n\
OXy5/IVoxWgQfIir9BUvMcNQ0oQv+H56j9jUn8bOTh0idhkRkfXirMeiScZ2D6muqW1J7Vkaxrlj\n\
pjGEE3N108qLnB9z2/nUwzHE1pctOK/MHQhFasqLobH+NP1/wpsmkRRAma6t48f33xWTe32qXf8A\n\
x93H2SM/8u9v9/Hue34n8KyIhbSXCJFbiQsxQPKxcuR1xyBgdz0rphiau0pq/kr/AI3sS6ceiOqi\n\
0jz/APj3mtpf9yUGmXGiXMIy8DgfTP8AKsTSYra9R5Et/MCEgmP5W644wSM+1dXZyappVvHcWVx9\n\
u09hkJLlsD+YP+cVTxjWzT9dPx1X3i9iuqMiD7ZZNutZ5oSD/A5Fb+n+NdYs9q3Pl3cY6+YMN+Yr\n\
b0ubS/ESMoiEd2Blon4b6qe4qvf+FcZNu/8AwF/8aznjKEnyYmHK/PX8UNUppXpu5r6Z440q7AW7\n\
32cp4+cbl/Mf1rpYTFcwrLbSJLEwyHRgQa8fv9Imtj++jK84z2P41BZXF/pU3mWNxLA3cKeD9R0N\n\
RPLaNaPPQl+qGsRKLtNHszw54IzVG50y1nB82CNs+1c3pHxAjKrFrNsyv0M0IyPqV/wrtbaWC9t1\n\
ntJo5oW6OhyK8mthauHd2reZ1RqRnsczdeHLV8mPfGT6HIH4VlXPhqZf9VIj+x4Nd28VQPFRDH4m\n\
ltK/rqJ0act0ebXOl3UAJkgcAdx8w/SqTQnmvTpIvas+7023uP8AWxKW/vDgj8a7aWeSWlWF/Qxl\n\
g0/hZ528NQPD7V2N34fI5t5M/wCzJ/jWLd2EtuT50ZQep6fnXrUMww9fSMtez0ZzToThujAeGtHQ\n\
9f1LQ5c2kpMR+9E/KH8O34UskPqKrSQ11zhGa5ZK6M02tUeweEPF+nazdQRM32a8ZgPJkPU5/hPf\n\
+dFeVeGYseJNMP8A08x/+hCiuSGDhSvybM6FWclqe06gP+Jhcf75piLVi/H+nz/75rjvH3iP+x7L\n\
7JZyAX846g8xr/e+vpXzsKMqtXkju2dkpqMbsyfiF4qKeZpOmSKdylbmVeevVB/U/hXnsSdKRFLM\n\
SxJJOST3q5DHX1GHoRoQ5Inm1Jubux0MddHoWlhsXE65H8CkdfeotE0wSkTTD92Oin+L/wCtXUxJ\n\
0ryczzHlvQpPXq+3kdOHoX9+RJEueatwpTIkq7CleFCJ2NlDXdRTR9InvHI3qMRqf4nPQV5FZRSX\n\
t6WkYvLKxZ2Pcnkmt/4hap/aGsizibNvafLx0L9z+HSk8OWmEaUjk8L/AFr6KhH6nhXVfxP+l/mc\n\
M37Woo9DXtIAqqqjCgYFZfjDVHtol0yyJ+1XA+dl6qp7fU1q6rfx6Ppr3Ugy33Y1/vMegrjdOjln\n\
le7uiXuZjncewrgw1NQTxFXVL8WbTd/ciX9IsxDEkSgYHLEfxH/PFUtekW51rylG6OzhO7H949f6\n\
Vo3+oR6RaDaA95JxDF1JPqfasR4zZaVcPI2+4k++56l24xn8a2oczbrT3lovnv8AJImVvhXQj0sR\n\
q1pKYy6ITKsQPBdRwT68dq29G1PWdV8TQ/bZI/7ObceoXao6fn7VzSTeTNbhSB5R3Ejt2pyahLbR\n\
l0chpNzIBxjn5T+v64rPEYWniotTWvR2V1dvb5am1DEToO8Xp2PX7rw99ogaWK5thJ/DFuyT+Pau\n\
etrh7eRomyrKcEehrjdF8RTy644hcpEApZVOFDY5+lbwuzeX0sqnIZs59a8PNsow+Ew9OdJu73u7\n\
9Nz1cDjqtepJTS+RtXet3NggnthukQEgfhXB2t3q91aTXV7YzfZhMsSOASSTxjA5xwOfWu+s4Fcj\n\
eMit+1uIEP2fKoojZlXoC2OBXBlWPnQnHC0kvekt+nQ6cbhY1YutPomeV6hPPtCveJzwFuIg5P45\n\
w3481kG7lLko6tHBlxlQkYYcjCDjPucke1bOqXkYd4g0MUg4eKbgEjjcD2zXJaxcrIhgSVJZm+Xb\n\
EcpEvc59a+2jSlz8trHzN00Z+prdXusWqqUunDgRyRR7QxZiSSPXOck8mvXdN0+W50WWy1FEJjfk\n\
qAByAeg6VxfhSEWwiunjDojgPnsCeD+Bx+denWDS6u4tLEKicu744TPUn1Jrx8ZjaEaE8PKLcm1Z\n\
/ivnc+jyzBVHWjinJKCTTXqrf19xzGmeHtM06eVyn7xxjeWIYDuM5osvC+kQ6tNfyt55dQFErlim\n\
OoHYg+/rjmvRYNHsIVEMdoLyb+J5Bu//AFVWeS005jK+nW8QXqyoOK8ehmWMpwaheUdejklfR62/\n\
JndiKWX1Jq8LO6a15W7fPYXw3pcVpoI3IYi5Yx9iE7V574mCaHPmbUJZ5JIw7SzEEkD29q9Jn1Nb\n\
u3LxvuBHGK878R2yaiyRXcaSKvCsw5ArPKcbSp4iTqN2t26nJmNCdamuRK97/Ix7BL6/mtvsdpct\n\
uikmQygxKEAIXDHJGT2HarCu1mDHGfmkwsihfkZun3Tx17jBrtLqC5t/BvnM6fZAnlL82GI6cV5r\n\
b2V/quuWcdhZQLo9uN0iyf6pgByz+pr2MNj61RSlWhyxeq6X3773drf8FHm1sFTjaNOV316/l2O5\n\
8H679jmSKY/8S+Z9rDr5Tnvn0NfROkjbplqB0EY/lXzVodtbTXTQIR9mmcxAAYUZyRgdua+ivCaS\n\
x+GdMS5z5y26K+Tk5Ar6DCOMqjntK2v9d+h5stFboar/AHG+lcAy/vG+prv3+430rhiv7xvqa5s1\n\
WsPmXR6jVWuQ8aeMU0nfY6aQ+oY+aTAKw/4t7VF478W/2cG07THBvGH7yUH/AFQ9B/tfyrzFQ0jF\n\
nJZmOSSckmngcBz2qVVp0RnWr292IHdLIzyMzOx3MzHJJ9TViOOlijq1HHXvHEJHHxVmOPpT4Yiz\n\
AAZJ6Cui0zSlTElwuW6hD2+tc2JxVPDR5pv5dy6dOVR2RX0nSjNiWcER9l7t/wDWrp4YwoAUAKOA\n\
B2pI0q1EnSvlsRiqmKnzT26LsejTpxpqyHxJXFfEzVGRINLgfG8eZMB6fwj+Zrtb66i07T57uc4j\n\
iQsff0FeKzTy6hfTXVwcyysWP+FejleH55+0ey/MxxFSy5V1JtPt97KAOSa7G0h2hVHYYrH0O2y+\n\
8/w11FrF04ozetz1I0l01+b/AOAGGjaLl3EuJ49PsJruX7kS7vqew/OvOtHV77U3uZ/mZmMjZ9a3\n\
/H+pktHpUB64kmx+i/1/Kq+g2vlRKSPmfn8KuivquFlVe8tF/X4in+8qKPRF/wARW4fwvO2OYnSQ\n\
c/7WP5GuO1X97bWTDG7LRcdcEZFdz4ncQ+FboEDMhRB/30D/AErirkY020fA3C5QA49jWuAV6F30\n\
f6E1fj+Qy0061utQtDqN032Vw32g+YqLkn5SxA+bjsa273ULO0SG2MoW3UFInHQA4Ix9CAfcVgT6\n\
Rbz6iba8cra5Em0fxr6ZrU1zUdOub3S7GbToTHDIGVEQjOMcH2xXLN1KU/aRd48t7X7aprz6djqh\n\
yVIKnLR37fLUvw6vBcWFxa6iVWKWUyLKOVSTqW+hz+lRyapNFEEvIjdwqAEnhOWA9/WpNZ0+zsEe\n\
7hut4u5XZIwRiJBj5AOn4GuSuZ1gZ3SS2t1RdxfYyfoO9VSqU8RTjU5dJJOz08rrtt8+xlUpyozc\n\
G9UXL67t7kstpZPOeSS8exV9y3FZv2t1jb7OIkBBCvDDtMn+ymPmI/2ie9a+iwza5NMu0y2tvb+e\n\
TLkiRvRR071y/wBom1TUDpmmBvtt0RGHIKlRnPLH6dBxWsaseVuL92O93e2l/wAheylzJNas29St\n\
EhvYoJLQLeuRi2SITSHIyASc8+/NXFguLK/vnudNitnjVdkry4K5HRQP5iuw8L6bZ6A6JqLDUtbV\n\
MGTy2kaPP054p3iRLO8zctZ3JmUAG4uYBHGi5BwAepOMVy0XXxHI3ZRfk7vzW1k+l7v8DoqKlRck\n\
rt/LTy833scneXUKndHPHbzuAZYZgSjN/eH19RWU0U12GaSaExBSxEClSygc/M3Qe45q5qt5FIxO\n\
nzXn2cH5Y9g+X6E9qxtDgfX9bXToJEhiizLdTbizbB1G7qfwrqqThSUptaLutfT/AC3OeEJVJKK6\n\
iasYbJWWQb90YURopwTj5VGeQMn6nvXTW1lqL+G9I82ysdORcRTK3yMqf3zjkZIH51peIIdNi1ey\n\
vU05Z5IIeJZDuLOOhI7/ANKnfyNRt5EvBOiSffmkhaQv+AGMfWsJQq1pRlFNJa33d2rNdtPm21p1\n\
ZqpwpJxve/5J/qcy11IxnRo3mihTdc3AO6Nn4GBx8xz368VNbGQLDcyo0b5+VhIYpAPcjj86t6tN\n\
/ZVm8FtdW80OSyN5e3c3U7l7HNZ9r9tnvlGpiGMoqs4Q5LseiitYylBPXfsv6+75bGbjGfwr72fY\n\
Voc2kJ/2F/lVbWxnR7wf9Mm/lVm1/wCPWHjHyDj04qDWMf2XdZIA8tuT9K9Sr/Dl6P8AIzW55XHF\n\
VmOL2rA1bxbpmm5SJvtc3TZEeB9TXG6p4r1bUiVjkNpCeNkJwfxbrXgUMuq1dbWXmazrxieiarrW\n\
m6Qp+2XCiUDIiT5nP4VxWq+Or65JTS4xaR/3yAzn8+BXNRWsk0mSGd2PPcmt2x8PStgz4jX06t+V\n\
epHB4fCrmqu78/8AI53VnU0iYLrPdztNcyPLK3V3JJP41rWOhyyANIPKT1bqfoK6my0mG3A8qP5v\n\
77cn/wCtV4QonMjovOPmYCsK+aP4aEfm/wDIuGHW82YtppkMAGyPLD+Jhk1fS2JOTTp9U0q1/wBd\n\
fQAjsGyf0rNuvGWmQjFtHNcN2wu0frXnfV8RiJc0k2/M354QVlobEdr7VFqF1Z6XD5l7MsY7L/E3\n\
0Fcff+LNUvR5dqiWiHj93y351QOmuxN3rFwY1PJeZss30zXZTyzkXNWlZfiZSr30grlrUfEOoatM\n\
1vpatbW7cZH3yPc9vwqCz06O0UtHgyY+eZu3rj0+tRtq9vGhh0e1acDgt91T9W71n3TSzK8upTmS\n\
NRkwxnbGPr61tUdl7OHuR/8AJn8t/vJXd6v8AuJRfMbewyLYHEtxnG/jOxPc+vpVNrcKs6Sm2i+Q\n\
RhXA+7yQAOyjHXqTTfNkklVJU4KMWiT5fLTGdo9D0J9+O1dr4Vu7GDT08zShaxyFXd3G4zL/AHs+\n\
4rjx2LWBpRlCF1fuvv8AP5fkdWFw/wBYk05W+RnTyJPo+nTadJNPO8YiFuIlXLf3hjGB9fatTwxq\n\
LWDNBfLi0YjzCORGx43ZHqRg/T2qz4xudEu9Vs5NHhRIUiZWWPgdOpH14/GqmnywRR2SXqp5aqYb\n\
kIOGRyXSQfQk/lW1PDqipU780Ht3s9fw6Gdar7RqVrS6/LT/AIcv63o5tJFvLElAh3hkPQ9QwrqP\n\
C2uprEf2W82pqCDPHAlHqPf2rmIbqfw/c/Yr4GfTWOFkPJjB/p7VHq1ibSaO7sJP3THfDNG33T6Z\n\
p06ca0VRqO6fwy/R/wCX/AM23B88fmjvbuyBUqygg9QR1rmtR0GJwTB+6b06j8u1bHhPxAutRfZL\n\
vCahGuT2Eo9R7+1atzbdeK8ucK2DqNRdmdCcKsddUeV3unSQNtnjKnsex/GoLK4vdJuPO0+4kgfv\n\
tPDfUdD+Nej3Vorgq6Bl9CK5zUNEwC1r2/gPT8K9XDZxGa9niV8+nzRzVMK171NmtoHjuC4YQazG\n\
ttJ2mX7hPuO38q7IKksYeNldGGQynINeK3NphipUqw6qRyKn0bW9R0KUfZZS0GfmhflD+HY+4rbE\n\
ZZCqueg/8iYYhx0meuvF7VBJFVTw74msNcjVAwgvO8Dnk/Q962ZIuvFeFVoSpy5ZqzOyM1JXRkPF\n\
VeWIMCGAIPUGtZ4/aq8kVcsoGiZy97okTgm3PlN1x1X/AOt+Fc9eWclu+2ZNvo38J/GvQJIqqzwL\n\
IhSRQynqCK7sLmlfDaN80ez/AEZjUw0Kmq0Zx/h2LHiLTjj/AJeI/wD0IUV0Gm6OYtesJLY/uxOh\n\
KMeg3DpRX0uHxtLEw54M4nRlTdmdZ401ePQ7a7u5MNJvKxIT99j0H9fwrwu5uJr67luLly80rbmY\n\
1v8AxD1aXV/FV5vysNvI0USemDgn6kj+VYcMdGDwqoJt7smtU53ZbD4Y8Vt6PpxuHDuCIlPX+97C\n\
oNKsjczBeiDlj7V19vEqIqoMKowBXJmmYewXsqfxP8F/n/w5ph6HO+aWxLEmMDHFXIkqOJKuRJXz\n\
MUd7Y+JKqeJtVXRdFluBjz2+SJT3Y/4da1IUryzx9qv9p62YIWzbWv7sehb+I/0/CvUwGG9tUSey\n\
3MK0+SNzBtY3nny2Wkdsk9yTXfWUCwQKpICIvJ7e5rnfDNnvn80j5U6fWrHjXUfItE0u3P8ApN0B\n\
ux/Cmf69PpmvSx169aOHj01f9eSOej7kXNmHqd7/AG7q5kGfsFt8sY7MfX8f5U2bUjAXjs0WW4Bw\n\
zHiOL/ePr7VSfGPsMMqwxRD99MG2jOOQD2+uOB7mq0sUkIVVfy1UZVIoQQg+hOc+5GayqqLaS2Wy\n\
/V+pcb2uaNlA3mPcSSF525kuX4wPQegqrfXAu2jaJWNpESIfWeX29h61XdhKCZ1ubpV7TP5cIPuA\n\
AOvv2qGOd7i5DPIpA+VnI2oPSNR2X1749KI6S55O7+63p/S+bB7WWxHIkQkZGlR7lG+aPqC3qcfy\n\
qndSGeWKz0+dbjU7h9pk/hjzn6jPP589q6jwV4ch13VJ2kns58NuG0FEUHr7nHoa6h/Adrp+sC5t\n\
T8itlR6V5mJzalh5Si73/C/b+vQ9Gjl0qkYyvoYVj8PbrSbWMys21uSOh69SP1/Gte0s/swAxjFd\n\
rLM8kAR+cDvXJ+I76PTLcysCzMdqIO5r5+FapjZc1Z3PWdONHSmi1FN5eBmoNRbz4+CQw6Eda4cN\n\
fajJunuJOTwqMVUfgKvw6VfRLuhuLhM+jnn8Kc6OHg9dGawhVnomR6xBJOT50ccp6ZYc1if2a7Pt\n\
EYC/3VGK35DqsTfO0Uo/248fyxVO4t768JWVgkZP3IhtB/rXrQzGXJyyqNr+vmcby2XNdRSKyXe2\n\
H7Fa/MrEGRx04OcD8QK9C8A6ulta3llJ8sz/ALxD/ewORXEXWnvYaRcXESjeijb9ScZ/WrXg+x1f\n\
i5v5QELMY8kEnAzxxxnp6dawnhKmOoVMRTslG/4L/Iv6zDCVIYSad5W/Oy/E9Mv9Qmuni07T3ghi\n\
SMzXE8zYVAOrNjGe3tXJeJ7C7vrBn0SRb91BxdW9m8cf0LAbWFKVltdf2a1Cj2K/P5SPuN0QcomP\n\
97HB9K3YVm164ke40865dR5XyWm8qxtvRFGDvI6FiOeQPSvfoSvRp+wdoqK29PXvf9TwK6aqz597\n\
s5vw1cLoGiXaapcyXDhiV2ptKgDnr7+1Y2n63Ya6Lm0uZ2tppYyYGJ27vTFdv4i0CYWbPNpmlafx\n\
yYLsAH/eRgFP559K57TbO+u7OKJ2luIYch7rCqoXP3RI3CjHGcnHoa8x5dQqS54R1vdu/p8unlv1\n\
O2OOqRjaT6aL+tSNI5brw8bGabZabML58yrLIP7wU4J9QePxp/h7U92h3WizWkaafEqwKY5P3kgK\n\
ks5/H6d/St3TrqKFRb2s7WkGcbNGt/MeT3a5lxuP0FXf7GS7iAi0HXnHBDz3arn0JBO0/rXXiMGq\n\
lNRqJ2Vrf1dHNSxMoScovV7nnekXG2Ozkt41hHm/JECWc7GxkE8YIFfWGiOJdIs3UgholOQc9q+d\n\
rzw9MusfZS7NfTbQlssgfywP4pCoAH0HX2FfQvh2zGn6FYWakEQQqmR7CvTwMWldu/b0v+m1zGpJ\n\
Slov+HNB/uN9K8a8e+KF0iOSysmDahJnJ6+Up7/X0r2G7YraTMpwwRiD+FfJM7y3N1LNO7SSyMWZ\n\
mOSTXVUw0a04ylsjGVRwVl1I0UuxLEkk5JPerUceKIo6txR12HMEUdXba3eWQKiksfSn2Vo80gVB\n\
n1PpXTWVolumEGSerdzXn47MIYVW3l2/zNqNB1HfoM02wW2AY/NIe/p9K1I0psaVbjSvlalWdebn\n\
Ud2elGKgrRHRpVuJKbElRazqMWjaVNezYOwYRf77dh+daU4OTUVuxN2V2cT8TtV3zQ6RA3yx4lnx\n\
/e/hX8Bz+IrkrOP2qDfLdXMk87l5ZGLux7k9a19OgMkqIOpNfXUKUcPSUe2/6nlzk5yudDotvttV\n\
OOW5rTvrqPTNMnvJjhYlyB/ebsPxNS2kAVVVRgAYArhvHGq/2hqC6fbHNvbN85HR5Oh/LkfnXz9C\n\
m8ZiHJ7N3+R2ykqULGPYLLqF+89ySzyMXdq7HT4ssOKydItPKhUY+ZuT7DtW3PdwaVYPdXP3E6KO\n\
rHsBWmPquvWVKG0dPn/WgqMeSPM+piePbsF7LTkOSv76Qe/Rf61l6zD9n0SxDcOZ1bGfY/0pmnJN\n\
q2py315yGbc/p7KKu+MQFttPXgOZCwGOMY/+vXfG1J08Mt93+Jj8XNUKV5Ksd1pkjqGyWjYHoVI6\n\
GqV7EI7+4t4p2hSSPy1kB5VG6DPpnil1Z8T2UeASoZzz07VSnuEmF7cMeGQRxkDk7e//AH1xWFHS\n\
KjLa3/t2ho3rdGr4lmsrjw7aadpgdbpVVWLkNvA4z/vZBzVjw98NrVtI+0+Jp3VwC+0NgKO2fwrj\n\
EttU1DxC6aXC0jQJvb+EDnOP5V6obnWNSfTNJkSOK6lCvOHUMF9AccH1xXBUozdaOFoz5Y6tpPXv\n\
pe9k76s9CNRKk69SN3stNP8AgtGhpt5HoWig6Vok4to4SI5poWCMCOoOO/qa5nRLm3gt1vtOsltt\n\
SuGfet1tGwZ4IJOV65yeK6+4sLfULie3tGa/ltyftep6jKWghwMEJHnafywPfpVXTNBTULjGk2rl\n\
DhmuZQvmyf7TEjEa9woG4+3SuqGEozh7O1op36636ybd3fz36KxyPFVFLnvq9PTyX9fMXRtkFgkT\n\
aveXMjkySJo0GVLHqWkxz1HesXxbcslrJDb3Wqski7Zbe+HLqe6mu8XwlqUS7k1Y28mf+Wc8px+o\n\
/lXNeMbTWxpr2urqupQdY7mIbniPbcMA/iBVOdL2vNzKX3X/AC1++5kuZra39ep5a/hy51PRZL+G\n\
7W7ZHKTRgsBC2RhT7YxXR2/l2ekx2OiLHEZFAvpFAc8feCn1+lV9Ni1EQz2x1AQW05AitlA2sc8u\n\
59Mgjr2zXYRwwT6XBZPd+baoux7m4zFbRjHIghBHmN/tNnrn2rP2Mql1UfNZ3Wm3VPza7v8AE3dZ\n\
Qt7NW018/wDhyh4enjvrm3hgs5L1ogN0SDCkj7qE44A6nHJNegCDxNcQB57mw0q3UE7FjB2j8e35\n\
Vn6bqtppNmLPwxpkksxGPPuF2bj7KMsfyH1qO7tGu5Vl8WatDHECCLdsYz7RAnn3Ytj0rerBzfLy\n\
2j3l+kV+pzRlbW/3f5mNrFrZ3KES6rd6q2eJYoo1jP0cjn8M0zTdKull8yPTJ7hCQVkW3WRsdiSU\n\
/lXY2mtaDp2DZWV5cS8fvnhy3T+8+APwxTpvGrs4ENi4y2MzTKvH/AdxobmlywpOX4fgrBdbuSX4\n\
nrMH+ojzkfKOv0rF8doZPBusooJLWsgwPpW1Cd0SN6qDWR41uFtPCWr3DhisdrIxCdeB2r1W2ldI\n\
HqfM9noc7kb0EY/6acfp1qaafRNMOLi5NzMOPLh5596x9Tv7m9UteSPZWQGfIi5kcf7R/wA/Q1Rh\n\
vYrZW8mF4VVlGIQA4B7tIeQf90DrXG685fE7eS/z/wAiVTS2X3nUjX78pjStGMMR6SSgjP8AL+dQ\n\
teeIrjIa6SAHtGFGPy5rHgLMvnJ9sR2J+dLhpGOOuQxPcHp1rWsNXuUO1hBfKOq48uUfh0/SuZyv\n\
rTir+d3+LdvyNGraSbI5LPUp8m41CZ8nOPMbGaYuh7iWklJYn0JrXPiLTF4ltryNx/DsU/1qCbxN\n\
YDi2s7uVz0BUL/U0KpjtlG3yX+YrUurK8Whwgjczn1wtFyuk6bxcsDJjiMtlj9FHNV7u+1e9GP3e\n\
nQHsmTIR9ev8qzpIItOiaZEIc/8ALR/mlc+g9Cfbn3p+2q3tUqXfaNvz/wCHDlj0X3luXVr1j5Vl\n\
AmnKQSMrumZR3C9h7niqMyRxSCWQLdyMocTTuZOD0xgbRWeglEsoygfB3lvmUyEfKueuF6/UZrXu\n\
G1BjYWem28UpkjVzd3P7hpFx8ocKR6Y9ayrYj2Tinpe93fsu7/4HfY2pUHUTtq1bT/gES6hJIQBH\n\
auegzOR+mKiuRLkTXQeV15jjRDHDGexLNjcabrDatYanZ2v2KIySkNIltO+yT0GW5wPrVie2Ml7c\n\
QTxtFLD8zmOUhB+Ock/h+NRDEUdOWyb6/wBalVMLWhfmi9DLRxCZVOJnbAlJU7TnogHp1PPX8q65\n\
pri/8OB728ga5JKJFCMCJR0B98Vyc5ihkjSIrujP7qCNW4Y9WJOWdvc4H5Ci1nkXUzAzF2jiIk9m\n\
znH4UYnBrExXRx1Tt2W3o+tvLcMPXdGTXR6M0NG8LTTw3v8AxMfJvCR5SuDjHrkc4Ip/2xn1aXTY\n\
nVZLWItLK7Haemdo7/TvXU6XZnVbBRG3l3aD92+f0Psf0qSDwrfWUN1qF95sCqp3RCX5Jn/hLAfe\n\
A+orxaOZTjO03p0+/wDr8z2auCo1KV4K0lvr+RRttRuFtfsl5EbmFR0H+sQeoH8S1JpGoQ2jSwFz\n\
Ppsh/exY+eI9mweQf51zM199t1FLW0WOac5YQ+aRs9eeo/Ag+1aLWt1a6z5EiRxCPaod5WYyM3AC\n\
Ag8eua9yVanCtyTsnLp+vr5r8UeGqU5Q50tF1NvUbKS1ljntpdw4khnjPDD1B9RXWeG/GUNyi2ut\n\
usNyOBcHhJP970P6Vy+nz/2fGYr6J5dOlZkkVfvQyDgsvv7dxT9W0R0hW4tyLi1kG5JoxkEe47V3\n\
TVOvFU6z9H3/AOD3XXdHMnKDvD7j0yaAMMrggjII5BqhNb9eK860nXtV0TCQS+daj/lhL8y/h3H4\n\
V1Vn450u4CreRTWkp6kjen5jn9K8rEZXVpv3VdeR0wxEZb6E9/p0dym2RfoR1FcxqOkywZJUvH/e\n\
A6fUV3cE9pepus7mGYf7Dg02W29qww9etg5e7t2Zc4RqrU8rmtip3LkEcgiuq8N+N7mw8u21cNc2\n\
o+US/wDLRB7/AN4frV3UtDWUs9vhHPVT90/4Vy17YvC5SVCreh7171OvQx8OWS17dfl/XyOKUJ0X\n\
dHsFldWupWwuLGZJ4j3U9D6H0NDxV4vp91eaReC5sJWikHUdVYehHcV6HoHjmyv9kGpqLO6PG/P7\n\
tj9f4fofzry8Vlk6fvQ1X4nTTxClo9Gbrx1WkirWeMMMjBB6EVXkjryJQOlMqaXHjU7bj/lov8xR\n\
VzTo8ahbn/pov86K9XK42hL1/QyrPVHjfiJM+JdU/wCvqX/0I02zt2mkVEGWPFW/EMf/ABUmp/8A\n\
XzJ/6Ea2NEsvJjErj94w4HoK9vG4uOFpOb36epwUqTqSsXtPtVtoFjXnux9TWjElRxLVuJa+NcpV\n\
JOcnds9SyirIliSrcSVHEvSrW6OCJ5ZnVIo1LOzHAAHU1tCImzD8aaz/AGLpBER/0u4ykXt6t+Fe\n\
UWsZY5OSSe9aHiXV313WJLn5hbr8kCH+FB/U9av+GbDzpxK65jj5+p7V9Rh6ccHQcp77v/I86pJ1\n\
Z2RvafHHpulmWf5UjQySH8P8iuCe6luXvtauRhzny17LxjA+gwPxrovH182230qAnfLiSXHp2H58\n\
1jazCINCKIQBuSMe/wAwJ/ka4qV4x55fFUf4dTWW9ltEwYwfs1zmdY3SMkMwzk9T+ZH6UyabVZdP\n\
0+aygWWS4BDy45LZ5Yn2pYLe6uJnNtC7BAWLAcce/T1rQgfXLi6jheGWGBVV7cMMD8PTNcuKqezS\n\
qK3Muj6rql+HpY68LFTbhK9n26PoJdRpHCsU7pNMRukYgMoPXAz7Y/HNYWpSxxRGOSXzLqUbIlVQ\n\
BGD1OBXoPhrwvYskVnEs0k8rsZvMU5RcE/N+OPSs7UPBps75ikakZ4bHOK5oZthacuWUm+ztv1t5\n\
NbfI6amWV0lJqze67f8AD7nZfDzQNL0bR45rGRpJZVBZm69Of1rpZG3HmuW8PI9pAseTgdq3xLxz\n\
Xw2LrzqVG5O/mfQ0acYxSSsSPHkcVxPxBsZHtLa4QExwud+OwPf9K7IzqvU1DNPbzIYpQHVhgrjO\n\
arC4t0nqgnSu7o8Y8Qy3FvZW62wfbJu37OpAxx+tb+nafqGkaXDqG94y+C8EpyrD0I/rXUT+G7dG\n\
zA22ENuEVwjBVPbDdR+taEsUu2J1is5XQYA80tjjsG4r7DLs8wFHDujXhe976Kz9f606HiYrKsTX\n\
xKrUaqitOrTX3HPDXdIm2b7hYnYco4OVPocD/PtWhLbxRxB/l2kZBByCO3Ncz4g0OXVNZgli22j8\n\
LKj4XIB+8Ox4449K7rTLe00e0t/tskQKLtjEnY8nPpmuXF4XBVacamBbc5P4N2vPpou7/wAz1sNm\n\
OJo1JwxqXJFaSta+35/euxgrc2sgaCUK8bcMjdCKreFNbtY769sYbWUi1mY+Y/JdBnC+2MZ9/wAB\n\
WjrWq2d3NHDdLEyMfldQFI56qw69q04tIs9PsZ5p7iZ0kQL+6hG854BbHXGawpVKmChPCYiLXtEr\n\
JPrda+d1dP8Aq2eIqwxs4Ymk0nC+tujX4W3X3nPhRe6jc6irBbiQYRd2SHYhAB9ATXdxXN4qroHh\n\
WOJVtgFuLxuVRscgL6jjn+eK8y0o3FncCJHZ5lfbHleSQ3ysTj1IOPavUpbq38F6FDaRKJ9UuBuE\n\
YPMj92Y9lGeT/U19M+VUlGMdL6R2/pL+up8vK/O3J69WUtTsNG8PBJtUWTW9XlOUWdt2T3IU8KPf\n\
pU1j4e1DX2ju9fnMVsMGK2QbUUdtq/1P4AU/S9Kt9Ot5Ne8Wzq1zLg/vOAO4AX+S/nk1m6z4u1HU\n\
n8uxDWNsxwDjM8g9MdFz+JrSnGq/dp6yXX7MfJdPnYzk47y0X4s6y5vtG8MwBQYoGPQD5pH/AKmu\n\
fbXtZ8QytbaLbtaIes0nLgeuOi/j+VL4f8GPLN9r1UNEG5KFi0jj3Y8gewrtLeG3sLcQ2cSRRjsv\n\
f6nvXNWVGi3KrL2kvw/4JceaW2i/ExdL0my8KadcXk7mW5CmSadzkk/U/wCfw4rvPD1019odjdPG\n\
YmmhVyhOSuR0rxzxprB1C/NjE2bO2IMxB4kk6hfoOpr17wo2/wAN6ax7wIf0r0cvhOUXXqfa29P6\n\
/AiUlzckehfvf+POf/rm38q+UEj+dvrX1fef8ek/+438q+W1T5z9a9OBhV6BHHWlYWTTtxwo6n0o\n\
0+zadhxhR1NdHbQLGgRBhRXm5jmKwy5Iazf4ev8AkXQoOpq9hbS3SGMIg47nuTV6NKbGlWo0r5Zu\n\
U5OUnds9LRKyHRpVqJKbGlWo0rSMSWOiSvKvHeu/2xqYtrZs2VsSqkdHbu39BXU+P/ER022/s+yf\n\
F5MvzsP+Waf4mvNbePkV9DlmEt++l8v8zixFX7CLFrFzXVeG7XdK0pHCjA+tYdpCXZVUEsTgAV20\n\
Ig0jS2muWCpGu5z6n0/pXTmNXkpckd5aGVCN5XeyKXivVxo2mYhI+2T5WIf3fVvwrhNEszNL5kmS\n\
B8zE9zTb+7m1vVnuZAfnO1E/ur2Fa11d2uh2KGY5cj5UH3pH/wAO2ayjB4Shyw+OX9fgW5e1nd7I\n\
0nmh0+1e6u22xr+p9BXKXFzdeIr0SS5itI/uJ1Cj19zTNl5q8yXGqMUi6x268fp/U10Gn2RKqAoS\n\
NeijoK41KGDWmtT8F/wTVp1N9ET6VagKiRrtjXoPX3NYevTjUPEKwRf6u2/dA+rZ+b/D8Kva1r0d\n\
pG9npbCS5YYaZTlY/p6msGVX0+1jijP/ABMrsHZn/lkvd2z7Vvg6M4N16u72v+f9dCKkk/ciVLhj\n\
f31xIjFYs+UHHQKOp9smqeCswlLjZEMrxiKMDoxPfHYdzikvXAsrhVR1sYkIxuxvx612PhDRNK8Y\n\
rYH7C1lZtiJ1LnGcfe/SorV4UZwTT5W0r9n0ut9b9DalRdSMmnqtbeXX7jl/Avir+y9dkZoDIl62\n\
1Qevov8AKu6bUL6bxEYFtHhuLhvKjlJztDLyR74qnqdjZeF9ajfRrWG9l4VFlbbt9GB7VLYXMx1R\n\
RAVbUNzM8qncE7ZHbvxisoYeUcdOXLul87fkl17ms6sZYaKvs38jrdRe2eMaNaOlto1iR9ruD0lc\n\
dvcA9u54q5/wkdzHbraaLZi1jP3XnBeWQn+IoO59zWFptlJdTwRQoHkdv3CHooz99vUnrntXpel6\n\
TZ6PFmMCS5I+ed/vH1x6CunEexw9P99rfW3d93+i6I44c037uhy0Oi+ItRG+71Ce3Q56sqf+OgE/\n\
maqavodhpcI/tTWL2WR/uQQO+98f8CNaGv8Ait5GkttGdSynbJdMMpGfRf7zfoKreH/Ds+pyteXT\n\
zJC/3ppOZJvp6D6cVhRUpx9rKKpw9Fd+lypNJ8qbb9TnU0qK8ulSw0/y5WOTz50zem5z8q/kfqKv\n\
3Vja6VcrFIwub7GXhgOSn+/Kc4+n5Vva7qsOlZ0jw8BBMpBubhQG8odcZPVzx9Bz6VyAOGW3tEZn\n\
kbgDlnY9ye5r0qEpVVzR0j+L/wAkYTtHR6sszXcgDgyi3iIx5NqSgP8AvP8Aeb8xSaVY3d9KU0qy\n\
69ZAu0fi3euq0HwWgVbjWz5knUW6n5R9T3rsF8uGMRwoqIvAVRgCuavmNKhdUld9/wCtWaQoSnrI\n\
46x8Es2H1O9OepjhH/sx/wAK6Gw0bS9PZWt7SPzB/G/zt+Z/pVqSb3rldY8TCO6NnpircXQbEjn/\n\
AFcX+8e59hXkSx2JxU/Z07tvojoVOFNXZ60v3R9KxPHP/Inazhgv+iycntxWzAcwxk9So/lWB8RS\n\
i+BNeMoBQWcmQRnjae1fSyXutPsYnyXczC4JkiBMKMdjN0lbux/2R+tRxCCS1hYxify3LHeTiUsO\n\
u32IHXitq10u71gSwWtvbhY40ZTM+Dg55wOOueMY/OtDVfB2qyWsn2KWCSbgAqh3LGB+WevavDeK\n\
w7qrCKVpPRLW/wDTOqFCsofWEtFrc0dR8PapfRJcO9rHFIihIUQKYhyScjv2A989q5QQT3mo3FpY\n\
QtK9oN9xJLJlIwOwPr9K7jZdWGhWQuGYS/6p898Dg1Ut4vL02+jsrNLia5X5ozxvPvXi1MXisuqS\n\
w9WztbltpZd/u79d7npRw9DFxVaF1e9/X/h+xk2kVy7bLedZCF3CG5QSBh3weoP50rahc27bW0xA\n\
O5gcD9MZpkWnarAkcmoQpBOTuVYHywwOuP6Ussmo3Ee6J7G6XPEpyG/EDoa+guqkFOLTi+91+K/r\n\
1PHcXCTjJWZDJqFydxj0+OIcnzJphge5rMIM8n2ia482U/LFJjaqn/pmvc/7R4FQakrxrm7k8+Qn\n\
CoF2rn0VerH61nardGwiEd0d88owQSeAeDitKdopuCX9ebJtdpNj5LizhuJImuQ9xHgRwxAlVPU5\n\
Pc8c+tXvCMt5cam4dJWhY4Ak67ff+ddJ4MtNINjBcLp0CzQgqsm3lvc+vSuy8CadDMdQcwr5EUir\n\
Ge4JGSPp0/OvExOa05RdJRv3+R71LKKlKCxDkulvmcc0Tw6m1tdkloj8jN1KnoaueFfCVtDcvGJp\n\
LmSdizH+6vqf8969LvdO0+6AF5axS7ehYcj8aIRZ6fC0dlBHCp67R1/GvBWNlRhOCdlJWfy107M9\n\
OUadblnOLcls76a6a9zyLVtAuLeWSK1vHtmXjaAMY9VJ5H4Vh2umR2eYoTvdj8716d4gSK5YkgE1\n\
zUlmkQLAV6eHz+vWoqi0uZ6X6s8upltOlUc1t2Lfh6f7JtJIAUdTV7XvGVjdWUlosxfjBKKSPzri\n\
NUupJrj7FExEYAMuP4s9BWrpujBolYrxXNiI0qTTZ2YanKrp3OPt9KnudXWe3lS0RW3efMOABzk+\n\
grupme8v3eVxK1tAkokC4V1QqcL3xnnNW4xa2EsIuYwYSw3/AOfSs2XUwb+7uZY3jTmJQ67VYHja\n\
vrx/KvRy3Fyr1nOXRWXndrT8DkzXCLDQUIu99X5HbafZQ6jqeuWDj93cAXUZH8LYHI/76/Ssa1v7\n\
zwvey2s8fn2THJj6fVl/wqPRtWa0m0/UhukEaLHKB/Eo+Uj8iPxrsNfsbbUrdZU2yQyKHjceh6EV\n\
69dvDNc6vCSs15rS/rax4cf3l7OzRny6Vpms24u7FhtfklOCD6Eetc/e+FnUnZIrD3GKpvFqGh3L\n\
y2MzR56kDKt9RW7YeL7O5Aj1SI2k3TeoLIf6irX1iEefCz5o9t2vkS+Ru1RWZysuiXdu4eIMrjGD\n\
G2CKsW+r69p+AtxLIg/hmXePz6/rXbbba7TfazwzL6o4aqVzYHn5T+VZPMaj92tBP8CvYRWsW0ZE\n\
Hjm4QBb3T0cjq0b7f0Oa1I/EGh6tGsVw5hdv4Zlxg/73Ssu9skUEyhAP9rFc9ey6TGzLLcQBgM4V\n\
sn8hVQeHrO6g4vy1E+ePVM6vUdAdIzLasLiHr8vJA/rXOXFp145H6VBpmoPbOG0bU9hbpGx25/Bu\n\
K34Ncs71xDr1r9mnPAuYhgf8CFenSq1YL3vfX3S+a6mEoRe2j/Ah0DxNqOhERqftFp3hkPT6HtXo\n\
mg+JNO1tQsUnk3WMtDIcH8D3rhtQ0GRYhPast1bNyskRzxXPTWpRty5VgeCOMGoqYbD4xOUHZ/1u\n\
hxqTpaPY95sYsX0P++P50V5r4J8X6lBrFjZ3x+1wSSpGGbh0yQM57/jRWOGwc6HNFmzqxnqivdWn\n\
neKdSZh8iXMhOR1+Y8VsxLUmoQLFq1+F73EjE+pLGnRLXh5hiXiazfRaL+vM6KNP2cbdSWJauRJU\n\
cSVchSsIRKbJIkrhfiPr4Yf2PZvnkG5Zf0T+proPF2vR6Jp7JEwN9MpESj+H/aNeTxI8khZyWdjk\n\
knJJr3cswnM/bT2WxyYirZcqLGn2zzSIkalmY4Ar0Gwt4rCywzARxqWdjx9TWb4d0020fmyr+9cc\n\
D+6P8TVbx9fi306Owib99cHLAdkH+Jq8VVeLrLDw2W/9eX5ipx9nHne5zVq76prFzfzZIZyUB7Ds\n\
PwFXvFEappFspHzPcrjj0BqTRbXy7eJcc4yaPGLfPpNopG5pDIR9MAfzNZKoquLSj8MdF8kx8vLT\n\
13Zz9jaRzSMtwha3XerpHkO554HYE8c46Cug1PWbPRNC09wHWVcKYtwkCDsNw71m3Ub2+pzxoSpl\n\
jE0RH94cH+X61kXl+kpLNGB5ZEhOOAff8a5q+Dp4qalUV9O7tqt/U6aOKnQjyxPctEvXl0i3mdCh\n\
lQNgjBxUF5GspOQK868CeML/AF2fynBdAOMDHH0r0XDBRvFfD5hh6tGbpz6ba3PpsNVhOPNEpCAJ\n\
0FNkbaKtkiqt2vynFedZp+8dV10NDwtpS6vdSPdMwtIcF8fxH0zW7qF/HHKun6PZw7zwFVBwPUn0\n\
rC8IaklvbX9mWxK5Ei++BVdNVNloetX0JBvGkECZ7E9P5/pX6NkdKjQy9V4RTm3b53sl5HymaVak\n\
8S6bbUV/kJfTz3N81hZyTarfL/rFgYRW8J9HkIOT7AZ9cVnavp2pWdu7TNZNxnZDdZf/AL5cYP5j\n\
61YsYbuR18O6LM1vDFzeXKn55H/jw3UAZ69SfzqzqenaNpNxFp+laZFqetygAC4+fYvPzOTnA/U/\n\
ma761Sd0m7t+V7/LZL1vpqzghZao4nRNf1CKDUIriBolRsQz5GQ3srdq1NM8+TN3cXepXl067FWx\n\
s428v6zOvl5PcL9MnFaV9p32G9gtDHDqWtyAERiMLbWqnphB949cZzWzB4RtUt/tXie7aZwMlHcB\n\
E9v7o+gA/GuanhcPh1KrpHm7LfyXl9y7G9TEVatoN3t/Wp5z4q8MXV3cw3VwmpRQxHfvAickjH3v\n\
KJH44HSodR1e91jUJoYba+j0+2XAaCYJuOONwOGI9Md67a5j8Ks5h0ayvbi4zx9heQcj3J21l3nh\n\
1LBTd6tG1okz5jsVlD3E5HQFgAFA6k896iWHhWlGTjrHZtNP5K/X0KhXlTjKKej3F06SDT3iu5Le\n\
OaWDBRRws1yRgID/AHY1yWPPPvXQ2KxaPDJr/iUtdalOcW0G0b5G7BVPRR2zwoyx55pPDekwWFpJ\n\
r2urHFBCmYYQPkReoCj0z+JPPpWFfXd5rmrm4eEteXH7qCEdY485C/U9Sfp6V6VOkpScIvbd9vJe\n\
b6nJKVlf7hJpdQ13VVafN1fyMfLiU5jgHomegHdjyfYcV6J4e8N2ujxiWbbc3p5MrDhfZR2+vWpf\n\
DWhw6HZDgPeSAGWT39B7CtCWSuHG49RXsqOkV+JpSpfaluLNN71xvjLXpLZfsGnyKL2VSXkz/wAe\n\
6f3iPU/wjvg9gak8VeIvsWbOwZH1FxkBuViX++39B3riLW2muroWtmHuLqdtzyNyzt3Zj/kAcVhl\n\
+Blipe2raQX4/wDAKrVeRcsdzS8L6N/a+pJboHFlCd0zkkk85wT3JPf6171YokdnCkahUVAFUDAA\n\
rj9B0uLRdMjtYyGf70j4++3c12Nn/wAesX+6K9mhifb1pKPwpaGap8kddxbv/j1m/wBw/wAq+arS\n\
1ae4ZV45OSe1fS1yM28o9VP8q8JtbYQAqOSTkmjHY1YSnp8T2/zCNH2klfZD7aFY0CIAB/OrsaU2\n\
NKtRpXybcptyk7tndolZDo0q1GlNjSrcaVrGJLYsaVm+J9eg0GwZyUe8cYhhPUn1PsKl1/WbXQrE\n\
z3J3SNxFEOrn+g968h1O+udX1CS8vGzK/AA6KOwHtXrYDAus+efw/mc9atyKy3IZJJby6kuLhi80\n\
rFmY9yau28XSo7eKt/RNNa7mBb5YV5Zv6V9DKUaceZ6JHAk5OyNDw5YKqm8uMKi52luAPVvwrmPF\n\
utnWLwW1ox+wwngjP7xvU+3pVvxj4gW6A0zS3/0deJXTo2P4QfT19ax7dINNsHv70ZRf9XH/AM9G\n\
/wAK4aceaX1mt8l/XVmzdl7OPzH/AGiLRbRH8vztQn4ggHJ/3iPSsuGCYyNdSSQT379ZZm3LH/sx\n\
xjlj/tHC+metVbqWf57ic/6ddsBIf7if3F9OBzUulTWUUyw3VwyebvwYomLzSDACFugHfHoBWdar\n\
vPrt/wABfr316GtOneyNC2j1GRS8OoIzg5bbb/MD6HOSKe2nXt1hbzUJZE/u4bH5YAphciVZIpWS\n\
TtIPvD6/3hVuOXXbmLNrLFKp43qq5/8ArVlGE4+9TcV6pITaejTGSLYaDb+dIu+b/lmJACWP+yv9\n\
TWPiRRNd3zf6TIN8zE/cHZB/WtIaY1oz3upzCS57NI2Vj9/r6AVlu32+YNtb7AjZXPWd/wD4mlOT\n\
ldOV+76eiGlboVx9ktbWQajbRzHyw2GPCk85+v6V3nhHxxpc9lFaQxmJooyJNoz8g6kAe2RXn2rx\n\
i8W6JbCAeXuHOSOtd/4d0bQ7HwuJrN4ftBt3jMpXMmT97Pvjj8K4cy9nz0JyV5uSt5N9/wCrnfgu\n\
ZwqRTsrO5oWEj3mgS6hcZCzylYreBQsl3M5zh5Mbgi9NoxhQPwtaboyaXHq6oxMtnbhWcj/loQM4\n\
56fMQPoKxdH1qK3utMjeZWt4Lnz8qfunAVs47YHH1rqROp0bxVICDulzu65B6c/TFd8p+zbcdn/n\n\
Ffqzz7X3/rc6LwNaRwWtzfyBRk+VGTj5UXrz2/8ArVha9rkutsYrcyR6WWKjYxEl52GMcrH+rcdB\n\
1TV70HRrLSIjth8sT3ZB6hjkJ+PU+31re8HaMyldVvlw7D/R4yOFU/xfX09KKlOHPLFV9Un7q9P6\n\
/USbsqcPmHhrwyIgt1qsKAj/AFVrgbUHqR0z7dv5WvFuutp1slvZbTfT5WJeyDu59h+pwKva5qsO\n\
m2clzcMQq8ADqx7Ae5rzS6ubiaeW4usteXBA8tedi/woP6+9ctD2mY1uafwLf/L/ADLm1QjaO4wr\n\
I7paWvm3E7t1J3PIx6sT6n/PAr0Xwv4dh0WDzZ9st+4+eTqE/wBlf8e9ReDtAGlW/wBru1P2+ZcE\n\
E/6tf7o9+ma1dS1C3sbdp7uZIol6sxrTMMdf91S2/MKNG3vS3LMklYusa3Z6ZHm6m+c8JEgLyOfR\n\
VHJrmtW8UXV4THpim1tz1uZR87D/AGUPT6n8jXOF44Gd1LPM/wB+aQ7nf6n09ulc2HymriPerPlX\n\
4/8AAKniYw0jqauq6xe6nuEzvY2eeII3/euP9twfl+i8+9ZccpM0dvZxcs2FjjXqfoKjs4LvVboW\n\
9jE0sh646KPUntXpvhbw3b6JGJHxNfMPnlI+77L6D+dew3h8uhy01r+L9WcyU67u9j0C3BEEYYYI\n\
UA/lWJ4/kaHwTrkiAlltJCAEDknb/dPX6VvL90fSua+Jm8fD7xD5RIf7FLjHrtNdMn7rZslrY8B0\n\
HSrWKGC8jW8j1FwWuBcfKxY8kbRwAD0r1vwhaw22hSXk5BknO3nsBXzz4Q1bU7jXLeJkknjkO0uc\n\
n6817MNXt5baOwlnuPLtV2MlrEzsT7kDAFfI5bh5U8e62IfNaLaers7209NUj18ZWTwvs6Stql+F\n\
/wDIPFX2e8sbiCNlDj50x6jtXld5q+p6eVfToZJXHBVRye1b/ie9trWR7nTLmciJv31vcKQ6D1HA\n\
4p3hzUrU6g0sW05XcRjoSK6s8jScFjYx5raNP8P67GGWSld0G7dU/wAyvc3OoreWdzdxulw6CRUb\n\
17rj86y9bm0iaV7iNlgl/ijIZHB9Bt613njWK0C2Yum/cyRkGYfwMTkN+n61w+qR6nasQJbeUY+W\n\
Vovn+uR1rsp+7Qpe10lyrZ236Xs72VvzOSrZ1Z8mqu/6/M5s3X2aQSx2qoWPyKwPmOPVmJyq+3BP\n\
0qp4OXStU8RiTVyqk/cBfA69s0zVnYytbxsZbuXh5DwI1PXA9T0ya2vBnhy0ilW7vQw3KUB25Uep\n\
+tOtUhTjF1Z8qb33/Pe/p9xrhac5yfs4cz7bX/L8zudRtUs4WWCLZ2CKMc+mK7vSrRdH0O2tcASh\n\
d8p9XPJ/w/CsHSLMalqcMwjYWFuQ5YjAYj7oHrzj8q6VYW1TURAGKxj5pXH8K18TUTc3ToK7k7Lz\n\
PscbWVoxnooq78vIrQW97qUhWyjJQdZW4QfjV7+wLGHB1HUZJnHVIvlX8zzUl7qEsrf2docP7uIc\n\
nOFX3Y1y11NZ+c8d5rbPKpIdLSBpAp9N1fU4Ph7BYZL6z+8qdd2vkl+bPk8Rm1eq2qPux/H7zQ1r\n\
RNLnhP8AZs0kMwHAkfcrH39K4S6WRGeCZSsi9Qa05WcygafqKXL9opY2hdvpu4P51UuLn+0AYZl8\n\
q+iOAHGD9DWmNyWhJe1watKOtu/yfX8ycNmNRPkru6fXsef6tHcQS6g8CkS7gVI6gHHNaHhnRLxt\n\
KN2/mxXZfEWG+ZmJIH+OPSuri0wXc6/MILtBjDDKsD2PqK39O0i/QCNIbeBenm78gDvgdR16DFcW\n\
X51QwSnCrC8v6VmmduIyqeMnCpGoopb7+t1bcxvE2hPrN7bR2F3NBDFNul8tcgpnoxzxx/Op9QWG\n\
9lso0RPsNssv75jjdsQltowfpu461uaxf2GiW8dq8gAdSAxOC7epxXMQTie0ePavlx26xL6ANLk4\n\
/DFGVUVio+1aWjajotNrvzfbtrbceb4nlqOMLq6V9Xrbb087fMmh09YHtrWYiKK+gSaB2+6JCB8p\n\
PoeR9SDUFprF/wCG5mtLmFpbPdzC/DJ6lT/TpXU6zYJq/hDTWhZfMiiAU+4GCp/KuZh11PL+xeII\n\
juQbROy7sj0b/GvZjW9opU3Hms9V102a+W/3niOFrSvbz/QtP4g0W9Un7T5DHqk6Fcfj0/Wsi+Ok\n\
Pn/TbL8Jl/xqS5sdLuEMlu1q6HuGx/Wuf1KKwswC32UE9AF3k/Qc1zwVOM70lNP5Fvma96zHXKaX\n\
FJui1WGJz93DZ/Vc1DJLFjc+uyMv/TPznJ/DFZqzzJM7N+7SP52iAAIXrlsd8dF6+uKvWjTzafFd\n\
yyFHupWMSRbjhR0JYHA47V1yxbgkpvfvb/ImNHmu4rYZL/ZxO6U6jfP/ANNIpAD+GM/rVZmeUP5M\n\
cdlAuN7naGUf7iZY/wDAiKkb/SbZ5mvHNvnbvCZ3kdQrdDj1xWXdKosGWDzAzsFRYhj5SwDHceSx\n\
6bvwHFTzOesnf5u36IFG2hoLdQw3MEEc9xIJlOVmhLE46HJPf0ArqrJIBbQNcBn0+VvLfcCGgfsw\n\
yM7T6dK0dQtLiz8MQl7DKhlZZXKs8ChRklvbnmsqyu4GtpHHzwTErKM9V7OPUj0rhwWLeIg5rSzt\n\
ZPt+V+n+TOzGYeNCSgtfO39bdf8AM1fL1PwvcCWyk82zfko3Mbj3HY+4robGbR/EsIwiwXuMvDnD\n\
j1x/eH+TVLwtexz239lXjqXAzbs3SRf7v+Ht9KzNb0OS1n8+yLKyncApwVPsa6JzTqclZ8suklpf\n\
1ORJ2vHVdjc07w3Na6/YSRYljW4QnHDAbh2oqz4J8VLdalaWmrYjujIqpKB8shz0PoaK7qFTERTj\n\
V1ts+5PLB6xL2qr/AMTi8/67P/OiJKm1Rf8Aib3n/XVv506FK+Xcfefq/wA2dl9CWFKj1jU7fRdP\n\
a6ujwOEQdXb0FS3Fzb2FpJc3kixQRjLMf5D1PtXkWv6vPr2pG4lGyJflij/ur/j616eBwbryu/hX\n\
9WMK1XkXmV767uNUv5bu6bdLIfwA7Ae1dB4e0vLJcTKNo+6p7+9V9E0oybZphiPOQv8Ae/8ArV19\n\
rF04xXdj8cqa9hR36+Xl6/kY0aLk+eZYgQKpZzgAZJNebXkw1vxFPdLkwZwuf7o4H59fxrqfHepm\n\
x05LKE4nugdx/up3/Pp+dYGhWfl26kj5n5/CufDr6tQlX6vRFzfPNQ7bm5p0OSDiucuLkar4nlni\n\
Obe3URRn1x3/ADJrU8Qan/ZdgIIOb24G1AOqju3+FUdDsxbokK4JHLEd2/8ArVlRXsKLqPeWi/Vl\n\
S9+Sj2HeJAIrjSpOjHcp9xxXJahpMN751vJdPbr5x3MDwVHbHrzXV+IpRc61ZWSc/Z13uR2Jxx+Q\n\
/WshIBOdTQDLpK0i474AyPxFdcPcpRvo2v8A27Qhv3n/AF0O2+HWmaHb2VreadL+5tSygkfMzkYO\n\
4+ntXSajqVuv3XX8DXA+HtQi0jR5bazi2qx88hE3MFb+ML/EOOQMEY71x/iLxDcxTSGPIwcfJyPq\n\
P5183WyetWqOpKd1d6dbdLvRfce5TzGHIoJWaXy8/M9lguFnYhWBPXFOuQVQ8V5ppmmTf2fHfiWd\n\
Jm5LNlXBrs9J1DVrrw1e3DWJupLfiJ8487147468denWvMrYaEZuEla2h6cYT9mqsXdMxNa1VLGd\n\
ZPM8pweGzioU1oz2spyTFMyO+P7ynORXNHTjrd00l3OfMk/jx936D+ldfonhqGy0GVI5ZJjHgNI4\n\
4Le36V7OBxVDBaXsm1da991006+R52MwNasuZx2T10+7vqdz4QvY49b1oORvZTNGPVCScj8xT/Bc\n\
kdvouo+ILxt1xcEyO5PQYBwPYZA/4D715l/wkMOn3UW6eOO4t+FV22HHQxtnqvoR0rqdN1OKbwJq\n\
OnxttaJ16Hkxtgf0Ir2asJe9bRvlj8r2f6Hgxa0+bNvw/dRaVpFx4h1JWlvryQ+VH/EzHsPTHA/A\n\
0mn6Pe+LLpr7V5sWisQIwSUXHZR39yao6gjahqGkWcH8FtGqj+68nzM35fzr0G6lttE0g5Oy2tYs\n\
k+wH86vE1I4ePtEveei8ktNPMUE5uz26+pm6rf6b4V09RbQDzpDshiTl5W+voOpPQCsjwvolxq16\n\
2ta6fMZvuLj5SOyqP7o/U1R0Gwn8T65Jf35YQqBuXtEhwRCPc4yx/wDrV2XiPU00jR5p0Qfu1CxR\n\
r3Y8KB+OKwnKWHXva1ZfhfovPuWrT/wo4/x7q63t+NPj/wCPazYPKR0aTHyr+HX64rZ8A6P9nt21\n\
S6X9/OMRA/wp6/U/yrlPC+lHVtXSC4Yuqkz3L/3jnkfiePoK9WkYKoVRgAYArbFTWEoKgt3qyKa9\n\
pLnfyGTSda5DxX4jFiTZWWJNQdcjusQ/vN/Qd6k8WeIxp7CzsQsuoyLuwT8sK/33/oOp/M1547iE\n\
OS7SSyHdJI3LO3qa48Bl7xcva1fg/P8A4BpWrezXLHcXlWKRmSe4mbLMeXlc/wCeleo+DvD39iWz\n\
TXW176YfMR/Av90f1rO8C+GTZrHqmoKRdMp8uJhjywe59yPyrsHauzMMYrexpbL+rGdCl9qW412r\n\
pbH/AI84f90Vycr11en82MH+4KwyiXNVn6fqbVVoiWf/AFMn+6f5V4qE+c/Wvapv9S/+6a8eVPnb\n\
61Wcq8ofP9B0OoRJVuJKSJKtxR15MYmrYsaVm+JNftdBtN0hEl0w/dQg8k+p9BVHxT4rt9GVra12\n\
z6gRjaDlYj6t7+1eYzyz3929xdSNLNIcszV7GCy91PfqaR/M5q1dR0juS6lf3WsXzXV6+524AHRR\n\
6AelOgh6U6CDFdDpGjNcASTZjh7cct9P8a92c4UIXlokcSUpvTcg0jS5Lx/lG2MfeY03xXr6W8Um\n\
j6UMYGyaQdvVR7+pq34r15NJgGm6cMXTLyy9Igf5sa5bRtO3YmnBKZ4B/jNcXtPar29bSC2Xfzf6\n\
I2ty+5Hcl0XSwVWacfu/4V7t/wDWqlrlyL7VxGMGCyGNo6GQ9APYV0Wq3P8AZ+lz3b43gbYx/tHg\n\
CuGbdDbpEH2yyAzSyZ5GemBjJY9h71zqrPEJ1notl+r+4vlUPd+8kmPnSyybv3dsp+Y/xSHBP5D+\n\
dEmrypbN5TRwtG2FkIGQxGOB6kYFQKHlRInQ21tg4V+HcDkhVPPuWOAKgk1EWkkCpYwSR3BCo7nd\n\
IMtkMAOmcnr2I9M0e6qdmrrt5dfmy4Xc9HY7ebwrPp3hSG6020ub66faZHl44J7DPA561lRWci3D\n\
peCS0dDtaZAcBvf1HvXrP/CQSQeGNPtrsMpC7SkP35AMYA7AnI+g5rP1HS2TQ5r3VgsdzetHDbWi\n\
8iIbs9TyxIySayw37qEZxm5Ke10r+89F527W+ZpiJKUnFxs12fY4S48LyOyy3txLdpjKAH5W981j\n\
304Nw9tZFDMgw0g/1cC/4+1bGtxXNtFJbW93MluT/q1cgVz02LWNbW2VSwG45OFz3Zj6D/PWuivS\n\
nCzqPm7LZerOeE1LRIy9ddIbbyovljjUKMnkknqffvXXfD/w9PaWRv8AWZ/9BuQohiXJdmJwMf4V\n\
yH9nnXLsWlrK7QxnLzbeWY9Wx6D0r0ueCLQrLSbWbUC8FujMzJJtlY4PyoOxONoJIxkntXBjrVJ0\n\
8M38Wr0d2l+WtlffXTy7sNenCda22i9f17mLPpthpmqXNrp9lcyXDSlwzSYwGyNr56DgmptC1Vxp\n\
ktrcbGN0V+VCSq7Tzk9/Sum0LRjqOn3Wo30FhZWO0MZp4yyxpjO1EJA75LMSTnJxwKrWujQw2q3z\n\
blF23lWyOAG8peWcgfdzjp2+tddGmo1HCT7NrfXTTr2vv3Zy1KnNG9jc8MaY2q3sSOcx8T3DH07L\n\
+QA/CvR7+6jt4XkldY4kGWYnAAFZfhKyFjpAnbHm3X70+y9h+Vcj4j1oay7xwSD+yY2wWH/L2w64\n\
P/PMHHP8Rz2HPPi+fG1/YUtl+Hdip2pQ5pbsqavqrarcreNlbKPP2aM8Fj/z0I/l9c10fgrQWMi6\n\
rqCc4zBGw/8AHj/Ss7wxow1OQ6lqW1NOiyRvOBIR6/7I71L4g8Uyakj22jSNb2I+U3QHzS9iI/Rf\n\
9r8vWuyUfZwWEwq9X/n5/wDDGa1ftahs+IPFcFlcSWdkhu71eGAOI4j/ALbdvoMmuFu5pbq4+06l\n\
Mbm4ByM8JH/ur/XrUO9IIhHENqDt/U+pqjPcdea6sNgadD3t5d/8jOpWlPToWbi6681c8P6Be+IJ\n\
iY8w2g+9Ow4Psvqa1PCng6XUPLvdVBitT8yQ/wAUg9/QV6REkdvCkUCLHEgwqqMACsMZmMaXuU9X\n\
+RdKg5ayKuj6XaaNaC3so8D+Jzyzn1Jq0X5prtUDSfMK+bq13J3b1O6MbKyOzT7i/SsPx3CLjwZr\n\
ULcLJaSKT6ZU1uJ9xfpWb4mtzd+HtRt1dIzLAyB3GQuR1NfW1Fem15foc0XyyTPnHToZdIbydEeW\n\
4kuYwBbRx5Ct2bd7VvNbXFlYD+2rbU47dRkrZSIEXuWYKdx+tTReEbvSw5tJbTUEI/1ZkkgYnvg7\n\
iKzZI9Lmka2SO70TVY85Tzi2ffk4YV8/hqNOhD3ZX2vLd/O23rZnVia8687yVuyON8bSJJFJHbXM\n\
lxC0ReGV+WVTwVJ7joa1Phd4XvDYfbbxlMcqllKknHoD+tczqWnT3t5LbpcwWsbSGOaRx8q84O09\n\
snJ49a9Z8NWaaHokVpDdi6jAz5g6NXFxDi/Y0I0b6vy6fl/XQ7Moo883PoiV7H+0tImtJPmktzgZ\n\
/u153qmk6hbb4YLiVIj/AAg8D6elereEi1xrFygXKPESxx0x0p+saVH5pyK9rh+s8TgIe11auvu2\n\
PPzWmqWJlyddTx7S/DghjmmlyTtJJPU13fgtkt4AjKCDxgjg1DrskMCmygwZD/rCP4faodOYwgV8\n\
/wAT4qNWoqVN/D+Z6uUUXCHPNb/kd7Lejydq4VQOg4rL0/XYYodVijb/AEp9oXnqvPH51QS9jZNs\n\
jgZ4GTiub1LR00TW7j7DdyXOoXoXyxEwIj5OSB7kEZ6cE9q4OH4VqmLVdq/J92t1+WvyOjNJQjQd\n\
O9ub9NTtJIrzVnbRtIbyrGA4vbsEjzpOpUEdvX8q17bwrpFrCiTB5io6btq/gBWVpfhTUjp0UN5q\n\
b2VuoyLaDI5zkliCCSTk5J79B0qGXwla+YRaeIJFmJJwzkkn8G/xr6qpVcbwhVUX13bb82vy6Hzs\n\
Y31cbjNf8I2ksJbSJ2jkA/1Urblb8eoNcnbk6sXs7wtFqtqCI5W6sB/C3r9a072+1fw5crDqzefb\n\
scLOOcj1BA59wQD9axPEF2q63ZahbEHz1KuVPXA4P5fyrSnVrpctR3dm4yXl0v59mJxhvH5o1dFv\n\
IrmU2mpIY7iI7Sw+8pruLLRvMiDJqX7vsGXnFeVa3qCDVbKePiSSM7z64PFdhpusMLIc9vWtqmV4\n\
PMoxr1qfvPtp+RVPHV8LeFOWn3kniTwzp95qELyyyXktvmUA8KgHO4+1c7o8G8JAo2i5iHkluhIJ\n\
I/PGPxrttNm8zwZq1ymDcS+YpJ7ALwP1P51hNpian4QtZLR8XNoWQc4J5yPp2IrGlGhg3OFKPLFN\n\
Lq7Xu769L/qFSpVxFnUd3uUNM8QnRhNY6jHIbQsSMD5om7jHpVbVrzR7tTIt7bFT2c4P4g1BNq9v\n\
KPs/iG3ZZkG37SqnJ/3gOfxGay7tNAIMkdxaEdRvc5/I1VanTnL2kotS7x1T80yISaXKmreZk3km\n\
mPK6wQm5IPJjJCj6seKqQTW4ubeG0hj8+diirEcscDruPQVLeSpdJttMraqcNOybI0/3R/Efaq/h\n\
y5uP+EgtbzTbVjZwNiOUqcSdic46Uq1adKlKTdtHa78v60NKVNVKijb1sSRadfXWn3t5b2cgiik8\n\
hBP8gVupbb1P1PrXfeE7tl8Ppp91GjBF2BguMitu5uhe25DIF3cke9ZawiI/KMV8TjM1ljqfs5xS\n\
s7rufSYfBRw0uaLvdaiP4b0/UZtOiffHDbApHDGdoJY9T/OuR1zwtqqeIhBO6m2jlB+UY3AHjNe3\n\
+EdBW3to9RvgfObmOM/wj1pNXtopbkyEAtnNfXcO4GtSoe0xDvzaxT6Lv87niZriKcqqjSW27/rs\n\
cGl8YoJLC7PmRINuG549K5C4ivb+/vE0u18myt1MjzXDYBOOAPetu+ctqtxvG0lyMVJqgv002OKy\n\
02O6hlcb2d9uzHf+dfNUaqwuLlGlopO2vRc3TzsevVp+2oL2mtlf1djHtEP2ZRM5RQyhZs8JIRkZ\n\
PYHBIPaugXxJLap5GuwSF14FxGud3uR/hWXpV5EjX9vqkYjtp8K3cRtyVJP5imNdXFnH5BEd9aYx\n\
H8wDAex6Ee1fX1mpJQqRv26fc+j8nufOR0d4s6HQ10+/8Q6dLZXMLuLiMkA8/eHUdaK57w4babxX\n\
pJjsLqOX7XGRm3Ix8w5yOKK6MInCLim7edv8xSs3c9U1Jc6td/8AXVv50bkhieWVgkaAszE4AA71\n\
PqK/8TW7P/TVv515r478QfbZTplkwNvG3711P32Hb6CvHw+GlXquK2vr95vUqKEbsoeLdefXb7y4\n\
Sw0+I/u1IxuP94+/9KXRdL8zbLMMR9l/vf8A1qj0XTN2JZl+Xsv97/61dXbRZxxXoYzGRw8fq+H3\n\
6vt/wfyMKVJ1HzzJraLpxxV+WaGxtJbq6YJDEu5if5fU0sEYVdzEBQMknoBXBeLtabWbxLGwJa0j\n\
bqvPmt6/T0rzsHhXXnbp1ZtVqKCuZ5lm17WZLu44DHO3PCIOij/PWty8vYdKsjPLgt0jjHVj2Aqo\n\
pg0XTt85G89VB5duyj1rnprp2uXu7wF7ztGPu269h6A16Na1aS/kjovP+u/+ZjC8V5suWkU01293\n\
dEteS846iIdgP88VqXeow6RAEXEl44xHEvJz2J9BWBHLdXGUjuEiTuIPmf8AFqtQQ22noZJWSDP3\n\
ndsu39axlyynzVNX0ivyKWisiS1Q2MNzfX7brlgXcnnHt9c1W0tzbWU88xIPls7/AFOf8RUd7ci6\n\
8t5U8ixjO6NZOGmbscelQsz3DKHRhErbhGwwXb+83oB6VpUvLWp5X8ktkvP+mJabGjCTF4chm+7c\n\
WjI0bDqAxAK/Q5H5Vnm3hi1fzCimESKNuOFDcgfnkflVmSf7XEtjAxZN4e4nHKqAc7c9zmqgmSZb\n\
+X7sTodp9lGAfz/lVJXh+8XxX+5tW/VoE3GV49D1XSl0u/WP7SZH2DHkMQFH4DtXTxzRJGkcCJHE\n\
gwqKMAD0AryfQbpptISUnEsQBz6iuu0nUTIg3HNfE5vha2XVnC/Mnqn1t5n1ODxSxlNN6W0t0+Rt\n\
XWgaRezmea1VZmOWeM7C31x1qTUYLeLSmtbaJI4QDhQP19zTYp8jrT2IkUhuhry/rKnGx1uElpfQ\n\
8P1drLStciu9ThE6RPuRJORkdK0dI1Rbu2nnhhkhhkdo49wKqQedq9sDCn8PevRNb8M6LewefqMW\n\
7ysvnOPqD7Vz97eW17ctbRtALWzcbAvZC6DP5bifwr7LK8SsQ24J6Wu276dLa73+VvkfP4+l7OK5\n\
ut7f12/rudFpDL/wlGiOjZSS3icH/gBU/wAqu/EW9Ml1bacpJjA8+ZQfvYOEU/jz+Fc8JTZxWVwP\n\
v6ZeGB++Yy25T9Oa2plGpfEErzs8yMe2FQN/M168VGrVhN7RTf3ar80eU7xi13sdpoVkNL0WCDH7\n\
0jzJT6uev+H4Vw/jnUTcapHaIw8q1XzZMd3OQo/AZP5V3esXaWlncXEhASJGc/QDNeb+GLJ9Y1yJ\n\
boEmRzdXHt6L/wCgrXLgl7fEyxFTaGvz6F1fdgoR6ndeDNM/s3RleRcXNx+8c9wOw/KqnjHxB/ZM\n\
CwWqiXUbgHyUP3VA6u3ooyPqeBWr4j1eDRtOe5mBbHyxxr1dj0UV5Jc3E08811eMGu5zukI7Dso9\n\
h/jV0MPLH1nUqfD/AFoKc1Sjyrcjkfyw7NI0ssh3yyv96Rv7x/zx0Fdd4B8OG6kTVdQQ+Sp3W6H+\n\
Ij+I+3pWR4Q0B9dv/MnDDT4j+8bpvP8AdH9a9aO1FCoAqgYAHau7MMWqUfY0/wDhjKjS5nzSB2qv\n\
K+KdI2BVSZ6+YqzO+MRkr/NXaaYc6fbn/YFcDNIFBZiABySewrudCnjudGspoHDxSRKysOhGK9HI\n\
3erP0/UnEKyRbl/1T/7prydU/eN9TXrMv+rf6GvJtQu7bTYJLi9lWKJSeT3PoPU13ZpBzlBLz/Qy\n\
pOyZaRQqlmICjkkngVw/inxoSXs9EfA6PdD+Sf41geJvEtzrkvlQ74bFekecF/dv8KzLe2PHFb4P\n\
LVC06u/Ywq4i+kSOKJncsxLMxySTkk1o2tqzuFRSzHoAK0bDSZJCC48tPfqfpXSWNnHAuIkx6nua\n\
3xOY0qHux1l/W5FOhKer0RT0rR1iIe4AZx0TqB9af4n1tNFswI9r3sgxGh7D+8fYVf1XULfRrB7q\n\
4IJ6Rx55kb0FeZsbnWdTkubg7pJWyfRR2A9hXDh4Txk/bV37q+7+u5tNqkuWG4abaPeXDTXLM2Tu\n\
dzyWJrq7SDeV4wBwB6CobO2CosaD5V6e/vUmualHo9gdjA3kgxEncf7R9hWGIrSxlVQh8K2/z/ro\n\
VCCpRu9zB8V3K3uqQadEf3Nsd0pH9/8A+sP5msSxinvblDakKZ2LuxbC+X0Ab2AA4HrVy2tmt9Fv\n\
buXcZZI2we+O5/E/1qtZyi3exV1BRgUYe20V31LU4exh00+drszi7vmZBd29vBYzGNLW4uJD88Ns\n\
p+UDs2fvDOT6VY+GMN1qPjAX89k4sreMqu8ZGcHBPvnnjpgelXtP1Q6a08sar5hzD5oAztHb9aj8\n\
L+PltZXsRAD5sowwHQ556djXl46Ff2EqcPevpfW6T/B28tX1PQwkqPtVJ6W1+a/zPSLWWAeJbvUt\n\
QQm00+EGJDzljxwPUk4+grV07Tb3xDdnVNakaC2GRHEG4RfQe/q34CuZ8MF9c8SPBPlLaJlMg6ZK\n\
qev/AI9+JFdHqM83irUf7O04bdJtyAzDhZCOOfVR6dzXfOPI4xppJpaPpGPf1f8AW5wNuV3PW7+9\n\
jNau/Cs9tLZw2AnVRtM9vDkqfZ+5/GvGtd0RpbqWG1mkmiIzGANhc9lcdsV7Pfy6To7m0trNNSvI\n\
xiSSUgRRcfd9Af8AZHNclrSw3aeYbCCFwM77YsuPz4IrSjTco+7zNPq7feluS5WetjndJ1e08F+I\n\
bC3sYoLsvtVyEOMntitG+EWq6/cXzW8cc0rMWVgOpDKMj8BVBnW2SWe3XyJjjfKgyAexz1Wqem2k\n\
V7DavatqP2vJG+QnErbshh/n37Vz89WnLlk2/XdPr0WnodD5KkbrR/h+p6ppip4nuLG1DFtJsokk\n\
kXPEkpAZs/QkAe+49qk8sa/4rZI8Cxg/dLt4VUX7/HTk8fhWPoMr6R4PgsrI/wCm6gSwkTnbDk/P\n\
+JLY9TStMkNh/Ztmxjt/+XqVD/rMdIg3t/EfXNdEKcnUbh0ul6veXy2/A5nJJWf9dkanijXTqjyW\n\
di7RaVESkkiHabgjgovonYnv0FUtE04anI11ekQaPajMshO1cAcKP0+g/Co9H0yTW7oxxkQWMI/e\n\
y9FRR2Hvin6xqcep+TBaI0Wi2oAt4j/y3I/5aMO49M9evpW8Kaor2FH4nu/19eyIb5vfnt0F1vV2\n\
1lFhjT7Po0ePJtgNplA6M4/u+i/iaybif3ptzN15rOlkaRwkYLOxwFAySa7KVKNKPLEylJyd2Omm\n\
LEKoLMTgAdSa7/wZ4PWARahrCEz53xwN0T0LD19u1WvA3hVdNjS/1FN1+wyiH/lkP/iv5V1zNXj4\n\
7MN6dJ/M6qNC3vSFZqhdqHbFVpJK+fnUOxIWWSqxk+cU2V6zNT1KHTrczzk4Bwqryzt2UDua5m3J\n\
2WrNUkldnqUf+rX6Cs/xL9l/4R/UP7QANp5DeaD0K45q/A26CNsEZUHB7cVS8QWq3uiX1s7lFlhZ\n\
Cw6jIr7yWkHd20POPIT4WtZIvN0LU7i1Lcqvmkp+GP8AA1yviSK9gK2evqXxzBeIPnQ+oYfeHqOD\n\
7VZlj1TwjebXBls3PBX7j/T+6faujh1Kz1vTnhmxLC4wyHqp/oa8Rzlh5KVRKUHtJb/15Pc1SU1a\n\
Oj7HjOqWd3LLcIkdvLO3H7zO1zjIb3B2jrxz7V3tvqltYabY2EskQ1AxgyRR9FPfGOMCsu9sZNO1\n\
N7NsMwDPau3SVO6Z9/0P1rKS7itdRkuUYiQps2S/wjPzbvcc4+tc+Z4GGMhZa2V49P69P8jpwWKe\n\
Hl2T3PWvhxe241C8WVlEjRfLn2PNY3xG8XJpis0QYBgVSTBwTnHBrzXQdVurrxHNLZ3MYs1VtrO2\n\
CT0AA7811jC21Kzjn1CS4kBO2EyYVGde4B5bnsBgACtcqlLC4Z4drW776XX5pix9qlZVen+X6Edl\n\
Zz+Sks6sC6hzu68+tbGnQ2V3Z3pkuxC8MZKAdWbsK5tZdShfUPOmnD3squpuAV2IOy59aytL06f+\n\
0NSlYm3MkuxEmYqoGc5IPbHevFhlMoVlLE6xvsr6379V/wAA9GWPjKm1S0di3dqdS0C3e5mMMsE+\n\
6WeF/l2Bum7pnA/Out8NSTreT3OlWqFySsVxfPsWMHq5zyxwAAB0C+9WdL0C71p4NrSR2MS4+1SL\n\
tU+0Kdl/2uprpE8J6BBHsmkZ37sXAJr2oQwuFi1e1+m+7vr/AMPtoeTUrVa+6uV4vDn9pZfWdda9\n\
c8mOM/u1PsucfmCfequoeBLMxf6BcxBx0WaFcH8QOKlv/Bulzgvpt08EgHXO4fmMGuebU9T8P3Yt\n\
NXLvATiOc8j8+4/lVxrVLc2Fmml9myT+7r99zPkjtUXzuUJLm4tZpdH1gP5DYUxytu8o/wALofSv\n\
P9fvWsYlWY7jbyPGoz1PTiu98dXqXUOn3K4MyTeVkd1YZ/mP1rhbq5iivmubpFkVbkzBXGQcYH+N\n\
dkZxqUueK1fTbXb5XuQo2lZv/hhmi+ZdTi61CUAkYC8/KPQV3en3Fq0QjWdd2OM8VzOt+JrTUNsk\n\
cMcIUYwg61Hpt8sp+eGURn+IrkfpXnrN8TTinKmo26Xf5nof2fSm7Rk35naabqkuj3ckFxzp918s\n\
oPRD03f406w1B/D+oOkxMlhLw+3kFf4XH0qlCpNth/31s/Rgc7fcGqk8dxpa7HjNxYMdwTuPdT2+\n\
ld2Gr0cepTprVq0o9fJr9H18mcVehUwzUZbdGdNqNvaanD51pJFPGe4wfzFcZrVva6epkuPIX0XY\n\
pZvoKjkj0qZ98d+bVvSVCpH41Qnn0jTmLW8hurns6jdj6f41CwkabtGUvSzX/AJ9o5bpGTq8032c\n\
vOWErDYqk8xqf4R6EjrXo3h/W0j0uHTpEQpGgCnbjAx0rziKCW+u/tN0CkKcqp7f4mtizdwxkPy5\n\
/QVw5zhIVKEaU/ibuvJHfl1SVObmtrHoUFzEzYyKv2lqs1/aocFHcZ9xXj9zr1yhMySmC2U4DAZL\n\
f59K9T8A35vLS3ubwhljbcHA25UjuOx/+tXzFXLOScHG7Tkl97R7MMVdSUrXSbPTPEGpRWY8sNgI\n\
No59K4i612NpDhxVhNY06e5eeW3uNUu2JPlwRGRIh2BxxmsHxXe6bqKsk1jNpd8f9VJJCY9xHb0P\n\
pX6HLGxhPk5HbvbT/hj5FUnJXvqc54mEn2+SS2PMo3Lj1qvo03iJNF1I3gaG3RcRux+8CQCMfjVb\n\
TtajdUhuSBOku3B6gjrXoUlzHdeGrsqqvMhXCHn5Rz0r52tS9nmkaFOKak+a/bd2X9dT2adTmwbq\n\
Sbula34f16HEySxnTov36R38W4yB8FZ0Y55HcZ/KuYuxBcCWTy7CCJDmSRV3Y57DFbGsyweWzWs8\n\
IhGW8mdAxhPfGelcXcwy65eLaWhkKs21pm4B9lA4A6V6smlzS2S3v0/r5+R5sYuTUUdd8N7ifUPH\n\
VibKIx2gljKvNDjeAw4GMYor1bwbpciXWlLeGRktNkasylTIQeOPQUVyYDGOu6jjayaS+49LF4Sn\n\
QjBa3au/Xt8iv8Ttb/s17q1tnxeXDsBjqiZ5P9K8/wBD0/eRLKv7sdB6mrWvrNqfjTVZLliwW5kU\n\
n0UMQB+lbNlFnaFGFHAHpXXiKn1On7Kn8ctW+39dPvPLivay5nsi1axZxxWvbxBELOQqqMkk4AFZ\n\
N9qdlpEO+7k/eEZWJeWb6CuU1HU9R8ROYkXyLEH/AFYPH1Zu/wBK4MPgpVPelpHuzadVR0W5d8U+\n\
JDqX+gaUW+ynh5AMGX2Ht/Oq0EEOh2T3l7nzFGMLyQT2Huf0qWCG10a0e5lbJUcyEc59FHrWPJLc\n\
X12lxcLsZeYIOoi/2m9W/lXourTjT5KWkOr6vyX+Zhytvmlv+RU1G+m8/wC1XgWO6I/dRk5+zp9P\n\
75q3oNq1+xQzw28VjGbhwEdmJOeGPQkfXvWawSaYzYEgLARhjjcN2C5PYZyc/wCyKsag19o17BDe\n\
XsMB+69nAPk25ypJB+YkHOcd648ZVkockHyytovTp+nqzqwtNSlzSV49QZ4rz97DE0sT5KtNbsuR\n\
kjIOOenbNVopU+0eXZwW5n7eUhkYfi3A+tdPretNcaNAlssYhQDbt6Age3515vrWrXMqywwJOpk+\n\
Uu8xfA9FACgE+pzxTweIlWp8z93e6vtr/l2DEYf2c+WOq7nT6Z/xM9VFvb3Efn+W00tzMWbCjHCn\n\
gc56jApjw25lkQxrI6k5VpcH6kMwz+tVvClpqt5aQXd28qQ8QQyTDK4HRfUD8cUa3aSxSlbiAgDu\n\
cMP1pTrOjW5K91dK39dfzXzLjh1Vpc1J3s9f66fqTXd1HFGsU08Nrb4xsSRS5HoAuQv1PNUmuJL8\n\
i3tEKwtgM23HA6KB6Uyxsk4baqKf4mjGPzHFdZYaVdIAUYJn+6o/nVvH4Wj78ru3T9XqJYKrLQt2\n\
UYsdMMT/AOskGAvt61saRlQKp2ulSBt0hLN3JrbtLbZgYr5LOMyWOqc1rJaI9vAYR4eHKa9rIdoz\n\
VrzMDNUoRgU25eURO0UUjqv3iozivnYwcpWieo2krsbqSrqUD2jS+Wsg2kjtXCeJ9Mg8KWEVrpqz\n\
3m8lnLMdzMf8OmPesvxJ4lu7TUIo4JDHufG7bk/QD8a7TSrmK+0mb+0ZI0uo4w6TY4IIOGx65GCP\n\
X9PqaFOtgFCpT1Unt0batv8AM8ipyYpSjPRr70rnO21/PE15bXaSeV9nVZXwWXJGQoOOSK9D8DF5\n\
/ExlcjcLcM3/AHwgrhkWXV7SX7W0LvDGrOwiAJPQHr1J4GPQ16L4OtFtvEeogkr9mhSMg/7q5/lX\n\
1FGUo0J+1+K3T5HgVVB1F7Pa4vxEvgy2+mqw/enzphn/AJZoRx/wJto+ma1PA9gLHRnvrj5Zbr94\n\
S3ZB0/qfxrkreOTxH4oZ8ZS5lHT+G3TOOfflv+Biuj+Imqi3s4tJtjskuR85U48uIYz+fC/jRGjK\n\
lRhh4/FPV/16EcycnUeyOS8R6wda1M3Kk/YocpbKf4vWT8eg9qzdOsZ9Y1OKytR878luyL3Y1BdS\n\
BVwoAAGAB2HpXqPgLQ/7I0sz3Cj7bc4Z/VV7L/U//Wr06s4YGhyx+Xr3OeKdad2bum2UOmafDZ2w\n\
xHEuM9ye5Puae7U52qvK9fK1qjk22ejGPRDJXqlK9SSvWRrWpQ6bYy3NwflXoo6s3ZR7muKTcnyr\n\
dm6SSuzC8Y6iSq6Zbswlm+aZl42R9+fU9K9d8JhV8M6YqAKot0AA7DFfPrSyyTS3N1j7TO2+TH8P\n\
oo9gOPzNfQXhI58M6Wf+ndP5V9ngMGsJQUX8T1f9eR5s6vtajfQ0rltlvK+M7UJx+FfJut6rd67f\n\
vNcsRGGPlxA/Kg9vf3r6wvBm0nHqjfyr5jsNNWJ8ygM+fu9h9a2rVqVBe0qb9O/yJcZT92JS0/TJ\n\
JAGxhf7xrpLGxjhA2rub+8RU1vATjI9h7VqW9v04rwsTmFbEe7H3Y/1uzop0Iw1erGQQdM1NfXVt\n\
pVk91eNtjXgAdWPYAetV9X1iy0WEm4cPPj5YFPzN/gPevPNV1K8128Et0QI14jiX7qD+p96vBYCV\n\
Z80tI/1sKrWUNFuN1fULjXtS8+ZdqD5Y4x0Uf41u6bYfZ4hHj94fvkdvak0XTPs6rM4/ekfKMfd9\n\
6rat4jisWNtpqrcXXQv1VD/U124qTq/7Lh1ot/8AL/Mxprl/eTNPU9UtdFgUzfPOw+SFTyfc+grl\n\
raC51O9+36iQwc8Kf4gP4QOwpLTTXkuDc6izT3LncVJ7+/8AhXRQQrFG1xdOEjQZLHgACuf2kMKu\n\
SjrN7vt6GlnU1lojN8TnytG2tgSXEioqgdhycewwPzrm9SLQyQoAd8aZK47tgAe3StC/vl1S+e8m\n\
3RadaL8ufTPX/eY/54rKnuGiM10VAvXIk2nhIl7Ke+cH9a64UfZ01Ge+rfz0I5uaTaI4ZmlUKWzF\n\
E+6WQfd38/KD0Jyf0rq/hnd6FZWUxbykvvMMme8vJA/LnishvDWqXrqli8V5cyRgxyRylkjVhzsU\n\
cZ7Z/Sm6L4Qi03XIpNcvvsYt8MFY480+n19q8zMFTr4Lm5vdv079mvla3/DnoYLno4i1tbdfzOl0\n\
7VYI7+8WxlLXFwzwthvmBbufw3fnXoeoT/2BoltpOmEJqVygLY5aNehYD2yAPc1wdg9i+rwao8ME\n\
UcU/McK4LEKfTqcYGf8AarbF7dve3F0ZPLv5xueUYP2dOgVf9rGQPxPpXo+zlXsmvVem0b9v0PPk\n\
1Buz/rubun2+jeH9seqnz7/AcWkaNM0ef4mAzyfVqv3Hi+2AIWxl29Bkxj9N1ZXhzw5JqUXmBja6\n\
fuyWHLzN3OT1P+0c11cem6PpMLSLbQKFGWlm+Y/XJ6fhWGNdCL/fSbfZaJDpc7+FWXmeb68mn6vI\n\
01haXcF2w2nyoQyvnswB5rm4dKv7O5liNv5VyysrNIdrRRsD/CM7Nw4/vEE49a9H1TxVd6kDb6Kr\n\
QwyHaLgDMkn/AFzXt/vH8AaeumxeF9OW9niSbUpH/wBGtyxI80/xuTyxA5JPTH0rSguWKlUT12Td\n\
2/wWnqEm22o/8AwJrSSwJgabGoOitcPgboEIwox/CxHCr/COeppunWM2rXkdjYIEjUAFgPljX1NQ\n\
yea0i28bPc3U8m53P3pZG6sfT6dgAOgrvYIYPB3hmWeQLJdkZcjrI56KPYV21q31aC/me39dl+LM\n\
IR9o/JGJ4ouYrW1j8O6Y2IYlBvJF4LccJn1bqfauZuZetSOzKHaUgzysZJWHd2OTWbcy4zW+Ho+y\n\
hZ7vf1InPmfkRXMtehfD/wAMtagapqMeJ3H7mNhygPc+5rH+Hvh7+0br+0r1M2kJxGrfxv6/QV6e\n\
7V5uZYzlvSh8/wDI6KFL7TEZqidsUO1V5Hr52cztSEkeqsj0sj1RvbqK2t5J7iRY4YwWZ2OABXLK\n\
VzZKw2+u4rW3lnuHEcUalmYngCuKe4l1HUUvrlSiL/x7Qt/Ap/iI/vH9KS/vJNYmSe4Vo7JDugt3\n\
GCx7SOP1C9up56QtLmVee9fT5Tlfsf39Ze90Xb/g/kedisTz+5HY+iLf/j3i/wB0fyql4inNroV/\n\
OqbzHCzBc4zx61dtv+PaL/cH8qz/ABRBLdeHdRgtwGmkgZUBOMnFevJJpqWwtVseZWeuaZqsZs7z\n\
CGQYMNxhd3+6eh/A1zmt+Er3TJ2vNEaSWEclV5dB6EfxD9awbjzrSZ7a/gaNxw0ci9f8a1tH1690\n\
4qLW4Lwj/lhOSy/8BPVf1HtXnrAzopug+aL+y9n8xe2U/jVn3RSurqLWrBIJiLfUIzut3J+UuO27\n\
tnpg1yWrxxSXbPfwFXQqLi3ZMkt7gckY9OuK9MuV0PxJITKDpWpycfNgxTH37H9D7Vjaxot7ppjG\n\
q2xuLdOI51kOVH+zIMkfRgRWUaMX+7jdPXR769n1Xzui1NpqW/n/AJmHHpsdvqJPhu3nWS6QRrAk\n\
TAHjkqD29+gziu20nR9b0q0N1cJpVjOqbPtV44kaNQOFXB2qOvHc9az9CmtoQ0cGv3mlCQbWL2sJ\n\
J9P3oXn8a6q18KaTdstxdaldajL1WR5d2PoDnH4Yrm5I4WKpzaXdtSbfTyX4ms6kq0ub/KyMDUbx\n\
71QkviEXUZ6i307ch/4GflI+hrJj0zTkuEuDc3qzLj5lhh4P0DV6avh/RAPmtBIT1MkjMf501vDu\n\
gsCDYRjPcMwP86unjMJTVlf7l/wTN06r/pnHwLol2oTUvEGpq+etxujT25Py/rWt/wAIPpUkJaG8\n\
kYtyHYK4PvnvU974J0+Xc1hdXFq56Aneg/A8/rXLXml614VYzWzYturPAN0R/wB5O31GPrVqaq/7\n\
rUs+zSX42FZx/iR08i9feCb22/eabPHMV5ARjC/4c4NYU2pyTQzaVru50+7vkX95C3Yn1+tdLo3i\n\
1bxhFMBDcdlDZVvof6VD4yso9YsWuYFUX8Ckq3eRR1U/0qKeKbqeyxUbS77Nf8AqVNcvNTd12PKd\n\
WlngVbacfvbSbGM9TggfXrn6c1yesSG4nSwtD9puWcD9z8wHtnoST+FdpdrFeTWstwXeGRNkio2C\n\
xTtn12kflTby/wBNtLyG7AiF9K5yyLhcD7vB68dTWtacqD92N972e3ff5/gVQhGo7SlYxV8MX9lo\n\
wvplHKgxj0ycZrZ8K+Gru1tJtSuJU3k4iAYbmPGAee5JHSu10/Uk1axQ3EalGUAqRkY/wq3bxafY\n\
hXgt0R16HcTj6Ak4riwOa4SnGp7ZXbb3tt2f9ant4vIMTWlSlQmkklfffuv60JNDsUW+vbFRuhKm\n\
VPbnB/Pio54ls3e3uwWtT0OMlK2fCVs8jXOpyghHXyos9x3NN12JJEOa+Qji6mCrxr0Xb/LzPVxl\n\
ClXcqbWn6nF6noNrLmSKWFkPfeKw2sbG3b7wdvRBn9elbGoW6KxJxiq9rbo74UA19VHiGvWh+7pq\n\
/fU+deV0qcvekzOFu9wQNmyIdFH9adqUIg06QEfNL+6UfXr+ma7Cy0dpUBC5rlPFRaHXoraUFUiU\n\
Fc9CT1P9PwrzvrM6kpSqO8md1OjFNRStFC2On6YNMZtXbyrePDmTONpHT6/SupmuLWbRxBY3Aigu\n\
WC+a79IuMnPTpVPT47GZfs+or/o4iMjKQCGxjg57dfyp1hZHxLfWEdkY7ewt0LbmXiFRjkE9Tx1P\n\
c+1bZXKpWtd2jCXNrts7ed09e3zHm3sqGkEnKUbXV77/AHW6bX+R1dsLm4tYYLC8h0HRAu2Bmwk9\n\
x/t4PIB7dzkGsTxhps9np8zrqTahZ7cyxyEkgf3hknkeoxWjnw8sjxaXok+tzZKyXLEnee/zHlvw\n\
z0rl/EVulmri1sLzSVkBHkSMXgcHsAQCp9+R617kVNy5oL746vzvfm/BI+ebVrP8/wCkcR4d0CfV\n\
PFqKlxGFGX+Y/fNeyTWUemXEJJBiYeXLzxg968u8IaXcr4ljv9SuksrWMfu1Zhl8HAH1/wAK9M1a\n\
cSxcHK+tfL57iqlHHQlTesbNf11/pH0GW0oVMNJSW9zn/FPgpZLgyqgKNyCO4rKtNIi026tkjA8x\n\
fmI9K9etri0uPCkMzurTIm0juW9K8hjuZZr66nnItpHmkWIMM52jP4DtX0mbYmVbARlSV+e233/n\n\
oeTgaSp4lxm/hudtba95+uaRbQ3E8UwuY9/lwl1I3DKlui0VznhSS8vfF2mS6pIEla4TizQjftOO\n\
cdv6UUZNhFhKHIne7u9/602DHYh16l7bE2rRJb69quSADdSs7Hp941h3OvTT5h0YbEHDXTjj/gOe\n\
tR+NbprrxLqkYBNql3KojzgSsGOST/dHp3NZMV3Kh4W044AeQgD2wBxVSg1NzmryffZf12Oa+lls\n\
aVrpyyymWcvczMcl5Cav3l7baZGqzHfL0SCMcn8O1YT6lPLuT7eqAdUs4st/30en1qBZkhglnh22\n\
8S/fuHPmyH23dM+wzTcHPWtK/ktv69EJO3wouTefcTfadRdQ68pFn5Ifc+pqCSYXCtFbl1gb/WXH\n\
Qt6qnqT60zyDk7ojN/FmR8t/3yeBTZZJEXMhW1ToZGYO+PRVHc0fFK+mm3ZfLdj2RSlLG7doQFWP\n\
5OD8qAADH4ZxVfSY4tX8TTy3UzOIQzAK+N2B6+1XDI4cwWyQwH5RumJZYVBz8w/iPUnPc+1ZVnod\n\
zLrMUVvKgieT53B2rj/OeK01dSMI7trfW/f79eo4+7TlN9F0/A9JvdGjltYZ7B9vmRIxIwQ+VGcj\n\
p1zWFZeGs36S3eH2HIGAB+ldn4esFs7O7jDs0KyKIyfu/d+bb7ZxUN5OkT4HXsB1NfMZrSnga06V\n\
OWjf5/8AD2+R9pllOjjsPTrzjZ2/LS/ztcRtEikshbQ3k8EAbckQUOF+hJrhvEWkX97qxt9RuWd/\n\
+Wch4Vl9R/XvXb/bZYVVpIJ0RuhaNgD+lSpfWd0uJlilHYMoOP8ACu3B8QNOKxK5kla9ldejt9/c\n\
48dw7Sqwawb5G3fd2fyM3Q/DcOnra2/miaWSNjOBgjAHBPp83861fDaLbav/AGa/zW8oJiB/gYc4\n\
Hsan+22trAwgjiiB6lVAzVzwjpk13qS6rOpS2iB8rdwXY9x7VyZzjKOMrKdBW018/wCvyNcBl0sv\n\
wcqeIld3bX+SNaWwVCcAVXeEKOlbdxjJrPvAFgdzgYGa+UqwtI2g9Dmte1GTTLR51iZ0Tk7RmpbX\n\
xcTo9jbKsq/aR5gRQVZ93Td3xWfo/jCC61W50lYg9wBxu6fSm6PcXE1/eXtwy6ZHGg8+5bDPCueE\n\
j/2mx+Ar6vJcP7Cq242klv35vy2/RHiZnV56aV7pv8jm/EVqLW5jvHgDt5gIVo2GDnjg+9TX1reX\n\
Xhxpb2aK0uHlIgSFstsLZwe3J55rsbyzguITJfPbaVaMuVOpSme5cdQ2wnC/rWRqWl2NxA0Vheza\n\
ltwVQ2zhtw6cgY+mRXsV4SqKzdtb7X1Wz7J9H1aPPoYj2T2vpb5PdefddmV/DtrcW2t2dne280Zl\n\
MTTO7bgVXJzkfyrpJtRK6Rfzwkpca1cuFYHpAnBb244H1rnPDum6tf3htrqeVZI9zXc7nPkrj5uR\n\
wDjgDtXRaNYrr2tItuhjslUKo7RwL0A9Cx5/GuvDUm4p13stfvv+Lsl5I5q0lzP2e3Q6rwTp8ema\n\
NLqU6hGlTK5/ghUcfnjP5V5/f30moXU+oTkmS5OVGfux/wAKj8Ofqa7r4i6gsGn2+lW7bWufvhf4\n\
YV+9+BO1fxNedyh55khhXdJIwVVHcnoK6sEnVnLEy66L0MK3upU0b3gHSBqmsm4nTdbWvznPRn7D\n\
+v4V6s5rN8PaWmjaRDaJgyAbpGH8THqauu1eRmGJ9tUbWy2OqjT5I2GSNiqkr1JK9U5XrxqkjqjE\n\
imkABJIAHJJ7V5zq2pnWL4Trn7DAxFsOnmHoZD7dh+fetHxZq32yd9LtWJgT/j7kVuv/AEzH9fbi\n\
sCVwAAMADgAdAK9/Jcvt/tNVen+f+X3nHi6//LuPzGSyc/jX0P4O58LaV/17p/KvmyVyWAHJJr6V\n\
8JxSQeGdLimUrItugZT2OK+hmclLc0rn/j3l/wBw/wAq+f7a2+Yk9M179eEi0nK/e2Nj8q+SXi1K\n\
8kJvNRYg87QxA/IcV5eOoxquLnJRt3OqMnHZXO4u9a0vTBie4V5B/wAs4vmauev/ABjfXBKabEtr\n\
H2YgM/8AgKoW+i26LukkYjuduB+ZqKXVdPtZPJ06za/uB75VfqamhSwsfhvN/h+iIlKo/IjtNPuL\n\
ycsQ8sjHLMxyfqSa0zcaZonNxKs92ORFF82DWFd3l7PGzahfi2txyYLUbRj3I/8Ar1n/AGlISq2t\n\
p5bv9wMN87+/PCj3xmumddTXKnp5f5/5Gap21Nu6v9T1kMWcWNgx5LNt3D3PU/QU21l0nTgBHcxb\n\
x1fqx+g7VUhiS5YtLbyyxxp+8ml3fK/UIN2R29OnpV0xxWbZubZGgYb454IlwR7r2rlnJNckFZdl\n\
ZX+b3NUmtZbj/wC37ZAVsLWW5k7EjA/xqGaO+1Mh9VmENspyIl4x+H9TTzqelxA4uJiR/CsZBNZ1\n\
9cvfQNJMps9KB+dmbDzf7I+vtRRi4awp8vm9X8gk77u5Hc3Uc4zAix6dC2YlPPmuBzI3qB27ZNUp\n\
7ZbixlFxciB5cOxK5ZsngZ7cU66kAZZLmNYYQAIrZuCfTI7L/s9T3qtdaXdard2Vn5ohuLyXJV+N\n\
q8Yz6H2puatKc3ZL+vv6vtsOCbaij2bwVBYeH9CtmsLhWKQkiRjkjIyT+GDxWLf2MettNdT77i5j\n\
/fiFU3Rwr1Bkc8A9CQOmaof8ItcaDo5tDqE8rzzfICoGxACSOPWu1traG8i0PQbXAtJIlu7xk480\n\
HJVGI69GJ+g9a8/Lko4T3ZX5nJ3fXq279LK3y07nXj2/b6qzSS9PI5bw9pk15q1vPekIpQzLEqgA\n\
A87se4ViPoK6HQbE6pqEFvyElJnm7fJ6flgVetV+1XniS6VBiNGjQL0UYCgD04Dfmau/D5E8+9uc\n\
qFSJEB9Aefy4Feoq6hRlKOloq3z/AOBY4HFymr9WdRql9aaPpzSSskFrCuAAOg7AD19q861C7vNe\n\
ukW4jdlkb9xYgcD0MnqfY8Cna3qf9rX7XZ3Nbo2yzi6jg/6zHdieB6Ae9dz4Z0ZNKs1mnUG/lGZG\n\
PJTP8I/r61x0qMcLD6zX1k9l2/4P9bmkpOo+SOyF0TRYNJiE0+2W+Iy0p6L7D0+tcLrmqnVNQlvS\n\
T9njzFag/wB3+J/xP6Cul8b6mUtVsIi3nXfyttP3Y/4j+XFczoenDWNZhtAuLSP5pdvACDt+PStc\n\
A3VcsXWei2/X/JE1tLUonQ+ANHAjOrXafvHOLcMPur3b8f6e9U/HN8bvWIrNT+6swJXHrI33fyHN\n\
d1cSR21uSAqRRL0HAAAryOW5a5827k+/cuZefQ/d/wDHcUYSTxeKdSW0f6QVUqdPlXUq3cnJpNB0\n\
yTXNZis0JCH55XH8KDr/AEH41Uu5OtereB9DGjaQHmUC9uMPKe6jsv4fzzXo4zEewp3W72MKVPnk\n\
btvBFaW0dvboEhjUKqjsBSO1Oc1BI1fI1Z3ep6SQyR6qyPTpHrM1XUbfTrV57qQIg4A7seygdya5\n\
W3J2W5skkrsdf3cNpbvPcyLHEgyzMeBXD317LrEwmuEKWKMGggbqxHR3H8h260l3c3OpzrcX4CRr\n\
zFag5Cf7TerfyqvPL719NlmU+xtWr/F0Xb/g/kefiMVz+7DYJ5sk81U8z96v1psslVPN/er9a904\n\
j6itf+PaH/cH8qbenFnMf9k060/49Yf9xf5VHqJxYXB/2DXLW0py9H+TO2O6OL1PTrHWIBFqECzK\n\
Punoy/QjkVwHiDwPeWTNPpDG6t858o/fUf1rvopferMcvvXzWGx1Sh8L07HRUoxnueGpcEbo5Vwe\n\
jIw/Qit3RvEF7pwCQyCe1/it5juUj2J5H8q9C13w5putxN58QjuO08Yww+vr+Neaa94c1LQWLyr5\n\
9p2njHA+o7V71LFUMYuSa17P9GcUqU6Tujq7Ox8O+Iw/2ZHsL4jLxodpH/AehH0qnc+B9QtH8zTZ\n\
45RnPyMYW/Tg1x8FzkqwJDDoynBH0I6V2Og+MZ7ULDqhaeAcC4UZdf8AeHce45rKvRxFBN0nzx7P\n\
V/8ABKhKE372j7mdNP4h03idr6ID++gkUfjj+tEHinUkxmW2m/3lKH9K9Mtb+K5gSWKRJYnGQynI\n\
IqG50rSr0H7RY27Mf4tgB/Mc15qxWEqaVaKv5af5HR7OrH4ZHF2/jCUECeyYj+9FID+h5rYsfFen\n\
3B2NN5THjZOu3P502/8AAlhMC1hczWr9gTvX9ef1rltV8Laxp6ktCt5B6xfNge6//rraGEwNb+FJ\n\
xf8AXf8AzIdWtD4lc0/EnhS3vo2vNG2xTffMSnCuf9nHQ1zml6zNFKbS+3LOh2gsME47H3qKw1O4\n\
spM2dw8DDrGeUPsVP9K0tRW18URjCraa2o+XHCz47A+v6it6uGmo8lfVLaXVevkTGpFu8NH2OD1L\n\
Fm97En/Lvc+ZGAOit0/Rv0rO0awsr3xXp8V7DLdRyIzbY+FjOerHuB39K1NRjke8Vp4JHlQeXcRf\n\
dZsZwfb0P4Vc0KOPStSs7oWZW/W0IeNpdy7jz69+prmxtSpTpySi3Jrp6I6cJGLqKTaSXc7Cz8P3\n\
E6gWvl2tsOA7jr9BWnYeEAZg2o33nQj/AJZxjbu+prkPGPiu8t9LaaJQkkYy6pIG2jjnI7Z/nS+E\n\
PGN8kEEmp28n2WXH70nkc9celfL1cvq0I+1qW17d+x9PDNZYqTp0bq35Hp17MsUIjjUKijCqo4A9\n\
KY2iwiy+1axOYt4ysS9h6mqVxcoZ7ZwwZDIpzngiquuXUms6slqk4i82Vl3H7sUaDJPpntXRkeAo\n\
4yVTEYpXUWkl8r3flY83MsXUw8Y06Ojlrc898bSLYu5tJvNgJ4Pcexrm/Cnna4WLTTqwJwFJVcjq\n\
Bjvj+Vdf4q06ymhmk0u4uL1QGxLIqpGzD+6xxu/WmeHrhbK40+ytYLYQyrh5XfbtcrlgvY85HvXr\n\
YjDUKVOSpxai03p0fnfdficuExM51IubV7q9+q8rdTo/A+ozW9++najL5gZcws/XI7Z71F8QLHS9\n\
UWEXgw7FsFG2sEX7xJ9K5nXI7+bWphYNEyW6eYsofZ82egqz4ijMQtdQhvDdFR+8jQKURgMkk/Xt\n\
Xj4LDqOIhKtez2tde9bS/bvY9PMK0JRn9Xa039OthV2tZrfadYvaRNF9kE0nzmVQeEQN1PXnFWND\n\
gk8lraSKa7RsKbaN9qHBOFdhyRyflXitqw0qfUJ7GxJZbxrdZJE3YWxtuixgdnfqzdT07111xqei\n\
+FYVtbVfMuQuBHEoaQ/X+6PrgV9NH2OH2jeT2W7dr9fW/wCNtD5yc51fiei+4oWj+KY4hHY6bZ2c\n\
CgbYwm0fTJOazdZ1DXHs5Ida0OSW2cEMYfnwPXH+FWG1XxJrZP2CNraE9BCoZvxduAfpSnwtr8q7\n\
5L1t54PmXkmf04p+xTfNWUYP/E7/AINkKdlaN38keTanA0koi010eQH9yZ1+4f8AaHqK3n1G5jsd\n\
M0+R4jPlUnlJ5JPoP89K6u/8I61EDK8VvfccqW3E/RiAw/A1iSrborW1y0mmTnpHfQ74yf8AZkwG\n\
H4mscXhKOItKVpW+dvP+lY3oYmpR0jocxPdanBqoSzv0SzlVmOTg5HAwD3rb0WCC8jWMQpc3EMZV\n\
UfiKPk7pJCOoAHTuTis2bTfsF99pvza3KMBGsmRIiA55A9c7Tk9hXR6GsA0/yr2X7NYzzGa7m2bW\n\
usH5Yo0HJXue3OOaWGpun7ifuq1v12/LRt+tx4ipGolN/E73N/4feF1u9Ti1S5Drb+arxhvlLkHg\n\
4HH4dB9aK09H1HVde1myTT4GsdLglUlF4ZgD0Y9AP9kc0V6tF1GnzWiui628/M5Fy9NTyLxPHcy+\n\
MNSjgfy2+3yDduwqqXI5yMZyT2P4VNNpWoDULiBLKIWtqf39xcuAAnUuvcj2HHPSk8WSJ/wk+oO0\n\
QlU3kq7SM/MHNW/Bq6jrWuvqN5LGdGh/cBJXBDAdcjPH414uPq1KKdZNJLdPvfprvvv69DvwlOFZ\n\
+zabfdfqc7dpFdBdsymyGW82aVggUdTtUAkew9O1dH4T0iPWtaS4v4tQTTrWKN7Ji3lRtjoQgPHr\n\
6+tJ480NLnUwVZo4jj5IjtRh2GK7CzlvjosRaN5EiQIXA9BXlY/NHPDQ+rayne+91+Hr8juwuBUK\n\
0nV2jt5nA649uNch0qxtLq4LnCbfnYk9ckkY+tVdR0iawxvtns5inJKiSUfjvbA69CfwrsdPntoL\n\
/wC17VMg79657xldf2jIckttOUZTgrzWuX5nOrUVGatFR31ev/BM8VgYxi6kXeTe3kchfkW1nwjK\n\
mPkL8PK54HYcD2GB9TW74Skmjt2lib95ECSP7y9x+XNc7/Z0kk/mEO8h43uxY/ma0rO4a3ja2tTl\n\
2+V3HQDuBXpZhOE6Ps4vz/r+kZYCM6dVTPTNPurnW5I7axXc5UEsT8qL6muvsLCx0UAWyGe7PWd1\n\
y7ew9B7CuH+HN59gvpYpBgXMYVWz3XJx+p/Ku0n1ddOht0tUlk1G8HJjTc6jqFUcduSeK+dw2Gq4\n\
2v7KMttXJ62Xl3bZ7+Y49UqabWnRLS78/JFi5vbqKMSyW8wibo2Mg1nF9K1Jv9KtLeV+mWjAYfj1\n\
rK1y9v7UB7htSs5nPyvcBWjY+hKniuTi8Ri4vIywCXQcpIF6HHeunG5H7Kk61Cq5OO6aX4WPLwuZ\n\
+0qKE4Wv1TPTLbSdFidZI9Ot968gld2PwNaE91kdawLG6ZrdWb0oubzapx1r5l4ubXLY9l0k3du4\n\
viC6mWxlNpzPj5R6mue0fxDfWuirL4isWW7Z2jhiXDlvRj2HoM569D0rur4W+h6EjsFN7cYDSSAH\n\
Zk44/OuOa6trPVnvpAZWt7mby0LZ3NHF+7H4ksa+vy7J3QhCpibNv3kra7aXb067WZ8/jMwU5ShR\n\
v2vcxb7S/sVyJhZiO8kxP5ZxG6qvOSwbcB35AHsKt6JZ3kUVmv8ArNSnPm2yEZW3Vv8Altg9ZG/h\n\
z0HOK3orIXK6Rpcknm3Opn7bqVx/FKq87f8Ad6ADoAK0NFuILe+13X7zHkQSNFHjGQF+UAfl+tez\n\
SUKblJrX/J2svV+S2fc8yc5TSTf9f8MaFtpGi+FrI3WptG9wxzJLLl9zn0HJY+5yapifWPFrGK1E\n\
mlaOOGlziaQenH3R7A59SvSquh6XdeJ9TOp6wSII2O2PPyoP7i++Ordewro/FGsx6JpiJaxp50h8\n\
q3hHyjOOvsB1JrKs3GS9p71R7Lovl1f4IUdVpovzOW8Tva2VvH4c0aPZaJh7op1cnon1J5Pt9a7H\n\
wvpn9k6UBMoF1N88p9PRfwFc34C0UyynU7w+YFcsGP8Ay1lPV/oOg+ntWz451U2OjSJCwFzcnyIv\n\
YnqfwGTV4mbilhou8m9fX/JBBJ/vHt0OC1/UTqOrXt4SfLZ/JhBP/LNMgH8WLt9CK1fhvpLXWqPq\n\
cynyLfKxk/xOR/QfzFcx5TTTQWduNzuViQfoK9m0iwj0rS7eyixiNcE/3m7n867sZUWFw6ox3tb/\n\
ADMaUfaTcmW3aqsrVLI3FU5Xr5arM9CKIpXrkvFeuG3DWFg7fbpB87r/AMsEP8Wf73oKt+KNeXTY\n\
xBbgS6hKp8qPsv8AtN6KK4UDyw5Z2klc7pJHPLt6/wD1q7sry54mXtaq9xfj/wADuZYiv7NcsdxA\n\
EghWKIYReB/ifeqc8lPmkrS8J6BL4g1HZylpEQZpPb0Hua+snONOLlLRI81Jydkbvw38OfbLhdVv\n\
UBt4z+4U/wAbg/e+g/nXuNp/x7Rf7ormLeGK1gjgt0WOGMBVVegFdNaf8esX+6K8rCYh4itKT2tp\n\
952cihFILw4tJzx9xuv0r5Fl1W9XPlvpsS85fJ4/P/Cvrq9/485+37tv5V8fQ6ffTq01m8NtHvEY\n\
kllYsf7zjOePSt8Ty3XMkwSb2ZXuHt7llbVdVa8OflhhDBAffA/kPxqRrnMPl2lnM8Y5CBfKj+pL\n\
dfqc1ZvHNtGE8y6V143D5sn3H+FZgjluJAk9y8YYcfucPj8Tx9a5Zrn0e33L7khLQaskTSebcyJP\n\
MufLjjz5ULDnOf4mHr0Hap5LaWa5tYYIHS7vsGG2yAnP/LRyAScdcEmoLvybfS47y1geW3WQxqY1\n\
zyDn69e56muq8CabJodvFqFwxTWbwGQC5k2pbpnr0JyenSsK9azjGm9W2lpppu/lu++27OilSTTl\n\
NaLX/gfP/gkWp+Gr/RJpjeS3l6LhD5eHCQw/L8zMufQYAxVWa5kt4Qi38Vs2N3kzxkjnoyHPf69a\n\
7K+voriGWKTUbFDJkMqwuGlH93zW556cAde1edat4iluUxLLbIFHyq0ZZ1U8gH8K0o03Gk025Nvr\n\
a+29rW/rcyqVFOSaVvQadQuZJSsE/wBolx1t7eOPHuXYEj68Vb0KA6tr9rb25Q3Tx+Y9zNvdsYyE\n\
VmPGfUf/AFq5hbi71W7jstOS4mllOzeU2pGD3Cg/qa9Y8I6TYeD0aGKB9RuYjveSTAjVuy5/pWVe\n\
tOLVKnrJ7+Surt9uvr0NaNKNnUqaL82eX6jexWF+8SBreUHYUjgAlb1xIT+vX2qx4X0fXbrxVa3J\n\
sJYEUh13cKijpyev17muqhgsNY1FtZutKeS6a52rbdmx/EPb611k82ouHu7iC6swgHlxxxB1Uf7R\n\
DZ/SoxM6lRypU0ox1V3rfpok7v52/Euj7OmlUm232X6mZ4011tIubJLssXLDaADz838jyDVjwbq8\n\
dr4hRblsLu8tCRghWUhAfpkD8a5yXW57jxPC1zEbhLVRL5jDcsS555PbNJ4gutL010linkkS6Dys\n\
ZehZiSVX2HGPzpYaXsmsHJXtDdaeW3Rr8fQK8VUi8QtLy2/4J6R4TbNt4giGBJtPy/8AApP8RVDT\n\
pvK8J3UUbES3ksdsfZAuWP5Aj8a53wHrEoufMkE32e7R4g8gxu44PvyAM1r2rFdNjU9Fdzj3wBXf\n\
Sp81Rp7Pk/DT9Dim7R+86DwTYrfa0904HkWQGxccbz0/IAn8q7a9nWKN3dgqqCST2FYfw/j8rw60\n\
neaZ3z9ML/SqHjm8LxxabGSDcZaUg/diH3vz4H415+YynicT7GHe3+ZrRtTp8zOWvb17ue4v5AQ9\n\
zgRIeqxj7o+p6/lXovhPSv7I0hRIP9Km/eSn0PZfwrkfCOnnVNbFw6/6LakOeOC38I/rXoc79a6c\n\
xqxw9OOHp7Jf1/mRQi5N1Gcx48usaWtmpw144iOP7nV//HQa4O+kG49q3vFV6LrXJEXmOyj8oH/p\n\
o+Gb8lC/99GuUvHLNhQSScADvXZlNLkw6m95a/5GWJleduxteB9I/tfXFkmTdaW3zvnozdh/X8K9\n\
adqyPCmljR9DggIxM48yU+rHr+XT8K03avJzDE+1qO2y0R00YcsRkjYFVJXqSV65fxB4hWykNpZI\n\
txfkZKk4SIern+nU15UYTrTUKau2dN1BXkWNc1q20tFEm6W5k/1VvHjfIfbPAHqTwK4yV5rm6+2a\n\
hIJLrBCKp/dwA/woP5t1PsOKYu5XkmnkM11LjzZm6tjoB6KOwqGWWvqsvyyGFXPPWf5en+Z51fEO\n\
poth00vvVKWSklk96pyye9eocwTS12PgHwo99PFqWpR4s1O6ONh/rT6kf3f51T8FeE5NakS8vcpp\n\
yngdDKR2Ht7165EqxqkcahUUBVUdABXlY/Hez/d03r18jpo0b+9I6hPuL9Kq6scaZdH/AKZt/KrS\n\
/dH0rP8AEc32fQb+XazbIWbavU8V1VU5UpJb2f5GidnqcFFL71ajlrntO1CC9i8y3cMBwVPBU+hH\n\
atKOWvh7uL5ZaM9DfVGzHL71YSQEEHBB4INZEctWo5a2jUJaOc8SeBra8DXGjbLW56mI/wCrf6f3\n\
T+lee3cN3plybe/heCYdm7+4PQj6V7bHLUepafZavbGDUIFlTsT1U+oPavZwmaTp+7U1X4nJVwyl\n\
rHc8j0vU7ixmMtlL5bMcvG3Mcn1HY+45+tdzo/ia2vWWJ829yf8AllIev+6ehH61zOv+Cr/TC8+n\n\
E3doMnAH7xR7jv8Ah+Vc3FOGG1x0P0IPt6Gu6vg8Pj4+0pu0u6/VGMKs6D5ZbHtEd171ZjufevMN\n\
K8Q3FoAlyWubcdGH+sX/AOK/nXXafqkF3EJLeVXX2PI+o7V87iMPWwkrVFp36HfCpCqrxL2veH9O\n\
11C1wnlXOOJ4xhvx9R9a8w13R77Qp/LvV327N+7nT7rY6e6mvU4rn3qWcQXts9vdRrLDIMMrDrXb\n\
g8ynS92Wse3+RlVw6lqtGeXHbr8KKX263CP3MzYxcqB91u24DPXqPxwzTYjdxSWUL28NzH/rdPvo\n\
t6ZHdH+8v64o8R6DdeHbpZYXZ7IvmGcdUPYN7/z/AEq80Mfia0W6t5Ba6zbjG8cBj7+xr0MQocqn\n\
B+49n2fZ+X4p+RhC97Pf8zkPE0dz5v2a/tZAwQhUciQrxxtf+Jc45PIxU9/d3BGk6VaBrotGqzys\n\
FGwhck544H0q/qVxNewtp+ox+RqkHzRMw4J9vY+lc3e6o8W1kVShQnJ/hHQqx+oHPoa5K2GWIioy\n\
Vmr6X08n5rtqdeGxc8NJum9/y7HVeDEub20aK3aRrRg5iLggxsp54PY5z/k1VlTV4tW8rVo0i0uS\n\
VVlIkBMqEjdgdhgc5qLwf4puxHcQnd5NvwHZeCO4B9KXxLeWN/crKZY5LxI22RsT8vHXHQ15FCni\n\
cDjvZW9yevfRbPpqvT0uejXnRxWH9o/ij+Z1unXMU7z3UVhb3+pSqWP2k7bawth91SSCOmDgfpWN\n\
caZNrVwPscaXHzBzJp9p5EY9NhYk/wDAiozWpo0FtNpFtpbzLBYQot1qtwxwJGPIiyevqR7Y9a6A\n\
eJXmX7H4W015FHSSTKqffuT9TXvvRvli5P8AC3d9Eu3V7vc8Netjmm8N36QmObTdQ253M6G0kYn1\n\
LMqnP41yM+jmHUGhgTGM7g6qxBznLRo7Kx+pUepr0HWLG4jRZvFOsSAyY22dtnc3sFU/zJFZhv8A\n\
7KoTTbeLTolPyvgSTn8fuofoDWlCg6j5nr6bfe/0uKVTlVv6+40NNsNWfT2i83+y7O4fzbi5llxP\n\
cMerPJ1GegVAABgBq0tN/wCEQ0ZdpvLe6kHOAu9cnvtUHJPqcmudtdJv9XkEsVnPdEn/AF9ySw/A\n\
tx+Vbdv4K1OQf6Rd29uvomWP5cCtakKcLqVRR9N/v3/L0Ii5PVRv6m3L4y00ErF9pdV4ytu4H6gV\n\
SfxrbknZZ3pAOMkIM/gWB/OpIPAtmuPtN9cynvsAQf1rQh8J6JDybZ5TjH7yRjn34NeZUpYHrOTN\n\
063ZHPyeNmy3l6dOQOm+aNc/kTioX8UajfIYbfTbSUEfMrs8w/75CjP510OoXHhrQ8CW2tRMRhYl\n\
jDyN+HWsLUfGN7Knl6ZBHYQn+OQBn/BRwPxP4Vrh8NQm70abfm3oKdScfikvuM+TQr+YNcXVrp+m\n\
xdTILeO2GPc/M/5Y6UtsPD9gDJuuNWuTwwtlKxsR2aVyCw/H8Kxru4+0S+beTSXcoOQ07bsH2XoP\n\
wFTWFnqGrSbbG3kkHTeRhR+NeuqLjH35cq8v83dnNz3eiv8A12On0zxRqNzq1hbxC0sLTzkUQwJ5\n\
jFcjjccAfgv40Vd8M+CGt7+2utSut0kbqwih6ZB4yT1/KiopSw+qpGiVT7RwHxB0dbbxBfX6rmzm\n\
uG80f883yRu+h6GsZNLtoLNrOJCkc2GkhVseZ7g/xfhXoc9zBf6jqcUqhojcSxSI3+8a5y5t49Du\n\
RY38QutCuD+6aT/lk3pntXlKq6l4y+KLfz/4K/FHRbl1WzOaje8vk1GO9nKMERLMRjJjO7G09ugz\n\
1rS1/wAVX+keHIrOOWTfbgB12hS5xzke/wBat6lbDS5Fa3nlXT7ghFnyGaBz0VweHQ+/I9R35LU7\n\
e+ur1rWGW2t5s7GZyWEYPVkGORjkZ6fhSoU6dCbrUkl1uvx6eWq7+pc6tSqlTmyzDDqcenG4vLeW\n\
Isu/DDBx1rmra+ku9QWGaWWMsNwWIdF9Sa9x0qKCTQbdrq9XUkMf/HwwwHFcvd6boun6jItlBG10\n\
qchJAQoPbJ7fT1rxMBiFXnKnKm7K9+Wy9Pit9zPWxMPZRUlNJva+v5HPQ+Hjcghbx5lHUBs0l5oR\n\
i0+5S1OJlTIx1Hr+ma1vDcVjFJc6q0k8s94u8wxrgKM87scKMj2+lUb6WTWdRurfSB9nnA2usfTB\n\
HUAnr+WaVSjUpVFUi3yJpvmSXXVNLf1Wj6HVHEUKlJ0mrTd7Wd+mju9vR7FvwD4dntYYpfNd3lId\n\
Q6EAAH73XsMjNb2n6hdT6jNd3ky6UsMYha4YiR+T9yNR1chUz6Ae9ULme5sbOz0Fpmk1KSHExJw5\n\
GMBcjpx78DnPFbnhfwzLcKt+bprK0f5kuSP3tznqyA/6uMgDAGGIAJJzgexTkqtapi5NRjJWXom7\n\
N92/6R4le1OlDDK7cdXfu7XXyKetuk1s4E+vtEwO5rq0LRsPXsQK4DTfD6Q6tbTRXKujTGSeQtkB\n\
OwA617Fqem3Fshk0TXbhpF5MN2/mxv7E9V/CvKvEd6RdyO1v9mnGfPhVgoDDknOOhHf6VcFTqwcI\n\
O6fb/Ky+W6MIylTkpNHf3WpWoSNbZgY2HysCOcVQnmLqSDXn/hmOePWNPtLq+imN4omiMbErhj7j\n\
8K7G/wBRtLHXbfS5JMyysFHbk18djMBChWcKF5K19e3X9T6WhiZVKfNU0exe8Ua8NR0TyJ0cTou3\n\
5eQ3+FcT4b0/xJfm6uT5QtYMMPPfBY5659hn+Veial4cuU09rzy08oDO0uN5HqF61TsJUm06a03h\n\
IpFKtXpVM6xtKhCNSNtFZtdO/mckcvw9SpJxd+9n1/Qo+EfEEf8Ab9jG8yzfZ0e3Lq2dit93P4mt\n\
N/Ml0/TNPRV/fTyXBA6Mxfaufx5rk5dFj0JP7P0kYufOLXBaUMJSR8mCPTPT19a7jwha/wDE80dP\n\
vGO1SR9x74bP619Phqim3VaatfR76Xf5s8KtT5PcTv6HoErW2i6RtLLFbW0ZZmPYAZJNef6fBdeL\n\
Nf8APn3xIycKR/x7w5zj/fbjP5dqveOtSe91KPSrXe6RFXmVRnzHP3I/f1I+ldfoGlpo2miM4a5k\n\
+edx/E3p9B0rno/uYPF1Pil8P6sJe+/ZrZbl0JFa26QQKEijG1VHYV5d4t1E6hrcrA/6PaZij/2m\n\
P3m/p+BrsfGGrnTdMcwnN1MfKgX1Y9/oOtedWdjJe3lvp9qS0kjYLH82Y/qarKqftaksTPaO3r1f\n\
yJxErJQXU6j4b6P9oupNXuB8kRMcAPdsct+HT8/SvQZGqKytYrCxgtIBiOJAo9/f6nrSSNxXJjsS\n\
61Ry6dDWlDkjYimeub8T67HpMCqiia+myIIM9f8Aab0Udz+FS+KNej0i3AVRPey8QwA4JP8Aeb0U\n\
dz/WvO5ZJZJpLi7l8+7l/wBZLjHHZQOyjsKWX5fLFy556QX4+SHWrqkrLcRi3mSzTSGa5lO6WUjG\n\
4+gHYDsKqzSUs0lR2VrPqV/DaWq7ppW2qD0Hufavrko042WiR5msn5k2j6bca1qcVnbDBY/M+MhF\n\
7k17VomlW+i6dHZ2o+VeWc9XbuTVbwxoFtoFj5UPzzvgyzHq5/oPatYmvnMfjfbPlj8K/E76NLkV\n\
3uITXSWf/HrF/uiuYZua6ay/49If90VWUu9SXp+pVXZDrrH2abOMbD1+lfJOu6d9rAiVhFbl8boH\n\
DAj03D+oFfW9y222lYgHCE4PfivnW+tdP13T2utLiW1vQDuReFY91I/kRXo4qUYuPNdJ6X6fMyV+\n\
hwy6ZFCZJ7oXE7KxSK180rhTgbieuevWmPo91qmuQWsl9b2Ntcw75Bvy4TumfXHetG4vZUsVdA5A\n\
zFluWjYdUb1U9s9DWPbSWr6zprS2C3lzG7gt55EcGdoQuenBDcf14rzq1OcIzlFu9n5/n+e/rZX6\n\
KU1KUYyStf8ArY7Dz1XQLe10ONYLISDYnlgl9p5O49fUnGB61Lo41B5p71LNpZXORMsfmlB2Cg8A\n\
e+Kh0O68wQ2CwvdMPllEf3CgPywhsfKucliASeBzXokNt4skgCwHTNNiH3Y/KJ49M7ifzANbckKM\n\
NIq3S7tpe++7u9fzMZVJVHq/6/I4DxNdPdaZPG17dPPGuZbS8iVWUf3lI9K5qLTNOutCvg720N/H\n\
LvGx90jKwBy364+ld/4s0XUpogdYv9CaUH92xlMDgn0JyMexBrltO0e2t/KiuUS4jbLPJb3GzziT\n\
nLvtzjtwOnSsnD28Eou1nf3X+F1b+t+5cKnsm2+qtqQFbvSdGs30mAwzxIM3M1uV8wHvz14rW0dH\n\
IuBiaW7mkbaAgM0nPRV5ES+rnn2rVNjZ6ptjubrQNPjJwUaeSaXHsZCB+lb2m+DNDSHC6lJOTxuh\n\
cDd9RyDRehRvKfut+Wr9RSnUqJLcz7XwRdmHeDaWgJ3bEcswOOct3rJ1OwbRZP8Aib2rGCQ4+12k\n\
rLs+o7/jiuquPCFtGN2mandW8w/vHj/x3H9awNWfWtHiZNWVb+wcbTMmCfoeB+oH401iHVfuOMl2\n\
Wkvle9/60J5OVe9dfijktdt0gmaN5PtdpdoR5vRnA5wfcdapa7qdlcnTZLmxhnjsyCqAY34AIB9i\n\
B+BqrqrmG4iggmQWu7fBJIeFB4IPfjJ468dKj8O2L3l2J5IJBpkMpVpZDhpdvAIXqg4JGRk5rSca\n\
c+VVmr7Lo9dNOqfp10LpupG7p3tu/l3NGLWJ7pBf3MZjjuWby0Qlli29s9j0OK6PSJDNpglYtuzh\n\
gRwC2Tn8xUFjbw3U4sneT96WMQDgLHGNxOAOpOFGTnrmtfR4kmmghcqseoWhVNv3VlQ8fjxV0J/V\n\
4+9rta3Zf8BfeiKyVSV4/wBM7zwLIG8KwAdUd1P13E/1ritXu/tN/e3hO7zHMURzn92hIGPqcn8q\n\
0fDWqNYeGNeTG24tiZFUnHzsNoH/AH0o/OovDGmLd69a2pXfbWihnz3CjA/M4p0KcYYiriJbLb56\n\
/kZTbcIwR3XhzTv7J0WGBsecw3yH/aP+HSma1qEWn6fc3c5/dwoXPvjt+PStK4frXC+Mb8S3kGnJ\n\
hlTFxP7YPyD8WGfoK8OXNjMQqf8AM9fTqdelOF+xzMrSJB/pBzcSMZZj/tscn8un0ArV8BaONT1d\n\
rudc21qQQOzP2/LrWHcebdXKQwKZJpWCoo7k167oOmJo+kwWiEMyjLtj7zHqa+lx1ZYejyQ3ei9D\n\
how55czLztVaV8A065mjhieWZ1jjQFmdjgKPUmvOdc1+bWt0VoXt9JOQW+7JdD+aJ/483sOvzdLD\n\
1MVPkp/f2O6U401dlzX/ABI1xJJZ6M+ApKy3eMqp/up6n36CubjRLaPbHkk8szHLMfUnuaUlI4wk\n\
aqqKMAKMACq0snvX1OEwVPCxtDfqzz6tWVR6iyy81UlkpJZKqSyV1mQsstdT4N8Hy6u0d7qAMWn5\n\
yF6NL/gPerXgjwab/wAvUNXQra9Y4WGDJ7n0H8/p19PAVFCoAqgYAHQV5OOzDkvTpb9WdVGjf3pC\n\
RxpDEkUKKkaDaqqMAD0oz8woJqMN8wr5+Urs7UjrV+6PpWT4vOPC+qH0t3/lWsn3R9KxvGpx4S1c\n\
/wDTs/8AKvsI9Djlsz59ikZZRLBI0Uw6Ovf6juK37LxEEIXUEKD/AJ7RjK/iOorkYpqtxTcdawxe\n\
Ao4pe+te63MqVedPbY9HtrlJY1kidXRuQynINW45a82tZntnL2krW7k5JTlT9VPB/n71t2fiKWPA\n\
vrfev/PW2yfzQ8/kTXzuIyfEUdafvLy3+7/I76eKhPR6M7eOWrMctYGnana3y5tLiOUjqFPzD6jq\n\
PxrRjlrzlJxdnozffVGvHLWB4g8JafrO6VB9lvD/AMtYxwT/ALQ71oxy+9WI5a6aOInSfNB2ZE4K\n\
SszyLWdC1PQnLXURe2BwJ4+VPpn0/GqltdFJRLBI0M399O/1HevbyUlQpIqujDBVhkGuV13wLYXq\n\
GTSyLK564GTG31Hb8Pyr3KOZ06seTELf7vmjinh5RfNBnPWHiXYVW/Tav/PdOV/EdRXUWt4ksayR\n\
uro3IZTkGvPNU0rU9DfF/bssfQSp8yH8f8ahs7owMWtZXgcnJKHg/VTwfyrOvk9Op+8wsreW6/4B\n\
UMXKOlRHqkyw3trJbXKCSGQYZT3rzjWNLuvCeoJd2pM1m52qx44/uN7+hrWsPE8sWBfQeYv/AD1t\n\
ufzQnP5E10drfabrVvJbiSG6jYYeIn5vxHUVyU3Wwd4V4+49+3yZrLkq6wepymoQ2vifTo5Efyrl\n\
P9XJ3U+hrzz+z5jqrm9jj8mGUPcxspPC8lQvfd/WvRdW8LX2kTteeH909u3LwkZZR6EdSPcc/Wud\n\
v2ttQkFx8tvqAwjwztsWYDsH6Bh2P4GuinpBxi+aD2fVX6PqvXbqQ37yezG3/iy0utNvNJGlvHPc\n\
ESLMq8qp6jgdfb2qnPYvJZRkIhdhtUBcuqngbm6ZPYde9QafpzrqMsTwXpmbaPMWOUmNDn5QB8ue\n\
46g5r0HS4NN0ySK41torVIc/ZNKR/Omzj78gUks5/SopUoU4whNXUNF1dt9Py/OxrVrSlJyi7c2/\n\
a5P4U8GvLZW76rIwtEw8cPqe7HPc/wB48+mK1NY8SW+lb9O0GCJp14kk/gh4/iP8Te354rPu9Z1j\n\
xHN9m023mtrbusbDzXH+0w+WNfoc+4rb0PwdZ2MSG+2TMvKwpkRr/Vj7mtptt8+KfLHpFbv1Oddq\n\
er7nL6RoeoazcvcZY+Yf3l5MOW/3R6ew4rtNJ8L6bpuHdPtVwOfMlGcH2HQVsNKqKFQBVAwAOAKq\n\
T3SxozuwVAMlicAD61xYnNZNckNF2RrToJavVl1pQBgYAHYVC8/vXJX3i+yUulgJL+ReD9n/ANWD\n\
7yH5f1J9q5y+1vUbwnz7lbaHP+otSckf7Uh5P4BawoYPFYrWMbLu9P8AglTq06e7O21jxNY6Y3ly\n\
yGS5I4giG5z+Hb6muT1PxNqd7GURk0+I9RGd8hH+90B+ma50SpExS2TDOei5ZmJ9+proNJ8H6tqW\n\
2S5xZW56+Z98j2X/ABxXs0stw+FXPXfM/Pb7jllXnUdoKxgebFAWMY+dvvOxyzfUnmtXSfD2q6wV\n\
eOIwW5/5ay8DHsOpr0DSfC2k6WyyRwGadf8AlrMdx/AdB+VbRfAwOBRXzWMVy0l/XoOGGvrJnLaR\n\
4H0+zIe+Y3soORuG1B+Hf8a6hNkSBIkVEHRVGAKY0lQvLXi18ZOq7zdzqhTUdkXLZ/8ASYv94fzo\n\
qnZy5vYR/tj+dFd2WVOaEvX9CaqszyLxNDd+HvGN7JKrNDNM7gqvEikk8e4zW9GbPWtNaCUrLBIO\n\
COqnsfYiuu8Safbax9rtLsfKXJVx1Rs8EV5Zeadqfha9DMB5bnAk/wCWcv19Gq5JYyXPTdqi/G36\n\
kfwtHrF/gVpoZdNaXRdUbfDKhEUueHU9PxH9K47UbySzkLXSh2thsfLbd+Pc+o/nXqkd3pPiO0Fl\n\
qQEUxGUDnDKfVG6Gud1fwvdWTMb+D7TagAC6jTfkDpuXqDjvTpv3mpK0uq8+69e3fYGuu67mXoej\n\
6qmkXl1rdyY1kUiG0SUMORkAsDwPU1oeGIJ5JZbaws5zG20tHAvmbeOcluCfQscD0JqxbaIupzxS\n\
WOoaeFUH5ZJsFSe+3rwK7aw0F7O1jil8RC3g67LVVjDH13HknNclOMaTlOrJc0um34Wb+e50Vavt\n\
EoQWi+f4mFq+iNDbhRpOpxlRkS+ZHN0/vKn9K5PSo9SsdQuI7e3jtLaYb5SY/mkOMd+g/Wu/lsvD\n\
lozfbPEV5M5Pa5JOc88LVKX/AIRgSF0/te7PQ75GUH8WxW8Karx5X7y/wya79UjFVHSfMnZ+pjWW\n\
gXV7ePI97Ba2zj5pbg4GNoGFBOWGAPb3rqBZ+DYvmv72PUbhuTJcT72PT06DpWQl74diZj/wj0km\n\
eMy3CscfnV+28QaGuEPh4KoGNwZWP866Xh6kVaCkvRJP8/8AIy9opO8mn6tjbq18ESg+Q8dpITnz\n\
LeYoRWBq/h+3vUJsdQtdWjxgJKyicD09G+hrtrXU/CV03lNBDA54xNGU/I9P1qTUvCOh36BoQ0Dn\n\
lXRtw/X+lc/tYU5Wqylf+8l/wH+Jootq8Uvkzz6G0nk1G3njEYvIMjyZ38uYDsoDY+UHnA4P6VFP\n\
apZ3bXscgN4jB5Y5AVkGM4IyOnJ5Ga2tZ0q90aPGoRDVNJX/AJaA/vIfdT1X+Vc9r0Mn2JJhMbyy\n\
4MNznDpn+Bv5Zp+yirctmn/Vvl2sn11H7ST3buYeteItQbV4Fto5XLKxJXJBHTntx61d0fULKVJL\n\
XVXdFkQj5TtOau+ALG7GtrLPdW9rCyPElpyzSL1Jz0pPFHhrRv7dE8d64mUENDHzj6+nX9K8zG1o\n\
YqusJO+i0av6v9PI9HDQdCj7ZW132+QmhX+nQajNBaTeZbxtja3LAKp25Oc9Tk+9dtoV7HYXy3s2\n\
dlrpEJwP7xXAH1NcELW20+0VltmRzHk3A/dl27vtHO3H/wBbrXTaTb3N0tnYqh+0T+XI6nqqhcRq\n\
fwyxr1sPF1VZq3T8N/u769zzq9ou6dzqfAOkvcXL6negsUcuGI+/KeSfw6D/AOtXZXlwsaM8jBUU\n\
ZJJwAKW3gi0+xhtYfuRLtHv71554y1pdSkfT7Vz9iici5lVuJGH/ACzHtzyfw9a5K7njq6o0tvyQ\n\
RtSheRk61qf9qajJfYPkKDFbA917v+J/Qe9d14C0T7BZG/ukxd3A4DDlE7D8etYfgvQDqVwuo3iY\n\
s4z+6Q9JGHt6CvRJG9K7cZWhh6SwtLZb/wBfmZUoucvaSGSNXL+KvEcWlxGG3KTai/EcOfu/7Teg\n\
FQeKvFSWbSWOllZtQB2uTykHux7n/Z615/8AcLu7tJNId0krfec/57VzYLLpYl+0q6R/P/gF1a6h\n\
pHcczN5kk08hmuZTmWVurH0HoB2FVpZKSaWm2Npdapdra2MTSzMM7R2HqT2FfTJRpxstEjg1k/MZ\n\
bQXF/dJbWkTyzOcBVFex+E/DkGgWnaS8kH7yXH6D2pPCPhyDQLMZCyXsgHmy/wBB7Vuk14GPx3tf\n\
3cPh/P8A4B20aPLq9wJqNmoZqiY148pHUkBPNdXY/wDHnD/uiuPLciuv0/8A48oP9wV6eTv95L0/\n\
UzrLREswBicEZG05FfN3iLTJdEv5NR05SbGRv3kag/u//rf/AKq+j7s4tZj0wh/lXz1puuTRbo7g\n\
C8t2ypDYD49+xr1MVTqys4Lmj1Xf0MFKK0ejOH1yYCaSSLm2ucSEg8Bh1+h4H50zTZporeRZPMSK\n\
5kDeZwATsOWyxyecAdutdZqWjaddyM2lXUduZPvWt0Ngz/sseP1p1noQXyotX0y8mt0xhbXayN/w\n\
IZ9K5uTRL/gPa23+Q1K1zS8F3UWn2THRLBr3UJSdrBcRwr0BJ7k9cDOM+9dGdA17Vfn1fUTDGefK\n\
Q7B+SnP/AI9UUXiGaygFvpGgPbRLwu4YGMe3NVZ4vEmsjE8dx5XeGIeSv4sSCf0qJRqVJ83Il5za\n\
/BXFdJWv9xNJpnhrSMia8knuOhjtgC5+oUFvzNULi700keRopC/37m7ZSffCk1fs/BupMm1mtrOM\n\
9VHzH8cdfzq9H4DjP/HxqMpOOQiAc/jXSqtGn/Eqtvy0X4f5kcs38MbHMS3Fm+P+JZCoHUJeyc/m\n\
tRrbaHO/71bu0kP/AC0eNJlB7cryB9a6mbwBAf8AU6jMpx/GgNY174K1e2+a1khugOynY36/41cc\n\
Rh56RqNfP/O5LhUW6HxeFJJo/N0XVoLhR02TOmPwBIFVLkeIdGz5/wBoaLuZFE0ZH1Xp+NZUkl9o\n\
96DKk1ldjo2Mbv6MK67RPFy3IWC/2RTngN/BJ/gfaubExnSXO4RqR72Sf4fmaU2paJtM851ZIppR\n\
eWUYglHMsCnKOO5T+q9arQpM+oxCV3i02QGebymz9rbA2rn0HP04ruvGGgR3Qa90hFWccyQLwH9x\n\
6GuCkdo7Fp4c+QWy6gf6iXsw9AT+XNKbpYmkpR1W1nuv66PfzvYqDlSn5lK1NrZ2s10LueExTsCJ\n\
Mn7x+Xaew4P1q1ba1J5KiJg0aS+dG542uOpHY59BWPHO82oWSiRNnmtKYQocMwBIyOgGfWuktbNt\n\
Vtbi7lfEVrwZThY0bqcE9T7LyaS5o3T1S1183t8v1saS5ZJS2v28uvzOit9TW6vZhBlBd+VM65xy\n\
rBm/9AP/AH1XfeAbTytOub1x81zJhf8AdX/6+a850PSbi3eKORCLudcpGf4fMIVB+SsfbNewBYdK\n\
0uOJpFSG2iAZ2OBgDkmjGTVDDKC6/p/VvkZU1zVG+xT1/Uo9OsJbmT5iowiDq7dlHuTXmszvGksl\n\
ywa5nYyzMOm49h7AcVd1fUm1a8F5LlbSLP2aM8E/9NCPX0qbwtoj67qAmnU/2fC37w5++eu0fpmq\n\
y3CrCU3iK2kn+C7erIrTdWXJHY2vh5ohXdq15HhmG23Vh0Xu349q6nWNUtdMtWuL2URoOAOpY+gH\n\
UmqniLX7XRIo4ipluXX9zbR9SBxn0Vfc151eXE99eG91FxJcH7qj7kQ9FH9axVCpmFRzlpH+tEaO\n\
caMeVbk2sajca3OJb0eXaKcw2vbrwz+rdOOgqlLLnOTzTJZfeqkste7RowoxUIKyOOUnN3Y6WT3q\n\
rJJTJZaZbQXF/cpb2kTSzOcKq1bdtWJIjZmdwqAszHAAGSTXongnwWYmi1HWV/eD5orZh909i3v7\n\
VqeDfCEOkIl1fhZtQIyM8rF9Pf3rrSa8TG5je9Olt3/yOulQt70gJpjGhjUbNXiSkdaQM1MDfOKa\n\
zUxW+cVk2Wkdsn3F+lU9ZtY73Sbu2nBMUsTI2Dg4Iq2n3F+lR3v/AB6Tf7pr7KbtBtdv0OLdnz34\n\
l8E32kkzWG+8tOuVX50+oHX6iuYSUg4OQR1Br6EVq57xB4Q0zWS0pQ290f8AlrFxk+46GvOw2a/Z\n\
rfeFTDdYHksc3vVlJqua14Q1fSN8nlfabZf+WsXPHuvUVgpN717FOpGorwdzklFx0ZrMY5SPMUMR\n\
0PcfQ9RV601K+tcC3vGKj+CYbx+fX9awkmqZJvepq0KdZWqRTCM5Q+FnYWvimVMC7syR3aB936HB\n\
rYtPEmmy4BuREx7TAp/OvPVm96lE2Rg8j0NebUyWhLWDcfx/M6I4ua31PV7a7imGYZUkH+ywNXEl\n\
xXjkYjVg0YMbesZK/wAqv22q6hbf6jUJsDosmHFcc8lqx+CSf4GyxkXuj1reroVcBlPBBGQa5vV/\n\
BOlagzSW4aymPOYvun6r/hiuetvFupxY82K1uB7ZQ1q2njWMkC5sZ4/VkZWH+NZxw2Nw7vFP5ajd\n\
SjPRs5rU/B+tabloo1vIh/FBy34qefyzWJOXjdUvbd43HQSIVYfTuK9Tg8Y6O5w9w8J/6axMo/PG\n\
Kvi+0fVowhnsrpT/AAsyt+ldccyqw0rw/C3/AADJ4eL1gzy6w1q9s8fZb+VR/dk/eD9ef1q/NriX\n\
3/IU0yxu2PBlRmif9P8AGuxvfBWi3RLJC9ux7wtgfl0rHuPh2uP9E1Jx7Spn+VaRxOCm+a3K/u/I\n\
ThVWm5z6p4efaH06/gX+IRvEyk/zNa1jeeGbM5i0q7fvhgMfkCBTJfAeqIrGG7tpCDwCSuahHgnX\n\
PW1/7+f/AFq3c6El/Ff3/wDAItNfZ/A6E+NrOGHZbafcgD7qKqqP54FUrnxrcOT5FgqDjmaYD/0H\n\
NZ0fgjWmkAd7VF7tvJx+lXIfAF4xBn1CJOeQiE8Vyyw+Avecr/N/oXz1nsjMu/EeqXH3ruK3X0gj\n\
yf8Avpv8KxZ5YpH3XDSXMnXM7l/06fpXoFr4B0+Ngbq5uJ/VchR+lbljoOk2GDb2UW8dHYbj+Zoj\n\
icFh/wCFDX0/Vh7OrP4meX2tjqmoMFtLK4cHoxXauPqeK6XTfAM0hV9Wuwg7xw8n/vo/4Gu+L4GB\n\
wPamNJXPWzepLSGhpHDRW+pU0vSNP0lNtjbIjd3PLH6k81dZ6gaUetRPN715NTEym7t3OiMLaIsN\n\
J71C8tVnm96ryzBVLMwCjqScAVyyqmqgWnm96rvLXPXniiwjdo7Z2u5hxtgGQPq3QfnXOahqmoai\n\
pWeUWlux5hhPzEehf/CurD5dicU/djZd3oZzr06e71Oxi8QWkOtWdrEWubh5kUpD82zJHLHoKK5D\n\
w20cOtafHCqonnpwB/tCivpsJlsMLDlvdvc45YiVR3Oxt9YS81bUYGwlxBO4ZM9V3HDD2/rWqyQX\n\
lu0F1GksLjBVhkGvLdWupLbxVfT25CzRXUm0kcH5jkH2NdtoGsR6jbCRcJKvEkeclT/hXkZhhJYW\n\
ftYfC/wf9bG9Cqqi5XuZOueAmO6TRnSSM8m2mP6KT/X86wrfVNY8Pz/Z5Hlh2/8ALC5XeuPY+n0N\n\
epQXHvU06W97AYbuGKeI/wAMihh+tVSzLmjyV48y/EUsPZ3g7Hm7aroWohTq+gqZDy0toR19cEg/\n\
zq/Y6d4IumVUnVJDwI7hzG30AfH6Vq3/AID0yfc1jLNZv2UHen5Hn9a53UPBes2wIt/JvYvRTgn6\n\
qa7ozoVValVcfX/g/wCZi1OO8bnW2/hLQkAKQu0eOAJDj9KuxaBosQUCxibb0L/N/OvJiL3SZSrR\n\
3env6IXiB/AcH8q1LLxXqkIA+1pcAdriME/muP61FbCY1q8KnMvW3/ACNWl1jY9K/sjRz/zDbP8A\n\
79LVe58OaJcgh7CFc94xsP6VyVt41l4F1ZE+rQOGH5HBrWtPFenXDKv2kRSH+CYFD+teZUeNoazU\n\
l97/ACudEVSns0Rah4BtJVJsLuSFj/BKN6/41z0+meIvDJ3QKZrQckR5ki/Lqv8AKu+iv1cZRww9\n\
Qc1ZjvPeiOaSmuSslJef+Y3hkneOjOJ03xTbXuIZv3UzceXJyr/7p6H6dfauV16yOjvO8ADaTdHa\n\
0Y/5Ysfb0P6V6PrPhjR9ZLvLD5M79ZIsDJ916H64z71zl34T1uxhkitJYNUs2BXyZyd230yTn9TW\n\
1L2V/wBzLR9H+j2087Ey5vtr5o8qb7dPNbWdnqENs9xIU815gvlKvLe+T7V0EtvYJqCW0E8hLbEk\n\
mVC8kvGSYxjlm4UfXtzWj/wjtzbXMTnStQhwCNpj80Y7gHIIFdD4f0fUbOY3GmaOILgg4u9SICwg\n\
9SkYPX33Z9+1bzoN1FVlsl5JfN3/AOB5MFWSpumlv6hc2UOlpbT6naqjsc2WkIwd3Yf8tJ3/AIiO\n\
CeSB7mut8J6O+l28uoamym/uMySMeNmeT16f0AFc9DeaTot5Ld3FxLruvH7zR4KoecDPCqB6cevX\n\
msjWNW1DxBKIrsl42Py2Nvkq3+8er/Tp7VtGjVqR5YaX3fS3ZdX5vr5Ixc4xd39xqeJfFTakklvp\n\
EjR2Zysl2ODIO4i/+K/LNR+FfC76oIZZo/s+lJ91RwZcdh7eprY8P+DjvjutbIYggrbDkf8AAvX6\n\
V0+rapZ6PYme7kWGBMKoA6+iqB1+gqJVqWEj7LDaye7BQlUfNU27FoCK3gWOJVjijXAA4CgV5/4m\n\
8XvdebaaG4WIEpJe5yD6iL1Pbd09M1k+IfEF3rpaNw9rp2eLcHDyj/poR0H+yPx9KxZJAqhQAABg\n\
AcACtcJljk/aYj7v8/8AImriPswAFYo9iZC5JOTkknqSe5PrVaWWmyy+9anhjw5d+ILn5Q0Vmp/e\n\
TkcD2Hqa9ic40480tEjmScnZFLSNMvNbvltrGPcerOfuoPUmvYPDGgW3h+yMUJ8yd+ZZiOWPp9Pa\n\
rWi6TZ6LZC2sY9q9WY8s59Sauk187jce63ux0j+Z3UqKhq9wJqNmoZqiZq8uUjoSBmqJ2odqiY1k\n\
2WkBPIrtNO/48YP9wVw5bmu303/kH2/+4K9bJX+8n6fqZV9kWH+430ryrW/B+n6lI81qfsdyc8xj\n\
5WPuteqSHEbE+hrgIrkFiQQQeQRXXmeInQlBwdt/0MqdNTTTPPtQ8L63pq58hbyH+9b/ADEfVTz+\n\
hrGjuVgkK7Xt5F4IUmMj2OK9miuPeku7Wzv1AvbWCcDp5iBsfTPSopZxdWqxuRLC21izy+28QahE\n\
QYtTuh7Owcf+PCtO38YatGfnmtpx6SR7T+YP9K3rzwJo9w263Nxan0jkyv5NmsS98AXsWWsL6KYd\n\
llUofzGRXUq+BraSSXyt+RnyVo7M0YPGrAD7RYs3qYJQ36NtrQtvFmmTkK1x5Eh6JcKYifpng/ga\n\
4C90TW9PybiwmKD+OMbx+lZ63xGUf6FWH9KieU4esr0pNejuCxE4/Ej2MXgIBBBB5BHenrd+9eQ2\n\
l2bfH2Oea19oXwv/AHycr+lbNv4jv0wHFvcD15jc/wAx/KvMq5PiqesGpL7n+P8AmdMMVTlvoeg3\n\
sVrqNuYb2FJoj2cZx9K4fXfAzrvl0V/Mjxk20jfN/wABP+P51cg8U24/4+Unt/d1yv5jIrWs9cs7\n\
jHk3cL57BxWVLEYnBv3k16rQuVOnVWjOCsNcnsWNtqQkUxnaWdSGT/fHX8awvE0P2Oe4uYBusb9C\n\
GxyFkP8AQ9R7169qFhpmtRj7bFG7jhZkOHX6MP5HiuWvfArQpIun6lEbdwd0FxgKwPqOR+IxXVSr\n\
UJy5qb5W909vk+mvcylGaVpa+Z5Vps11G1yYgxwFEmYxlsdgfp6f4V6R4ciS10az1PW7cpZIxNjY\n\
DBaeU/xkd/x4A5rLTQY9NJgkutMCBt3lg+Zv74wCWI46Hj2rSSVhdfaZFa7nA2rNejaiL6LEuOPb\n\
5Qe+a9L2Upt8vXqv06X8+nqYuaVr9DpdD22CzeIfEcyRGZyYVOSSxAACDqeAAAMk8nFY3iDVp9Zk\n\
Bu1MFgCGS0P3mPYy/wDxP51QuryS4vRcTSy3l8RsWRwCVB/hRRwo+nJ7k1t2XhxIbY6j4nnFpZr8\n\
3lFsM31Pb6Dn6VboUqTVWtutl29O78yOaUlyw+ZS0PRLvxBch8GOxDfvJj39Qvqa6DVvEltpsD6V\n\
4bSNpoQUabGYoD7/AN5/Yfiax9X8Q3Oo27WljGdN0oDYFQbZZF9P9hT7c/SsXckUaxxKqRqMBVGA\n\
Kv2E8S+atpHov8xc6pq0N+44/LJLLJI81xKcyTSHLOff29hwKryy0ySWqkktdySirIw3JJJfzqnL\n\
LTJJfeum8KeDbrWSlze77bTyMhujyf7oPb3qKtWFKPNN2RUYuTsjH0LRr3XrzybJPlHMkrcKg9z6\n\
+1eu+GfD1poFrsh/eXDj95Mw5b/AVo6dY22mWiW1jEsUK9h3PqfU+9TE189jMfKv7sdIndSoqGr3\n\
FJpjNSM1Rs1eY5HQkKzVGzUjNUTNWTZaQrNTFPzimsaYrfOKzbKO/T7i/Sor7/jzm/3DUsf+rX6C\n\
ob//AI8p/wDcNfbVf4UvR/keetzklepVaqitUitXyCkdti2G9aw9b8KaTrG55oBFOf8AlrF8rfj2\n\
P41qq1PVq2p1pU3eDsyJQUtGeYap8O9Rt9z6dPFdIOQjfI/+B/MVyV7a3enS+VfW01u/YSKRn6et\n\
fQCvSTRxXERiuI0ljbqjqGB/A16lHNqkdKiv+BzTwyex8+rN71Ks1eral4C0S9YvFHLaOef3Dcfk\n\
cj8sVy+ofDi/hDNYXcNwOyuNjf1FelTzGhPd29TCVCaOVWb3qRZaW/0LV9PybuwnVR/EF3L+Y4rN\n\
EtdkZRkrxdzFprc1BLTxL71mLN708TVQjUE3vSN5b/fjRvqKzxNTxL70AaUE0kBBt7i4hPby5WH6\n\
ZrTt/EWsQDEepSOPSVFf9cZrnRL708S1lOhSn8UU/kUpyWzOwt/GerJgSx2U3qSrIf0JrRi8csFH\n\
nacWPfyph/7MBXACWnCb3rmll2Hl9m3o2aKvUXU9Gi8c2Rx5tnfRcf3FcZ9PlYn9Ksp4y0hlBaae\n\
M9w9tJx9flxXmQm96cJj61hLKKL2bRSxMz08+LdD/wCgnb/malPiLSO2qWH/AIEJ/jXlwuG/vH86\n\
TzzWMskg9pv7kWsW+x6e3iLSf+gpY/8AgQn+NVH8V6LzjU7Y4OMqxI/MV55559aPtLD+I/nU/wBh\n\
Q61H9yH9cfSJ3E3i7TQFMZupt3Ty7aT+ZAFUpfFu4gQ6fcc4+aaREA/AEn9K5Ezk96Y0/vWkcjwy\n\
+Jt/P/ITxlTob114h1WbiNrW2X1RTI3/AI9gfpWRcsbk5vrie6Oc4lf5R/wEcVUaeonuPeu6jgcP\n\
R1hBX+/8zGdapPdl4zKiBUAVR0AGAKryT+9U/NZ2CoCzHoByTXT6J4I1TUSsl4PsVuecyD5yPZf8\n\
cVvUqwpK83YiMXLYzfDk2fEWmjPW4j/9CFFes+GfDOmaLPE1rDvuMj9/L8z/AIen4UVy08ZGtdwW\n\
iOhUXHc8a8SF4vE+qJIrKwuZOCMfxHFJY3UtvOs9s+yde/8AeHofUV7z4j0ywub1JLiytZZMfeeJ\n\
WPX1IrNj0fTBjGnWf/fhf8K6XapC01dMy5XGV0zltA12LUUKnEV0n34if1HqK34p/etBdI00SwMN\n\
PswyuCD5K5H6VvC0t/8An3h/74FfOYnKeSp+6lo+530694+8tTm45/erCT+9b4toP+eEX/fApwt4\n\
f+eMf/fIrNZdU/mX4lOqn0MJmSVNsiq6nswyKybzwvol4DvsYo2P8UXyH9K7UW8P/PKP/vkUvkRf\n\
88k/75Fb08JWh8M7feZylF7o8rvPh7A242N/LGeyyKGA/KsO98F63AhCJDdp6I3J/A17iIYv+eaf\n\
98il8mP/AJ5p/wB8iu+nPEw3mn6oylTg+h86yadqNg2Hsbu2I7xBlH/jvFLDq17Cfkv7pfaQhv5i\n\
voryo/8Anmn5Cka1t2PzQRH6oK2ko1P4kIv5f8AlRcfhkzwOHxPqibT9rgfHZocZ/Wrf/CYarsws\n\
toh9dhOK9hOmWGT/AKFa9f8Ankv+FH9mWH/Pja/9+l/wqPqWFevs0HNV/mPGJvFOsTDadQ2Dp+5i\n\
Cn8+aSOy1nVztMeoXYPXz3ITn2OBXu0NpbIi7LeFcDsgFSNFHn7iflVqMKf8OCQcrl8UjyXS/Ak2\n\
E/tC5SGFf+WMA7emegrr9N0uw0mPFnAkZxgyHliPc11Pkx/880/75FUNbs7afT5Y5reGRD1V0BB/\n\
CuWtTr1naU9DSKhDZHA6/wCNoIGe30gLeXQO1nz+6j+p7n2FcJd3E91cfab+4e5uOoZ/up7IvRf5\n\
17KNJ05Y1VdPtAoAwBCv+FMbSdO/58LT/vyv+FduGwdPD6rV9zCpKU/Q8Slm96qSSknA5r3N9H0w\n\
k506z/78L/hVnSNK06PUEeOwtEcA4ZYVBH6V1OVlczUNbHm/hPwPLeeVeawDFbHDLB0Z/r6D9a9M\n\
giitoEht41iiQYVEGABW/wCVH/zzT8hSeTH/AM80/wC+RXjYmjVru8padjrhywWiMImo2auhMMX/\n\
ADzT/vkU3yIv+eSf98iuR5dN/aRp7RHNs1RO1dT5EP8Azyj/AO+RTTbw/wDPGP8A75FZvLZ/zL8S\n\
lVXY5RjUTtXX/Z4f+eMf/fIpDbQf88Yv++BUPLJ/zL8SvbLscYW5Fd5pf/IOtv8AcFVPstv/AM8I\n\
v++BWlAoWFAoAAHAFd+WYSWHnJt3uv1M6tTmSG3X/HtLn+4f5V4BpWryadKVJeWzzymcmP3X29q+\n\
g3AKMCMgiuPXStPyT9gtP+/K/wCFerWoU68HCoro5nKUWnFmBY38VzCssEgeNujA1fjn461t6dp1\n\
jFPOYrO2QtjO2JRnj6VoC1t/+eEX/fAr5yplU4TajPQ7FXTV2jnEn96mWf3rfFtB/wA8Yv8AvgU7\n\
7PD/AM8Y/wDvkU1l1T+ZfiDqrsYazVWu9P0+/Obyzt5m/vPGCfz6104t4f8AnlH/AN8il8iH/nlH\n\
/wB8itYYGrF3U/zIc4voedX/AIF0i5Ja3821cnP7tsj8jWDd+ANQiybK8hmHZXBQ17J5MX/PJP8A\n\
vkUvkxf880/75Fd1P61D7d/VGUoQl0PBZtA16zyXsZWUZ+aMhv5VRlhuQxFzYSFgOd8JOPzFfRHl\n\
R/8APNP++RS+VH/zzT8q7I1qv2rfiZOjHoz5yjnjUfLDt9lBX+VTKpnG9LJps/Lkxl8+3NfRH2eH\n\
/nlH/wB8ijyYgOI0H/ARVe06qKv/AF5B7LzPCrPRtZnUC20+SJD3IEYrcsPA9xId+q3ixoOSkPJ/\n\
M16x5Uf9xfyqhrVpbz6fJHNbwyIequgIP4VjUqV5aRaXyKVKC31POJ9Y0nQy1v4ctI7q9HDTscon\n\
1fqfoK5q8uJ7u4+0ajcNc3AOVLfcj/3F6D69a9cTTLBYkVbG1ChQABEuB+lNOl2H/Pja/wDflf8A\n\
Ct6OHjTfM9Zd2ZzblpsjxuWb3qrJL717S2lacethaf8Aflf8KY2kabg/8S+z/wC/K/4V08xnyHh8\n\
svvUUEU97cLBaxPLK3RVGTXuDaPph/5h1l/34X/Ctjw/p9nbQym3tLeIludkarn8hUTm4xuio07u\n\
xwXhXwLBaKlzrAWe56iHqifX1NduTgYHArb8qP8A55p/3yKPJj/55p/3yK8WvhqtaXNOZ1xcYKyR\n\
hE1GzV0Jhi/55p/3yKb5EX/PJP8AvkVzPLp/zIv2i7HOFqjZq6fyIf8AnlH/AN8ikNvD/wA8o/8A\n\
vkVm8tn/ADL8SlVXY5RmqNmrrTbw/wDPGP8A75FJ9mg/54x/98ipeWT/AJl+JXtl2OOZqarfvBXZ\n\
G2g/54xf98CkNrb/APPCL/vgVDyuf8y/EPbLsacf+rX6CoNR/wCPC4/3DVhegpswDROGAII5Br6a\n\
ceam4+X6HKtzgFapFeur+zQf88Yv++BS/Z4f+eMf/fIr53+zZ/zL8Tp9quxy4anhq6cW8P8Azxj/\n\
AO+RS/Z4f+eUf/fIqll0/wCZfiL2q7HNBqeGrovIh/55R/8AfIo8iL/nlH/3yKpZdP8AmX4h7Vdj\n\
AD04PW75EX/PJP8AvkU7yYv+eSf98iq/s+f8yF7RdjCDVSvNH029ObqwtpW/vNGM/n1rqvJi/wCe\n\
af8AfIo8mL/nmn/fIqo4KpHVSt95Lmnujzi+8BaJclmjjlt2P/PJ+B+BrCu/ho24mz1EbfSVOfzF\n\
eyeTH/zzT/vkUeTH/wA80/75FdcI4mG1T9TNxg+h4DdeBNdgBKRQzjP/ACzkGf1xWRdaJq9of3+n\n\
3K8ZyEJH6V9K+VH/AM80/wC+RS+VH/zzT8hXVCrXXxWf3mbpR6Hy1J5kTFZUdGHZhikE3vX1G1tA\n\
33oYj9UFY2q6Tp0gzJYWjnfn5oVP9K6IVm3ZoiVK3U+eBN704Te9e3/2Lpef+QbZf9+E/wAKUaLp\n\
f/QNsv8Avwn+FbXM+Q8QE1OE1e2/2Npf/QNsv+/C/wCFL/Y2l/8AQNsv+/C/4UXDkPEvOo873r23\n\
+xtL/wCgbZf9+F/wo/sbS/8AoG2X/fhf8KLhyHiJn96Qz17f/Y2l/wDQNsv+/C/4Uh0bS8f8g2y/\n\
78L/AIUXDkPDzP71JBHc3TbbaGWVvRFJr37SdJ02NyY9Ps1ORysKj+lby28KAbYo1+igVjOq46JF\n\
xpX3Z8/6f4N1y9IJtvs6HndM239OtdTpnw5t4yG1K7eb/YiG0fn1r1jyo/8Anmn5Ck8qP/nmn/fI\n\
riqyxE9pJeiNo04Locrpmj6dpYH2G0hiYDG8Llj+PWr5atvyY/8Anmn/AHyKPJi/55p/3yK4J4Kp\n\
J3lO/wB5spJbIx7Y/wCkxf7w/nRWwsMQcERoDn+6KK68JhpUotN3JnK5/9k=\n", "Base64"], 
   StandardForm],
  ImageSizeCache->{653., {103., 108.}},
  TrackedSymbols:>{}]], "Text",
 CellChangeTimes->{{3.5108700915682564`*^9, 3.510870091617237*^9}, 
   3.5108701814582863`*^9, 3.512834361827942*^9, {3.513619417933592*^9, 
   3.513619418921967*^9}, 3.514287656968896*^9, 3.5147477972551036`*^9},
 ImageSize->{820, 272},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel",
  FontWeight->"Plain"],
 StyleBox["\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Examples for some random values of ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineFormula"],
 " evaluated with the help of ",
 ButtonBox["Mathematica\[CloseCurlyQuote]s CUDA",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.wolfram.com/mathematica/new-in-8/cuda-and-opencl-support/\
"], None},
  ButtonNote->
   "http://www.wolfram.com/mathematica/new-in-8/cuda-and-opencl-support/"],
 " capabilities."
}], "FigureCaption",
 CellChangeTimes->{{3.509219656680394*^9, 3.509219694547472*^9}, {
  3.509220005381826*^9, 3.509220038615546*^9}, {3.5099815154713583`*^9, 
  3.509981526150408*^9}, {3.513343818050085*^9, 3.513343821544558*^9}}],

Cell[TextData[{
 "To recreate shapes similar to those shown above try the fast interactive \
application below. The resulting object is ",
 StyleBox["not",
  FontSlant->"Italic"],
 " a fractal for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[LongEqual]", "-", "2"}], TraditionalForm]], 
  "InlineFormula"],
 " (Dufner ",
 StyleBox["et al. ",
  FontSlant->"Italic"],
 "1998, pp.\[NonBreakingSpace]224\[Dash]226) and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[LongEqual]", "0"}], TraditionalForm]], "InlineFormula"],
 " (Dufner ",
 StyleBox["et al. ",
  FontSlant->"Italic"],
 "1998, pp.\[NonBreakingSpace]125\[Dash]126), although it does not seem to be \
known if these two are the ",
 StyleBox["only",
  FontSlant->"Italic"],
 " such exceptional values. The special case of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[LongEqual]", "i"}], TraditionalForm]], "InlineFormula"],
 " on the boundary of the ",
 "Mandelbrot set",
 " is called a ",
 "dendrite fractal",
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[LongEqual]", "-", "0.123", "+", "0.745", "i"}], 
   TraditionalForm]], "InlineFormula"],
 " is called ",
 "Douady\[CloseCurlyQuote]s rabbit fractal",
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[LongEqual]", "-", "0.75"}], TraditionalForm]], 
  "InlineFormula"],
 " is called the ",
 "San Marco fractal",
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[LongEqual]", "-", "0.391", "-", "0.587", "i"}], 
   TraditionalForm]], "InlineFormula"],
 " is the ",
 "Siegel disk fractal",
 "."
}], "Text",
 CellChangeTimes->{{3.505752058138624*^9, 3.505752103966365*^9}, {
  3.5057522395493755`*^9, 3.505752240392164*^9}, {3.5057523228942437`*^9, 
  3.505752328438758*^9}, {3.5057531923994026`*^9, 3.505753192767147*^9}, {
  3.5091234164206576`*^9, 3.50912343243372*^9}, {3.509123531964548*^9, 
  3.5091235331353507`*^9}, {3.511469486417302*^9, 3.5114694893694715`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"Thick", ",", 
         RowBox[{"RGBColor", "[", 
          RowBox[{"0.8", ",", "0", ",", "0"}], "]"}], ",", 
         RowBox[{"Dashing", "[", 
          RowBox[{"{", 
           RowBox[{"0.02", ",", "0.008"}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Line", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                "d", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                ",", 
                RowBox[{"-", "2"}]}], "}"}], ",", 
              RowBox[{"Offset", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"-", "12"}]}], "}"}], ",", "d"}], "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Offset", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "12"}], "}"}], ",", "d"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                "d", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                ",", "2"}], "}"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "2"}], ",", 
                RowBox[{
                "d", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
                "}"}], ",", 
              RowBox[{"Offset", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "12"}], ",", "0"}], "}"}], ",", "d"}], "]"}]}],
              "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Offset", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"12", ",", "0"}], "}"}], ",", "d"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"2", ",", 
                RowBox[{
                "d", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
                "}"}]}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"PointSize", "[", "0.0001", "]"}], ",", 
         RowBox[{"Point", "[", 
          RowBox[{"cjc", "[", 
           RowBox[{"p", ",", 
            RowBox[{
             RowBox[{
             "d", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "+", 
             RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{
              "d", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}]}]}]}], "]"}], "]"}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "1"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{
       RowBox[{"d", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
       "+", 
       RowBox[{"\[ImaginaryI]", " ", 
        RowBox[{
        "d", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}]}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"1.2", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotRangeClipping", "\[Rule]", "True"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", 
       RowBox[{"{", 
        RowBox[{".374", ",", ".31"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}], ",", "Locator", ",", 
     RowBox[{"Appearance", "\[Rule]", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Thick", ",", 
          RowBox[{"RGBColor", "[", 
           RowBox[{"0.8", ",", "0", ",", "0"}], "]"}], ",", 
          RowBox[{"Circle", "[", "]"}], ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "24"}]}], "]"}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Pane", "[", 
       RowBox[{
        RowBox[{"Control", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"p", ",", " ", "2", ",", "\"\<power\>\""}], "}"}], ",", 
           " ", 
           RowBox[{"Range", "[", 
            RowBox[{"2", ",", "10"}], "]"}], ",", "Setter"}], "}"}], "]"}], 
        ",", 
        RowBox[{"ImageSize", "\[Rule]", "215"}], ",", 
        RowBox[{"Alignment", "\[Rule]", "Left"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Pane", "[", 
       RowBox[{
        RowBox[{"ActionMenu", "[", 
         RowBox[{"\"\<value of c\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\"\<0.38 - 0.212 i\>\"", "\[RuleDelayed]", 
             RowBox[{"(", 
              RowBox[{"d", "=", 
               RowBox[{"{", 
                RowBox[{"0.38", ",", 
                 RowBox[{"-", "0.212"}]}], "}"}]}], ")"}]}], ",", 
            RowBox[{"\"\<-0.731 + 0.164 i\>\"", "\[RuleDelayed]", 
             RowBox[{"(", 
              RowBox[{"d", "=", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.731"}], ",", "0.164"}], "}"}]}], ")"}]}], 
            ",", 
            RowBox[{"\"\<0.361 + 0.324 i\>\"", "\[RuleDelayed]", 
             RowBox[{"(", 
              RowBox[{"d", "=", 
               RowBox[{"{", 
                RowBox[{".361", ",", ".324"}], "}"}]}], ")"}]}], ",", 
            RowBox[{"\"\<0.373 + 0.144 i\>\"", "\[RuleDelayed]", 
             RowBox[{"(", 
              RowBox[{"d", "=", 
               RowBox[{"{", 
                RowBox[{".373", ",", ".144"}], "}"}]}], ")"}]}], ",", 
            RowBox[{"\"\<0.367 + 0.144 i\>\"", "\[RuleDelayed]", 
             RowBox[{"(", 
              RowBox[{"d", "=", 
               RowBox[{"{", 
                RowBox[{".367", ",", ".144"}], "}"}]}], ")"}]}]}], "}"}]}], 
         "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "215"}], ",", 
        RowBox[{"Alignment", "\[Rule]", "Right"}]}], "]"}]}], "}"}], "]"}], 
   ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", "Top"}], ",", "\[IndentingNewLine]", 
   RowBox[{"AppearanceElements", "\[Rule]", "None"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"SynchronousInitialization", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{"cjc", "=", 
      RowBox[{"Compile", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"power", ",", "_Integer"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"c", ",", "_Complex"}], "}"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Module", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"imax", "=", "1000"}], ",", 
            RowBox[{"dzmax", "=", "2500."}], ",", 
            RowBox[{"maxpt", "=", 
             SuperscriptBox["10", "5"]}], ",", "z", ",", "dz", ",", "roots", 
            ",", "branches", ",", 
            RowBox[{"i", "=", "2"}], ",", 
            RowBox[{"res", "=", 
             RowBox[{"0.", "+", 
              RowBox[{"0.", " ", "\[ImaginaryI]"}]}]}], ",", 
            RowBox[{"pt", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"branches", "=", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{"-", 
                FractionBox[
                 RowBox[{"2.", " ", 
                  RowBox[{"N", "[", "\[Pi]", "]"}], " ", "\[ImaginaryI]", " ",
                   "k"}], "power"]}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"k", ",", "0", ",", 
                RowBox[{"power", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"z", "=", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"0.", "+", 
               RowBox[{"0.", " ", "\[ImaginaryI]"}]}], ",", 
              RowBox[{"{", "imax", "}"}]}], "]"}]}], ";", 
           RowBox[{"dz", "=", 
            RowBox[{"Table", "[", 
             RowBox[{"1.", ",", 
              RowBox[{"{", "imax", "}"}]}], "]"}]}], ";", 
           RowBox[{"roots", "=", 
            RowBox[{"Table", "[", 
             RowBox[{"1", ",", 
              RowBox[{"{", "imax", "}"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Re", "[", "#1", "]"}], ",", 
                RowBox[{"Im", "[", "#1", "]"}]}], "}"}], "&"}], ")"}], "/@", 
            RowBox[{"NestWhileList", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "z", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}],
                   "=", 
                  RowBox[{
                   RowBox[{"branches", "\[LeftDoubleBracket]", 
                    RowBox[{
                    "roots", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[RightDoubleBracket]"}], " ", 
                   SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"z", "\[LeftDoubleBracket]", 
                    RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}], "-", 
                    "c"}], ")"}], 
                    RowBox[{"1", "/", "power"}]]}]}], ";", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{
                  "dz", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "=", 
                  RowBox[{"power", " ", 
                   SuperscriptBox[
                    RowBox[{"Abs", "[", 
                    RowBox[{
                    "z", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "]"}], 
                    RowBox[{"power", "-", "1"}]], " ", 
                   RowBox[{"dz", "\[LeftDoubleBracket]", 
                    RowBox[{"i", "-", "1"}], "\[RightDoubleBracket]"}]}]}], 
                 ";", 
                 RowBox[{"res", "=", 
                  RowBox[{
                  "z", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"i", "<", "imax"}], "&&", 
                    RowBox[{
                    RowBox[{
                    "dz", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "<", "dzmax"}]}], ",", 
                   RowBox[{
                    RowBox[{"i", "++"}], ";", 
                    RowBox[{
                    RowBox[{
                    "roots", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "=", "1"}]}], ",", 
                   RowBox[{
                    RowBox[{"While", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"i", ">", "1"}], "&&", 
                    RowBox[{
                    RowBox[{
                    "roots", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[Equal]", "power"}]}], ",", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "roots", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "=", "1"}], ";", 
                    RowBox[{"i", "--"}]}]}], "]"}], ";", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    "roots", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "++"}]}]}], "]"}], ";", 
                 "res"}], ")"}], "&"}], ",", 
              RowBox[{"0.", "+", 
               RowBox[{"0.", " ", "\[ImaginaryI]"}]}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"i", ">", "1"}], "&&", 
                RowBox[{
                 RowBox[{"pt", "++"}], "<", "maxpt"}]}], "&"}]}], "]"}]}]}]}],
          "]"}], ",", "\[IndentingNewLine]", 
        RowBox[{"RuntimeOptions", "\[Rule]", "\"\<Speed\>\""}]}], "]"}]}], 
     "\[IndentingNewLine]", ")"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5057429392203484`*^9, 3.5057429410733485`*^9}, {
   3.5057435085730705`*^9, 3.505743534039465*^9}, {3.505743589155882*^9, 
   3.5057435894649067`*^9}, {3.505743646420295*^9, 3.5057436547276773`*^9}, {
   3.5057437095538545`*^9, 3.505743712841964*^9}, {3.505743751125576*^9, 
   3.505743752994749*^9}, {3.5057438159148984`*^9, 3.50574381629093*^9}, {
   3.5057439096355453`*^9, 3.5057439165339956`*^9}, {3.5057440418378344`*^9, 
   3.5057440484130526`*^9}, {3.505744080639291*^9, 3.5057440926482306`*^9}, {
   3.5057441278671494`*^9, 3.505744129403297*^9}, {3.5057524035785017`*^9, 
   3.5057524157633133`*^9}, {3.5057526382035694`*^9, 
   3.5057526986746244`*^9}, {3.5057529052574606`*^9, 3.505752957999319*^9}, {
   3.5057532324979916`*^9, 3.50575327166774*^9}, {3.505756585002763*^9, 
   3.5057566173876147`*^9}, {3.505756717767749*^9, 3.5057567424412336`*^9}, {
   3.505828935071189*^9, 3.505828947317532*^9}, 3.5058293651606803`*^9, 
   3.5058294294650826`*^9, {3.505830211616268*^9, 3.505830245380468*^9}, {
   3.5058302778494377`*^9, 3.5058302781361527`*^9}, {3.505830365592201*^9, 
   3.505830373166546*^9}, {3.511180538268361*^9, 3.511180542494628*^9}, {
   3.511181032973448*^9, 3.5111810610106583`*^9}, {3.51118130498621*^9, 
   3.511181314878165*^9}, {3.51118140362665*^9, 3.5111814058805513`*^9}, {
   3.5111814762606916`*^9, 3.5111815078923397`*^9}, {3.511181798352477*^9, 
   3.511181847098968*^9}, {3.5111818927662277`*^9, 3.5111819003422565`*^9}, {
   3.511181957210995*^9, 3.511181957612156*^9}, {3.511184604170356*^9, 
   3.511184610396845*^9}, 3.5111846515753098`*^9, {3.5111859239640617`*^9, 
   3.51118597803168*^9}, {3.511186675742653*^9, 3.5111867019571347`*^9}, {
   3.511186799090973*^9, 3.5111868324393067`*^9}, {3.5111870068680506`*^9, 
   3.511187016562927*^9}, {3.5111870687557955`*^9, 3.5111870808076143`*^9}, 
   3.511200362614037*^9, {3.511200429889489*^9, 3.5112004373709855`*^9}, {
   3.5112005312121286`*^9, 3.51120055210186*^9}, {3.511468608992117*^9, 
   3.5114686154544864`*^9}, {3.5114686807262197`*^9, 3.511468688589669*^9}, {
   3.511468790983526*^9, 3.511468907445187*^9}, {3.5114689627113485`*^9, 
   3.511468969000708*^9}, {3.51146899981647*^9, 3.511469025231924*^9}, {
   3.511469080496085*^9, 3.511469088046517*^9}, {3.511469120949399*^9, 
   3.5114691341821556`*^9}, {3.5114691752065024`*^9, 
   3.5114692060292654`*^9}, {3.511469245189505*^9, 3.5114693008466883`*^9}, 
   3.511469405720687*^9, {3.5114695975056562`*^9, 3.5114696912930207`*^9}, {
   3.511469735632557*^9, 3.5114697497363634`*^9}, {3.5114721865757427`*^9, 
   3.511472187559799*^9}, {3.5114738399203086`*^9, 3.5114739056930704`*^9}, {
   3.511484264878582*^9, 3.5114842786923723`*^9}, {3.5114843113092375`*^9, 
   3.5114843932689257`*^9}, {3.511484425501769*^9, 3.511484442733755*^9}, {
   3.511484474623579*^9, 3.5114844898144474`*^9}, {3.5114845584473734`*^9, 
   3.511484633724679*^9}, {3.5114847098950357`*^9, 3.5114847613329773`*^9}, {
   3.5114848279907904`*^9, 3.511484898606829*^9}, {3.511487429442585*^9, 
   3.51148744335338*^9}, {3.511487492490191*^9, 3.5114874927072034`*^9}, {
   3.5114875380667977`*^9, 3.5114875758429585`*^9}, {3.511487765181788*^9, 
   3.5114877820237513`*^9}, {3.511491520864601*^9, 3.5114915971079617`*^9}, {
   3.511491631012901*^9, 3.5114916558523216`*^9}, {3.5114916860270476`*^9, 
   3.511491716826809*^9}, {3.5114917802274356`*^9, 3.511491800777611*^9}, {
   3.511491834130519*^9, 3.5114918972691298`*^9}, 3.511491944007803*^9, {
   3.5143005397467766`*^9, 3.514300577002816*^9}, {3.514300616084067*^9, 
   3.514300835832892*^9}, {3.514300883447092*^9, 3.514300910515092*^9}, {
   3.5143009670928917`*^9, 3.5143009703376923`*^9}, {3.514301027904092*^9, 
   3.514301041975292*^9}, {3.514301076021492*^9, 3.514301167976283*^9}, {
   3.514301210317955*^9, 3.51430126817673*^9}, {3.5143012988797283`*^9, 
   3.5143014551257315`*^9}, {3.5143014908529606`*^9, 3.514301556590788*^9}, {
   3.5143018747464414`*^9, 3.5143022271442413`*^9}, {3.514303075250088*^9, 
   3.5143031477331533`*^9}, {3.5143031783903503`*^9, 3.514303242714563*^9}, {
   3.5143032797376003`*^9, 3.51430341830569*^9}, {3.5143034682888207`*^9, 
   3.5143034735460544`*^9}, 3.514303550824176*^9, {3.514303623084648*^9, 
   3.5143037427594175`*^9}, {3.514303782385671*^9, 3.5143038175668974`*^9}, {
   3.514304128556385*^9, 3.514304164868185*^9}},
 CellID->7775854],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`d$$ = {0.374, 0.31}, $CellContext`p$$ = 2, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`d$$], {0.374, 0.31}}, {-1, -1}, {1, 1}}, {{
       Hold[$CellContext`p$$], 2, "power"}, {2, 3, 4, 5, 6, 7, 8, 9, 10}}, {
      Hold[
       Row[{
         Pane[
          Manipulate`Place[1], ImageSize -> 215, Alignment -> Left], 
         Pane[
          ActionMenu[
          "value of c", {
           "0.38 - 0.212 i" :> ($CellContext`d$$ = {0.38, -0.212}), 
            "-0.731 + 0.164 i" :> ($CellContext`d$$ = {-0.731, 0.164}), 
            "0.361 + 0.324 i" :> ($CellContext`d$$ = {0.361, 0.324}), 
            "0.373 + 0.144 i" :> ($CellContext`d$$ = {0.373, 0.144}), 
            "0.367 + 0.144 i" :> ($CellContext`d$$ = {0.367, 0.144})}], 
          ImageSize -> 215, Alignment -> Right]}]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = Automatic, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`d$2452$$ = {0, 0}, $CellContext`p$2453$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`d$$ = {0.374, 0.31}, $CellContext`p$$ = 2},
       "ControllerVariables" :> {
        Hold[$CellContext`d$$, $CellContext`d$2452$$, {0, 0}], 
        Hold[$CellContext`p$$, $CellContext`p$2453$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Graphics[{{Thick, 
          RGBColor[0.8, 0, 0], 
          Dashing[{0.02, 0.008}], 
          Line[{{{
              Part[$CellContext`d$$, 1], -2}, 
             Offset[{0, -12}, $CellContext`d$$]}, {
             Offset[{0, 12}, $CellContext`d$$], {
              Part[$CellContext`d$$, 1], 2}}, {{-2, 
              Part[$CellContext`d$$, 2]}, 
             Offset[{-12, 0}, $CellContext`d$$]}, {
             Offset[{12, 0}, $CellContext`d$$], {2, 
              Part[$CellContext`d$$, 2]}}}]}, {
          PointSize[0.0001], 
          Point[
           $CellContext`cjc[$CellContext`p$$, Part[$CellContext`d$$, 1] + 
            I Part[$CellContext`d$$, 2]]]}}, AspectRatio -> 1, PlotLabel -> 
        Part[$CellContext`d$$, 1] + I Part[$CellContext`d$$, 2], PlotRange -> 
        1.2 {{-1, 1}, {-1, 1}}, Frame -> True, PlotRangeClipping -> True, 
        ImageSize -> 400], 
      "Specifications" :> {{{$CellContext`d$$, {0.374, 0.31}}, {-1, -1}, {1, 
         1}, ControlType -> Locator, Appearance -> Graphics[{
            Thickness[Large], 
            RGBColor[0.8, 0, 0], 
            Circle[{0, 0}], 
            Point[{0, 0}]}, ImageSize -> 24]}, {{$CellContext`p$$, 2, 
          "power"}, {2, 3, 4, 5, 6, 7, 8, 9, 10}, ControlType -> Setter, 
         ControlPlacement -> 1}, 
        Row[{
          Pane[
           Manipulate`Place[1], ImageSize -> 215, Alignment -> Left], 
          Pane[
           ActionMenu[
           "value of c", {
            "0.38 - 0.212 i" :> ($CellContext`d$$ = {0.38, -0.212}), 
             "-0.731 + 0.164 i" :> ($CellContext`d$$ = {-0.731, 0.164}), 
             "0.361 + 0.324 i" :> ($CellContext`d$$ = {0.361, 0.324}), 
             "0.373 + 0.144 i" :> ($CellContext`d$$ = {0.373, 0.144}), 
             "0.367 + 0.144 i" :> ($CellContext`d$$ = {0.367, 0.144})}], 
           ImageSize -> 215, Alignment -> Right]}]}, 
      "Options" :> {
       ControlPlacement -> Top, AppearanceElements -> None, 
        SynchronousInitialization -> False}, "DefaultOptions" :> {}],
     ImageSizeCache->{463., {246., 253.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>($CellContext`cjc = Compile[{{$CellContext`power, 
          Blank[Integer]}, {$CellContext`c, 
          Blank[Complex]}}, 
        Module[{$CellContext`imax = 1000, $CellContext`dzmax = 
          2500., $CellContext`maxpt = 
          10^5, $CellContext`z, $CellContext`dz, $CellContext`roots, \
$CellContext`branches, $CellContext`i = 2, $CellContext`res = 
          0. + 0. I, $CellContext`pt = 0}, $CellContext`branches = Table[
            
            Exp[-(((2. N[Pi]) 
               I) ($CellContext`k/$CellContext`power))], {$CellContext`k, 
             0, $CellContext`power - 1}]; $CellContext`z = 
          Table[0. + 0. I, {$CellContext`imax}]; $CellContext`dz = 
          Table[1., {$CellContext`imax}]; $CellContext`roots = 
          Table[1, {$CellContext`imax}]; Map[{
            Re[#], 
            Im[#]}& , 
           
           NestWhileList[(
            Part[$CellContext`z, $CellContext`i] = Part[$CellContext`branches, 
                Part[$CellContext`roots, $CellContext`i]] (
                Part[$CellContext`z, $CellContext`i - 1] - $CellContext`c)^(
                1/$CellContext`power); 
            Part[$CellContext`dz, $CellContext`i] = ($CellContext`power Abs[
                  Part[$CellContext`z, $CellContext`i]]^($CellContext`power - 
                 1)) Part[$CellContext`dz, $CellContext`i - 
                1]; $CellContext`res = Part[$CellContext`z, $CellContext`i]; 
            If[
              
              And[$CellContext`i < $CellContext`imax, 
               Part[$CellContext`dz, $CellContext`i] < $CellContext`dzmax], 
              Increment[$CellContext`i]; 
              Part[$CellContext`roots, $CellContext`i] = 1, While[
                
                And[$CellContext`i > 1, 
                 Part[$CellContext`roots, $CellContext`i] == \
$CellContext`power], Part[$CellContext`roots, $CellContext`i] = 1; 
                Decrement[$CellContext`i]]; Increment[
                
                Part[$CellContext`roots, $CellContext`i]]]; $CellContext`res)& \
, 0. + 0. I, 
            And[$CellContext`i > 1, 
             Increment[$CellContext`pt] < $CellContext`maxpt]& ]]], 
        RuntimeOptions -> "Speed"]; Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5147468292081165`*^9}]
}, {2}]],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel",
  FontWeight->"Plain"],
 StyleBox["\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Julia set. Drag the circle to set a new value of c or use the buttons to \
change the power of z. "
}], "FigureCaption",
 CellChangeTimes->{{3.509219656680394*^9, 3.509219694547472*^9}, {
  3.509220005381826*^9, 3.509220038615546*^9}, {3.5116282595647373`*^9, 
  3.5116282612153587`*^9}}],

Cell[TextData[{
 "To set the desired values drag the small circle around the graphics and \
watch the Julia fractal and the ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineFormula"],
 " values change in the above applet. The button-control on the right allows \
powers of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "n"], TraditionalForm]]],
 " higher than two. Use the menu in the top right corner to paste and \
evaluate a snapshot and build a grid of memorable shapes."
}], "Text",
 CellChangeTimes->{
  3.506040256577675*^9, {3.509123611220072*^9, 3.5091236153725185`*^9}, {
   3.509127105043563*^9, 3.5091271534407244`*^9}, {3.5091272000808706`*^9, 
   3.5091272091606283`*^9}, {3.5111805243962*^9, 3.5111805265098343`*^9}, {
   3.5114845513499675`*^9, 3.5114845520540075`*^9}, {3.511630519483938*^9, 
   3.5116305250143385`*^9}, {3.5116308495770764`*^9, 3.5116308505292377`*^9}, 
   3.5147390572545395`*^9}],

Cell[TextData[{
 "The equation for the quadratic Julia set is a ",
 "conformal mapping",
 ", so angles are preserved. Let ",
 Cell[BoxData[
  FormBox["J", TraditionalForm]], "InlineFormula"],
 " be the Julia set, then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "\[Prime]"], "\[RightTeeArrow]", "x"}], 
   TraditionalForm]], "InlineFormula"],
 " leaves ",
 Cell[BoxData[
  FormBox["J", TraditionalForm]], "InlineFormula"],
 " invariant. If a point ",
 Cell[BoxData[
  FormBox["P", TraditionalForm]], "InlineFormula"],
 " is on ",
 Cell[BoxData[
  FormBox["J", TraditionalForm]], "InlineFormula"],
 ", then all its iterations are on ",
 Cell[BoxData[
  FormBox["J", TraditionalForm]], "InlineFormula"],
 ". The transformation has a two\[Hyphen]valued inverse. If ",
 Cell[BoxData[
  FormBox[
   RowBox[{"b", "\[LongEqual]", "0"}], TraditionalForm]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineFormula"],
 " is started at 0, then the map is equivalent to the ",
 "logistic map",
 ". The set of all points for which ",
 Cell[BoxData[
  FormBox["J", TraditionalForm]], "InlineFormula"],
 " is connected is known as the ",
 "Mandelbrot set",
 "."
}], "Text"],

Cell[TextData[{
 "For a Julia set ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["J", "c"], TraditionalForm]], "InlineFormula"],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[LessLess]", "1"}], TraditionalForm]], "InlineFormula"],
 ", the ",
 "capacity dimension",
 " is"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["d", "capacity"], "\[LongEqual]", "1", "+", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"\[LeftBracketingBar]", "c", "\[RightBracketingBar]"}], "2"], 
    RowBox[{"4", "ln", "2"}]], "+", "O", 
   RowBox[{"(", 
    SuperscriptBox[
     RowBox[{"\[LeftBracketingBar]", "c", "\[RightBracketingBar]"}], "3"], 
    ")"}], "."}], TraditionalForm]], "EquationNumbered",
 TaggingRules:>{"Punctuation" -> "."}],

Cell[TextData[{
 "For small ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["J", "c"], TraditionalForm]], "InlineFormula"],
 " is also a ",
 "Jordan curve",
 ", although its points are not ",
 "computable",
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Mandelbrot set", "Section",
 CellChangeTimes->{3.514287340763647*^9}],

Cell[CellGroupData[{

Cell["Basic definitions", "Subsection",
 CellChangeTimes->{{3.506042240235095*^9, 3.5060422451425858`*^9}, 
   3.514287340765649*^9}],

Cell["\<\
The term Mandelbrot set is used to refer both to a general class of fractal \
sets and to a particular instance of such a set. In general, a Mandelbrot set \
marks the set of points in the complex plane such that the corresponding \
Julia set is connected and not computable.\
\>", "Text",
 CellChangeTimes->{3.514287340765649*^9}],

Cell["\<\
\[OpenCurlyDoubleQuote]The\[CloseCurlyDoubleQuote] Mandelbrot set is the set \
obtained from the quadratic recurrence equation\
\>", "Text",
 CellChangeTimes->{3.514287340765649*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["z", 
    RowBox[{"n", "+", "1"}]], "\[LongEqual]", 
   SubsuperscriptBox["z", "n", "2"], "+", "C"}], 
  TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5142873407666492`*^9}],

Cell[TextData[{
 "with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["z", "0"], "\[LongEqual]", "C"}], TraditionalForm]], 
  "InlineFormula"],
 ", where points ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]], "InlineFormula"],
 " in the ",
 "complex plane",
 " for which the orbit of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "n"], TraditionalForm]], "InlineFormula"],
 " does not tend to infinity are in the ",
 "set",
 ". Setting ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "0"], TraditionalForm]], "InlineFormula"],
 " equal to any point ",
 StyleBox["in the set",
  FontSlant->"Italic"],
 " that is not a periodic point gives the same result. The Mandelbrot set was \
originally called a ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]], "InlineFormula"],
 " molecule by Mandelbrot. J.\[NonBreakingSpace]Hubbard and A.\
\[NonBreakingSpace]Douady proved that the Mandelbrot set is ",
 "connected",
 "."
}], "Text",
 CellChangeTimes->{{3.5060340149819965`*^9, 3.5060340164201403`*^9}, {
   3.5091169376611567`*^9, 3.50911695065604*^9}, {3.5091177246753416`*^9, 
   3.5091177556583414`*^9}, {3.5091183259811373`*^9, 
   3.5091183297564583`*^9}, {3.509118427040553*^9, 3.5091184278517585`*^9}, {
   3.5091185643526335`*^9, 3.50911856697345*^9}, {3.5091187718335204`*^9, 
   3.50911877381472*^9}, {3.5091191311087685`*^9, 3.509119132341177*^9}, {
   3.509124073153014*^9, 3.5091241169023113`*^9}, {3.5091253079510837`*^9, 
   3.5091253088720503`*^9}, {3.510877304940753*^9, 3.5108773056004887`*^9}, 
   3.514287340768651*^9}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzsvQlcVXX+///6/1tcy61y30EUZd8FEUFFREURVxS3EjVDURNF09Bcbioi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    "], {{0, 501}, {501, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSizeRaw->{501, 501},
  PlotRange->{{0, 501}, {0, 501}}]], "Text",
 CellChangeTimes->{
  3.510877404914747*^9, {3.5142872623911753`*^9, 3.514287274626177*^9}, 
   3.514287340774657*^9, {3.514290809366468*^9, 3.514290822628745*^9}, 
   3.514290864451*^9, {3.5142909650343595`*^9, 3.5142909998857384`*^9}},
 ImageSize->{646, 635},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel",
  FontWeight->"Plain"],
 StyleBox["\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Mandelbrot set."
}], "FigureCaption",
 CellChangeTimes->{{3.509219656680394*^9, 3.509219694547472*^9}, {
   3.509220005381826*^9, 3.509220038615546*^9}, {3.5099811562996902`*^9, 
   3.509981166625554*^9}, {3.5100571462440357`*^9, 3.510057153185749*^9}, {
   3.5108775001566353`*^9, 3.510877511335162*^9}, 3.514287340774657*^9}],

Cell[TextData[{
 "A plot of the Mandelbrot set is in ",
 StyleBox["Figure 5",
  FontWeight->"Bold"],
 " in which values of ",
 Cell[BoxData[
  FormBox["C", TraditionalForm]], "InlineFormula"],
 " in the complex plane are colored according to the number of steps required \
to reach ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["r", "max"], "\[LongEqual]", "2"}], TraditionalForm]], 
  "InlineFormula"],
 ". The kidney bean-shaped portion of the Mandelbrot set turns out to be \
bordered by a cardioid with equations"
}], "Text",
 CellChangeTimes->{{3.5108799747863874`*^9, 3.510880010704015*^9}, {
   3.5116284088822393`*^9, 3.5116284094119897`*^9}, 3.5142873407756577`*^9}],

Cell[BoxData[
 FormBox[Cell[BoxData[
   FormBox[GridBox[{
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{"4", "x"}], "DisplayFormula"], TraditionalForm]]]]], Cell[
       TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{"2", "cos", "t", "-", "cos", 
           RowBox[{"(", 
            RowBox[{"2", "t"}], ")"}]}], "DisplayFormula"], 
         TraditionalForm]]]]]},
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{"4", "y"}], "DisplayFormula"], TraditionalForm]]]]], Cell[
       TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{"2", "sin", "t", "-", "sin", 
           RowBox[{"(", 
            RowBox[{"2", "t"}], ")"}], "."}], "DisplayFormula"], 
         TraditionalForm]]]]]}
     },
     GridBoxAlignment->{
      "Columns" -> {Right, Center, {Left}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]]], 
  TraditionalForm]], "EquationNumbered",
 TaggingRules:>{"Punctuation" -> "."},
 CellChangeTimes->{{3.505697351732292*^9, 3.5056973684002457`*^9}, 
   3.5108796973594027`*^9, 3.5142873407776594`*^9}],

Cell[TextData[{
 "The adjoining portion is a circle with center at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "0"}], ")"}], TraditionalForm]], 
  "InlineFormula"],
 " and radius ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1", "/", "4"}], TraditionalForm]], "InlineFormula"],
 ". The region of the Mandelbrot set centered around ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "0.75"}], "+", "0.1", "i"}], TraditionalForm]], 
  "InlineFormula"],
 " is sometimes known as the seahorse valley because the spiral shapes \
appearing in it resemble seahorse tails (Munafo). Similarly, the portion of \
the Mandelbrot set centered around ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.3", "+", "0", "i"}], TraditionalForm]], "InlineFormula"],
 " with size approximately ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.1", "+", "0.1", "i"}], TraditionalForm]], "InlineFormula"],
 " is known as elephant valley. "
}], "Text",
 CellChangeTimes->{{3.5108792840687847`*^9, 3.510879289249712*^9}, {
   3.510879531386818*^9, 3.510879535690096*^9}, 3.5142174137264647`*^9, 
   3.5142873407786603`*^9}],

Cell["\<\
Shishikura (1994) proved that the boundary of the Mandelbrot set is a fractal \
with Hausdorff dimension 2, refuting the conclusion of Elenbogen and Kaeding \
(1989) that it is not. However, it is not yet known if the Mandelbrot set is \
pathwise\[Hyphen]connected. If it is pathwise\[Hyphen]connected, then Hubbard \
and Douady\[CloseCurlyQuote]s proof implies that the Mandelbrot set is the \
image of a circle and can be constructed from a disk by collapsing certain \
arcs in the interior (Douady 1986).\
\>", "Text",
 CellChangeTimes->{3.5142873407786603`*^9}],

Cell[TextData[{
 "Zooming in on the fractal boundary encompassing the Mandelbrot set shows \
the same type of patterns appearing on deeper and deeper levels of resolution \
reflecting on the property of self-similarity. A few regions of the \
Mandelbrot set at various magnifications are shown in",
 StyleBox[" Figure 6",
  FontWeight->"Bold"],
 ". They were produced with a code based Demonstration by S. M. Blinder ",
 ButtonBox["\[OpenCurlyDoubleQuote]Magnified Views of the Mandelbrot Set\
\[CloseCurlyDoubleQuote]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/MagnifiedViewsOfTheMandelbrotSet/"]\
, None},
  ButtonNote->
   "http://demonstrations.wolfram.com/MagnifiedViewsOfTheMandelbrotSet/"],
 ". The choice of the color scheme to plot the Mandelbrot set is quite \
arbitrary, and a different method from ",
 StyleBox["Figure 5",
  FontWeight->"Bold"],
 " was used."
}], "Text",
 CellChangeTimes->{
  3.509127658850382*^9, {3.5108826510764427`*^9, 3.5108827215192547`*^9}, 
   3.510882776625203*^9, {3.5108845208282433`*^9, 3.510884548340234*^9}, {
   3.510886744736324*^9, 3.5108867705949764`*^9}, {3.5116284800090475`*^9, 
   3.5116284900898895`*^9}, {3.5116285420210295`*^9, 3.5116285467264614`*^9}, 
   3.5142873407786603`*^9}],

Cell[BoxData[
 DynamicBox[ToBoxes[
   ImportString[
   "/9j/4AAQSkZJRgABAQAAAQABAAD/\
2wBDAAYEBQYFBAYGBQYHBwYIChAKCgkJChQODwwQFxQYGBcU\n\
FhYaHSUfGhsjHBYWICwgIyYnKSopGR8tMC0oMCUoKSj/2wBDAQcHBwoIChMKChMoGhYaKCgoKCgo\n\
KCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCgoKCj/wAARCAKvBBkDASIA\n\
AhEBAxEB/8QAHwAAAQUBAQEBAQEAAAAAAAAAAAECAwQFBgcICQoL/8QAtRAAAgEDAwIEAwUFBAQA\n\
AAF9AQIDAAQRBRIhMUEGE1FhByJxFDKBkaEII0KxwRVS0fAkM2JyggkKFhcYGRolJicoKSo0NTY3\n\
ODk6Q0RFRkdISUpTVFVWV1hZWmNkZWZnaGlqc3R1dnd4eXqDhIWGh4iJipKTlJWWl5iZmqKjpKWm\n\
p6ipqrKztLW2t7i5usLDxMXGx8jJytLT1NXW19jZ2uHi4+Tl5ufo6erx8vP09fb3+Pn6/8QAHwEA\n\
AwEBAQEBAQEBAQAAAAAAAAECAwQFBgcICQoL/8QAtREAAgECBAQDBAcFBAQAAQJ3AAECAxEEBSEx\n\
BhJBUQdhcRMiMoEIFEKRobHBCSMzUvAVYnLRChYkNOEl8RcYGRomJygpKjU2Nzg5OkNERUZHSElK\n\
U1RVVldYWVpjZGVmZ2hpanN0dXZ3eHl6goOEhYaHiImKkpOUlZaXmJmaoqOkpaanqKmqsrO0tba3\n\
uLm6wsPExcbHyMnK0tPU1dbX2Nna4uPk5ebn6Onq8vP09fb3+Pn6/9oADAMBAAIRAxEAPwD2PVfi\n\
7oemapeWE9lqTS2szwuyIm0lWIJGX6cVU/4XV4f/AOfHVf8Av3H/APF14x44/wCR01//AK/5/wD0\n\
Y1YtfPTzKupNJrfsfaUsjwkqcZNPVLr5I+gf+F1eH/8Anx1X/v3H/wDF0f8AC6vD/wDz46r/AN+4\n\
/wD4uvn6io/tPEd19xp/YOD7P7z6B/4XV4f/AOfHVf8Av3H/APF0f8Lq8P8A/Pjqv/fuP/4uvn6i\n\
j+08R3X3B/YOD7P7z6B/4XV4f/58dV/79x//ABdH/C6vD/8Az46r/wB+4/8A4uvn6ij+08R3X3B/\n\
YOD7P7z6B/4XV4f/AOfHVf8Av3H/APF0f8Lq8P8A/Pjqv/fuP/4uvn0cnA5PtU0VrPLu8uF229eK\n\
P7Tr919xLyTAx3v/AOBHvn/C6vD/APz46r/37j/+Lo/4XV4f/wCfHVf+/cf/AMXXhqaRdsASirn1\n\
apxoU3GZox64Bpf2rW7r7if7GwPZ/e/8j2v/AIXV4f8A+fHVf+/cf/xdH/C6vD//AD46r/37j/8A\n\
i68bXQk2ndO2e2AKemhwDG6R2P5Uv7Xrd19wv7GwX8svvPYf+F1eH/8Anx1X/v3H/wDF0f8AC6vD\n\
/wDz46r/AN+4/wD4uvI00e0XqjN9WNB0a0z0cf8AAqX9r1u/4CWT4N/Yl/4Eeuf8Lq8P/wDPjqv/\n\
AH7j/wDi6P8AhdXh/wD58dV/79x//F15Iuj2YzlGb6sf6U1tFtT03j/gVH9r1u/4B/Y+Dv8ABL/w\n\
I9d/4XV4f/58dV/79x//ABdH/C6vD/8Az46r/wB+4/8A4uvHToUW4YmcL3GKik0I4Plz89gwp/2t\n\
W7r7iv7GwV7csvvPZ/8AhdXh/wD58dV/79x//F0f8Lq8P/8APjqv/fuP/wCLrxKXRLheY3R+foar\n\
SabdxtgwluM5U5prNaz6r7gWTYHz+9/5Hu3/AAurw/8A8+Oq/wDfuP8A+Lo/4XV4f/58dV/79x//\n\
ABdeAOjpnejLg4ORimU/7TxHdfcWsiwT2T+8+gv+F1eH/wDnx1X/AL9x/wDxdH/C6vD/APz46r/3\n\
7j/+Lr5+oo/tPEd19w/7BwfZ/efQP/C6vD//AD46r/37j/8Ai6P+F1eH/wDnx1X/AL9x/wDxdfP1\n\
FH9p4juvuD+wcH2f3n0D/wALq8P/APPjqv8A37j/APi6P+F1eH/+fHVf+/cf/wAXXz9RR/aeI7r7\n\
g/sHB9n959A/8Lq8P/8APjqv/fuP/wCLo/4XV4f/AOfHVf8Av3H/APF18/UUf2niO6+4P7BwfZ/e\n\
fQP/AAurw/8A8+Oq/wDfuP8A+LqG5+OOgwJuGla1KO/lxxEj8PMrwSimszr9bfcJ5BhGtE/vPaD+\n\
0Z4VViG0zXAR1Bhi/wDjlH/DRvhT/oG65/36i/8AjleHXdlb3a4niVvQ9CPxrBvfDsiZazk3j+4/\n\
B/Oumnmblo9DkqZDThrFNr1Po/8A4aN8Kf8AQN1v/v1F/wDHKP8Aho3wp/0Ddc/79Rf/AByvlSaK\n\
SFykyMjDswxTK6vrM31ON5bQW6f3n1d/w0b4U/6Buuf9+ov/AI5R/wANG+FP+gbrn/fqL/45XyjR\n\
R9YmH9nUOz+8/RDTrpL7T7a7iVljuIllUN1AYAjPvzVisvwp/wAivo//AF5w/wDoArUrvWx4ElZt\n\
BRRRTEFfK3x2+NvjDwZ8TdT0TRJrNbGBIWQSW4dstErHn6k19U18EftW/wDJb9b/AOuVt/6ISgC9\n\
/wANL/EL/n507/wEWj/hpf4hf8/Onf8AgIteKUUAe1/8NL/EL/n507/wEWj/AIaX+IX/AD86d/4C\n\
LXilFAHtf/DS/wAQv+fnTv8AwEWj/hpf4hf8/Onf+Ai14pRQB7X/AMNL/EL/AJ+dO/8AARaP+Gl/\n\
iF/z86d/4CLXilFAHtf/AA0v8Qv+fnTv/ARaP+Gl/iF/z86d/wCAi14pRQB7X/w0v8Qv+fnTv/AR\n\
aP8Ahpf4hf8APzp3/gIteKUUAe1/8NL/ABC/5+dO/wDARaP+Gl/iF/z86d/4CLXilFAHtf8Aw0v8\n\
Qv8An507/wABFo/4aX+IX/Pzp3/gIteKUUAe1/8ADS/xC/5+dO/8BFo/4aX+IX/Pzp3/AICLXilF\n\
AHtf/DS/xC/5+dO/8BFqpqP7QfjPUlRdRi0S7VCSon06OQKT6Z6V4/RSaT3Gm1se0QftI+PoIY4Y\n\
JdMjijUIiJZKFVQMAADoBXpnhr4j/EjW9Gsbwaxo0Uk7OzRLBG7CMAc9cbvmX5c5wc8cZ+TCCACQ\n\
QD0969A+F/iqfQYb6w02CObUdTeOJDcOqxIoOWLFuMH6jHWuTHe1VPmouzT8tuu+1tzuy9UpVHCs\n\
r3Wm+/y1bZ9V6T4x8VT26edfWz7ABNMEj6+yAZGQRwSOlS3HxA1tt8Vu8YccBzGp5+mK5PQr6z0S\n\
ymtEYzIsu11jG5VkKoVSM5wQ27j3I470sclxNdkvaiCMRPKs4O8EKeQ2OM9PunqfTJHyNfF491ea\n\
MrRW2u/r+K6LQ96OGoqTU6Sstum34v7m/Lc6m68c+IWsZ44LhIbgOPKme3Vhs9XGcZ468AfpVK48\n\
eeJbOSytrrUInc7mllS1VC442hQQdpJOCCMj9TzV3fFJMyyBRngdRUsM0DxSzyoGTZ5ZQyFRKT/l\n\
fXORxinHG4uMbubd/P09P16suWCo0v3k4Kz/AK7f15Hc6v441i2+z+RPCFlAKllUluM5AH1qs3jz\n\
XYXiElxAwkYLgRKCM+54/OuORLW1hLwxlLuZkd5FjQsy4UMCAOBkHgDPGfarOlaDcajYGW3kiijQ\n\
bItw3btoAzxkY479evFTPFV6L9pOtLlv1dvO2nlZGUqOFhBqSSt1t939eWx0eleOfEKS6g2o3sEq\n\
KR5MaQKrRADLq56M2D/Cex6UuofELXopHETQAYJQeVk47Z96wrBEkupoLjdayhfKdGO4vuU/K5Aw\n\
SCflPsPWm3MFuWs1Jfe8mwnzhtYB1BO5RnjIAx3yDitfruJlU92o7ev3dOv3fiP2WGjPmlS+Xyvf\n\
+uh3Wh+ItevbCKe5u41aRcgRwr/Wo77xP4ksJ/3gFxbudivHGoZSehIAOfTGMe/PHO+Gr67s7GaC\n\
6EZitYwoYcOrEn5SP1HTgisbUPFcqzssAY4OCQf6964P7QzFV5LnbS6XOaGCdepNxUeW+mn9O52+\n\
heNtX1LVZoXKRJFGGaJkG7cTj0GBweDzXRHXtQH3igB7hBxXmGleJpbhyGZiw6q3Bx7HvXZaddm4\n\
hYlty7dwJ61zYvM8cp8yqOK7XOfG4B0/fskl22Keq+Ndds9XFqs0BAAO3ygS2emP8BTZ/HWvJdQx\n\
zKsIZMuqW+/awIGM55zz2GARmuX1Ewy65fvdLN5gdYUG7IVdhBKgA/NjPGO496fo+pRaVNeNqFtc\n\
mcx/M+0bgAMkdscHt1+tegsfi1R5udt2X6dfn6/I6ZUIOmmoK9l0V9ba7+Zpa38Tta0qNIZZLZrt\n\
hl9sQ+T/AGfc/pVHR/i7q8l/DHeNEYnYKf3QX9a4vxHp8l5q0U1qyyxXOAmGBKnuD9Oavv4Jl+yn\n\
ypH+0YyN5VQT6Y6iu2niqjpJ1Kz5n/XyPYo5bgpUU2lr1PQLXx3ryX4hvLi2KPIIFeJEK+YQcd84\n\
yP51teDNb8U3viRIdYltvsBDDaIgrFgMjFeYfbIDKZNSaZY7aERTIqgMrAD5mB6sWIHTGMcnnHaf\n\
DG9mv/EVpP8AaxeWvlvGhY4eMgDqMckjvk9fznC4vGPE04yk7NpO54tfDKnSm+RbWvbr5ef6HsdF\n\
FFfZnzoUUUUAcv8AE/Wrzw74D1fVdNZFu7aNWjLruGS6jkfQmvm21+Ofju6mEUEtkzn/AKdl4+tf\n\
Q3xltzdfDLXYA23fEoz6fvFr5dsLKGxgEcC49WPVj715ePxToNKL1PoMnwUMTBymlZM9Etvix4uW\n\
EC4urR5O5W3AH4VL/wALa8Uf89rX/vwK8/orxnjK7152fQrLsKtPZr7j0D/hbXij/nta/wDfgUf8\n\
La8Uf89rX/vwK8/oo+t1/wCd/eP+z8L/AM+19x6B/wALa8Uf89rX/vwKP+FteKf+e1r/AN+BXn9T\n\
2Mfm3kSYJG7Jx6Uvrlf+d/eTLAYVJv2a+49Xt/iL4iMKGSa3LkZP7gD9Kk/4WLr/APz1t/8AvyK4\n\
6isfruI/nf3mSwGGS/hr7jsf+Fi6/wD89bf/AL8itTT/ABtrU1uzXE0EZJ2q3ljAzjDH25/SvPFG\n\
5gPWty9jEOjyoBjCDgHODuFZPHV3XpUvaP3n3MMRg8OklGCTbXTzRv3HjDxXFcMCm941LGKOJNkn\n\
A6McHvzjNVdH+KGs32pCwntBbXeeUdRzg/MMEDHHTJ6is/SNWj1C3Ww1A7ZsYjlPQntn3/nWN4mW\n\
6s7e3mg/4+UufsyggEMGBJU+oyo/Ou3ESxVJuLm79NWOGX4ealCVNKa27ddfNeuq7nRx/EXX7fUI\n\
5Lm+sLnSpGI8yJFBUEgBiDzwSM49615fG2txOUd4wR/0zGD7iuI8QafLqOkRQxCG3kjZWERxGpJB\n\
3bfUZ7/Xtiuf0HxRfaFIbDUIftVlGxXy3ILR9vlJ/l/KsKONxM43U22ul/x7G+CwOHxEG+SPMumi\n\
uvJ7XPbdN8Z3d3GoZo1m7rt6+4/z/jV7/hI771j/AO+a8sv/ABVokVqky2FyZZF3RoU8sH8QenHb\n\
NP0zxHMt/BZajcLbyXCh43ADKueiMWzz75x2xWkcfWteTa+ZxVsohJ3pq176Py3ta+3/AA1z02Xx\n\
LeqhLSRIP7xAGPzrBvPF2roUNvq1vtd9iiS0746ZHX8u49awPEL22lWT3mp3ckpAxFGCAzn0HtXI\n\
3V2RoTahIjPdyqsQKE+WgJyNo7AYGe+7PPWnHMqzScJPV21/4JVLK6UIKdua7stFb8ex6WfEXjAq\n\
GhudPlU90Qf1qEeJvGxONluP+AJ/jWTYTTwW1vfwDfazosjIOgyOnt9f/wBVdDbzx3EQkiYFT+Y9\n\
jXXTzOrJbmeJoRw+qpxa72/B6jYde8Yuf3lzYxj3jB/lWxaa9q0SH7TdRzue4iCAfhWdWLrOpKEM\n\
EDZJGHYHjHpSqY2s18Ry0sP9bmoRgl6Iu6v4+1SG3v5bWSILDCzRkxjkjofzqHRvH2u3NvYfbhCj\n\
zFyxiQE7cAqcc465+mTXJeKd2neGZLiVV3zSoio/IIB3cjv90Umk6gIhY30sDW9nPCYZ5IfmVSSR\n\
ls5PofavNxGOxHJeE3v37I9HGYGhClF06atdq/ey2/XzehJq/wAX/Ea3T/Ymt0hUkANECTXdXHjH\n\
WEgt7mKWJ7eVFfIjGORXlOs6Tp1zeFbWeWOSVsRmSPajZ75z0Pr7GtKx1y48LWkdjqMQvbTDCN4z\n\
jYQSCnPUd/oe9VHH15xjySd+qb3OlYfBVIQhTprmXRqza+fVdD1y38U3k8KyRtGVYZ+709qhvtd1\n\
iRQbO7ihcdmhDA/4V53pfiS2eeM2sNzbxTFQqXAAR2PZWBOD9eP0FdKmq22SspeJxwQ6n+ma64Y2\n\
r1k0/M8mtljpTvThdfJ/J7heeKPGdtkn7PKo/iihDfp1/Sso/EbxGpw01uCOxgFakms2qdC7+6j/\n\
ABxVSfUYLpJPNs0lhjXLPIQAo9TxxXXHM5R+M6aWH0/eYdfgvzY2L4ma0FPnCBzgAFVC8+p61c/4\n\
WTd/89m/8B1/xrHGnaLepvi863BON2SFJwD36cEHnFRzeEXxm3u1Ps6Y/UUva0K/vc8o+kn/AMEc\n\
qGA05oct/LT9Ua0nxM1NXxGqugI5KhSR9MHH51SPxI8REkia2HsIRxWU/hfUVbCiFx6q/wDjUJ8O\n\
aoCf9HB/7aL/AI12UalKmrKbfq2/zNoYfL1som1/wsfxF/z3t/8AvyKP+Fj+Iv8Anvb/APfkVlp4\n\
X1FmwwhQerP/AIVet/CJzm5uh9I1/qf8KuWMpr7QSjl0d4x+4m/4WP4i/wCe9v8A9+RWtpXivxZq\n\
BDebbwwf89HgHP0Hem2GiWNkQ0cO+QfxyfMf8BWlXJVzCT0pnn16uG2pUl6tfobA8RX4AyyE/wC7\n\
1qv/AMJjJ/z8wf8AfB/wrmNcvhHGbeP77D5j6D0/H+X1rC59a4Xiq3ST+82wmUU6sOeorX2OI8cf\n\
8jpr/wD1/wA//oxqxa2vHH/I6a//ANf8/wD6MasXqcDk+lYVPjl6v82e/Q0pR9F+SCirlrptzcBW\n\
VNiHnc3pWlb6HGMGeQucDheBnvWTkkN1Y9NTBHJwOT6CrVvp91OoZIiFIyC3ANdPBbQwDEUar17c\n\
1LWbqdjN1JPyMOLQj/y2mA9lFXYtItI+qF8jHzGr9LUObZLu92RxwxR42RquOBgdKfS0lSJJLRC0\n\
UUlAxaSrEFrLMeBhe5P4f41dj0+NFDTyKBkDcWCrn0yawqYmnB8t7vstWZyqxjuzKp7Ruoyyso9S\n\
MVpm40+JjH5sXU54LAH8sflU6Xdq+RFcxED3Kj9cVNSpiYrmVGVvR/5GbrP+V/j/AJGOIZCMhePq\n\
KbsbdtCkn0HNdE25SQ2QR1BpMn1NcKzKX8pKxD7HOMpU4YEH0NFdA0aNklFyRgkDB/Oq0tjE/wB3\n\
KHjpW0Mxg/iVi1XT3Mikq3PYyRDcuGUckjt1qqQQcEEH3rup1YVFeDuaqSlsNZVdSrgMp6gjIqvP\n\
YW0xJkiXJGMjirVJWl7DcU9zHl0OI/6qV1OO/NUbjSbqInYolXjlev5V01LVKo0NOS2ZxLqyNh1K\n\
npgjFJXaSxJKuJEVh7is650aCTmImJs9uR+VaKoupaqtbo5yirt3plzbqWKh0AyWXtVLocHg+lWn\n\
fY1jNS2CiiimUFFFFABRRRQBFPBFcRlJo1dT2YVg33h3q9k+P+mbn+Rro6K0hVlT+FmVSjCp8SPP\n\
riCW3kKTxsjehqKvQpoY54ykyK6HsRWBqHh7q9k//bNz/I1208XGWktDzquClHWGqPuHwp/yK+j/\n\
APXnD/6AK1KzPC6lfDOkKwwRZwg/98CtOvoVsfDT+JhRRRTJCvgj9q3/AJLfrf8A1ytv/RCV9718\n\
EftW/wDJb9b/AOuVt/6ISgDyKiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACp4b\n\
WeWJ5YoXeOMgOyjIGemaS0ELXCC6Z1h/iKDJ/Cvf/h7qfhWx0fVLjSLa2ik8uKON7iQbmm2bmLgk\n\
DGfugcErx83TixuLeGimo3/I9DAYFYpu8rW6aX+59O5D4R0/R9W8NaVDrWjKdVhc/ZreG1MeDtJ3\n\
OM7nDZUk8D5Ryeaj0P4Ww2t5Be3Rinxu8wTlY4pecAqh5x65wfQZr0nQ71bdkvLgBr0xKNhLIqLt\n\
y5O77qj5h1JH4c17XWo9UubiaS0nsjGN0YnUqJF25OCQPQkHuPSvmcRXxNCTVJXi1e9316Jb6X36\n\
/I9/2ack6i0ilrbe2l7frbuZVr4b0/SbW7gsZbgvvBiacsURC6kmQA7SqsuRx6Dmr9rDNaiOG35Y\n\
Su8YUKNuVCklcFQD83GT1PAzzZvp/NYllwqjoQMj1FS+EWWS8WaUgsZlBz2Hb9a4/azjTc5av9en\n\
3HX7FxpuctUrab9Nvw6HWaR4et7SFXu1E1wwywPQe1WZfD+mK5nmt1HJOzJK5PX5c4rUbiXn1qHV\n\
ThUP8IBNfOfWKs535nqfOUa9XEVHzSa8loYEq6VpYn8q0UmbBZXYnp39qzbfxRbWQEVsIooc52xg\n\
4z65rB8T3LyOik8OS5/pXH38zNK0YJCLxj1NetQwftl77bufR0MvpyXvK7PQJrzSLzVpbia8EcUo\n\
JdY/v7jgYORjbgHuevGKhN3plvZj+0pQ23KQrEQSOc+ZweQePl498np54q5IAGSTxiui03wxNOVa\n\
7YxFukSDc5/w/WvVng/ZQ/eTstNOun9Wf5m6yiCafO0l/XqbJ8R2ltYXMayiUT5cqnGHwMMBt4z0\n\
wSenU9+JmnklJJbAHRRXfW/hK3UK32Qsw4zLNgn6jI/lVa98L2gjP7iW2JPDgkjP48VNF4anJt31\n\
6nVhsPQoXjCVzktMu5IbqMbicNkexr0u7v57WzgsrTzo7uQCcsAApj5O3dng8E/hXBW2kPBr9vaz\n\
5KsSyMo++ACePfiusupbaa8knh2WavC24OC8jFlxyMcA+mSMDjrWOLp03Wj1W/8Alf8Ar8TgzO3P\n\
GHz2/r+t7DdPeWaGdJIXeZ5M+WfvFDkByRkYOO/YjIHSqd/qdrZbII3uJbwq0c0cLAoc9EVsdM4P\n\
c11nh+2il0O7IVIZxI6SSN94gdNx+mOPQV5/c6LdWd6upbBLZiQShxzuAOTj8j9MVnSqU61aUWrJ\n\
dPPt/WpzYSNGvUca0tn6X2/r8TtPDOjTPdSXly4e9nBI4+SBPQY7n9fzNbl9LZae3l+W1xPjnc3A\n\
+vb9KsaE6hZQCDmNCpHdeen5iudgVry9w5OXJdyMfj+pA/GumDjaVWq/div6/wCGLrTbm47Jdv6/\n\
r1LUepCSZUNqGI5CQs6kc4ycE4HvW94EiaPxcZRbSRJMhLZkVgWA68c9MDp29SapSNBYW+5yEQfq\n\
al8A6pJf+L4lxshEblV79Op/z/jXLl2YSxOLgqNNKN1du/8AV/vOKvOVWjOy0SPWqKKK/RD5YKKK\n\
KAOT+K3/ACT7Wf8Armv/AKGtfL1fUXxV/wCSfaz/ANcl/wDQ1r5dr57N/wCLH0/U+v4e/wB3l6/o\n\
goooryj3wooooAK1PD8e6eSQ/wAI2isuug0KLZaFyoBc5z6jt/WpnsZ1NkjRopaVVLMAOprEgvaP\n\
B5lxvPROfxrW1CMy2Nwi43FMgn2IJ/QGiyg+z26p/F1NWAgk/dsWCyAoSpwQCMHGfrXgyxf+1RrL\n\
aLX3J/8ADnm1qnNLm7focTXTyRHUtOsb15/LeMMjOIhIVfAG7k9cKOR6e9cy2Nx29O1dl4ORZtIu\n\
IpBuQynj8BX6FmVJVaN2dmLkoQU5K6vr6Pc5S2S60S7Y31zHd6Yd7LclCzxuV4wDyrHjv+NMk1nR\n\
p5DdXMcbyvuyyRbZM9s/wg9eeTx78dLcxPYXhUgMvow4dfcVT1fwLYajGLrSn+xTuN2w8xnPt2/D\n\
8q+cqQpxleel+q/r8vuNXTw85e0nLl5lo1t87aq/dfcTadPHqkdsdLaCYHPmR3YDBSBgZOM4xjAH\n\
p+IpXNvpuoW6Q6grrfRychicEtjccDB4x0/yOW0S0vLPxCbWRTFLCx83n7oHOfftj1zXY6jpP/CQ\n\
3/n2m2e0hkSVWLELvClSQM47k8g8jPpnlqUlRqWcrR3uebiqP1WektN732+fmnoYV74MuW1GZYWI\n\
tEJw+N21R2+o9K0pY7aC3sbCymS7hQM0u/cqEMMbeBknqcdtpNPt7+eGW4S0uJLcqcPGxAUMfmbB\n\
II6HqOcjjrzJptza6dqO69gdzbqcrgFkcH2+90POfTAHQOTrSjzTd7bW9Ov9IVStWqr3nfl6ddPX\n\
8LMxbXxVeeHLm409bZJbSKVtkTkqyAnPDfrzWjB4inmgkv8A+yJbOFACZIpzkgn+EbRngE8EdOa2\n\
JPDdlqc6ak7BbaUh9kgAI9ic1lavbLLot79gBe4aQeZKBndHjClSBgL1X8DThi6crWjrom9f+GOm\n\
ONpyUYwiruyb1+7e1997v8zf05xrVmJrPU2mt24YYII9mXPWtG00qCAh2zI47t0H0FeI6feXml3X\n\
n2Fw8Eo4OOQfYiuuh8c6/d27pbWdsZUXLypGx2j1xnFdVehW+zLT5I9CvhGv4NRKL7+6166a/Itf\n\
Fy/QpY6ahBk3Gdx/dHQf+zVy/hvUZrG9Aib5HOGQjIb8KzJ5J7m4knuZHlnkOXdupNb/AIW0Sa8n\n\
SZ2WKMttQuQC7eg9etXOMKOH5G7/AOZpiJUaOGjRb92N9e7e/wAux6DNPb6n4ZM1y4gEPKYIX5wD\n\
gf8A6sVkRxW7PNHqMFwbUhRtMa/PIFGGUg9DyD0G4GtbUrHTbPRfsl8wWVfnjCn5w2MfkenPBrnt\n\
Ou47UTtdS26pFGWfzSFUEK2MM3y+o5yB7GvIw0VKMrX/AK6r9fwPmIxUnKVJ2SenTfs/61+ZFrNs\n\
dVtrptIQpDbskyfOq4J7E5+pA7fQjO3pfifTrmz8jXnitb6H5JFlHDH+8p96qG5t5ruBrmNSGIEk\n\
yszY4UnpjPtxg/TOeW8VaWxu5L60JmtpnPO0gg4B6H2IrvioOSpTbt0fX+nuejg5J2o1rrqn1v11\n\
/wAzf1zxTo1ufJ0i2+23JOA2WEan88t+H51H9lnvLmxa8uZ5lXE/kQKCI8ckFQAM8DPORkdetc74\n\
W06abV7ZioQK2cuvy/iK7LRNSi0hp7eWJTK42yENho+vBzwP0GB6YqcTU9muWk7tf18vkaZhW9na\n\
nQvs73d276P7l2KckqWmuiJTLEl6/kmOYYxgDyyO4wCFz35rfsL+axl8mcExg4Knqv0/z/jXnfia\n\
3lg1MX8E6zIZFZJFOdjYDAH8CK9NsZrPxJpkd3EdsmMNj70bdwa3jU9lCEnts/JmrjT+rx5/eT0f\n\
l2/rubUUiSxq8bBlYZBFOrmlF5pUhYDdEevdT9fSta11W2nADN5Tns3T8+n54rrhUjJXTPGxGAnD\n\
3qfvR8i/RUYniIyJYyPUMKimvbaIZeZPoDu/l0qro440aknZRf3Fms7VNRW1UxxkGcjpjO33P+H+\n\
TQvdZeQFbYGNf7x+9/8AWrIJycmk2evhMrd1Ot93+YMxZizEkk5JPen1JZWr3cwROB/E3oK6D+xr\n\
X/b/AO+q56uIhTdmerWxEKTSZ534p0czeMNclnfCNfTsFXr/AKxutMtrKC3C+XGu4fxEc/WtzxR/\n\
yM2r/wDX5N/6Gay6VaTdSXq/zZz0tacb9l+SFopKKxNRaSlpKAFpKWigBKKWrNnaNcZYnag4z71E\n\
6kaceaT0E5KKuyGGJ5mKxjJrUt7FIjl/nb9KsRRrEgVBgAY+tSKpZgo6k4FeNXxs6vux0RyVKze2\n\
iIppPLWNYwrSyOIokJxlj0z7Dvj26ZzVRr3T5pXiv7e4Z1OY9+9RgjPCDOO3HU9c1Qj1Iya3azyY\n\
EcThQMYwue/vya67WNKgvIJlMY/eA5wMkN2dfRh+vTvz9JQwEsBSjJfG1dvr6L08t3cbUKMoxq7v\n\
r21Ods9Fh1K0ilgc20zhjsb5kOGKkA9eMe9H/CJ3wPE1t/303+FU4LqXTJXEk6RFm3iKRsIW7vG/\n\
bdg9RgHOQDito+J7aOIpf3IsbkAExvF5mQeRtK8EfgK6aWYVIrllq/S/9fiazliOflpP5Nfl3X3l\n\
aLTdV01VVUinhLbikZG5uxxkZz9P1q1DNHOhaFsgHDAjDKfQisie5k1SaA2khZGfzEeQDd8uR5rD\n\
nCDoB3Jx6Ct3W7N/ssepWhUXUUSlyF4cFBk4OfU9c/WuLE4WnmMnooz79/X/AD3XmZVVquZq7dr7\n\
K/n+V/z6MoqpYX8V4uPlSbvH0z/u56/Tr9cZq3XzOIw1XDTdOqrP+tu5jKLi7PcKgnto5uWGG9RU\n\
9FZRnKDvF2YJtaoxLm1kgJzyvHzCq9dEQCMEZFZl3YsrM8XK9dvcV6+Gxyn7tTRnVTrX0kUKWiiv\n\
QNxKWiigBKrXVjb3JzKg3f3hwas0U07bCauc/d6LJGN1s3mD+6eDWU6sjFXUqw6gjBrtqr3NpBcj\n\
EyAn16H860jU7lxnKPmchRWpfaRLDloMyJ6fxCss8EgjBHBBrVNPY2jNS2CiiimUFFFFABSUtIaA\n\
PsTw9/yANM/69ov/AEAVfqh4e/5AGmf9e0X/AKAKv19jD4UfmNT45er/ADYUUUVRAV8EftW/8lv1\n\
v/rlbf8AohK+96+CP2rf+S363/1ytv8A0QlAHkVFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFAB\n\
RRSgFiAAST2FACUV1ngDw7b63qVwuoXsNjHbReaPtCZSU5ACdQcnPbniq3xC0r+xvGWq2SpsSKY7\n\
Uznap+6CfpisFiYOs6K3SudUsJONBYh7N2/4P6HOVc0m4S21G3lmkmjiSRXYxfeGDnIz3qnXQeCN\n\
Kh1fXoYbqW3jt1+ZzO5VW5wFyOeTgfjV1pRjTlKW1iMNCVStGMN2z3rT/FI1jV7iDT7b+1ba5s03\n\
DbtitncAKjyYyVOWzwSCBjua3dKt7mGTyLgRwyrIvy53ZwgzgZwMNnnvk/jmeA/ClhoEWpMZlFg0\n\
u+OfzHVXG7Kqy9OMdR1G31rprbb55kMiTBshZUbIIzggH618LjcQoy5YJtW3fn+GvXqtOp9ZG8rw\n\
dla2nmu3oZ8md7Z6k1XgVrKYywt8h+8hzjH1FbN7DEI3l25YDOAcZqECKGa2gM1vHczN8u5ycMDk\n\
AZHOcZGQM/SohU5ouyv3Ox4i0bJbm5YeL4jbRi6gkd8DDp347/pVjT9ca+nit7+EWyXQL2hbPzDj\n\
Az6nP6dTmuaK29zeboJYxDMitG2M5G7aTuGScnHHX5gOCc1Nbulzu+yXXlywgzK5famNzHJXBwcn\n\
OevJ44zXO8HRd+WL169vl/w/U8qthaaXtIR5Zb31/pea1H+ItFmbKBCGQ5RscEeled6lbyW1/LHM\n\
jI/XBGK9SufEOoXrRJYxGJ0GZFwGLn0HBx/+vnpnhfF4Qtayq4dmDhyB/Hu557885966sshVhKPt\n\
NmejgMTU9qqVWNnbuXPCGmfu0u3UNNKdsIP8POM+2T+n1ru4Ilgj2R9/vN3Y/wCHtWP4eChLPa2Q\n\
IBtPr8gH8iTW9DE00qRpwzHGT296uc3VqOcjvxc/e5XsgiikmcrEjOwGSB2/Gra6ZdA5BiHH985/\n\
lWxDEkMYjjGFH6+9Q3V9b2o/fyqpPQdSfwrPmcnaKPHlipN+6jjvEGhGeNSiLbXaEmF2UFCe47gZ\n\
Hp+Vc+mqS6VO1hd6e0TXi7CxwVTsPLA4wDtJweoHoK9Bk16yZWR45XQ8EbAQfzNZGr2tnqdr5dvc\n\
RAowkRZxyjA9ieDkcf41o6DkrVIaGyqQqq1ePo/68+//AADAltmtby4Ek0bzJlzzlcMR93PpkcH+\n\
lOYK9nbfaLxBHOxQx4IMSkbFYDoQTjt6elTJoWp2ReZbe3Ebx+S8UEWSVKbS4bH3sk8encngyWNn\n\
bQ+fdapF6LAkoyyxbQQvzDjljkkZ7etZQw7cknv5b/8AA/rcw9k5Jcz+a1+Xl/WrIPDNzPYvbW6X\n\
X2i0VjhjGd6oOvIJG3r1B6dRjjctHj06wa6uGGZMEALhjxwvuep9sn61WEUVoHup4VtoOAEQ4aUg\n\
kgEfU9OOnIwKxr68lvZzJLwBwqDoorDFP60vYQel/ea8ui7930+Zo4SxEtXp1f6Bf3s19OZJjgdF\n\
QdFFdL8LWA8XwqSMmGTA9elcXc3CQJluWPRfWuh+EUrzeO4Gc/8ALGTA7Diu/L6cYVqcYqyTRWMS\n\
jhpxitLM9+ooor7k+ICiiigDk/it/wAk+1n/AK5r/wChrXy9X1D8Vv8Akn2s/wDXNf8A0Na+Xq+e\n\
zf8Aix9P1Pr+Hv8Ad5ev6IKKKK8o98KKKKAFVSzBR1JwK623j8qCNMAbVA4rn9Gj8y/U8YQFjXSV\n\
nN9DGWshK1NHttzmVxwvTIHWqVpA1xMEUHHc46V0kMaxRKijgD0xXk5hiOSPs47v8jlxFTlXKh9I\n\
enFLRXiHCcpqwb+07ospXdIzDIxkE5B/Kur8EqRpcrdmlP8AIVy+tszalKWGDhf/AEEV2nheEw6J\n\
b56vlz+J4/Sv0t1ObBUm+qj+RvjpWwsV3sWtTtBd2xUD94vKH39Px/wqp4fl3Wrxk5MbcfQ/5Nax\n\
6VzGoarFocGr3kiglZdscf8AebLYH+ewryMXDmhZbmOXudanKgtdrfN2ON+IN6YfF0jWcjRzRwoj\n\
sjYJPJwfwxW74P8AEF3eTQx3D7w5IJxjBHevOJJJ7y7luJyXnncux9ya9J8NQnRNItLlLRZZZWAM\n\
jSYAJOSMY9B16euK5sdSgqUadry2PUzSFKjBQ+JpJX87flf8iXXJLXUb1ZNMRDEq/vZQpUfM2Ocj\n\
+fXJxyK81v8A4raTZ+JJbBbecWiTZSSOUMuXbc5OACDk9iR19sd5qVx9hXUNSvYttvbAzNHDySVB\n\
JVT0zwCeemfavlnxhrFprGvS3+nWX2IMcthyd7Z+/j+HPHA4Fd+T4KNe6mm0tN+v/APnMViFh6cY\n\
xd2rfd1V/nv9x9S3KLCZbQSEWhDTiMv8mASOSxByMqDnnkeoxZWcQSsbaVYhxbsy/LCRhSeQMD5i\n\
x46YbpkivkGDV9RguTcRXtws5BBfzDk56/ngV638FfGFnb2/9i3ETrdO+9JWEkyucksWUEBRt4P0\n\
B57bYnJ50YOUfevbS34io5hTrWhJa/LXb8f612PWvEHh2K+1B7mwVJ4JGI3wsMBh1Bqw2lR6Hplr\n\
vW4WOWXMzRDLPgghTwccAkdKseH9cj0vRmtGtzK8bN5Kom3fz/ET0OcjP04pNZ8QnUrCO2it/s5k\n\
wX81hjjkj14xnt0r539+pKL+FPe/4/11OyU8RNRoSWnfTVLqtfy6jLrS9Hur5JLe6WEzsSRJHtK8\n\
Z53YI6gVq6rpMcfh5TayEmJllG18BwCDjjjPHB9fqa8f8U+N7PRPE9vZXN0LmBAwljhQKsDDG1WH\n\
8TKRgn3OMdtvxBr0Gk6XY3s1xJNZ3DKkUJYchj15Pynpkc9Dx3rsll1W9NpvXuv69NSHUc7KVTRW\n\
v/Wn9eZqavqw02wmvoBCdRjheUC5uZAJto3HcSeDgN7ZC+gFfPnjTx9qviqH7Nd7I7ISCWOBOkbb\n\
cHB9D1wc/wA8+w+K5dF1/R7/AEmDUdLGpGQRoLkY+fbkgOwXbk7OfY186XdtLaXMkFwhSWM4ZT2r\n\
6HJ6EGuepH3ltdar0/zPPzKpJW9n8Lv/AMNc9y+EXjiG9hstAbT4/tSDbGX3PG4wdxPoSPXI4969\n\
htbrS5PDEUd9OV8rMajHIHJBx1Axjk4H0r5u+Eem/Zr86zqV7/Z2nBSivvAMzdduM5I+Xrg4OK9c\n\
/t7RJ57+G3vbcLaQrK8jBvK8tl6jaCQOcd+vIwcDy82wkHW5aSdr3077PU6sNN1KSnUdpLb+vNeX\n\
4anouiaNbQ28d7G5ZJUEgaT5SFIyM+lR+MLm1ntYESSOSV3BRgQflHX8Dke1cB4Y8TS+INNu2in2\n\
6aJ/LDLIGBUuQu5QAVJIJxwCMVn+PPGNt4P+xBoHlupmEhjDMuYiG6fp3yPrzXmUsuqPEct7yWy8\n\
vP79f8ym25KvUntfb9f+BoztozdQxzTPFC8MkS5uBl3bYDknIXDZ3D+tcnrTXml6s95p8s9stxll\n\
KZXuQVI74INc94A8f3PivxPcW12qwWiR7rWFJNmxsj5iP4uBknjHJ47eveH9HtdQ0WFLlceRK6g5\n\
OCM5GM9sEYBrqxKlgHzVY6u11020/I3weOjhmqy+HVN/1ozkdL17xZNHC8U6zRPL5amWNPmb07Hv\n\
2rXtNatpdQjs9WjS2mlAMdzCCsbE9mU9ORjI6+1JeCOTUbm2lhbyIpmiYR4jPl/dADHrwM44GffB\n\
PO+O4UW8iS25s9mYXGMNnnIwMf59c0U5xqTUVHlut196PVw2KeJrqNSKin/KrNLo33fl6noE+j3K\n\
H92yyDtzg/4frVV7G6VsNC5Ptz/KsTwB4uCImlavJtx8sE7HjH91j/I/hXo9RUr1qMuWaNMTOvhJ\n\
8lRJ9n0a7nJx6fdOflhYf72B/Or1torEg3L4H91Ov51vVma7rdlolqZr2XDY+WJTl3PsP61m8VVq\n\
e7H8DBYmtWkoU1q+25B4i1S38N6I86ou/wC7DHnG9z/h1P0ryX/hMdb/AOf+Wq3iTXLnXtQa5uDt\n\
QfLHEOiL6f8A16yvLb+6fyNd9DCqEffV2/mfXZdlVLDUv9ps5vV3t92p6z4o/wCRm1f/AK/Jv/Qz\n\
WXWp4o/5GbV/+vyb/wBDNZlZVf4kvV/mz5Sj/Dj6L8kJS0lLWZqJS0lLQAlLSVbsrVpmDEYjHc96\n\
ipUjTi5S2FKSirsdY2nmnfJwo7f5/wA/11VUKoCjAFKBgYHSivAr4iVaV3scM5ub1CoNQZk066dD\n\
ghMcjOQSFP6E1PWb4gk22KR/L80m7vngEfT+KujK6XtcZTj53+7X9Apx5pxXmjnq7/wvffbdLVXO\n\
ZYfkb3HY/l/KuAre8G3Xk6oYSflnUr+I5H9fzr9CxEOaD8jtzCj7Si31Wps3GnWmpz3mn3qDY7l4\n\
iOsbdcr+B/SuVtLSexvNQ0vU4Yr23s4WnhVxzxyu3vg9xXW6ixh1fzFB42MPfgZ/UGuefU/t/wAQ\n\
3EEIlt0X7M5wT8qksSMc/e/lXzOIi0pdrX9Gn09djOpz1MM+3KpejVtnurq4zwp9pv7C/wBTuDzv\n\
SFQBgKo5wAOgBYflXZaRIJrAI4B2ZjI9R/8AqOPwrkPCniKzsLzUNOv3It5J3dJnXjJOCGx06D9a\n\
6Wzkgt70fZriOa1mwAyOGAPbOPy/GtqU+WfK1ZPb0sgxlKU6Tio2Wjj20W3rucTf25s76eA5/duQ\n\
Pcdv0q/b63MMLdKJQON/RvxPf8eT61oeNbFlnS9Rf3bgI5HZh0J/D+VcvXuVKFHGU0q0U/0/yN6X\n\
JiqUZS1f69TroLu2uBmGdO3yudrcnAGD1PsM1OylWIYEEdQRXF1bttSu7ZAkU7eWBgI2GUc54B4F\n\
eBieGYvXDzt5P/Nf5GM8FJfA/vOoorIi1xWwJ4ApLctG3AH0PU9e/pWlbXEV0MwOHIUMV6Efh7d8\n\
ZFeDisrxWFV6kNO61X4bfOxyzpTp/ErFO/s+ssI92UfzrNro6zdRtVVTLGNo7jt/n/P11weL2pz+\n\
TNqVX7MjPpKKK9Q6QpaKSgApaKKAEqne6fDdjLDa/wDeXrVylpp22E1c5K9sJ7QkuN0f99en41Vr\n\
tiAwwQCD2NYl9ooAL2Zxgf6snOfoa1jUvuaRqNfEYlFKylGKsCGHBB7Ulam6d9UFJS0lAH2J4e/5\n\
AGmf9e0X/oAq/VDw9/yANM/69ov/AEAVfr7GHwo/Manxy9X+bCiiiqICvgj9q3/kt+t/9crb/wBE\n\
JX3vXwR+1b/yW/W/+uVt/wCiEoA8iooooAKKKKACiiigAooooAKKKKACiiigAoqWWCWEIZY3QONy\n\
7hjI9RUdA2mnZlu0sLi4liAikEbuE8zbhQT7nj860tS0S+8P+JfsbIl1LDIpR4f3kcoIDAgjqCCP\n\
5V6v8EtXS8ghj1u7LW1ssttbWQAZZiyM7Fwc89gfw6Zx2vha9h8R3zXOo6fF5cG8oVdg0BB+VWGA\n\
cnDfMOOOPfwsRmkqMpqa0inp3/L/AC87nuwy6n7KNSLd3Zp6fdb1/pleHV7N9GtJtQubfU7i6la6\n\
Z7eAmO2BO3djHCKcDnnLc9awviv4fub/AERru0jtryW9CyGcFAwWMdmHbaGJJJHHHWux/s63OqXt\n\
xFHG3n5VRt2iNGUq445YkHqScdBV+e0ZbNoW8l4XjaJ4mG1ShUjAx06ivAhmKpuKpJWTT26fL+nY\n\
9irB1I2kt09/NJabv/hjw2X4c2974Dh1nSxOuo+WoktZWwGcybfk3AenTnkjFZ3gvRLLRvHaWniu\n\
JGgh2sSZti/NjAJHQ/MM8jbg56V7lHHI4uEnhaeFLVFjiKjaWG0iMAHoVUJx1JOR64Wo+Hr+YWmq\n\
6psv9TSdBapLtEcSbssoTJUEg/xe+PuivTjmM3CUJSve/qm9kns1/Xkc8MHQlUjNJKSt5J6O+m/n\n\
5WNHTtQ0rVtNma8vrIMsjWzzWrF412fNn2BVT9cHHNaWhTXN/pTzO8EwGJY5ouN+5mz8p5AIAI6A\n\
bcYBzWVrvgzRtV0xIvsi2XnHJghYxBEJyHYDgyDkYPGCRmprbzdGsZNMiS+eGKCN4mOF3KvygPu5\n\
XDchgDnd16Y87ESjiINKV3t93z33XY643m9FZq3ytvbR6bddzZRvMima4ISNEJyxwM/56DucCk0W\n\
f+1p0ivwRAwcRMyjbIPl5UEdcd9oyRgcACr9nr+nSxyxSLKsxjZWYIpwythiR2KkZPGPlOOMZy5F\n\
igeG2ieH7NJct/rEy7E5OSvXAPJz13djtxyYalOMJe0g97Jq3bTv17oUZyrc8bct1pf53t/Wxe1G\n\
GCBbezgkh8iFv3bBwXVlxlgeoOcZPqaZeTzsrQmdvMIwkkWFdCeevTGeo6EE8E4NWbKGbynui0n2\n\
iSRzLAXAWQAbVxjgED0J5z1OMV9O0v8AtPU5rZJzFHFn5guWbGB0ye+amNqSb57pX3/H+rGadNR9\n\
96Rvr+f9LRj5oo4rG6aN1DSsVQXGYztZcttUfxfMeRms3xlol3cG0+xW8pRIVKoWLEZGTyfrVu5j\n\
mtnnsjKWNqwSPci7V5Ujj73Q8YOMt044mvNVvNQhmW5cm3ZPLaKAsjdM5HUHocjr7Yzneaqc0KlO\n\
3e/yS2/G5z0JzpyVRWdv12t/SMLwrraW8kNrfExSRMUVmGPl5BU+hGTj8K9O0WPFzMzD5kUL+Z5/\n\
lXnepQrJPHa/YoW1DG0ImxiwIYrznjaAvPTGSTiu4SY6RocMSuZJ5FADN1IAA3H6gA/U1s17V3ir\n\
N/1deR34jE+3p3UbN6epY1zVjAfItiPM/ibrt9vrXMsxZizElicknqaCSzZJJZj+JJrTtdL3ZNye\n\
OMBG68cg8fyP41rVr0MBTvUdvzZy3jSWpmKCzbVVmbGcKCTjOM8duetXotLncZYrHnHvjg/1x39f\n\
x2kRUACjAFO6CvnsRxDWnpRior73/kYSxEntoUE0uFXyxdh/dJ4/TB//AF1DdSWWkx5WMNNg7FyS\n\
3P8AtHJA/wAPaq+qa6qBorIhnI/1uMqPp6+uenTrXOSSNK5eRizHqSc0qNPF4v3sRN8vba/yVtDe\n\
hh51Naj0/MlvbuW8l8yYjOMYHQfSs69u/IwqYMh7HsKZfXezMUR+c9T6f/XrLAwMCvWhCMIqMVoe\n\
jCKtaOiHu7SNuclm9TXbfBv/AJHeD/rjJ/KuHruPg3/yO8H/AFxk/lXXgv8AeIeqMccrYaol2Z9A\n\
0UUV9sfBhRRRQBynxV/5J9rP/XJf/Q1r5dr6h+K3/JPtZ/65r/6GtfL1fPZv/Fj6fqfX8Pf7vL1/\n\
RBRRRXlHvhRRVzS7b7TcjcP3acnjg+1DdiZS5Vc1tHtzBa7m4eTkj0rQUFjhRk0lbOk2QULPJnJH\n\
yj+tcOJxCox55HNOfs43ZZ061+zRfN/rG685xVyiivmpzdSTlLdnmyk5O7CkPQ0tV7y7js4y7kb8\n\
ZReeT+Hb/PcVVKlOtNU4K7YJN6IwtQVrzW3iiUBmkEQwcg4wufxxmvQ4IlggjiT7sahR9AMVyng2\n\
wzK9/Iu1Fysf17n8BxW3favFD8sGJX9QflH+P4fnX6FiGoKNFbRVhYqE6040KSvyr8S3e3SWkDSP\n\
gn+FfU15z40uBZvpJu4fPSbzJWVmIzkqAfTOAeufvGuqs4ptTuvNuCTEp59P90f5/nXOfF8futIU\n\
Y+9J/wCy15rqqVaNM9TLMJCnWWHk7uV7vto7fcXrOGGSUTXGnfbIyRtngClyNowGAGM9PTv6VNq9\n\
tqMSB7m3wq5ZUUeYqDJ4XH3SAev+Fee6HdzW16nkyMu84OD1FeoaXrFx/YFxMbR7uSLgqvGR3J/C\n\
vNxEamHqJx1/rp2PNxeHnh/evzLtqv1Z5B8TrHWE8M/bNO1SKO3t1lFxB5bGQxtyFL4OQQ3Q4+pI\n\
r58r6s1fTbXX9Geyae5tTcZSVoHWNpBzgPnsSQTggngHjGPm7xR4cv8Aw/e+Ve20kUb/ADRl8E7c\n\
kDdjo3HQ819bk9ePK6cn73pa/wDn/wAOeNmtKpKSqWdl66dvRfr5mJW74GLf8JbpgXzDumUMqSmM\n\
sO43Dpn1rCrX8Oa7P4fuZbuwjj+3GMxxTuNxhzwxUHjJGRz0zXsVouVNxSvc8ujJQqRk3a2p9JeM\n\
vEVl4ehumhezuJ4FM4gjnGTFu25HB5BI4znivH9c+IAh8UyX+kBJbd4kyrJjbIuQCobO3AIHHUfU\n\
155dXU93K0tzNJLIxyWdskn1qGvNweUUsOvefM/M7K2ZVKllHobHijX5/EWpC/vIYI7kqFdogR5h\n\
Hc5PWql7ql9fM5u7qWUvt3bmznaML+Q4FUqK9ONOMUklscMqkpNtvccWY9ST+NNooqyBcmnLI6g7\n\
XYA+hplFFh3aNCw1e8sYxFBKRBvEjRH7rkEEbh36CtDxR4ou/Esdo2qJG95bgqblchpQTn5/Ug9C\n\
McVz9FZulBy57amirTUXC+jO2+GsGlQaiNQ1e/gjWNXCW+NzsQMkkdAMZ75z0Br3Kz8T2sGr21hp\n\
dw4nmt2l2Q5CkYDLlSM/dYYPse3NfK9aui69f6NfC7spiJ8KN7cnAIwM9R0A47V52Ny1YpuTetvl\n\
5HbhccqMVBx0PqK3uEOpPDPcLb3Mam5kZ03bApyWIyDgEAcjkH1q3Z29xrumywXdzDczSMyKI+FS\n\
RTuIXt2YZHHHBNfMnijxHf8AirxA1zB9oQzIqJbrIWx8oDAeoO3PvXv3gx9Rt9D0dnjjtntojFCs\n\
J3lOCG3ZzzkMcdBnFeJjMFLDUk21d/g/6/q569HFvEzvHdNWfT8vTzI7rwndROyTTQR47O3P6d+P\n\
yqpZa9reiE29tevsjJXypAGUduM112+xgvrOXUY0WTzASQ/MhY4z6hhuycE5w3rXP+K9MaO+mniG\n\
YnO8EDgg9CPauWFdNqFTVPr/AJHuYLMKjm6NZJrs1p/XnoVrrxz4gljKG68oeqRqp/PFc5NLPdSm\n\
SZ5JpGPLMSSfxqwR2oxXbCEIaxVj6GljqVFfuqST8v8Ahr/iQRQkEMevoKs+W3+TTkXHJqfyZf8A\n\
nm35VnOrrocGJxU68uabPQfFH/Izav8A9fk3/oZrLrU8Uf8AIzav/wBfk3/oZrLrmq/xJer/ADZ5\n\
VH+HH0X5IKKWkrM1Clop0UZlkVFzkntSbSV2GxJa27TvgYC9ya21AVQAMAUyCFYI9qfiT3qSvBxW\n\
IdaWmyOGpU535BRRRXKZhWV4lGLa0yOrPg4/3e/4Vq1z2vyl70IVA8tAv1B+bP8A49Xt8P0+fGp/\n\
ypv8Lfqb4aLdVeRm1Y02Uw6hbSD+GRT+tV6msYzLe28a9WkVf1r7x7M9SduV37He6xEGu7MnPzN5\n\
Z+mRj+Zri1u73Q/FI0tpc2fmBUHlqTsPKnpyRkdc8g13uqELAsh/5ZyJJ+R/+vXF30cepeJbnVJL\n\
v7MlncLbKrADcVOMhicdcmvlcVypvnWln9/Q8rDzhLC2qq6s0vKV9P1INU0rRZdQuY5LuSyuwN7l\n\
vuqc4x7gndg8dKakNjot/pVvE0sstzLHK0rqu0xv8uCQewJORnmsT4jeAB4w1ixu7SVLeOMsJVBD\n\
EqMHBK8KcdMnHIFdD4v0OX7JYC0UySW0YhMatu3Lj74PU56GsIzglTXtG73uu3b8TDBYmpKsqVeT\n\
UPXy7f8AB/zOzMiKz2V/tZWGFZuki9s+h/w/PmtW8MTwuz2AM0X9w8Ov+P8AOquj318YbbT9ZMbT\n\
O7R27bxvBAztYZ6HoD1zjPFbdpfTWpCHLxjjY3UewPb/ADxXp4XEzpq17naqE6bc8PJP8n5rscbL\n\
FJExWVGRh1DDBplen213BertGCx6xuOf/r1KLeAHKwxAj0QV6KxifQylmkqb5alOz9TzGC2nuDiC\n\
GSQ/7Kk1pQaDqwKyR27IwOQS4Ug/nXoI7Ad+gFZOp3/3obdwMAl5M4Cgdee3uegqJ41pbCp4+tiJ\n\
clOKS89TAinu7PcmpxOwDYMwYNsJ7Nj+vPXr0rQO1hwUdDkZUhge3XvWbpV4Z9W8+ORY4JeoZR+8\n\
hTEakgjIzknr26VPqa/2JqAUKTYz/NsHWNuhx/nkcdgR4GKy+GNTqUI8s+y2f+T/AAfkFSF52ju/\n\
udt7f19zRTv7YQtujB2H9Kp10ciDlSVZSOoOQR6j1rEu7doJDkDaehFcODxLn+7n8S/r7zWjV5lZ\n\
lelopK7zcWkopaAEooooAKKKWgClf6fFdqTgJL2cDn8a5u7tpLWYxyj6N2NdhUdxClxE0cq5U1cZ\n\
tbjjJxehxtJV7U7BrJgwO6JjgHuPY1RrdO+qN4yUldH2J4e/5AGmf9e0X/oAq/VDw9/yANM/69ov\n\
/QBV+vsofCj8zqfHL1f5sKKKKogK+K/2lfCOp6t8bL5rG2lmW7tomRwuEVliA2lun8P619qV4P8A\n\
EqSb/hPb6CB8SytFsQNgn93GPyzgVjXcoxvF29f6+Z6GW4WGKqOE3bS/4/5HxnPpkkNi1wZFLxye\n\
XNDg7ojkgbuMdQagubG6toIpri3kjil5RmXAb6V9TL8OdMie5eO3gMt1EwmLKdhGRjjt8wyGyDzn\n\
Awa4eb4Sa8LTVrLVbwy2SqLqGbf8odAQOoyPlJB6fpXn/wBq0YyUZSSem7s7Pt/WxrPB0re69baW\n\
2uu99dfLb0PCKK9T0yeK+tbjwpD4esXhMBEWotAyzedt+R92CcHIAGO4qh4K8MaJbw3+oeOJpLeC\n\
0khEdtGx3zls5XAGSOMHBBHtXR9eUYuU4tW2tZt322/LoZyy986jTlddXqkrev8AWh53RXXeP9B0\n\
/SbrTpNFnebTr2EyxyyY672BHrxjGDzx9K7DwH8Kzr+jxXF9e2NvbTKzRu4dJS/8IBbgrx6cg8eo\n\
ueNpU6aqy0T+8iGX1Z1ZUlvHfqvwPIaK674keGpPDOsRWkjWrOIULtbE+WzHJ+XcAemPxrd+GvhL\n\
WbtrxrFNIMzQqXW8KSMkTEBm2HPZvTPp2zU8VCNL2nfb+rBDAzlWdPoutvLT79jzdI3kzsVmx1wK\n\
ZX0lL4RTw0l5/YNwttp95bPHdWjxmUztsIBBOcck8CvBdc0KbSL+CzmuIJJpIlkfYTiInko2QCGH\n\
cdqihi/ayaat28+/3epWJy+dCMZb3+75dzd8B+CB4osdQvZLz7HaWC755nAKj/Z656BjnGOMd62v\n\
D3hObwvqcmpeIIkm0YI3lyQeXMJz/AAOfvY/xIrofCHw8s7OfVbC/wBRnuLxLaN5YbclYQjgMuTn\n\
588Hpjgd+nqnhyXRbKK1t7oxxyLkvJJgKpLZG4n1wPbn1JrzMRi5yhUnBuULbJa7X09e/wByPTpY\n\
RUacanJ78X6306+Xfr0PDvirpcNzZaDcaNa3UNsY2jNtJtb7O5kJbLL1DFhtzxgcV5tdWFzaajJY\n\
3EEiXcchieLb8wbOMY9a+wfENrYXc1qyvNEsC4he2wVUd8DpnGR9D3wK8Y8UaJq9/wCJdM1VJoLW\n\
SVlkMlvAwMJeTbg5zkj/ANBArDK82VSHLy2ST33vq/66ixWDhXtWk7N2+7byXn07F3w38PYPDJtt\n\
S115c3IRYLSSJGlDbhubaC2MYwM498V7lJpKW9qwhyWmAeSRkVWJ2gc4A/8A1k147BpeqxNpmg6v\n\
awXWm7d9teW+VmjJDsjbDnGTnPBHGB1GfSJ9aS18Oxw2l7HMkUI3ssXmIUUfMc5xtKqeQR1HcnHl\n\
5nSr42KUZq6ev+Hv8rbaa99zsdLlcfYR0vtbRP18vW24ySBrMRyZ3pJJ5QZeVDZxgsDxzx9aS+dp\n\
JPJYYlQbigJJA9+Mdx3P6GuYXSLQubnUb+IXkhy9pCQNgYnCueVLEsrbsA8ZPWugTTTpGn/awWuL\n\
eRicyOF+d3A+XIUjBzjIG0dCcVzLDRpJTjK/Tp6/l6nY5yT9969NLX/rX10LGiaRNq8kjiRUt0OA\n\
cZzxWhqWhajZmC5hzelCc7I9rAbi3Azz6dewHSpPDV5Jaag1sAJobibOSQrg4Jzjpjbzj0Herev+\n\
IxaMQGyQcAD+grnrVsRTrqMUnHovTT13T7HBUqYiviHGFrJLp+ZhsZblI2SU/bdywqjfxAlhnd78\n\
e42fXD7zR9Q0yGSeZ/PiwMGNj+6GfmHrtIA46AimQeLneZDOuNp+VmUHb/UVv6rrYl0VCg3tK4Vs\n\
HBCfxc4x6fn61Sq1vaRhGC10fn/SHWWIpNOaXK3+vTt+Nzl4Le1u1nLQQySzHzGeRQSfZcAY+uc1\n\
cQRpp8xtNPtUl+aNADsU5BDMxyM4BPuTjHPIrW0MEBkjkndlUhDsUbWO0fKvQ4yRznPStC5WBr6G\n\
a+SWG3UGNmMQQiMDgfMAeTkYxxz0zmuiVNqak5Oy7PXT5ry2v+ZtVqwT5Vd9Vdv5W19PT8qMAiUw\n\
w7t/l4UAjAJ3fNnnqe/PfqetXxqiWE+pP5LRwxqwiIPMWeSWBOfmwp4HoKivHsVmjl0pdqvCUi8v\n\
duL7sFiQeoByOuSR6c52uLJcaQNO8popwom855sibA4BzyDjOATx+NQlGcfeXxb9/n92y+Zk5RqS\n\
jGWi639bt228vn2M+11nUtVk/wCPP7SqZUNuCHB/hLf061pPZ61fbVubC2tBggkzYTJ4ztUkggHA\n\
4wK0vBFoRotqUQ+c+4Adx8xBP44/Ie9disdvpcBnmOZAMbvf0UV0SjCEnGMfJHoYr6vTfLGOvz/4\n\
YwdG0ePSLOW51AL5kxDyAdZGxwv+6OeO+ScAcVUuZpr65eQqzyN0Vew9BT7+9mv7kEgnJxHGvOP8\n\
9z7egrT06yFvGGlCtORywHT2Ht0qcZjI4Cnzy1nLZf10/PZHHUqOKvLfog06xFum+T5pmHzYJwPY\n\
f5/oBdorN1bVY7JWSMB58cDsp9/8P5ZFfHzlWxlVyesn/XyRxpSqy01bLV7eQ2URknbHoo6t9BXL\n\
6pqs14Sg/dwhshQev1/z6elUrmeW5l8ydy74xk1FXuYTLoUfenrL8EepQwkaestWFUr678smOP75\n\
HLen/wBepb2fyIvlxvPQEVjkkkknJPU+temdTXNp0CiiikaBXX/CK6WP4h2Fv1eWGU/QAVyFaHwX\n\
u/tXxthVT8sNrLGPrjJ/nXfltPnxEX21OHMZcuGn5o+qaKKK+xPhgooooA5T4q/8k+1n/rkv/oa1\n\
8u19RfFX/kn2s/8AXJf/AENa+Xa+ezf+LH0/U+v4e/3eXr+iCiipra3luXCxKSCcFuwryj3m0tWM\n\
giaeZY0HzMfyrqLS3S2gWNO3U+pptjZpapsjBZ26nua3tL05ncSSqSP4VAyT7/SuTE4mFKPNI5ql\n\
RL3pCabYbsSzj5eyn+tbNRyyxQZWWSNGUcoWG4cf3Rz+lRLqFkxH+lxjIzyr8fpXhzo4rFy51Tb+\n\
T/yPOnOVT3v8yzRWXJrVsIiY1lZ+PlZQo/PJ9+1UrnWZpMCBREOck/MT+fHT2rroZBjqr1hyrz/p\n\
suOHqS6G7cTJbwmWYkRjuBkn6etYkKXGuX2CfLt4xliPuxr3PuTj/wDUBxFpmm3Wr3BKltufnmfJ\n\
x+Pc+1dVqMUWm6XHaWw2hzySOWx1JPrnFfQ4XL6WVpyT5qj69vQ0XLSmqUXeb/D+v688bUdXgjt4\n\
4I47uONCUSAQE5wcZLZwTn9fzNWy1fRDOUvb4xOv3ozGwwe4Jx/Kq84I12fe6Lb3luJCrSbcSHKZ\n\
Az1JBP41n6von9qHzbOGOLUFZvtMC5xnjkfien+Fcrq2fLUbV+p0061OlP2NTRd13fr9z8+p2beL\n\
dAt7f93eqwUYCRoxP4DFec+LtSutb1NLmSCSK2CYt0Yfw+vuT7VLa+EbtnRZ5IInYFhEzgOVHU49\n\
K6xvs0cX2aA29zEkMe4OxGGwAChH16HHOeRg5yU6VGV6XvPuyZYqhhZXoe9e93e7t5dNTlvC+htP\n\
I11dsYoIsdskk16THeaboVrEhuIysgwPLO7PGe3rxj61Tg1LQobC5ijBMe3/AFbqQZDjOFJ79PTm\n\
vN/G+rXPhzSLfVrJoYkt22NEu1GuN2QUOATjbk59h6YHL7OWPqWmmuiXfseZiqk8S5OpeMPPTobm\n\
q6zA+uQGdVimvZvLt4pMfMRyD9M5ye1ee+M/iXZWlv8AYrXTba9lSWWORb1STGVZMcBuhA4OT0GO\n\
9cf42+IK+IvDtlafZII7oMZJJI1ZGjYN8uDnBBHbgCvPJHaR2d2LOxySTkk19VgMnjG06q1Wlv6/\n\
U8rFZi7clPbp6f5l7WdWutYuRNeGMFRtVIo1jRB6BVAArPoor3oxUFyxVkeROcptyk7thRRRVEhR\n\
RRQAUUUUAFFFFABRRRQAUUUUAKCQcg4Ndn4A8ZNoes2b6mZJrKFTGoJyIgxJLbejHLHrXF0VnVpR\n\
qx5ZGlOrKnLmiexeE/Huo+IfEy2cgSzty8s0TWsRLR4GUXHIKgjksDwWr2ttRuhpaQzW8DtE6wKy\n\
xgglgSvU429FA9e4r5M8M+JNT8OXEsml3Tweaux9oB4yDkZ4yMcGvX9B+J7avqqaXp2nlfO8sI5Y\n\
DOOXDnB4xnG0Dn2r53NMuk2nTiuRfh5/8A9bC4mNSHLN+932evnvY77xT4cjtrotGnkh+So5VT6V\n\
zv8AZUwPBjx65r0u0ujqsdrYX1rtkkQ7ZnkyZAvVgMc8j265GapXHhsxSH5pNoPbBr5tYmdH3Km/\n\
6Hv4bG3ioTeqOP0zRzJcIGId+uAOB7mut/siD++1aOn6WYxshjKA9Wbqa3f7GT3/ADrkr4xylqyK\n\
+NinqzjfFH/Izav/ANfk3/oZrMrT8Uf8jNq//X5N/wChmsyvbq/xJer/ADZ2Uf4cfRfkgpKWkrM1\n\
F61s2Vv5EfJyzdeMYqDTbbAEz4P90da0K8jHYnmfs47dTlrVL+6gooorzTnCiiigArmdbffqlwP7\n\
jeX1znbxn9K6ZnESPKSAI1L8kDJA4HPqcD8a4w9a+q4Zo61Kz8l+r/Q7MFG8nLsFbvg608/VPOI+\n\
SBd34ngf1/KsJQWIAGSeABXovh/T/wCztOSNhiZ/nk+vp+FfTYipyQt1ZeY11SpOK3en+ZLrBxYS\n\
e+B/48D/AErkNc8Kz6rbJeafOzNlmkt5G43k/MVPbJ5wfXr0FdVrzgWip3aQEfgD/iKi8PT7ZnhY\n\
8OMj6j/638q8HEuUVzx3RhgZSo4dVYpXTb1V/I8lY3enSSQbpreQHbJGTjntkd66/wAF6ibq1nhu\n\
kMjW5EikDLBc4YD2xnPauh8eaImo6VJdRLi7t0LKw/iUclT/ADHv9a5DwDJE89zb7zDcSof3xXcq\n\
rg7gRkfnXNWlGth3O1pLc68bKnicM60Fbv5P/Jr/ACM7xR9qt/EUrvuzCwaJh0Cjpj2FeoQRWmt2\n\
MN7CdrSoGyvr6Ee3T8K59bk6m09jMPs6RweREyjJlJGBkd/rxzXIRahqXhnUJ7WyusqrcqRlG98H\n\
oaVPmqpQWkor71/X5meHqPE01Svyyjtvqnv07q/X9T0eTQ5h9yWNh/tZX/Gql3qDaS4iudRhVgPu\n\
ENLtHuAp2j64riL7xjrF3EYnuPJU8HykCk/jnNO8EQNPqNxI6EoYm35PBGQSCT6gYyfWtn7WlFyq\n\
PY6K9CVGi6leUZeS1/Hp9x28OrafeIftOu2nl45jjdUz9c4z+Vcz4q16K/QaXoCO0GQZHRTmQg8D\n\
1IGOtLf2Vp4Zs2vbWzu9SNyyQonlfJtYjOSfb/61XreztbKymj0wfZ5ruIuiTsC5OOAB6cnk98el\n\
c7rxvz6vte1vO68jhjjKFOT9mr22vol3bsuhHMPsOu+a1xFNK9vHFPaM4WU8DJB6ZBG7H1HerniC\n\
UXPh+zmwcLM0aliCcAd8ZHt17Z71U8K2UcOmPfX0Xn6ndOyJ5y7mVQducHvnIq/4ria30myiY/N5\n\
jFsHPOP6cD8K78vhKNWKvdLQtQ9nKnTcr2emnk728tbFDQLtnxZsCx+ZkOemBkj6cE/X61qXEKzx\n\
lG/A+lcijFGDKSCDkEHBFdhHKk8STR4CuN2AenqPwPFefxBg/Y1Y4qnpzb+vf5r8hYqn7OfPHr+Z\n\
hTRmKRkOePbFR1t3kAniOFBcdDWKwKkhgQR2NZYXEKtHzRdOfOgpKKK6TQKKKKACilooASlopKAB\n\
gGBDAEHqDXOatprQMZbdSYTyQP4T/hXSUnWqjLlYLR8y3Pozw9/yANM/69Yv/QBWhVTRv+QRY/8A\n\
XBP/AEEVbr7qHwo/O6nxv1f5sKKKKogK+SfiTq0WlftG+Inu5pYYmtbYJKACiOIUYbsnj7px719b\n\
V8JftQahdWXxt8QLaTvEJYbZX2nqPIT/ABNZ1YucHFHRhaqo1VN9D1z4W+L4fGP9oXOwIkEybU3Z\n\
AyG5IJOMtn1/LFdhqM7xE8kH1r5e+H1zqPhnwre60sYFgUdhNFjcJgUEaOfTPQdsk16V8GPEVx4p\n\
0fVRdec1zHKjs7nIbKBTg/8AAAfxr4DPspXPPGU5XjGya7bL/I9mjaMoqpo2lp/Wmp1l5NbG7Sc2\n\
lu08cnmLIYxuD7du7PrgD8h6CuX8ceHY/GBY3srgZj8sKCGjwCDg5IIOScbck9+BXRXsJhuFV+C2\n\
SB3xxz+tWraMcE15+HqzoyjUpvXoezPD0JU9vuOT0Dw3Z2ekC31K0Z2RnHmI+0qhXZlfTcoyc/3j\n\
0rg/FVjrF1BoFvp9nJNpFszWyxXDENy3Ab5uy8Ag9BnjNe4SMkaFmAwBWVK8DMuLdAFzgZIBz6gc\n\
GvVw2Lqxm6kldv8ADRrTtuYvDqfwf1rc4+88MWPiDRZraZZLv7DcSLZSl85iwu1SwzkDkZHvxmjw\n\
1Hc+AdO18QGE/abQy29xIvzpsGdmTjdtycDH8JxXWwyGAt5AEecZAz26Dnt7VlzWaT3t00hjEc6Y\n\
bkMDznBBGO5we3bmtoV6rvGcrx3t93+X4lPDcr5+W7e/X5fLp5+pyngHW5tSt/t1vdaldpZoZb6O\n\
9jSaN0DAHy8DKkA9DnjpjFbHi3wno+pX1rrU1rNtjmXdAkQcOm7ldo6Z565Ge4q3YWCw2KW8eINn\n\
3UtdwzwDhsE9SBuA64AzjityDTdR+zp5FosaKMck/wCH41VWtaqqkZcu+76P+u2mwvq6do1LJW9F\n\
ffZ+ZzPgzTD4Z16WxkmA0p5MC5lO9lDLlVyQCqjac9vu+nOTcXNhqPiKSw1qHVb3UZyzf2fC4iWG\n\
IZGQSx3sVXd6enWuxl+2vNcQTskkUkbRvbyRBxgYPzE/dOQcHoQfUCq8NrAbX+0JreOKfZ9nWQFp\n\
5UyGAO8nIGGXgccYycYN89Sacpbvaz+d3p9/Xaz1FHkpvln9+r8vPXtvtsO0lPsF95Md3JqFvlmt\n\
MsWlBZxvDY4OAM8AHrxWtZ2t1qMj3ENo9woXbndtyRnA/Asf1qKKzdbdILrTZYp4EKWsvlFcjGeg\n\
5YsWOe49CCTXfeH8QaJZrdRmBwnMR+99SPU9a87GYn2SVaEdXp0/R/1s9jkq4hUouMIpt9L7d3p+\n\
Pnc87vrTBtre4tpx9nlDxJcZGxj95kP4kj6dPR9jZtBaSQadaxXenxxt5kDTFSQD91GUdCpP8Ocj\n\
qM5HceKI7e40zzhF5/2dt/lElS2QV6j659OK5K2S9lv49Ptp55FmMjMJ2IR8HIYN1GAqsApwe/XN\n\
PD1nWpqony2eu/zd99tepVLEc0btWa369/T/AIcwdN0wW+vSNPLd3k+oxBpbSfDbdgK7m2qF3fdX\n\
dndnceK1xeXUmmxwSND5zx+WUSMMjBsnKqCM/LhgATye9aM+m3djNLEsqeZNHsSRVYpk5zk/dyo9\n\
ecc9uGXd3Y2Gh5uVS5kvGMjkfIVPTCkHOMd88g+hxV1JwlCL5b6qz3enySVu25p9YlVmlFX8v+H/\n\
ADJrKX+ydUa6vrZjA37kTbgBCCducHBI47DgcdBXL+Mp/Ivtsbo+VyjKcgg96ZP4itVhWO1tnKoz\n\
lEkfdGu7PHTJAycZzjNZEFre6vcFkQseFL9EQDoPQYHat6eFU5qtJ2SVtf8Ah39yO/AYSqqjqVFZ\n\
f1qZ+WY5Zjn1JrpPDGsrA32TUR5tqQxUbyuGwQOR+VTWvhZAAbu5JOOViGAD9T/hVqPwtZyPtiN2\n\
7eisCf8A0Gtq08LJct36np1qFOrBwky9JJtsUBin89EVwVYnC8YfPGSNowB0PWsjxW91rGtRJE5m\n\
yvIPy7SOCT7Z79DWxH4QjaIRS3VzHAGDeV5gbn1xjFdBpOl29kDHp1uTJ/E2dzk+7Hp+lYXhzKol\n\
dr7vO9zy6OHjhqntHK9rr5dNWzk9L8LajAPMivvKV1w6bCFYEYI6gke+K17Lw5d3d0Re3CuCf9Vb\n\
bgGGMAszcgDnt365rsbfS2J3XLgD+6hyfxP+frUGo6pFZI1tYKocdWAyB/iaISnOXu797JEV8TCp\n\
K6im/T+r/cTGS10W1VBtabYFVF9BwAPRRXO3l3NfTBpTk9FUdB9Kgd2kcvIxZj1JOSauaXaGaUSu\n\
D5aHI92HI/Afz+hFbVZU8FSlWn0/qxzO0Lzk7sv6bZiBBJIo84gg4OcDPT9B+NXqKz9Z1AWNv8vM\n\
z5CY7e/+f8a+FqVKuNrc0tZP+vuRx+9VlbqyvrWri1zBbkNcY5PUJ/8AXrliSxJYkk8kmhiWZmbk\n\
k5J9TSV9JhcLHDQst+rPZoUI0o2W4UMQoJPQc0VT1SQLAE4Jc9K6jVuyM+4l86Zn5wegz0qOiigt\n\
KysFFFFAyO4lEEEkrfdjUsfwFR/s2OZPivbyN95oJmP1IrP8WTeToNxjrJiMfiavfs0f8lTtf+ve\n\
X+Ve3lMLe93Z5WaS/dyXkz7Dooor6U+NCiiigDk/it/yT7Wf+uS/+hrXzFBDJO4WJCxPNfU/xEUP\n\
4M1RWGQUXj/gQrwVVCjCgAegr5zOZWrRXl+p9XkMpKhJLv8AojHtdHw265cED+Fe9bFvAABHCmB6\n\
AVdtLCWc5IKL6kVpSiLTLN5EXc2cDJ6k9vpxn8K+cniuaoqNL3pvQ9WdVJ2WsiG2soreFpp3RZIw\n\
obfnahbpuwD6dP8AEGl1TStUFu86z/abZxlhCx2gD/Z6HpTtJeO70XUUuBuk81JSVwGBLDkH1BB9\n\
vXIOKoWs90q5t5rZp4GcSxy7hsQE4ddvKqRzgkjpjAr0YwWX1eaaUn3a/Lsv+Brcy1i3Kb2dtVdb\n\
Jr09e9jKoro9PuLLVLJby7gjmWSRkLRgoyYPGeecjnk5561tWGl6PIN0EKSMOSHJJH4GvahmVNr4\n\
WmbVcU6Mbzg/6/I4i2tp7qTZbxPI3ooziun0vwsAVk1B89/KQ/zP+FdRGixoFjVUUdAowKdWVXGz\n\
npHRHlV8yqVNIe6vxGxxpFGqRqqIowFUYArn/EUu66SMHhF5HoT/APWxW/LIsUbSSHCKMk1ztpA2\n\
pX7yuP3Qbc3P5LXnVZqKuy8shacq0tl+bOb+IGmMPDljfxrh4GxJ/uv0P54H41iaP4iczQrewQTq\n\
BtUumCM4zyOv416Z4rjV/DGqKwyBbuR9QMj9RXiEIJCAdcAVzYe1elLm6P8AM96ly4nC++tYyevk\n\
1c9PuLK2hht5YA3kXTF1gXho+Fz82OmfXIHoea5bxh4nPhjTobyW2P8AZM7COOOKPcV2kYLcjDYH\n\
U+gyPTttJs4tS0+Od7q8ieGPaFibATA5wAMnOOneuA8cWOpa74XubTTFtY2lXLlwRIVAUkKNp9Dw\n\
D356DPPgXCclTm9L2fTc+du48+mq7/g9Xbotd/Q5ofFfTZdeFvALqWwcBFeRFX5i2M+uAMdck4I4\n\
zxz/AMU/Fdxp+uX2maVfSyW5VY5YpYiPLcAZK56g5PX1PrXml7pt7p4V7u2mgBbCmRCuSPTNVZpX\n\
mlaSVizscknua+vpZbQhUVSHRWPFq4+s48stH6WGnk0lFFemecFFFFABRRRQAUUUUAFFFFABRRRQ\n\
AUUUUAFFFFABRRRQAVu+EfEl94a1OO4sriaKJnQzpGQDIisDt5rCoqZwjUi4yV0yoycHzRPpbwT4\n\
x1nxVfLqkOleVa2bsIj5hG4E42qOF54Df73HbHseiaimsWZnMbQSK5jYHkEjHI9ufQV8SeGPEWoa\n\
LK0dlPHEk2EZpV3BV3AkewOOcV9PeHNUbSPs6xahFeRYxcqExu7bs9iDnPqK+MzrKoxj+7ST6ei6\n\
fM9qlOWLheD99WX9ev8AXU9RRI4vmLbj2qTzm/55mufk8QWUcBlIkBAztI/rWL/wnP8A0xH5V8rD\n\
A1qmqiFPL8ZXvJqxU8Uf8jNq/wD1+Tf+hmsytPxR/wAjNq//AF+Tf+hmsyvpav8AEl6v82fTUf4c\n\
fRfkhKuWNsZX3OP3Y9e9Q2sJnl2g4HUnFbcSLFGEXoPWvNxuJ9muSO7/AAFVqcqstxwAAAAwB0FF\n\
FFeIcYUUUUAFFFBwASTgAEk+gHU00m3ZAZ2vXPlWYgUjdMct67Qf6n/0Gucq1qV0bu7eTnYOEB7K\n\
On+fXNSaRp76jepAmQvV2/uiv0jL8MsHho03vu/V7/5fI9WjFUKXNLTqzX8HaZ505vZl/dxHEee7\n\
ev4V2lRwRJbwpFEoWNBtUVJWFWo6krnzmJruvUc38jF8QP8APbpjkBn/ADwP6Gs+1l8m5jkz91gT\n\
9O9SalKJr6VlPyg7Bzxgcf4mq2C3A5JrjlaSdz6LDUuShGD7fmdhdsqWszSfcCEn6YrxLRtTfS2l\n\
KwxyrKqghu2P5/8A6q9R8d34sfDlyAcSTjyV/wCBdf0zXkJ7fT+tcmCpKopKWz/Q0wGHUsHOU1o2\n\
vwPR9N17+2NGeMBY5rUo6KoChdpAGB0+g+nXpUWp+H/+EgP2jbHBfoSkscbdffHUf5+lcp4Smktt\n\
TWSIkHIXj3rv9Znt/PsXdpYri4XFw8ZI/d5745J4/XnqK8+tB4eryU9N/wDgnkV6bw1W9LS/9P7/\n\
AMzK0TR7TTzLaEJc6g7qvlBNwwDyCxGB0PT0rRheRbST7fDBGsLy4CEYLjpuOSdoyQMeg+lQ+I7q\n\
DQsR6cmJtmHnc7nOByee5/rXneoaldajKGu5mcA4VSeB3q6FGWKfNfTu9y6GFqY2Slff+vkaTeJ9\n\
RkvTIX86NzgwsuQ4znp/KukHheXUZ5NW14m2BAJgjbLtgYG5uxPt+lUPhppqXWqzXci5S1UbR23t\n\
nB/AA/nXa+JJ8LFAvpvP8h/Wux8kaihRVvM9PEU4YbEKjSXvW1f6L/MNFs40iWYIqAjEaKOEXp+Z\n\
5/yazvHSk2dq3YSEH8R/9aukRQiBB0X5fy4/pWV4qt/tGizYBLRkSD8Ov6E162GtGUTwoYhzxanL\n\
v+Gx59W74em3QzQlh8pDqMc88Hn/AL5/zmsKr2iyvHqMKxn/AFrCMjnBBOOcdfX6iunM8P8AWcLO\n\
n1tdeq1/Q93Ew5qb8tfuOlqpqFuZU3oMuPzI/wA/59bdFfnVOpKnJSieVGTi7o508HBpK1r6zEgM\n\
kYAfqR61lEYJB4Ir36FeNaN0dsJqauhKWkpa2LCkopaAEpaSloASloooA+kNH/5BFj/1wT/0EVbq\n\
po//ACCLH/rgn/oIq3X3kPhXofndT436v8woooqiAr4I/at/5Lfrf/XK2/8ARCV9718EftW/8lv1\n\
v/rlbf8AohKAPJN77Nm5tnXbnivafBEF/wCDfDNnr8GqK1hcWdzLJGhG2OTIUKD1Lkqo6YG09ga8\n\
UqU3ExgWHzX8oZATcccnP865cVh3Xiopq19U1e6OrDV40W3ON9NPI9d+FPiqbVvE7299bx+a8LrF\n\
KjMqxgtuK7BkHLY9MV7JBdIuN7AEdjXzv4H0bVbXR5fEWn3Mtk8ciJESjDz8sQVRhnuApBGOTXb/\n\
ABM8fx6b4nt4LW3lD2oViuQrRMw+cbh97II4PHA718zmOXvE4r/Z1ps/Jr19e/qe5hMTKhQvXWkt\n\
U3/wNfwPVL6QPCjKGA3HIZSpBHqDWfWR8Oby21XwtH9hW6EOWaM3ThpCQSDk9xx1rYZSpwwINcHJ\n\
7KUqb3TPYwtRTppozr6RnmEKZx3A7mtzR9FUyRxhFkuW7nov/wCr1rKEWNWt2YcMwPPqP8ivRfCs\n\
AEE1wR8xOwH2H/66yxuIdGmuUrH4l0KS5f6ZcstNtrFRhBJNjl27fSrql2OFNMJyc+tWYl2oPWvm\n\
5zb1lqz4r2k8TUbkyrcafbTnfdRQyEDq6A1n31pplzKjzWqTyJ91iMen59BVi/nMkhRT8i/qawdV\n\
uypMERwf4j/St6Sno+Z/eerh8JzWTv8Aey7fa4UzHAFLd9vQfjXO3ut7CRLc4P8AdSsLV9RYu0ED\n\
YQcMw6k+lYssixRs7dB+telQwatdnt0MHTpqyR1H/CTmFt8TTcdy2KzJ/FSxkG2gt4XVSoaNPmwe\n\
2a5Sed5myx47DsKjAr1KOBjey6nasFSk05LU3n8TX2SYpGHfnGM+uKyby6nvJTJcytI/vUNdP4X0\n\
kELe3SZ7xI3/AKEf6f8A6q9H6vRwkOeS1OqNCnB8yWo3RfD29UuNQBCkZWHoT/vf4V1lpbNIqxwI\n\
qRJgZxhVH+ewqW0tjcMxYkRL1IPJPoK1RgKqqAFUYAHQCvMqVJ15XlsZ1a9vdRWisYUwXzK3vwv5\n\
f5+lW1DNtjjXqflRBgZ+gpvoByScAep9K37C0FtHlsGZh8x9PYe1S7QVzzq9fkV5asrWmlqAGuju\n\
b+4p4H1Pf+X1rSVVRAqKFUdABgClrP1u9NnaZjIErnavt6n/AD7VEVKpJRR5spyqvVlDXtV2lra2\n\
b5ujuO3t9a5ylPJyeTSV7FOmqceVHTCKirD4kaWVI0+8xwPb3/AZP4V0ltCsEKxp0Uegyfc471l6\n\
JDud5WTpgKxz+P8ATn6itmvkc/xbqVfYR2jv6/8AARyYid3yroNkdY42dyFRQWJPYVw2oXLXl3JM\n\
/c4Ueg7Cui8TXJhtEhQkNKeSM9BjuOnUfka5WllOHtF1n10R2YGlZOowooor2T0ArGv5PMumwwKr\n\
8o9vX9a2awZTumkPqxpk7ySG0UUUjQKKKKAOX8ey7bG2iz96Qtj6D/69b37NH/JU7X/r3l/lXL+P\n\
2Pm2S5+Xaxx75rqP2aP+Sp2v/XvL/KvostVoQ9Txsxd4z9D7Dooor3j5EKKKKAOf8fKX8Iaiq9WV\n\
QP8Avta8gtNMSI7pTvbngdK9j8b/APIr3v8AwD/0Na8tr4LiuvOOJjTi7Ll/Vn0OVTcaDS7/AKIT\n\
oPQVz3iCZmvBCwIWIcDPUkAk+3YfhXQSOsaM7jKqCxAOCQOcD3rjpXaSRndizMclj1J9ay4XwvPW\n\
liHtHRer/wCB+Z7WEheXN2NLw+8yz3Igi87MDFk3BcgYPU8D61BYvGuv3zTjN/Jhmt2Qx7ABjCZ+\n\
8eRgcAit/wAL2Ji0u7vJBzNE6IPbB/mf5VheILVLi3ju5ojI9jh2w2GaLPK5x2OD7DNermS9rVdu\n\
1v6+ehvG1d1IJ+WnV22+/ToZ8KL4XdftF0Xtbs5aIRkNHj+Mj1HQjvz7GupitJ3ijntSs0LgMkkT\n\
ZDe471iz+R4l0V3ihj88hyg3Dej56EjsccE9z24rG8LeILzwzdNaXccj2bN80LcMh/vL/h3rhpzq\n\
Si0vjW6fX+vxNsPUnVpyU3+9i9U+q/zW2u/fY9Bgv7+3ws8Ekg/20IP5/wCOat/2tJ5bMLKQAdSW\n\
wF9ycVmXfjXRILcyCWSV+cQrEQ+fTnpXnuueILzxFqEaTP8AZbDeNsS84HqfU1dKdaerjZd9TOnl\n\
8a96lSmopde/olud3ca3p9zMF1DVLaJF58uJs/jnkfqa1Yte0OCMLHqVkqqOglFeeeJtJgXTTOkD\n\
ebDP5DPzgqBwc9D0+o71yQhUHkE/U1KpQxSvzM3w1DCYmim5SjbokrfL/gnoHjbxfBfWr6bpLb4p\n\
PlmnIwMZ+6v17n0qronhiGe8EYuw0y8hWQqG4BypPXqK5C3iaSVUQZJ4AFer+FIYL6xSG6iEjwKI\n\
1ccMMdOR25rHGSWGp8kNvxObMKjw9JLD6RW/Vvz/AKt5Dbm+/wCEciS2sWtpi4+cyE5EhbAHHr0+\n\
uPWuN8VateaRp099bWq3MscwM0TN5bdSTx3Ix2H48cu8TafNHY3UaXTWFza+ZLGURmO7aAoGOCCO\n\
3TgEckmvnfVtT121F/Y6o0yfa9vmxzJg5Q8MB2PHXvk+tdWWZbCvqmnrr5ng16/1aLk9XLdr8Pl+\n\
BV8Ua3c69q895czTyKzN5QmbcUUnOOMD8hWRRRX2kIqEVGOyPnZScndhRRRVEhRRRQAUUUUAFFFF\n\
ABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABXqvwc1UStLpEWkx3Fy7G4kuwRvWNMMevJPy4AGM5ry\n\
qrmk3aWOpW9zLD58cbhmi3lN49Nw5Fc+Jpe2pOPU3w1X2VRSPqVYY5kjkKOoZQ4VsjGRnp2qfyR/\n\
zyH/AHzTPCmpW2qaTDPtj3gDcEcuqtjlQT2H9a2vtEXtXwdXEOnJwluj7mNec4ppXGeKP+Rm1f8A\n\
6/Jv/QzWdGjSOFQEk9hWn4lRn8UasFGf9Mm/9DNT2tusEeAPmPU08fiVQlLvd/myY1FClH0X5IdB\n\
CsMYVQB6n1qSiivnJScnd7nO23qwooopCCiiigArN126MEKwRSASSA+YAOQvGOff+noat31ytpbN\n\
IxG88Iv94/4D/PWuVmkaaV5JDl3JYnGOTX0uQ5a6k1iai91beb7+i/P0OrC0faS5nsvxCKN5ZFjj\n\
Us7HAUdzXomhaYumWQTgzPzI3qfT6CsvwjpPkxi9uFxI4/dA9h6/jXTV9Hia3M+SOxyZji/aS9lD\n\
Zb+b/wCAFVNTuvs1uSD+8b5U+vr+HX8qkurmO2j3yHn+FR1b6f41zl1cPcymST6AdgPSuKUuhngc\n\
I6slOS91fiQ1f0e3M94jEfJGd7H+X6/1ptnp1xcsPkMad2cY/Id6g8W63D4f042entm+lHUHlB/e\n\
Pv6f/Wrjq1Ob93T1bPbnP2j9lT3f4ebOY+IWqjUdZFvA+6C0BTIPBf8AiP4cD8DXKk8k/lWloOnL\n\
qdzKsrSCKONpGKd8c9ee1dDF4QxIk9o/2i0ckxy46jOOnrR9YpYT3G9Tqr46hRhHCU3pH8f63G+F\n\
9PWysG1C8eCOU/PBFMxAfn259a1r7UYdQv4byWNY0iCsIBIoYop+ZsHk8nb6dO/ToFSzsNDK6n5Y\n\
KqxjjYgPgDoue/Fcn5Qa3gDIv2hw0AkbBIUFCACc7Qcg4HHHOTXlQn9YlKpLf+v6fXsfNSquvUcn\n\
3tfW1nvb5LX8Cx42lt9R0ma9top4+R8zrhW5wdp7/h6V50B9w16t4j0WOy0Y29q80gkfeVdsjPcA\n\
dv8A6wrzK5s5reUoY3K9jiu7LKtLkcE9D1MnrxhBSi7pPS/Y7/4UkfZdSH8QkQ/htP8Aga1NcfzN\n\
QlH90Bf0z/Wub+Gs0lnrM9pco8ZuIA6BxgsVJ/oT+VdFq6ldRnz6g/oK0hG2IfodVdxnjZVIu6kk\n\
1+X6G7aSia2ikH8Sg/j3/XNSSIsiMjjKsCpHqDWLo14Ij5EpwjHKE9j6fj/P61uV6EXofNYui6NV\n\
rpujy/ULZrO9mt3ByjEDPcdj+VVx1rqvG1hh472McN8kn17H+n4VytexSnzxUj6LC1lWpKf9XOxi\n\
lE8McoOd6hj9e/65p1UdElMumqCB+6YrwR0PPrnrnsB+tXq/NsdQ9hiZ0uzf3br8GeXKPLJx7BVK\n\
/tBIDJEPnHUDvV2isKVWVKXNEIycXdHOsCpweDSVs3tqJkJUYkHT3rIdGRsMCDXu4fExrrTfsdkK\n\
imhtFLSV0GgtFFJQAUtFJQB9I6P/AMgix/64J/6CKt1U0f8A5BFj/wBcE/8AQRVuvvIfCvQ/O6nx\n\
v1f5hRRRVEBXwR+1b/yW/W/+uVt/6ISvvevgj9q3/kt+t/8AXK2/9EJQB5FRRRQB1nhDxtqnheLU\n\
JNOupEupkjSMkBgu1sng8dMjGO9YrG68QawTgNd3LZPJ+Zj9e5NZtbPhv+zYrtbvVZ5Vjt2V/Jhy\n\
JJP91uxHvXPKnGlzVYr3n/SOuFWddxpTfuru7ab7/P8A4B7H8JtQt7OSDR7a0lW5SAyTPJGUIc4J\n\
j5OSRycgAcjiul1nxPJa62kIeFbcMYZ0nXy2jYj5WDYOVzweMDjJo1a+0uz1uy1vTroG7+xCaz00\n\
PHvbzECk5P32JA4J5IPPTHgXjLU7ufUmtp1eBofkdChjbfnLFl3HByT/AIV85Sy/61iPay2ktdb6\n\
637eVuzPbqYiOFp2WqW3R+nW3c980SO8+z3V1cwrHHLN9rt8OWOwn5d2TkEgD9e9epeD72Ke1aNW\n\
HzHeo9QetfOPwekv5dMElxFeXFqt1thdJshDsIO5f7uCefUCvUrC5uNMn3Qhmh3bht+8p9q87M8H\n\
zuVK+q2OylD69hbLR9PzPVnUqee9Tq37nI6gVxI8Z+XATNEHIGSWQr+fatbwl4ij1tbhDH5UkbYx\n\
nIdT0Zfb+VfN1cFWhBzlHRHhzwNXCz5prR/19w6V9kbyH+EFq5W8lKQTS5+YKTn3rqNRQrbXC45A\n\
NcvcJ5tvJGOrKQK3pW3PewtrNnH9evWs/U3+ZE7Y3VokFSVYYI4IrM1NcTI3YrivdpfEetT+Ip0+\n\
mjrTq9jCR0cjsiXdGs/t+oRwsD5f3pCOyj/IH416CqklUjXkkKqjj2Arn/B1uEsprgj5pX2g/wCy\n\
P/rn9K6jTgDex5HQMf0NeZj6rqVXHotCasrL0NONFijWNPuqMZ9fenUUVklbQ8wvaPF5l0XI4iGR\n\
9TwP6/pW3WfoqbbV2znc+fpwB/n61oVhUfvHl4iXNUfkFcdrtybnUJP7kfyAfTr+v9K6y8l8m1lk\n\
HVVLD3wM1wVdmChvMdFa3CkdgiszHCqMk+1LU1lsa+t0cZDMcc9wpI/lXbVqKnCU30Tf3HQ3ZXOg\n\
tYvIgSP5SVHJUYBPc49+v41LQOKK/NZzdSTnLd6nlt3OR8RymTU2XBAjUKOeD3/mSPwrLqxqO439\n\
zvOT5jY+mSR+lV6+tw0OSjGK7I96jHlpxXkFFFFbmo2VtkTsACVUnBNYOc8+vNb0i743UnGQRWDj\n\
BI9Din0BbhRRRSKCiiigDh/Hv/IRtv8Arl/U1137NH/JU7X/AK95f5Vyfj5SL21fsYyP1rrP2aP+\n\
Sp2v/XvL/KvpMv8AggeLmHw1PQ+w6KKK9w+SCiiigDD8b/8AIr3v/AP/AENa8tr1Lxv/AMive/8A\n\
AP8A0Na8sZ40GZZFjTuzHAH+J4PFfn3FcXPGwjFXbivzZ72V/wAF+v6IzNfuPLthCApMvXPUKCDn\n\
8x19jVHQNKbU7rDZFunMjf0HvU1pY3Ou3pk2mO3BwXPIUeg9T/Wu3s7WKzt1gt12ov5k+p969nB0\n\
1l+FVBfG9X6v+rHr1sSsNT9nH4n+BIkSBFhVQI8BAo7Dpiud0KES3E/mLujKFWHY5PT8s10M0ogi\n\
aVuiDd1xnHas3SES0sGnmZY1b5mZjgAds5/P8a8/GT5YNdzLAycaU/No8su7OTwz4s8qNmMccoaM\n\
jgtGcHH8x+FdddTQw3lvDKtsbdgHjmZfmhVjyB/tDqAcnHPPSsPWNdsdQ8XfaRGJrdFWGKQjPQ/e\n\
weDyTW/qkQmVb6KWWeGRCC3lgfZ1HGOh4J7YzXJibylDn0bX4/1/kduYzk5xlVVpW19dPx3/ABVn\n\
sYviDwrc3WqTS2kZWJ8MGkyF246kn+tQad4Tu4LpGuUBUHcWH3ABzkn0xXRw6xe3kFxbrOCgiG5g\n\
oD7Tgcbu+eDkenqDT4Nb1S1s4oykEmI/KR+rErwenU5wPc56Vk54pQ5H/S73/r79DnWKxMYKDt2/\n\
rT8B8j2ct3d2AUPDcSqEnRs/vSNpHPUZU9OmD6isy88GRwRTXF5/q4xn90cbj2H41V1a+tdI0mO9\n\
v544IonB8x2AJXcSwTvuBOR69Bz1uW2oXWpaDbtcSk6a8ayl2XiRc9Mhe/OPpj0NJUpq06UtHo/N\n\
r/hjCMqtFWhL+vLzf9bEtr4TRYIpbXKJKgcEkMcEZ61szQ3PhzRlnsUjmO4GbepJ25AJHIx35rMj\n\
8T3FnYwWqW8c8sWFLFgAUHGcdvTOT+Oan1/xCl7ZG2sgwMuN5bjavXHsen6/Uc7pV51Epq8b/h5k\n\
VPrNdqEo3jfXXp/w3Tued+NPGzeH7qe4ubJp3K7y3zlDIzDam4EAEKrdc4wB718++ItSfVtXuLp5\n\
ZpVZsRtM25wg+6Ce+BgfhXsXxT1fWLDTryFtNc6VN5apclFKxyqvOCQSTkkfTp7eFV9zlFCMaftF\n\
GzfnfQ8jMqrclTT0Xy8gooor2DywooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigA\n\
ooooAKKKKAPdfgFqC6hp9xozbzcRnzI2yOFHbAHTk9TXsP8AYbf3Wr5Z+FOrSaT41sZI5TF5reVu\n\
3Y5PQficD8a+nPt15/z/AGqf9+l/+Kr4vOcor1cS6lGaSfe/6I+py2tVqUEovbQ19Ztlj8RarIeX\n\
a6lP0+c1Xq/4g/5D2pf9fMn/AKEaoV8pi5Odebl3f5s6qbbhFvsvyQUUUVzlBRRRQAVFc3EVrF5k\n\
+cfwqOrn0H+Pb34BZeXkNkuZfnk4xEDgnvz6DH+e45m5uJbmTfMxZug9hXu5Vk0sXarV0h+L9PLz\n\
+7udFDDuq7vRf1sLd3Ml1MZJTz2UdFHoPatXwvpP2+5M06/6NEef9s+n+NZ+lWEuo3awxA46s2OF\n\
HrXeSS2+k2kdvAuSowqZ/U/55r6+tUjQgqcNP0RtiqrglQoL3n+C/r/Mvu6xoWdlRR1JOBWVfaxH\n\
GhMLIiA4M0vyqOvQd+mfwPFVYIrjVLnLsdo6t/Cv0FYPiq8VPFGmWNgwH2YHzB13FsbgfU4A/OvG\n\
qV9eWO5zUcvhFvm96STfkrf1/wAA3rGfSbx/Mm1SKeU+smzP0zyfwrSa90fT0Ltc2cWO5kUt/ia4\n\
nXdJTUkhjjlitpbT5Jo5MjBblcDqeMH8zXFTwvbTtFLGokQ4POPxFcsKf1j7T9P60O/CUaGL/iVH\n\
Hy6W/D8j0HxB48TY0OjKSehuJFwB/ujv+P61znhieC41Kb7fH515MCySSneGbH3SD6+o5rAz64x6\n\
Vd0iJ2ullUH5ThcdzXRUw8aNFrZs6sVSoQpOjQ0XV9X/AMDyO/VNQ01J4k0mBUlQ5MKFgFIwRlf/\n\
ANfPtTvD+rz6Xp8kcdoZ4S3mB1JUAHAPO3t+ffpzW9pV79n0q5muSxjjGR3JPoPU1xdy15Y2GoT6\n\
bbp5kUbSxxMRsZAS21iRjByAPqfUGvFoKNdyhNf8P/X5nyzSk5wqJaW6vX8bq3l3HTuSbzUrqKXa\n\
BJIQinAIbpkjGOOfp9aw/Cni/RfE8ctlYSeXLaHIDBgZFPUgHjqcckcgYGDXj3iL4qa5qUkH2Dy9\n\
MijjKGKD5gSSdxyc4BBxjpxWJ4G8Y3vhC+luLGG2mE20SrKmSQpyAD1AzjOOuK+pp5LNUZcy97pr\n\
+ByyzSmppR2+emmlv10PrHwpcWqw3VlqBjRN/mqzNgk9D1PGMDj3qa8mWbVIdN0gAYcNJPs3cYz9\n\
COPXk8Vx3hfxTo/iaznmsEmaWKNVmzHtSNtqgYJySQAcdfuk9xXUaRoRv4Gvnla0CkeWVbPQ5J7d\n\
/b17Yr5nEYf2E3Kro+3ntf5nTJx1qXdn81fvpq/y3OQ1zUpbTxTFPCnz2ZVVzkF+TuJ+uT+dd9dt\n\
HqtjBqVi3mRsnzAdQP8AEcg1wvjKeLMUAkSe5RvmmCAHA4AJ/iPTNR+FfEc2hTlWVpbGU7njHVT/\n\
AHl9/Ud69GKk6UKkN1p6n02Fw8sRhoypr34dO66/jqjqq1tN1LYBFck46LJ6ex/xqS2XS9ah+0WE\n\
6nIydh5B91PT9KG0MgE/aVx7p/8AXrSOKh10ZyVp0aqdOsrPzWqL95bx3tnJA+Cki4yOfof5GvMr\n\
mF7a4khlGHRipFdjY6nBbXptI7pLmNSAxQEhCc4APTseM/rVPxnYZMeoQjKsAshHP0P9Pyr1sFiF\n\
J8vc58InhavspP3Zbev6P/gGX4euFjnkhkbCyj5emNw6fpkfUit6uPgleGaOWNtrowZT6EV2G9JF\n\
WSHPlONy5649PqOn4V4HEmF5ascQvtaP1W34fkXjKfLPmXX8wooor5k5QqG4t0nA3jkdCKmoqoyc\n\
HzReo02tUYVxbvA2HHHY+tQ10TqrrhgCPesq6sWiG6M7l5z7V7GGx0anuz0Z1U6yloylS0HIJB4N\n\
JXebi0UlFAH0jo//ACCLH/rgn/oIq3VTR/8AkEWP/XBP/QRVuvvIfCvQ/O6nxv1f5hRRRVEBXwR+\n\
1b/yW/W/+uVt/wCiEr73r4I/at/5Lfrf/XK2/wDRCUAeRUUUUAFKDgg+lJRQBq63rEmqTWj+RBbL\n\
awJBGsCbRgZOT6kkk5p/hmxttX1yK31O/SzhkDFp5STzg4/En1rHrtfCXh/RZLSDV9d1a2FjFMy3\n\
FqGYSkBQVAAGTuJA49/SuWs4UKVlp0Vld3f39e+h2UeevV55a21d3Zaf8DsdV4Zn1bwu9rYvo7Wd\n\
y1wsc9zc7oVa3b7pAJxn5XOcHPfNesalcwWNit55U9ypUN5UCbz/AI45xVKzOmeIrXRv9P8AJ0GJ\n\
oTBAVGZXBxHgnkbcEHr6Y5rL+IetW+l6xHbwDWrVreQlLi1jylxIBny1B4JHvgd+2K+XxcZ1MTGH\n\
LbRttdvXv5a2/L6CFT2KcYvdK3b8u1iCxu4bC4nKPNdwTJuEMZDiJlQl4jsyVYoNw465HYg9D8NH\n\
On6mZ72/JhuVaZN8gYRhsYTd1AG09e59c186+J/El7fX022eQIxHztGInkxnaXC8FgCRuxmut+E+\n\
oyXQvo9RnkWCFd4nMmNuRjHIPp0GM989K7cRl8nh5ObtzJXtv/l+H3nHKvTqz9gltf8Apf10PrDU\n\
YQ6iUDKOMNXI3UDW8xRhx2PqK6vw5dQ3mhWTxsXhkhXaWOSeMHJ+tM1DTQ6kFS8fUEdRXwkJ+zk6\n\
cuhpg8SoXhLpp9x5zq+nM7Ge3GSeXUdT7iubv4i8JIHzJzj+depNpGW+SQj2K1k6/odvCIDcSeVL\n\
MSBJtwo6fe9ASQK9TC4l8yhuz1442nTs5M8uHJp1WtWsZNPvXimQqQelVa+owU1KDse1TkpK6O98\n\
PoE0W0AyflJ59yTW1pw/01PUq38j/hWL4efzNGtSOylT+BNaUbmKRJFGSpDY9favDq3VSV+7/Mmq\n\
ua6RuUUAqwDIcqRkH2orTc802tFfdauMY2uR+gNX6x9Fk23Dxno65H1H/wBY/pWxWFRe8eXiI8tR\n\
lDXmK6VOVODgD8yBXG12Ov8AOkz4/wBn/wBCFcdXo4L4H6l0fhCr+iqTdOwbhVwVx6nIOe33T/kV\n\
QrT0KPEk8mfvBRjHTGf/AIr9KxzeXLg6jXb9UOs7QZr0UUV8AeecPqf/ACEJ/wDeqrVrU4jFqFwr\n\
HJMjN9ASSB+WKq19nRd6cWuy/I+gpfArdgooorQ0CsGUFZpA3UMc4GPet6sa/j8u6bgANyPf1/Wm\n\
TtJMgooopGgUUUUAcf4/Tmyk5/iX+VdN+zR/yVO1/wCveX+VYvjuPdpcMgz8kv8AMf8A1q2v2aP+\n\
Sp2v/XvN/Kvocsd4R9TxsyVoz9D7Dooor3z5EKKKKAMPxuHPha+8qIyuApCA4Jw6mvG4bJJJRLq9\n\
x5mzkwQkEqD0zyMA8c9/WvZfGgLeGL4KCSVUYH+8K8Ekf7cNRltN76jay7UCHGNqhcZ6MCEJIPp3\n\
FfO5tUVGvGpFe9a1+tr/AILzPp8lilh5Te3NbTfX8jtrfVLGNEjiDRRjgDbgD8BmpX1WzVSRLuPo\n\
FOf1rjvCms6ZrBEN4fst/wBPLL4Rz/s55/DP512kdpbWamQRpGFGS7dvfJ6V5FXFezfK07npYnAU\n\
aE+Walf13+fX5HPeJ9bNvFCjIIzO+2COTjef7z45Cjjp/wDXHAeKjrctwh1iVzE/KRocR8HoAOP6\n\
03xhq/8Aa3iSS5t3b7NDhIT7DuPqcmuw0u4iu9Be7v0aVVK/aEyAASQPMHHXHUDqTSqVZ0eWpJJt\n\
noTlLLIwdNLbXTVN9n32v59jivD2lTajqMUaKVQHczY7D0969QM9vpnh147S6tnlKkqjuMsTyRj1\n\
wen503Qo9Ks7UX0UrDn7shG4DPHHv1rJvniv9bllhYmJ3Urgbc8KDwe2WYn6jkYrzqtR4ur7+kY/\n\
n2PIxVd4ueqfLHV6dntqc14th1JvBd9HosST3jJtkiViGUFWBII6nbnsOMc9c+IeEfHmoeGV1CK6\n\
WW5kZPLjilxhXyM78jJAAxgEc1tfE7xlqcN9eaNHmzeGXYZbZzGJItoABXGQfqa8tYliSxJJ5JNf\n\
YZbgeWi1WS97Xz/r7jxswxko1bQbur37fpdrv6HR6/4y1fXbBbLUJxLbI25AwBZfmYj5uvG4j6U1\n\
PGevJpq2C6hKLVIRbxoDjYgPQY+lc7RXq/V6VrcqseZ9Yq3vzPt8j1jwp8UHji0XSb5EhtLfEUl0\n\
/wC8bYFIUHoMZIPsB35z7BptxZ6jp8dzDIbmB0zvTjr0zxwcfy6Cvkeu/wDhJ41l8L6/DFc4k024\n\
bZLG/QZwN34YH05rx8zyr2kHUoaSX4no4LMZQkoSW/y8v6Ze+N82zWlthJfbgd0iyTqYd2AfkjAG\n\
3GTyevp1rzKu7+NbXH/CwNQS7QI67WCgAcMNw6AetcJXp4Cn7LDwj5dDhxjvWkFFFFdZzBRRRQAU\n\
UUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAWNPuDZ39tcqMmGVZAPoQf6V9\n\
i/8ACQaD/wA9ZP1r4yrq/wDhNtS9Lf8A79ivLzHC1q/K6Lta9z1csxNCjzKsnra1m1+R9f8AiD/k\n\
Pal/18yf+hGqFX/EH/Ie1L/r5k/9CNUK/MsT/Gn6v82e7S+CPovyQUUAEnA5NVb++htI5FMga5U7\n\
fKAPB9z049OueOKeHw1XEz5KUbv+t+xpFOT5VuW1UnOOgGSTwAPUnsKy9T1WOENFaNvmBwZOCo/3\n\
fX0z+XY1lXmoXF2oSRgIwxYIowAf6/jmqlfW5fw/Ci1UxD5munT/AIP5ep20sF1q/d/mK7M7FnJL\n\
E5JPU0sMbzSrHEpZ2OAB1Jptdv4V0c2kX2q5XFw4+VT1Qf4mvfqVFTjc3xOIjh4cz36ItaXYro2n\n\
EBfMuHxux/E3ZR7df1rDvLzddzR2rw3d2iGWVi37pSONm4d/xAHTmtnXkkvW+xW7qsjIT82cEkfd\n\
OOxAx/wKuVstQe01dNP1LTorVnOd23IDdyB3U9O+eOvFfO4qrOUm1r/X9bHn0vaxpusleT1b029O\n\
39dgtfE+tahK9hbQ21iyI5ZkjOUwCT1OAfrVKDw0Pt8c11qtrslbf5jSYZjjJzzwfrXRXoknnt/O\n\
W2s7eU/6QVYKzjJwwzzx1x64Namn6JossziFnfKnCs4x0xkY9vw/SvMqYzki+Vct+2v4mdXHyjFu\n\
C5V1sr/iZuutYw3On3kXlXUcaBpSH3bsYCjHPBGRz6/Wsjxhoks+om5aFw0yhiF5KnHIPrUtrEID\n\
Y3E0IniLnekfJbaQDj16IfTj2rr9Z1bTfsMU8g87cQNqH5gO5IPIwPWufmnRlHk13RzQqvDzi43e\n\
608n+H+R55pvhTzUlnumkEMS7yqgbm9hW9pg0e1urJbePzI2BMrygqYhxtx2yck/QGuhg1rSLW3u\n\
BA2GU4w3Bc+grzvXtcstES3kv/LhF27ZLSEKoBbC4wQOuBxjjrjmuikq2Lk4zT8i5YmrXbcrqP3e\n\
v3evY77xZNpzaSYIpUMysDEsb5YOOecdOPpXm/xHE1x4A1GKEz7gpIWD5DgcnPHzKe4HpVTxJ4q0\n\
3QTo0shhuIbpwXbLKY0Khg+COMnnOCD74rnLr4yWEKXNvBpP2mBy8WZJSweMEbThhgHv0IHpXfgc\n\
ur03CVOLet9dOv8ATsckqlGjB03K7u9dL6r70eH0Vq+I7jSrrUDPolrcWcEmWaCVw4jbJ4VhjK4x\n\
15o8O2ml3V6F1vUWsbUclkhMjNz0GOn1r7b2loc7T9Op897K8+RNet9D2b4Gm7PhG5WRI/sYmYxy\n\
IcuHOzhhg4Xj8efSvZfCtrLLo1+I1kXe42Et8r/KMkD1znJ6H26V554e13womi2FhoF2gi3LbiFv\n\
vPIeS3OM/dByRxwPp1uha6+nrLFbGO4hVyhVZAdj55AI4HVQRnqe3f4TNY1a85tRtr106n0cIv6v\n\
GNN3aat2038jC8XaJc25+0eU2zJJHcDv+Gf51y4ORwSK9Ft7qWW7mmuYZLt7lCixqzcgnPydRtGP\n\
zzzWPrXhZ7e+eNYyRngqcfnSwuL9ivZ1T28Fj5RfLLRrt+JzFg0wvYltpmhlZgu+MkEflXU6lpvi\n\
OaCSI6hcXaxn95GZCCB2J7Y49auaT4fXTbCbU2RJZYcELI+FAzyff6Vsiya6S+1LUUcjOwRxnCuF\n\
49OmAO+ePwGdbHrn5qdrLy6his1qSqLld7aapb/n+Jz72y6ToloDLHHMJI5cxJv8yVWZgpx97tXY\n\
2ey6ju7GdfkBbA64Unpn2OMfWuH8P6kdT8T2EF4kMVtG52RKuBuVTsz7g12YH2fXiOzMf/HhkfqR\n\
+VdlDmpzXNu9fxM50ZezkqnxO8vx/Pv8jib62ezu5beX7yNj6jsa1fD1wvlyW7YD53qf73Yj9B+R\n\
rX8Y6aJrcXsS/vIxiTHdfX8P89K46KRopUkQ4ZSCD7ivaxFGOPwzpy6/g1s/67s3pzWMoX6/qjsa\n\
Kjtp0uYI5UK5ZcsgP3TyMY7dDjPapK/OqtKVKbpzVmjz9tGFFFFZgFFFFAFS5sklyyfK/A9qy5Yn\n\
iba4wa36ZLGsqFXGcjGe4rtw+NlS92WqNoVnHR7HP0Vdu7Jo8vHynp6VTxzg17NOrGquaLOqMlJX\n\
R9IaP/yCLH/rgn/oIq3VTR/+QRY/9cE/9BFW6+/h8K9D89qfG/V/mFFFFUQFfBH7Vv8AyW/W/wDr\n\
lbf+iEr73r4I/at/5Lfrf/XK2/8ARCUAeRUUUUAFFFFABTl5IDHC5/Km0UAej+LNVsIvh7oulWeo\n\
zzzAi4QFQuIyMFWxkZDqx65wwrATxtq8GirYW13IpaUyzSkAs52hVGeuAAf++j61zTyO6orsWCDa\n\
oPYZzj9aZXLDCQUeWp72t9TtnjZ8/NS93RLS/wDn/SN7R9JufESarcqZbi6tYftDRoMsyggE/QZH\n\
T1Fep+ArfTrbTlEL2rWEoDTtNuSRZBGS8eGxuALKMjg+nXPHfDHxbZ+HrryJLPDXKsr3iYMsbH7p\n\
XPGB1IPWusvfBEdtaag97e3N3pchS4UxqPOMjNtLn5SSOvAPt1rz8Z7STlGd1FWtb7vw3W35Hp4a\n\
MXTU4ay+0/O99W++z0t+J7p4D1W1n0iO33pGUyYwSMbc+1auveII9ItTIrJNJ2XfwOCeTz6V5lok\n\
Ef8AYmnNbeYkYiURkIYyAOMEduneq+sajeWN5bq1q08DSeW8rsCqEruUNkgDPrXyU8upzrud7q70\n\
Z1zwFGo1iJOzl0Xc6xfibDHfTW11ZnzIUDyC3feVHr0wRn0J75AxWNr+tLNbahqepLLdRx7Whjhy\n\
THkDG1ejY3bueoX2NY99qNhHPLe+Hry2vorSJPtdpPt2oA4G4sRgAA475z9DWlBqPn6pPPcWkK2A\n\
jiaLEwyHbL4yOSMAHPT5TxXZDC06E+anTs2u+u62W935Pb8YhRpwXOlf+npvov6bJfE7jWNOg1AK\n\
oMjOilRjIXGCRk4J54ya4weh616bGdNvfClvbrdhZrYCFkkG1t5ORgeh3Ag+leeapbvaX0scg2sC\n\
cj371pga3s6kotWSb+49nK6y5PZ31X9fkb/g27XZNZtw2fNTnr0BH6D9a6YV5tazyWtxHPCQJEOQ\n\
e1d5pWow6lb+ZH8sg+/GTyp/qPerx9Bxl7WOzPVkr+8bVhchcRSthf4GPQH0+n9frWgRg4PBrB61\n\
ctr1owFlBdBwCPvL/j9K4Yztozkq0bvmiakbtHIsiffQ5FdJDKs0SyRnKsMj/CuXjdJV3ROHHfHU\n\
fUdRWjpN15UvlSN+7c8Z7N/9f/PWrmuZXR5mJpc0brdGlqEZlspkHLFCB9cVw1egnpXC38P2e9mi\n\
AwqscD26j9K6cFLRxOWg90V619E+7J9ayK1NCLb5wSNmF28c5+bP8hWec/7lP5fmiq69w16KKK+C\n\
OA5XxPB5d8JQABKAc9yRx/ID86x67HXrQ3VixQfvI/mGByR3HQn3wOpArjvrwa+nyysqlBR6x0/y\n\
PZwdTmp27BRRRXoHWFUtUiLRrIMfJ145q7SOodCrdDQS1poYFFK6NGxRxhh2pKC07q6CiiigZleK\n\
IfP0K7AGSqhx+Bz/AI1b/Zo/5Kna/wDXvL/Kp54xNBJE3R1Kn8Riov2bEMfxXt42GGWCZT9QK9rK\n\
Za8vmeVmi/dt+TPsGiiivpj40KKKKAMHx1fLpvhLUrxlLCKMEAdzuAH6187+AbW5nu7mWRZWtSpe\n\
STHBbqfxIyPoTX0X41EJ8LagLnyvJKDd5v3fvDrXhWsJfLoUJ0V7UfJJ5e0uI+q/6zGcnsPc18tn\n\
0/3ipqycktX6s+jyqvyYSdJL4nv6L8+xzOseGbyxmZo0WWEEMrKwOAc4P0ODzWjZaJqeo6Q/m3V0\n\
zMC0cbysUIUrng59f0rb8CSa3LoiHUo7QTlv9IPHlhhnPvk9/fpxTrl9Y+06d5283I3GHyAAj88k\n\
46dRweMDnua8SeKrKXsm1ePX0/r7j11mNZxUL2/rt089dtTmdI8K3F1cObgSCGMFmCKdxwOg967f\n\
7NplnophjVbp58BFXDMrFeOvTAP61FHL4gFhKsoIk805eNMsODkADkjPccelZZETMWhZw+W3L+Iy\n\
Bx/vfp71hKU8RL35LTz0MKtWpiJe89PLy11fQzvEGo2Glafb3+oTqYndYGc8iIMDhjgdCVI3cjPX\n\
ms7TvGHh7WrTUINNukublLOSUwzr5aZRcscAAkfKCMc+uMZrzD42r4oFza/24qnSlZ1spY02KynB\n\
5HY+xwa8vi37x5W7fz93rX0+EymnVoqblr+F7/1oeTicfKlU9io3S/LsvLsSXtw13dzTuApkYttB\n\
JCjsBkk4HTrUFFFfRpJKyPDbu7sKKKKYgpaSigDS1/VJNYvkupsmQQRRMT/sIF/pWbRRUxioJRjs\n\
i5zdSTlLdhRRRVEBRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFF\n\
FFAH3Xr4J1/UgASftMvT/eNY9zfWlsoLzCRiMhIiG/M9B+p9qpeMr24k8SavC0hES3cq7RwCA5xn\n\
1/GsGvjYcOQ9rKeIle7bstFu+u/3WPvsNg3KnFzfRbei6mhe6tPcEiMmCLBXahPzA/3j3/l7Vn0l\n\
Fe9Ro06EeSlFJeR6UKcaatFWCilroPDWiG8kFzdoRbL90HjzD/hVTmoK7JrVo0YOcyx4U0XzGW9u\n\
0/djmJCOp/vfSuvPTPegAAAAAAcADtTZZPKjZ/7oLfkM/wBK8urUc3zM+Yr1p4mpzP5HO3c7f2lJ\n\
KjZKyfKfYcD+Qq14o0yLXNE86Jf9JjXzYGHUMP4fxxj64rKHSt7w7KTDNF2Qhh7Z/wD1frXl4mLS\n\
VRbo9+tH2UYzh9n8jxu5uJriXzZZWdyBgn07Y9K67wLqB+0EzlykKl3Cgk4HoB9a5XUIhFf3cS9I\n\
pnUfQMRWn4QkRdQmjmVmhmQxOFbBOfeqxVOFTD81rHXmeGjCDjTWjWnzOptfIkvZDpttMlpC/mKg\n\
Yghtufm6gkcnB9snoK5rX/E2g6FDfXFzqFldTx5RYLd/mLfLnnqGOScY9eciuo1iztrK/t2skKW1\n\
xFubzH3InqCDnGcDOevrxXzd8YtNitvFs09jp89raSqpJkBJd+7E5IOeuRwaeWYali5pSulb9b2P\n\
lK1eVGm6lNX77/i/Va9+rXX3LStc0rVdOl1GG+t2toGDSsXIK8KxzjJIHT6DngV4h8Q/GsXiGwt9\n\
PksIftFo7j7XHKxU88FRnGCB3FcjZ6reWGm39hA7RxXmwTDJBIUkgfmf0rOr6HCZXChVdVu76Hl4\n\
rHyrQUFp3/yJJppZ2DTSPIwUKCxzgAYA+lR0UV6yVtjzb3CiiigCW2nltp0mt5HilQ5V0OCD7Gu5\n\
8MfEW70Pw1JpkFpBJP5yvFK65ODneCc554xjpz0NcDRWVWhTrK01c1p1p0neLPqvwVe3sGiaXfXb\n\
Ob8YllVsH5WJOz2zvPU55HJ6Dsj4kguZWfUbFhb52oV5YHjJPYjnt6Hr2+cPg34nS01r7DqJd0lh\n\
dI5WmYeUq5k2gcgZIJJ5PpXVWXxf06fVIrGeBodPLuHujnc3y4UnqVGSx46eh5z8fjconOtK0b9b\n\
+v8Awx7sMRSqxjOWkr2ve3qu2/l182e3eJ7vTpNINtbyqX3KU8o7iCCMnI4HH5ZrF0e21W5S6Wwk\n\
eO3jIUwl8jjHAHbkHIyMdD6VQ0e903VtEF7YOs1s7pJyuw/ewclgQc7ccY6YBBrRfU4tJ8NiSxuF\n\
aRmHn7QQFkx0Cnp/WvHlQlRhyJa36+v/AADohTaXs4atvd+dn/w3nsY+q6TNqTLcaZai2vYH/fxL\n\
8vlcZBz9QT7fhW/pN3c3E9oupKovbeRI5ihyGGQQT6Hk5Ht+Fck3ime4D4tEe9bAEx6nkYyvc8Y/\n\
xrsorFtM0u2M+03k032iYqON2BwPpx9Tk9676aqQ5Yz+Xf8A4Y9qnGvCCp1l7rvbvrvZ72/U6MKH\n\
i2uAVZcEHvXnWuae2nahJFg+UfmjJ7r/APW6V6QRgkehIrL8Q6aNSsGVQPPj+aM+/cfjXuYeryS1\n\
2Z5GBxPsKmuz3OH0y9aznBJPksQJFxnI9R7jt/hmuljkSVFeNgykZ4P6H3rjmBUkMMEcEelXNLvB\n\
aXG5wWjYbWA649R71z5vlMcZH2lPSa/Hyf6P5bbe1icPzrnhv+Z09FIjxyrvgkWWPOAy/wCB5FLX\n\
wk4ShJxkrNHmhRRRUgFFFFABVS5skl5T5X4Htj/P8hVulHUVdOpKm+aLsOMnHVHtuj8aTZf9cE/9\n\
BFW6q6T/AMguz/64p/6CKtV+wUnenF+S/JHxc/ifq/zCiiitCQr4I/at/wCS363/ANcrb/0Qlfe9\n\
fBH7Vv8AyW/W/wDrlbf+iEoA8iooooAKKKKACiiigArT0S0067kcanqJsUXBDeUZN3qAB3+uB71m\n\
Uo4NTNOSsnYunJQldq/k/wDgHuekaN4V8F6nJd6lf6deI0kXkLkO0a7RliB0yWBK+g69TXp+r6Zo\n\
3iC00/VksknIhLRSHKgg5OSAcdcsPevk4DU/EOo4RJ728ZRwilmKquOg9APyFfQOmS67Z/DS40W9\n\
0yS2mtCsEIt926VCAQeCCc5wQODznGDn5nNcHVlGny1bTW+ttOul9T26Nb2s3KNP3Fc68yXFxaJH\n\
p+PMI3K2wNkYzxn19a8wuvFur2jzWurWsd9qkmIorJUYxXCBmzIwIIJ4IwAOnHWuA8Ka74jW9bTr\n\
PUZYYWdVcST+UkYDcZbI2j6EV3viH4iW+ja7Dp1rpsDtCYll1CZld2XIaQISpwM7hu59cVNDLZYW\n\
bhpN7rT835+R1fWY1l7SS5Y3t87/ANW6JmHceMdOidrrTEudMvQkaz2whzYXMijDBo+SBgkdsY6V\n\
ylv411KK4T94zWyqieWxz8qZ2Z9ducD2AFaviPxTe+LddGk6VBb2llcXBihjt4sGQu/Due7HgE+n\n\
41QsfCinV79JZWjtdOuFhuWkUBoycjJXqQGGCR06mvTpUqFKF68bNq9nq/Lp3/yuc9arWrSSw8rq\n\
9npbXrpd3Vt3pf11PdvBkserxaZA1yEe4ZQxMg3JHjcAMcncR34yGGMAVL48siupSMFw3XHr/kYp\n\
nhnS3ntYLawiEU8qx+XJgFSnXeQcgDbnDAYOc4ySK6DxZpTWlnaRBvNe2iWNnC437QATivlsRUVO\n\
vHXvp69fyR6GEqKOJbTvdfr+up5qOKlgmkglWSCRkkXoynFW7myDktEQCeq9qptDKmcow/CvUo4l\n\
JcstUfRwqJm/aeJ50ULdQrL/ALSnafx7fyq7/wAJRa7M+RNux04xn61yOG/uH8qcsUjfdjY/hTlR\n\
wj12Lco7s6iLxRI1wi21oRIzAIfNwc/lXSWOvlrpbXVrb7I8mRHITlWPofQ/hXL+GdIjjvYLvVJP\n\
KhB3KgUszY9hWhcqLyO9hhRnZ3kkLZYGQ43IwBPpyfy44zxP2Tk4wjZd9f8AhmeTisbD2qhFJpb+\n\
Xz/Gz/A9Q0u785PKkOZUHXP3l9f8/wBayfFNttljuFHDfKx9+39fyrD8I6tNcWoWYPFe2uNyuMFl\n\
Pf6Hn8/YV2V7Empaadn8Q3Ln+Fv88H8azpv2VRN/1/W5x4il7GpdbHF1d0mQJeqpL/OpUKOmeuT+\n\
AP51TYFSQwII4IPamtngpjepDrnpkHIz7ZFd+Io+3pSpd01/XzsOUeZWOsopsbK6KyMGUjII6Eet\n\
Or82aadmeYLXG63YGzuiUXED8rgDA9v8+1djUF7axXkBimGVPII6g+orqweJeHqc3R7m2HrOlO/Q\n\
4SirF7avaXDxSA8HgkdR2P8An/Gq9fVRkpxUo7M9uMlJXQUUUVRRQ1OHK+cCAV4PvWdXQEAjB6Vi\n\
XMDW8m05KH7rHHP5UyV7rt3IqKKKRoFXPglbfZvjeoAwslvLIPxX/HNU66b4TWpPxS0u6XtbzRt+\n\
WR/WvQyufLiEu5wZlG+Gm+yPpOiiivsD4cKKKKAMHx5YjU/CGp2Zbb5sYUH0O4EfrXzp4EuLhJru\n\
CR5o7UoVkUdjnBHPtkn2BNfR3jQsvhi+ZCQQqnI7fMK8B8t7GXU47QlL65csgHQ7lDcDoBh2BJ4y\n\
a+azxOUuTul+Z9Tk9ngqkLauSt+v9dDF1rxRd3r+VBsgtgQqIiAcDoPoPStC01rU9O0hmntbtGXK\n\
xSNGyx/NjOc8Z44+ta3hHQtM0grdX7rc6h2O0lI/p6n3rtVuba8jMZeOVH+Uo38Xtg14lX2UEoKn\n\
dLqe5iY0KVqcINxW72+7f8dzyzRPFlxZ3RMxby5AQxBLFcjrgmu036VdaE8sBWB4BkMNqu77eM+p\n\
OK868WaOdH8RSWkCubeXDwDrwe34HIrtNNtI7Pw8bW/nEAlI+0tjkY5CLn+LpnqBWWLpU4qNSlpf\n\
t/XyMcyw1OnyVIPWVmrdV6fevUyNe06y1nR4dN1OJBAsyzNGyFWfbk7eoIU5zgep5HSsPRfAmg6J\n\
a3txZRSG5+yvGZ3bIZWyGIHRBtYDnJwOx6+kaMNJvrNtPhjIycbioVyM8c8/5z61i3kEdjrt1aW2\n\
6NCMK7EuvQcHJ5GcginQxs0nRi2ktbd1fX+tdtDzbQlJ80bSWquk+v3+iPj26ge2uZIZMbkYqccg\n\
+49qir1H4n+DNZ3yeIJ5Yrt7mVg0cHzGNVUckjrxjn868vr7zDYiOIpqcXc+axNCVCbi9uglFFFd\n\
BzhRRXdfCrwdL4l1+2kuFK6bBKrTNs3jGc4IyOD61lXrwoU3UqOyRpSpSqy5Yo5nxFpLaLfx2ski\n\
vI1vFM2M/KXQNjn0zisuu8+NYP8AwsHUCz73+VGOMcqoX+QB/GuDpYebnSjJu90XiYKFWUVsFFFF\n\
bGAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRXQf8Ipqv/PqP\n\
++x/jWc6sKfxuxpCnKp8KufTvi3/AJGrWf8Ar9m/9DNZNa/i3/katZ/6/Zv/AEM1k1zVPiZ+lUP4\n\
UPRfkhKWnRo8rhI1Z3JwFUZJrrdB8NhNtxqKhm6rD2H+9/hWNSpGmrsmviYUI3m/kUfDugNdlbi9\n\
UrbjlVPBf/61dsqhVCqAFAwAO1FLXm1KjqO7Pm8TiZ4iXNL7gqhrMojsnXPzSEIP5k/p+tXqwNau\n\
BNciNfuxcf8AAj1/oPwrCb0saYCl7Ssn0Wpn1s+HPv3H+6P61jVv6WostLmupB1UyH/dUf8A6z+N\n\
ceKdqdu57uKf7u3Vnkd8putbuI42VTNdOAWOAAXPX/Paut8P6fpNldhJbmWSRAzS4T/Vlc9QOccH\n\
6d+tcxoVgdQuzPPKkcKMWZmbG4gZ2r7n+tdfLP8AbNSMgRDKVMQCtwGTOADwSTkA5x1HascVeVqK\n\
fTW3f+v61IznEylV9nCWkVb7rI6DxW9kNIjWBYpZ22iBsjP1z6Yz+deWePvEkPh/QJzbCzuLvICj\n\
ehaNsHa+wnkEEHH0J5rpLu2Wzt3uZZHitohkyt0UZ6nPC9859zXiXxsudKvL/T7nRXtLmGZDm5iy\n\
HYrhdrDpgYGO/wCGK1yfCRdWMG21r/wz+X4nzuJaw9FqE+br8/L0PN55pLieSaZy8sjF3Y9STyTU\n\
dFFfcpW0R83uFFFFABRRRQAUUUUAKCQcg4Ndf4W8A6t4hhgu7M2/2Bm2yTl/lhOejjqOo/OuPr1D\n\
4JarNb38tlFY3d4sjq7NGwCW65G6QjHXjrnoO+a5cbUnSoynT3R04WEJ1FGex7loFm11JaWHl7bS\n\
3VQ6RghQFxu+YY2n5QegyScepyPGs6iVLS2j8q0Ryyr3JPOSe/Wup8K6zaaXZzRXLbcsWGCWz2Iz\n\
+H4fSs7WDY6uUFzbGygZS3n78lTnC5Xrg/Tv9a+BjUlHEc0o+6vx8z6mjU9lXvUi7dP12/4NjnfB\n\
FsLrxNZI3RHaQ5/2VyP1xXoniOTdcxxjoiZ/M/8A1hXI+DbRLHxqkCSNIPs7MCy7SCQO30NdPrRz\n\
qc/sR/6CK721PEKS2tc92vVVetTktlD9WbdlL51pFJ6qM/UcH9QanrE0O52sbdzwx3J9e4/H+nvW\n\
3XdF6HzOMoujVa6bo4/xhpZSQ38C/I3EoHY+v4/561y1eryIssbRyAMjDDA9xXnmv6W+mXZABNu5\n\
zGx/l9RXo4arzLke56mW4vnXsp7rYqWV5NZuWhYYYYZSMgj/AD+NdDZ38F2AEOyU5/dsefwPf+f8\n\
65WlrDH5XRxyvPSXdfr3X9I7quGjU12f9bnZ0Vz1rq9xG4+0MZ0APDH5v++uv55rYhv7WZcpOqnG\n\
Ssnykf0/XNfH4zJsThdbc0e6/wAt1+J51SjOnuizRQeOtFeSZBSjqKSlHUUAe3aT/wAguz/64p/6\n\
CKtVV0n/AJBVn/1xT/0EVar9io/w4+i/JHxk/ifqwooorUkK+CP2rf8Akt+t/wDXK2/9EJX3vXwR\n\
+1b/AMlv1v8A65W3/ohKAPIqKKKACiiigAooooAKKKKAJbeea3kElvK8Ug5DIxUj8RXeeNPEklz4\n\
R8K2dvq93O8Ft86BDEow2AG5+ZhjAOOgHrXn1KSTjJ6VjUoRqTjN9Px0sb067pwlHuvu1uKzFmLE\n\
kk8k+tDOz43MTgYGT0FNorYxuz0H4QXGpWvie1Fnp8k0LSL9olSLLRxtxncQdg9xgn1rq9fgm8He\n\
M9Rvk1KyvYb/ABBGLuUPLLGTmQugGAQVI5xk4xnpWF4b8d2+gWuk2ljHGkphAvrsKpeQeYzCPkcD\n\
lRnPH4CvS9V8Jx+INFTWtGEcevs6GJ5eYwUYbnXdwckNyRyMdOh+exdaNKp7SsuXm93Xrva76bfJ\n\
H0NL3aKjGXNy7eWl+nb+noyymsWfhDWJo9MEVuJJsFJ3woUgbVA7AZyOnFeiFn1rQbPUNq+dIgLq\n\
vQOOGX88/lXit54e0rVNSgtdYnuxcWa7fKlclpHGC5jIGTGoPGSenXFe6+CbZbTwtY27nehTOcYy\n\
CSRXzWbRhTpwqbzvq+6t36lVqioTjVjsrL7+/wDT9TjbrSbeSQnDRP3C/wCFXdL8LpOWO0sQpK+Y\n\
xAY446dq7eXT0ZtyshH+0ORS5gskLSSoCRyzHAA9q8r65Nq0WbVcyvC1N6v7zzWeeC00u8ub3TrO\n\
M25aN8PtERGOWBPIOegOeKu6TFot2IHkMNu0iq8RDF0kBGSVOOPx7VhCyZNOu7YySz2nlyl33Zll\n\
c5wR0yCccZxnFTaSbebTNgvBKVEYltvLwLcOSwARun3enZQOO596pRpSTSv8r3+6+xpJVYJ3k07/\n\
AC28/wCvPt03iw2ttPp8NuCs3llHljBz5bEcEjtnnn0Nc2zxy6pYxR2SeTLI4uZRICLdVJ4wDg9B\n\
g8cZwSeQzV3ex3GJBdFITJsEm3AUjDFjwAOT65xVrSlkvBClst1JKEZWwxXrw2/r/F1zkYzinh4+\n\
yoxtL539d+lv61CNONFTT97T01/4doXQi0HimLc7sZbUrI0n3iSwOee2dpr0HRp9szQseH5X/eHb\n\
8v5V5ReX/wBj8WSy3LbxgRSMB2wBkdO49K9CsLrzoYrmJ1dgQcg8Ej+h/qaqom0m9mj0XQbw0L9v\n\
u6ok8R2Xk3H2hB+7kPzezf8A1/8AGsau6uIor6zKtzHIoII6+oNcVcwPbTvFKMOpwcV1YWrzx5Xu\n\
jhpSuuV7o09FnLI0LdV5BPcH8e34cEVp1zEEhimR1J+UgnHcdxXQWdyl1CHTjnBHcH0/z6ivls8w\n\
Lo1fbwXuy38n/wAHf7znr02nzdCeiiivBOcr31nDeR7ZlyQDtYdR/niuQ1CwmsZNsoyhOFcdG7/y\n\
/l+NdvTZI0lQpIodD1BGRXbhMbPDO28e3+R0UMRKi+6PP6K6C/0DALWJyP8Anmx579D+XX86wpop\n\
IXKSoyMOxGK+ioYqlXXuPXt1PWpV4VfhYyormFZoyrDnsfSpaK6DVq5gOrIxVxhh1FJWrfWwlQyK\n\
D5gHbvWUDmmOLb0YV3Hwc/5HeD/rjJ/KuHruPg3/AMjvB/1xk/lXTgv94h6o5sd/u1T0Z9A0UUV9\n\
sfBhRRRQBh+N3lTwtfG3k8qXChXIzglwK8agnhhnKatA8DT4YywuCGHQZ64AwOBwPQV7L43/AORX\n\
vf8AgH/oa15TPEs0LxOMqw5Hv6/Wvkc9zFYbFwp1I3g0n5rV7P8AQ+iyepyUn5v59DQi0iykjDxS\n\
SOjdGDgg/kKkfR7RgMIyY7q3X881ytjf3GhXxhdjLbHBKjoQe49D/wDqrtraeK5gSaBw8bjIIrSd\n\
JKKnF3i9UzsxNTE0Wpc7cXszlPFOhyXMdu7MsjW7ZilfPy5/hYj+Hpz7fhXBeJzrKTr/AGxBKiJw\n\
rgEocnOQehJ+te1TRCeJom6ONvTOM96zNKaO805re4VZUGUZHG4Fe2f5fhXDWkqFpcqa/L0O/A45\n\
Shz1oc3Lp2aT6rp+B5H4e1WbT9QicEvGx2sueoPoe1enfZLS98NSPZWUAdVJRiBuDZ5IY8huOvtX\n\
G6roFjY+LjbecILVkE8ad+T90E+4Nbt8yrKlgI7m1toUEjHzgBcAgn6cHJJGenY4rixijOcZU9Nn\n\
/Wqv2M8xdOU4ule+jvrt96u+lvv0OZ8UPqQ8H61Jpk6w3HlGRSqFi6gNx0Pzbcn0/THhvhPwLqPi\n\
Rr7z0mt7jyvOgaVcCViw69yOT0719NHSLprYG4sh5CIXZMnkHHbdnOAAQfTgDvIuj6leEXAIjV4v\n\
OiUkfITzj/eJOc4/HtXbhc0jhaUowsm+v6f5nnV4Ua8lKb0V+unzt19On3Hyj4j8E614fs3u9Qtw\n\
lqJTEHJwWOSAcHkA7SRnqKgj8Ia7JY/bI9One2MIuFdVyGT1GOv9K+mNY0+31rRGtdQiWWOVgI8o\n\
JNp3MGwMjnkHrnnr1FWTp0lhojE2X2XTpECyrF8qj8FOcdRzn72eeAfRhns7RjJLmb+X9f59DkeW\n\
Uk229Pu18r/1pqeJeFPhfPcQ6ZqmoFJ9PnYeZBlomCsuV+bHrn6cetex6TZ2uladDaQtJFBFD5eO\n\
ei9M4ODjnoOc5rbtvDd5dadbTRzxW/mbWKsM5UDC89+O3GM9sVN4h8P/AGKw+0WHztFjesh+8vrx\n\
1PT9a8fG5lHGTUJy76eZ2YZYWhJQT1btt19fX5X2PnX4222daS6MkkkhVAxFsFRV2jH7wfeOQeD0\n\
HGeteZV7z8XdI1bUNJkmOpW/9nxlHW2EQDySFW7jk98Z4GW6V4NX12V1FLDxSe39eR4ePp8lV6WC\n\
iiivROIKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigCzp1q17qFta\n\
ocNNKsYPpk4r7G/4R/Q/RvyP+FfMvwf0h9X8dWKBJDHCTKzICdpA+U/nj0z0r6a/snUf7l3+a18/\n\
nFTDucYVppNLvbf5o+hyaUqUJSU+W/42M7xYC3izWQoJJvZsAf75p+m+Hby8IaVfs8X95xyfoK9C\n\
1GxtoNbv5YoEWV7iRmfGSSWJPNMrWvi25PlR6X9qS9nGNNW0Wr9EUNL0q101P3CZkI5kblj/AIVf\n\
ooricnJ3Z505ym+aTuwoo71n3+oxwApERJN6DkL9f8KluxVKlOrLlgrjtUvBbRbUI85vu/7P+1/h\n\
7/Sudp8jtI7O7FnY5JPetHT9JkmIe4Bjj/u9Gb/CuepVjDWTPoaNKng6dm9SLS7FrubLAiFT8x9f\n\
YU74gXy2Xh2SJSBJcEQqB6d/0B/OujjRIo1SNQqLwAK8k8d6yuraxsgbda2uUQjozfxN+gH4VwRk\n\
69S72Rrl8JY3FRk17sdf8vvZm6Zqq29mLO5gR4cEBxkOhPcdq9Fhu7XW9GaxtodzDDxBiMlgd2CT\n\
wM8jPvXlDc5z6muv+H0kxnl8ho1mjjYoZclAeo3Y7da0zHDKKVWO61+ZhmeFp+9Vtqm387mX8RPD\n\
t7q2iT2EMk1rdopLQoykSEnOGbjK9zwMnnnJNfPXirw5eeGLyGz1JoxdPGJGjQ52A9Mmvq6NXuBD\n\
ePdCa5nG198gOxiMjnjAxk4x36dc/OfxiuNPufEzPp91LNKpZLhJWZjG4OMDIAA9hnpXsZLXqc3s\n\
ZbbvRny+YQTpqb3St26/j+f5nBUUUV9KeIFFFFABRRRQAUUUUAFdF4J8TP4V1GW/gtIrm4KbI/N+\n\
6mTycdzjj8TXO16P8GtMtNRv79NU077bZPGEyVGEkHzKckgg8H685rnxUoxpSc1dG+GjKVRKG/3n\n\
s/hnVY/EegWurGRd9wGMyrER5bKAOxye3QdfTt0CtcWl67SRi3+1QsieYD8w7HByc7sZJ9ST2qLR\n\
bWz+1R21/wCYttCgjiWNdkTEfKAzKB69Ce5zWL4y1m9N7JaCd0VflKqcAD0r4Sp+9q+zpqyevXa+\n\
lj6inRnWn7K60X9Wt+XTbzKvgycw+Mbd5mLM7vEXzncSD/XFd7r0ZS/LdpAGB/T+g/OvJ7SZrSeG\n\
eI/PFIJAfcH/AOtXtVwkeraZFPbkHcokjOeuR0/z3rprS9nWUntsfR46msO6NTo42/X9TnASDkEg\n\
juK6DTL4XKBJCBOByP73uP6j/IwGVkYqwIIOCCKQEgggkEHII6iutPqjlxOGjiIWfyZ19V7+0ivr\n\
V4Lhcq3fup9RVCw1QECO6IB7Sdj9fT61rKQwBBBB5BBzWsZa3R89Vo1MNP3tOzPNNU0+XTrpoZRk\n\
dVfHDD1qnXp2o2MGoWxhuFyOqsOqn1Fef6tpk+mzlJVJjJ+SQDhh/j7V6dGuqis9z3MFjVXXLLSX\n\
5lGiikroPQLcOo3UKhUmbYOityBxjof89PQVoQa4C/8ApEICn/nmTx785z+lYtJXFXy/DYj+JBN9\n\
9n96sYzw9Oe6Opi1KzlA/fbCeMOpH8sircRWVgIZI5DjdhHDED1IHTqK4ulBORXk1eGsPL+HNr7n\n\
/kc0sCvsyPqLSgRpdmCMEQp/6CKtVS0P/kC6f/17x/8AoIq7X2EI8kVHtp92h+fVNJv1f5sKKKKo\n\
gK+CP2rf+S363/1ytv8A0Qlfe9fBH7Vv/Jb9b/65W3/ohKAPIqKKKACiiigAooooAKKKKACiiigC\n\
e0tpbydYbdd8rfdUdWPoPU10+k+BNem1y2s7rSLpVZl87IKiNGOMk9uAT/SuSUlSCpII6EV3nhPx\n\
n4gOo6NptpdXK2MJSN7eJifNG4klgTyeSO2MCubEOrFXha1ne/TTc68KqMmlNPmurW1T12sdB4L+\n\
HNhrHiTUUuIr2Kw02Q5YOsiTYIwm8DG48kjsK9htrGJoZLaAfZojuGyL5QueuK898UfEbUPDd9ea\n\
bbBIrOORZbS5hjSQXAGA6n+EgkH5uoxVT4beNpdd8QQwXLTRtCJHVGkD+YGIzljgnbnI68Zr5fMc\n\
Ni8QnWcr04rTVv5vzv62Pbw9WjQqSp2XM3ba34HaHQoYbiGWWQXNzauWgk8sIyDGAuRyQPwz3z1r\n\
vfC2vQLpUVvOrExLtG3qMdiKw7i0VWaRpUWLOSWPSuZm1GC3lujfw/ZDCEIkkkCCUMOq5I47Z9Rj\n\
0z504LGQ5JO56NWlhp0/Z1PW/wDmdb4n1ye7uEisbqayijZd5i5Y54wff2rz3VbjWo/EtiA1tHbz\n\
KFZpZ/nklJJIy3GQpGcZ7nOflrpbO+0z7PDObm3No77FOMhz2xxz9f61R1vS9ujvcaPv8yG6F0zb\n\
TKHT+POTxgAkehJAxmtKDp4dqla19NV+b/4f0MpUaNJL2KVlb/hzSWW0t9Lt/wC0bmzgadgJYmm3\n\
KG3nCgnqex55xk96x/GGlWMGn3eoQ7rtZpFe5mt3XzmcSDcvBB2hSuAuO3rmudl8PXcFv4lvNWmS\n\
7u7SQXFlshaRUO8u+wMR8vQHPOOe1QaX44AOdY0eCw8PrtjLukjvgJkKMc5cDgk8HPNdlPCONR1E\n\
3bt56NW2enkt0Q7q13pr0/N7enk/u7KXWNOPhG1ktla/t5Z1jlMoJZ1LYKHG0E4Yrgenp11ba7Wz\n\
1YPpEsqCyGZkmyMK3Ox+ME9T1zwMccnzXU9bsrLTpzFqJv8AQ7txe2NuSD9llWUsYpOd65BODnqe\n\
+M1p+H/EOl6tNPL9pVIDeyXMqlUUsWO1MknaUVACfu/MRwaU8NHkcuVpa9Lq7023/wAntfQr2cZe\n\
6352vvr+Ktb5eh2V3Y2+sRSXF7IVvERZMwREeaDnKgeq4NTaBI+latBbbJlsbsbY/NyCpwCrEHGM\n\
nOe3PtS6e0t7cW72k1jc3Nxu2hFMSCRFORuDZI6N079uBVK7vEHiK0sVbMdvIy57AktwPzH4+wFZ\n\
wStKD0dr26L0+7f5Lc0wcqs6qpRlePX8f12/yPVtGm32xjJ+aM9/Q8j+o/Cotd0/7XBviA85OnuP\n\
Sqek3G25idzxKoDHtk4P8+PxroK5lNwkpxMa8XTqXR58QQSCMEcYp8E0ltL5kJG7oyk8MPQ/0Pb8\n\
weg17St+bm1X5+roP4vce/8AP+fN16acMRTakrp7o1jJTR0lpdxXS5jb5gAWU8Fc+o/A+3HGanrl\n\
o3eJw8bbXAIDAZ/n/nitO21X+G5XH+2g479R19OmfoK+VxuRVabcsP70e3Vf5/n5HLUoNax2Naio\n\
0nidtqSIzeisD/noakyPUV4U6coO0k16nMFR3FvDcKFmjVwOmRyPoe1SZHqKinuIYNvnypHu6b2C\n\
5/OiEZyklBNvyvf8Bq99DGu/DyHLWshU9kfp+fYfnWHd2dxaH9/EyrnAYjg+nPTPtXYPqFsmMyg5\n\
zjaC3T6VXOrRFCTBcFeATtTGT2yWr28LPHpX9m5Lz0/F2O2jiKy0tc4+qGoWpJMsQ5/iH9a66a0s\n\
bxd8SvaOQSgcAI2MemQOmOvfoax7y1ltJTHOm084PY49P0r1IVbvlmnGXZ/p0fyO6FaNR22ku5zF\n\
dx8G/wDkd4P+uMn8q5C9tjC5deY2OenSuv8Ag3/yO8H/AFxk/lXfgv8AeIeqJxrvhqnoz6Booor7\n\
Y+ECiiigDD8b/wDIr3v/AAD/ANDWvLa9S8b/APIr3v8AwD/0Na8tr884t/3yP+Ffmz3sr/gv1/RG\n\
Xr1sslr5+QHi9e6k9PwJ/U1T8P6s2m3OHJNs5+dfT/aFb0iLIjI5IVwVJA5AIxmuOlRo5XR1Kspw\n\
VJzg+lejw3iFiMNLDVNeXb0f+Tue/h1GrTdKex6ksibFlDAx43bhyCOua57Q5lhuJ/MYLGELMT0G\n\
O/5E1D4XvjLpV3aOTuhjdkP+zg/yP86wPEF0sFp9kklMUl9+74XcRGerYz0JwPoTjpTxdKzlTf8A\n\
XX8iMFhuRVacv6W9/uMC/vX8SeLfNjDeS0oSP1EY7/zNdddRJLeW0lwIktYVCRxif5ptpGcZx6d+\n\
uBWc8Nv4a0ZgskS3ShtjcbpGz0PUgD04/GsXw3o194ovjNcSyraJw9wxyT/sr7/yrhlFVvfT5Yx0\n\
/wCG9TpqUljL1Ye7Thom/wAPn6XfzNfxF4subTVZorZxJGnyhX5Xbjoe5yKq6Z4ruZp0imYLGQI9\n\
gJ2lemMnnp3zXV3XgXR7iJh/pKzEf67ziWz64PBrz7W9AvfDuoI1yhuLLeCsyDAYZ6H0P1pUaWGn\n\
Hkj8RrhsNhq1PkptcyWzVr27dH+Z3ctnaWuo3WocRw2zIY4lxzJjcQQe3zfn9MVSu/GMFxFNbXhC\n\
RS8Hy/mxz71jeKdWibS/JSTbJNMJmjH90jIyOgPTPNcb5qE/e/MUqGBdZKdR7bfI58HlcsRT9pKL\n\
fS/+R6jB4tjMMMVoTIkSBBkAHAGM4raae48QabHFZPHGgJE4c4JHZeh49f59j45bStHKrocEcivV\n\
vCc9vY2PnXU6RNIglCE/MQemBXJjMIqDUoK7vocuYYWFCF46Nbep5x458GzeILlrW4v3s9iKpSNS\n\
UDKc7mG3ksGOMEc896+etcsTp2q3FqUlRY3IXzVKsR2JFfTXivVbm0szJCl3eanfxSLF5K7CpIAU\n\
kjOw7eR0+nFfPOt2Gv3pvb7U47pktNu97h9xQMRtXJ6n5ga+tyetU5eWbXLp954WY0+ZKUV9y003\n\
+W/n+vOUUUV754wUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFW9KtB\n\
fajb2zTJAkjhWlcHagzyxx2FJuyuxpXdke0/ALTP7PsrjWZd6yudkShThgQcnOf6dzntXsn9ut/e\n\
aud8KWUFhottAwt4m25KwJsjLHqwHvx9cVsfZo/9mvzbNV9bxMqkl5fcfZYXD0qdJRkjsdX1K1Gs\n\
36PIUKzup3IcZDH0zVb+0LM/8vMf6j+lZPiAf8VBqn/X1L/6Gaod8d69+pJqcvV/mzop5ZRlTi7v\n\
ZfkjpDqNmB/x8KfYKx/pVeXWIVH7qORz74Uf1rLhsbmY4SF/qw2j9alvYLTSoRLql0AScLFEMs59\n\
B6/l+Nc8q6Tte78hrA4aDs22/wCu3+Y24v7m5+XO1TxsjHX+pqW00m4mwXHkp6sOfy/xrnrvxnNY\n\
jdY6N5EP3RJcZy3+fqarw/EHVJJAi2Vq7McBcMCf/Hqzn7eXwRt80d0aNT2d6Kil/iX/AAT0Oz0+\n\
C1wUXc/99uT/APWq0zBVJYgADJJ7V5ndePtWiLRvYW8Mg7MrE/lkVz+reIdR1QFLy7byj/yzRdq/\n\
iB1/HNc31SrN80v8xUcqq4iV5zjb1udZ418XI6Pp+kyhtwxNOh4x/dU9/c1wA4HsB2pAy9sn6CkJ\n\
5yfwFdtHD8itsj6KmqGX0vZ09X+LfmHQc8nvXR+CmTzp45XkSOYBS0eA3Bz3rmwGkYKoJJ6AV02h\n\
wGK4t415YNuY/wA6zx1VSg0j5/FWqQcZdTq9b0K2i0OS8tZTI5cbgyghiz4XAHQqWyD1968W+J3g\n\
fTNP8Mz6jZQR2155g8wzXCgnaBkKvOWO7JGf06fQNhZvfaPcW25U8zDKWXcOCDyOMiuH8YeF4tQu\n\
ktfEbPcWQUTFIcRq7DjOSeCMngnoevArjyrGezmk5u6ey6rt0/M+WqxUlOhJ3tqr/JHyXRW/4x0Z\n\
9K1e5MVvOli0rLE7xlVJ6lVPfGcVgV+gU5qpFSXU8CpB05OD6BRRRVkBRRRQAUUUUAFe0/Czw5rG\n\
kRWOrNegaZcqXeyJcEkkrllAxxgHJ4IrzrwF4abxTr0dh54gUqWLkjI46jPXBxkdfTmvpXwjp2p3\n\
Gjw6UGhvooJPJkvHOWKZxnk9cAEAdOPTJ8TN8WqcPZppd79tdulz0sDRt++lsv6/rv0Nc2dysED6\n\
tYItkFLnEmNnynI5w3zNtOPcg1wGsztc6rPKwxuPA9BgYr03xV5hhe1V3cRxgAsclsdzXmGqRlbg\n\
SdmH618vl9bnnzy/pH1OWQ5f3kt2Vh3H4ivQ/htrimE6TcsFdMtAT/EOpX6g8/T6V51kHrT0kaKV\n\
ZELI6ncrr1BHevUxFBVVeJ9Neni6H1aq7Po/y/rse53+nxXY3H5Jf74/r61iXGl3UJOE8xfVOf06\n\
1neGvG8MsSW+ssIpRwLgD5H+v90/p9K7GC7trhA0E8Uinujhh+leWqlWg+Vnz9SGJwT5JrT8Pkzl\n\
WgmX70Ui/VCKfa3k1ocRsNufuN0/+t+Fb9/rOnWEZa6vIY8fw7gWP0A5ridU8dT3VzHBpUHlROwX\n\
zXUM7DOMhTwPxzXRTr1Kj0ibw9rXg3Kn7q3b0X4/odlaajBOMMfKk/uueD9DVm4giuImhnQPG3BV\n\
hXHPePZ3L/2p5NzYbgpuIlCyRkkDJ2gKwGR279+h3C9xYKjxSC5smxtbOQB257fyrop4lNr+v6/M\n\
8qeEhUtOg7f1tfv5Mw9Y8MywEy2G6aL/AJ5/xL/jXOspVirAqw4IPavTbS+hugAjbZD/AMs24P4e\n\
tR3+l2d/zcQqX/vrw3516lLF9Jam1PMKlF8mIj/n/wAE81orqrvwk4JNncKR/dlGCPxFZU3h/Uou\n\
tsXHqjA11xrQlsz0IYyhPaS/IyaUdav/ANjajnH2Ob/vmrEHh3UpCCYBGPV2Ap+0guqNJYiklrJf\n\
efRGh/8AIF0//r3j/wDQRV2qukxmLS7ONiCUhRSR7KKtV6d76o/NajvNvzf5sKKKKCAr4I/at/5L\n\
frf/AFytv/RCV9718EftW/8AJb9b/wCuVt/6ISgDyKiiigAooooAKKKKACiiigAooooAKsWV5cWM\n\
/nWkzwy7Su9GIIBGDyPY1XopNJqzGm4u6JojJO8cHmEKzjAY8AnvXovw6tLzQb+S6WyjuLpbn7Bc\n\
RzBgbYE4J+pwQD2PXrXEeHtSg0u/+0z2cV0UVjGJM/JJj5W9Dg4ODXrfw3+JV7qnjC3j1G109IWj\n\
OEjhVS8uByB6lhnjHeuDGqpOMoRjeNu+/l/md+FVOyd/fe3l28tzvvHEdzBoFx5mmyajG37ry0fZ\n\
jPG4t2/DrXh/jy1up5dKt0yvnRs0Nu2/zNufk37ursMEAdFKCus+JXxD8XW2sz2MUv2SweYqpEYU\n\
NyDt34GQAQD9eetee+ONaj1HxXNqGnytjKSeZyMyYG5gOg54GOMAV5eUYGthoxVS19Xdart8vkd+\n\
KxSmpup5K2ztvp32flsdl4Ss9cjW1tv7HuWa2Xz3W9hdQ/zbRgAdAWLZPUivTtX+IWl+Clt7VbH9\n\
2kYx6hiSSuABnBJGe2OnTPiFj8SvEVpp1nbQ6ncLLFIzPPI5fzFOMK4OQwGDj6mneO/FNpqojW0t\n\
bWS5mhje6v1i2O8uMkBeigHI9W6mtK+XPEzUMTTum+jdvX8dF+A3iaPsnyy2S381tZemr267nsnh\n\
3xPD4i1XUr1jHFpcEPmrI4bHOwbS5ONw3D5cn8KwtQ8eeE76wuLaPSrOWxgg8xt8W2SaUSfLEpxj\n\
HzMQcnjPSvKrXx5rUGnQ6cZYZNOjiMZtpIY2R8nOTleucc9eOtaWheDvEF5e2N/p8Edz5yC4MiBT\n\
HGhJXPPGQVIxj09aqeDUf48rL7Ovbpt5fj1N6eN9pyqjdpb6bJ6bX2128uiF8QL/AMJDpDa1b6NY\n\
6Pp5lS13QqR5kvO1Rk4+7gkgdee9bXw/8PXOkzTSXIUTPK1ukTzJEWdHAZQWBCOByAwBOeDwa734\n\
rW1xNb6DFZXSGyt50nvZCImW2kGcOUwuB82OcL0yOarNDbNP9sijM+g6uI7mWKQ4k80so80E5wcb\n\
zleAf15/rE6tD2aVo9Vu0rrS76/1otTojSjTqqr9pLR7X03tt/Xc6LSFghkMb3V/dEyAAXijKDr8\n\
rDgnvnOSdp5zUfiSC1S6fUbVLiGVZldopkxwSSCPxHrWrpmnPqMSedJbiPT1iaAShkdowMA5PQ5H\n\
UAg8HFc3r1zbRI9lYgbWfzZCowoc8sF9s/yFefSlGpV/vdvX5Ldfjc0wTqOuvZ6W37Wvez/4Hc9J\n\
syr2cWDkYIJ/E/0xXSabdfaIQrn98gw2f4h61xnhmYyaPArnL+Wjn1OVGf1H61rxSPFIHiba46Ht\n\
9D6iublurdjtxdDmlKHVM6esXV9GWctNagLKeSvQN/gf8+9aNlex3KgcJL3Qn+XrVmohOVKV0eT7\n\
1N22ZwEiPE5SRSrjqCMGmV3N7YwXibZkyR0YcEVz15oVxESYCJU9OhFelSxUJ6PRm8aqe5jkZGCM\n\
inB2AADMAAFAB7DOB9Bk/nTpYZYSBNG8ZPTcpFR10NKSs9UaaMlSeZD8ksi/RjUX8RPcnJPqafFE\n\
8rbYkZ29FGTWtp+hzTENc5ij9P4j/hUN06SvoiW4x1Kml6fJfS4GViU/M39B71X8aRQ20azpgQWs\n\
iI8LfdcNgMf97kc+3Oe3ZSPDp9qFRQABhEHc/wCe9eeeM76HfaWVy4xLN5sxIyBjIAI9MtnH4dq4\n\
/byqTTW39XLw8XVbk1pZ/wDBH2sk9ioeSMT2sgDMispaQdnUZHHKjg+v0rX0+SC9hkt5Fl8pW2Is\n\
ifNEdpOC3TpnA9iOmBWJMI1u7OG7Zbveoa3RD9xTu+UDq3Q9scAY9bOghrqO/tWhdJlC4iZzlTls\n\
4GOu1VHA/lXHy/Wafs5/J9uzX9d12OdS5/d9X5/0v+AVdVsGtJmikGY2Hytjgj/P+e9aXwkiMHj6\n\
GMkf6mQj6Yq4y/2ppbRyc3MedpyAWI+nY/ln6CpfhaoPi+EnkiJ8H8K0yqpN4iNKr8UZJP8AR/Mu\n\
tUc8NUT3Sdz2yiiivvz44KKKKAOf8fsV8IaiwOCqqR/32teQ2eopL8suFb17Hj/9deufEMhfBmqF\n\
iANi8n/eFeCIyuoZGDKRkEHINfIcRYWFetFy3tv82fT5LTjUoST7/odd1HtXPeII3F95r8rIowfo\n\
ACPr0P4ils7+SA4J3JycGtG4EepWbJGVD5BG7sf/ANRx+PtXhZZKWWYuM6nwPRv1/LU9KKeHnzPY\n\
zvDol+03BhcRjyGDMU3YBwOneoLIxN4luZL0E3sWEZ2JlV8jIKcDH1IwB6Vq6PGltoWoyz7kfzEj\n\
Ix83BXgA9+elZ1jHdS7zaW0Alui3myTs3zISMIu0Fj8vAOAOD1r3M0l7Sq+XtY1qP2imo77aO2ll\n\
e/l09bGeJo/FVwDPaulraMd0oflwSTs6dT69gDXUQ3ksMKW9kkdvAowkcSDAqvplrZ2GnxWdxMlq\n\
qyOxVjmRuccjtwO/bHFbtje6PAcQXMIfH3nOD+ZrOnhrx0i7dL3KqYilRhyU4Nrot1/l917EFva6\n\
nNy88kQ/2mIP5f8A6qsyaXO8bK168gIwUkTKn65J/lWpG6yIGjZWU9CpyKdV+xh2PJnmNVyukl8j\n\
jpNC022lxqOlQSKx4lQt1+mf04rUi8OaDLbjy9NtGjI4YLz+fWtqaJJomjkGUYYIrnrOdtOvngkb\n\
MO7B44H+0P8APSubEUZWvBv72ejh8XVxMHyyakuibs/xOW8aeD4NMtX1HSQywIQZoCSwA/vKev1F\n\
R6N4nto70SiyC3BRY1ZmDAADGAMcZrufFcip4Y1RnICm2cDPqRgD868QhJUIQTnAqKUPrVFqp0O6\n\
NP67h+evq07X76X1/I9ce0OrRQ3Ojw2sKYxcI5xv+bONuMdzz7/QjgfFeiXmqaVLptj9nguZrlPt\n\
EzRBiSNyluOh+YnJ7j1Nd7pN/BpGnRx3EN0WmjDh414Yng4OeozmuB8Z302h+EtRvLF4GmQbQrSS\n\
F9pC5IPVSuchgec4PSsMA6vtFFdH7t/+HPnpJWnH7PTv1v3vtbZPzPnfxLo1xoOrz2N1HKhRjt81\n\
NjMuSASO3TpWVWjqOsalq5VL+7mufnLqHbOGbrj0qndW8trcSQXMbxTRsVdHGCp9CK/QKfMopT3P\n\
mppNtx2IqKKK0ICiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACvVvg5pESrNqrX\n\
qeYd1s9qEBbYwxuyTwevbnFcL4W0O+1e6Z7K1W4S3HmSLISqlR15HPAyePSvp/wzoq6hKJbW1+xx\n\
OqmdCc7OAdpI4ZiQc+xHTmvHzbGxoU3E9PAYdP8AfVNIr+v+B8yubiJdqmTOAFBPPA96k85f+eo/\n\
76ruJfDlnLAYyzkkYycY/KsP/hBZf+e/6j/CvkIY3Dy+J2Pp6GY4SpHSVrHcatbwvqt4XhjY+c/J\n\
UH+I1BHGkY/doqj2GK4rxF47urHxRq9q9pBMkV5MincUOA5HPUVh3/j7UblDHapbWuf4g29v14/S\n\
uitharqy06v82dOHyjFVacbWtZa38l/Wx2/ibxHbaHbncRLdsP3cIPJ9z6CvKZtRuL7Woru9kLy+\n\
YpJH8IznAHYYqnNO88zyzO0srklnckkn3Nb/AIf0pCIbu5USs+XjjbIUgdSWA68cD6VvCiqEbvdn\n\
o14YbLcO435pS0b/AEX9evY6Ce0+z3SLsS/S9i3MuQFjkJyGK9cDtnqDjtzVFsItMleOwSK7KBfP\n\
jbAJLHkY6AgY6DjnkGrNxK0l1LcLCsLibyzDIjOirsGWHA46HjPJ7c1Ut72K2v8AULWVXjY/6RG6\n\
qVRyCMllweOPvHHf0zXLFWjqve3/AKS/4G2p8vBSmrp/8HXbt27jtd02G+0q3WzmR7uMkiLBBHGd\n\
i56gAHpXFeROH2GJtw9q9C0q8tU1OE3dwYbNszDYuBI/uR0HzHgehznJroD4atLqZZjtaFvmDjHI\n\
+tQ8bLC6O7T/AKsdGHx31VOnV0W6PNLHRgbX7Tembyi+wLEMnoST+QrS/sDSS0SpePL5rbVZRgDn\n\
qc/n9AfStO5uri8kgs7VFa3WYgRLhI+DhSxPfHzbTnp2rivDmr28upapapqJnNqfOlaTJJG0ZKnk\n\
JgkjnrjrXZCM6ybnLVb26J7XIqY2rK8lLl7I7OPwfNDIVhAz64ya2NF0OCERyNPE5m4TEg+fHUCq\n\
Enii+Oi20OniKNki2vOxDqQAAMMcAHr97jr0rzjRfEIbxNd2p1KHCGAxIgAwxcEMGx87dMjjk4A9\n\
OOGDr14Sc5Wt8++/bp+JnVxWIatKy/U+hrWJbaM5I3EYAHb2rl/HnlmzhYEefE25e/Jxx+leX+O/\n\
Gmoabq+n297eQxi5ZWZdxBWHnn5SAGyO46juKg1fxULLxXYafcXEQicSNK7yllG0HGG5A6c46d/S\n\
lhcnqqUa17310/zOShGEK6rVp3ceiNDxJ4Zg1/TRbTrJKqSGURxnYSxyAS3PAHYAfzNeBeJfC2o6\n\
BKBdxZjYZEi8qeSPy469K9jtvihYwZ8wQxbrwWxySWSMfekOD057dce/EcnxR8J3emtBq+n3N2sm\n\
X8oAYVvmAOc5HAB/Gvdw1bHYaSiqTlEWNWFrpyUrM8Coru9Ti8B3yyy2l3qWmzYJWPyRMhPp1BH1\n\
/SuP1OC1t7pksbsXcPaTyymfwNfSRqqT5bP7v1PEqUHBXumvJr8typRRVzS7e0uLkLf3gtIecv5b\n\
OenoK0lJRV2Zxi5OyKddF4X8Kajr08Zht5Bab1Dy4wAMjOM9TjtW9og+H+mz201/PqWqkFTInk+S\n\
g9QBkk4+oz7V3/8AwtTwvDAq6XZT2qQplIyq4YgqMcHrgn8q8vG4yvCKWHpNt9drfqduHw1PnXtp\n\
K33/AJGzoWgRaFpdvbxRqRbszq8kSiQhs8NjocEZIPIUccV654Rjgg0eE2xypO5yTklj1JPr/hXh\n\
d58TdPk+0vGYZPKuo4lcEr5kbdWA65HP+eunpfjAx+K00vTbyJVuIFlBjm2qrZYsCSAMBV6+p6+n\n\
zOMwOJxVNuej3/r7z2MS8NVoqlCVmmtd+/8Ake0arpwunLpn2ZecexFcfrnhlTLHGXRZrgnZGcjc\n\
Rj8uo/OuM0DxrcxeMbzTdPu7eQqoKRNISJZOS+STycjORzgH1pPG3inZK1xNd21veyTRxBiofYCF\n\
O3Zk8c5zx07ng8tHLKtGqoOWlr6LX7v18u+xQr1qa0krL/g/5dy1ceF72GYoVIwcYPWtC38Ow2ln\n\
I95ta6baI43Ut35JA6cZ75rc8L67tSC31GCMWyAqJVLMyt97k+nJHqMc1l+IdYSa+utQjlgjhiYJ\n\
uZCUABwucYO44J5PGBnArWPtnVdKeiXX52X/AAV+J2TxtaouS1vPp8n/AF+JhXuiuE+0WhBQqSYS\n\
/wC8Qj7wI9sfyrHGRnaQD9On5V1HhvUmu7az1KRkuFaV1RriRA21uxx0454HA9cYM2q+Gxcot7Yj\n\
ZHKW+TrjBI710/WfZu1XVbX8+x6ODzWrSn7GcvT+v+GOUtoZrmcRQqHlfhQo5rpvC2iCXV7Uvdw+\n\
aWJVQCQSBkjOMHg9K0PCPh64i1COYoVCHJdv5Vd1uK1sdRVLCWGSAt5rgsGC9dwb25Hp0PNc9TFx\n\
quVKnppuv1/QnH5nXrz9jCV9P6uNuYbaa91aylENu77xE/UrjGflB7jgcfwHuaz9EbWdCQmUJLpk\n\
i7kikJxKDjhO6kg9+K0bSCOTBLK4kOBCzgg4HLZA5Ay31IHToKrQSy2uq/2fbCRkiws27DR5Y5Xa\n\
ecnnn2+gpW9lHSScXb+vLv8A8E82lXqUb0k9Ha9/VL+vnZ3NZ1jlt4rq1YvaTDdG3cf7J9xVq01O\n\
aHCyfvU9z8w/H/Guf+HF0Vlu9Fv0ZQ482NHGCD3H5YP4V0V9pc1uzNGDJF6jqPqK6o1VGXJJ+j7o\n\
9mtGm5eyqardPun+vT5GvbXkFzgRPl/7h4b8u/4ZqxXHkVcg1G5hwN/mKO0nP69f1rpU31POrZV1\n\
pP5P/M6Sk7Vkx6yvAlgYHuVbP6H/ABqY6xa4+7Pn/cX/AOKp86OJ4DEJ25T2Cz/49IP+ua/yqWq+\n\
nOJNPtXAwGiU/mBVivqofCj5aSs2mFFFFUSFfBH7Vv8AyW/W/wDrlbf+iEr73r4I/at/5Lfrf/XK\n\
2/8ARCUAeRUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAV6P8Gdde18WafYNZ2E0EzMhLwoJeV42uec\n\
gqCB9R3rzirFhdS2N7BdW7bZoXDofQg5rDEUvbU3Dr09eh0YWt7GrGT26+nU1PF2qXeo6vcC61G4\n\
v40kPlvKTx24B6dAPwFYdPnkM00kjfedix5zyaZWlOHJFRM6s+ebkFFFFWZk1pFJPcIkMRmcniMD\n\
Jb2r2LwT4tuLrUrTTLNLu1srS3ijeyt+VYry7sTznce3X19cX4NTJea1b6WLFA0kU++/RczxLsOA\n\
hPygZPPGTnGa9Z8BN4f8Lw2Ngqxz6jdOUhuooc7jtHVucHgjrnuQBXg5riHGMm6d3HVa/e/uXqe7\n\
go+xp88JXvurf0/W2m3UpeP/AAVdahd6bNbfZJDJIrXbYMbEbQQpboVwB15PpgVc8M3mpSyTWr28\n\
cVtCV3DesymYINwBHUZCHpzmtHxVFPrbRyrcrHDGCJo3LL5qD5hhl5BHP4GuG8GXGn6PpQa1vpL6\n\
COWRDPcQgxxlyq8LnJxwTk9AK8aNZ43DptLm7dL3v8vK/wDmel79+Sau9309Pl6fmep+HY9NbRGt\n\
LVxHez5aRXUpkKTjkjrjPv19MDz3XLQ2uouu9JF7OhyDjjrSWmura64uiXAllvpghQbSsZyD8xJB\n\
Ysd3GeMEjPFaXieGKGz0/wAlZFUhmZXXbsZvmKgdMDIAxxinQpexrKq5N8z/AM9b9ux04GcqWI9m\n\
9nf+r+R0nhq626ZZyoDgJsZc9QDg/wAs/lXTIyugdDuU9DXA+D7sPbyWjE74zvX/AHT1/X+ddNbz\n\
yQE+WRg9VPINY1k6VWUX3PXr0uZ3W5s/05FXINSniwGxKo7NwfzrITUIiPnSRT/s4Yf0p5vrcAEM\n\
5z2CdKjmi9zinQctJROhj1WAg+YskePbdn8qmXULRh/r1X/fBX+dcVf6/aWkiRiKaaV/uxLgOfwG\n\
azE8T3rNkaUvk5wGMhJJxn2HamqPMrxTOeWCgvifL6tL8z0k3tmRj7RDg/7QqJpdNZw7NbM46Hgm\n\
vOYvGkUk4i+wzFycbVwD+rGr0HivTHYJP59s56BwCv8A30DjtVexnHo/69BvLrO19fVHcnUbRflV\n\
2PfAQ4/lVabVmbiCLb7yc/oP8awhf25AI80qeQQo5/WszWtcFnZvJgRgghFz8zn0z2H0rNJN2Suy\n\
6eAV7W+8l13XZUuHtrLNxf4O+Qn5IMDPJ7H2H8zXNjQWvdSiOpXUolldUA8khR2xz0GeOnvVfwzq\n\
Fvc3ElvqKOWmLHzFfHJ6ZHTAIFdTeaPeDTBPdKptkJ2jf8wjJ5L44JIx0I5JP0qrU9i3TvZvS/8A\n\
kZ4nEVMPP2UfdT0W13/XRaW9SbWLRtIu9GeGbcIc/IvBbB9e+d2MfTHPByUuZbLW2vLC4lv5btPN\n\
8jowAycZ6gjB7YIPfNWIPMuVV4lkWeIMQ2TLx6evGeOvTueKr3SGzZGhcxPECzlWw23cAU+XG3gg\n\
cZBzxjjEUabUOa6bV1f8dfvT7+pyU3Up3lf3uunn+vrqatrqrzaqzagjW04AwAwLHgEg4UA5DLwe\n\
hxXReBYRF48BQqYpIndGBzuBAOR7ensK5LT/ALJ/acyTxtbqkO63jmUKzEqfmY5O5sheh/rjt/A0\n\
P/FRafOFyfJeNm74A+UfTr+lbUbfWaFba7Uf1X4ru9zPFNxpSk/tRfpboep0UUV92fKBRRRQByfx\n\
W/5J9rP/AFzX/wBDWvmOGeWE5ikZen6V9O/FX/kn2s/9cl/9DWvl2vns3/ix9P1PruH4qWHlddf0\n\
RsWesdFuh7bx/Wtq2uOElhfI4YEVxtTWtzLauWhIGeoPQ148qakrHtSp9j0S0u0uNqzAeYHVsE4S\n\
Qr93fgc8ZH/6lAdqGoX8Fs1taWgs7RABuhBIxwB835e9c7ZXSXUQeM8jqO4NbtjqAP7q4xsYbSe3\n\
4+3+enTCnXngnzRjzxXR7r0/yZySprSUVddv6/W5hHOTnOe+aSutlsraYgyQRtg54G3P1xjNRNpV\n\
mVK+SRkj5lcgjp0zkdvTufavSp8U4Vpc8ZL7n+paxkbao5+0vLi0fdbTPGf9k8H6jvXT6X4pVyI9\n\
RQIf+eqDj8RVGXRIGYeVLLGO+4B//iao3GjXCSYgKzIRnOQpH1BP8s10xzTLsXpz2fnp+en4kVPq\n\
+I0no/u/E9CjkSWNXjZXRhkMpyDXP+Iott2sgHDryfccfyxXPaTqt1pU5X5jFuw8Lcc9/oa6fUZY\n\
tS0uO7tTuCHkd1z1BHr0qcRQdLXddzmw9CWExEW3eL0ucp8QdUY+G7GwjwZLhvnx2VOn5nB/CsHS\n\
PDk32iH7bJDApG5Q7jLD6CtycR3HiKSN4YZI7WARFnj3HzOWwPxJHpxVbWtaj0hmSymilv3dvOmB\n\
zt6cAcAHr+fvXlOUkvY0lvr9/wCVj0516rSwlCPd973/ACsjTuL+KaK2W1iaSKycrHdK3LEYyQvU\n\
AHHPTjqO/O+NfDFv4qtEtptRRYV/epMoxJLk4CkD3bJ4JPB4wAXWfjK6Vo2uYbeZ1BVZXXcQp6iu\n\
jkhs54EubQ28FviNyG6K4Ab5BjPoe36nOUOfCvVcr6PfX+v60PIr4edF8tVb3Xf1+f8AwVY8kh+F\n\
2lf8JCXQXqWEbBgk4wrkODsBHOCnc4IPrzjF+K3g66k1nUNV0uxddPwJTK0inkhcoAMEY55PJAJN\n\
fRcel6C1hd3CylYAmTI7k+VgYLDPfp1z7V5P4+sLnXNKhsrZ0lWeQlJUORCgwNz7eSPvgDHUZOc5\n\
Hfgc0q1q6k3otHf5fj/Wuhw1KFGcJQjGzv2t006v/gX7HzuRg4PWkru/GPgOTw7oVheS3CGeXcro\n\
Mks+7gD/AICQSenI61wzKyMVYEMOoNfW0a0K0eaDujwqtGVJ2kNooorUyCiiigAooooAKKKKACii\n\
igAooooAKKKKACiiigAra8J+H7zxFqsdraQySIGBmaMZKJkZP4Dn8Kb4d8PX+uyv9jt5ZIYcGZ41\n\
3FV9h3OM8V69ovw4vND1yTVtD1CMRwqojhkDfOCNr7zxgdSDn0rgxmNhRi48yUnt6nZhsLOq1K2n\n\
3f8AAt8zc+HXgzXfCl21g91aTWl8ZPLQEk9upHQELk4/uj2r2bQtOXRrI27yecxbeQFCheAMfpXP\n\
6Zpo0o2mq39wnnLHu8nyiCpIwRnPT8PQdhTbjxKJJTjzApP8Ir4PMMRVxb5U0/5rK2q0/A9inhnX\n\
jywXufnqdvG8Uvy7drVJ5L/3zXI2GqmTDxy+Yo6qeord/teP+9+leLOjKLsjnrZc4v3UeZ+P9Fmj\n\
8Ta3dQSJMhu5ZHVTkplz/U4rj8gdsH6V7VqGk2ct/r8iTfaLl7mYMmceWC7EgD14HPsPSuCu/Dxk\n\
lO0K3vnB/GvrP7SUKs6beze/qz6HL8bz0+WfSy/BHI8uwVRkngCvSPCOnQ3tglrfb/KWRZU2nHzD\n\
jP0qhZeHLOwmQ6lN5LMu8DaW4zjqK6rQdS0ZN4W4VJFbavm4UNjpj/DrXFjcRUqw5qabXexjmGNp\n\
zg4Ru35HOa1BDYa/LawbY1dNi+a+Oq8gE9VHHXoB9K8D+KGryWnjGE2WpyzG0Xy2UMdyYbkElRnO\n\
OnNe1+LYLW7utSmgknXy93l3EB+dS2N23+9k8YPYV8ua5BNbatdRXBlMiyEZlzuIzwTnvXv5NRjN\n\
80nd2V79dP8AgniY2rVp0oxldOy8vO/9efketaF8Sm1y7tNPayS0nebiSKXygqAdz36Nx6kY9K9R\n\
t/F82h6G858uWB1aaIkM4Uei+o5GPfp1r5T0WPzNUtw0qQorhnkfoijqffA7V3niT4jmeVoNLRxp\n\
/kG38p8c9P3gOOGJB6AVvjsrjVlGFOKcd3/Xn/w5lQxUJU266T7fhr8j0S9vpNa0aG9sLnyZ2Dzq\n\
rjiZ8BtoU4DcFifTH5+DS3upw63LLcyzRXryfvfMYqSenzfgaq/2jdfZo4FmcRxszLg8gkYPP0qt\n\
I7yMWkZmY9ycmvQwmB+r8ydmn5HPisbKu1Lqj1HWfiPHDcWcOlBnsbeBreSDGIpjswHAPIGc8fqa\n\
4CLVWstc/tLSla3dHLwhjuMZ7c98dqy6K6KOEpUU1Bb7+fqc9TETqO8mXbzVLy88r7TO7iJmaPJ+\n\
4WOTj8aqvLJIcu7N1PJ9etMordRS2Ri5N7sKKKKYgooooAKKKKACiiigAp6yOmdrsMjHB7elMooC\n\
9i/bateW13LdRzH7TKpVpWGWIIweT396l1fWJ9WktHuyfMhiWEuGJLKvQ8nqBWXRUezjfmtqX7SV\n\
rX0PVNB+IVrZHSLSJpLeyg3m7Z03tLxwcZ+8cev4isH4ga7NLqc8OmXUg0m4RSqqw2yrgdQO4xgg\n\
+lcTS5rmhgKNOp7SK1/p/edEsZVlBwb0PbfhHe6hf6HFbxrDBbWjlWcDmUHnp6gAjJ9R3Ar23w74\n\
t0K5CacTHDJEMBQ2VPvkdM89evvXyRpPjLVdPa1RZgbaCVZRCqhVYjOMgDB6nqD1re8LeM47SXU7\n\
7UglxfSlfIQrtydwODjjHfr1Hua8XMMnliXKUtt1bv8AqdtPFU50405N6dfwPePHOsQxLqdyJZfs\n\
UOxl2fMq4wGZQD2G48jtwRXGaz8QvD0NpctZXcc08duslqoDAhwBgDjGQR37Z9cVg/FHVW/4RqDU\n\
NLuD5d6xt5HhlV14HzoeMjoOR156ivFq0y7Lo1KKc21Z7emmv9foPEYtUJclHVd/u/yPov4eeKL7\n\
xTFfahf2wSSM7EKYWMRkgqmSem4EcDvz0r0Gx0e8ubI3SPCLXGChflwuPlOQc5K9zxgdK8C+C+tX\n\
cN/LYOl7c2YRiixH5YCeSx9BkCvfdES9k0HUW+ZFYjEYGFD4+Yjv6cH1rzM2pPDSl7O0Vp9zf9fi\n\
dVCs61KKvrdL03OR1TUDb+II7qywk1uFB5LDdzkZOSRzg+uK9S8P65a6zah4HAnUfvYSfmQ/1HvX\n\
j1/ayxTu2wlScnjp9arwTPBIskUjRuv3XU7SPxqJUI1qScXqj6+jhKWKpRouVnHZ/o/zPd7iytpz\n\
mWJS394cH8xVGfSbKNS7yvEg6kuAB+JFeXr4n1tU2jUJiPUgE/mRWbe391fHN3dTTn/bcnH0rKlh\n\
qrdlIayetRV6lW0fK7/M9DutU8PW8hjW9uJ3BxthXd+uMfrVa38TeG2cKy3uT0LocfoaxfDRnudE\n\
uYLWCSSZHVV8rAOw53Z454yPxrREWltqLXf2GZJY1OcHpKP7ynB69hk5+oqZVIxbi23bz/4B5k8V\n\
GnKUJpu21n917Lr/AFc+i9KZG0uzaL/VmFCvGONoxVqqmkAjSrINncIEzkY/hHardfeU/hXovyPg\n\
Z6yfqwoooqyQr4I/at/5Lfrf/XK2/wDRCV9718EftW/8lv1v/rlbf+iEoA8iooooAKKKKACiiigA\n\
ooooAKKKKACiiigAooooAKKKtadY3Go3SW1nH5s7nCIDyxzjA9TSbUVdlRi5tRirtlWir17pOoWD\n\
hL6zntmLlMSxleRjI5+o/OtXTLVdH1z7FrOlC5nLeW0UkpVVyOuV78g56VlKtFRvHXro1qawoSlK\n\
0tF3aZvfDjxI2l6brETTItzHbPJYjy1YrIQA4HHRlznnt61qfD/xDH9vhFpEkupFmnIl+4JGJ4iQ\n\
DC43ck++CB0ta74T0LSZEt47adpL0pLE8zCNIFOVIV8/veTnAA+71rovCPw/TwzqgvVld7lB8kjH\n\
5R8xDBcYOcd/rXiYmphrTnJNOXT0X/B18z3KUa6UKW6V09/6/wCAd1YTj+yoUuGhuZHBLtGflOT/\n\
AA+3pWdqC6bpsF7dNBbiJ3QTSMq5jDEtkDsTjGePWtDRNK+3XPkW+IYd5ULGMEnqST6c11P/AAgu\n\
mtKdzyuz48zKoQ4HYgqc8cc+tfOOvQw0/fbXXT/gHbjZ06EYxqS9/wCZyVj4c/tNbm6ggt3EYKrN\n\
dyMJWyc7schc8HGO/bJxm+N7lZ7pUiVFhgPlqEG1enOB2r0HULeDSbKKwsV2xjgtgZbHrivNtVgZ\n\
5biNvv7yQfeijinWqX+ytvyN8vUpT9vUeuy9DHtLiS2njmhOJEORXX2HiK1nRRcnyJehBBKn6H/G\n\
uLIKEgjBHUUcV7fs6eKilPSSPoE01Znof9p2H/P7bH6Sgn8qyNT8SRKhTTwXkP8Ay0ZcKPw7muUp\n\
DShl1Kn703cdorVGhpl88WrJcSgTM5IcSDcGB9a7ptOW2lluvLljsHwYWMvDMFBCnOep45GOBXB6\n\
LbNdX8QUE/MBx616LqdzPJAmnwj/AEWJykoVdxd12t2+6Bg49cE9AM+fiKkpYhKmvX0+XXoeHmST\n\
qxcdG9/T+tvX7qkEeGtnW3g84syvdDDtlgcDacn17k8cn1o/2dHBp4M8UN3bxKVFy8mSjZUEHA/L\n\
juD0yatWmAXjuJ1BRtoRSyb3V+h5A5A+XJx0z1qGDT2sonaR7lbe4R5CA43xsTg5Tv8Aec45PzdM\n\
jNTGcY6PT7733Xq/L5LQ4VRjGLlzNNbf1fs+mn64ep6Nqel7GtpJPIlQSL5EpAPygtgA8gE9fSsC\n\
aSSSTdM7u+MEuST+ZruZWX7TGLPzp5Fby4kAHHrgEZXGW4z169K1dX8LK17KYQQpbPy4H6dqt4/6\n\
tbms27621PRw2ZTS9nWfT7/69ThfDdpLPqURCnqMCvQNRu5rmI2cRUWFsCLmZm6tt5AXjOMZ/oTi\n\
o47VPDz26xxg3lweJJULIijqT06DnGRWPc+JbfS9TtrfUrhTd61u+zER4XIPyEjpnJwOeoyTzkc0\n\
U8VU9ry3XTXXzf8Ak2cWLxH1iacdl+fkWTdCzhaOOWZTkllCg7zg4GCoPcgj2/APukmug0bQi4RA\n\
ZWKv8ojAPHLMP4hx+nStbQY7e0vLltSiZJRH8qtGAoUHBGQMZ6Dqf51g+IrjTpdRaTTJYbVpYwjM\n\
hOc8jG0c46f/AKwKca0pVHRSa0Xp+nd38znc3N2UW+7Wt38vIu+GoTfRG/jBgsoAzW0ZcuflyBnd\n\
nHPYepPGOfQfAX/IRsz/AHoi35qDXG6dbNZaDMxj8uW5lBlTbtAPLdOxwFzXWfDuTfqUAP3lDqcD\n\
A6cfXgj8c1u6b9pQcdlUj+q/P7wx8UqcuRWS/wAv8z06iiivuj5UKKKKAOT+Kv8AyT7Wf+ua/wDo\n\
a18vV9Q/FX/kn2s/9c1/9DWvl6vns3/ix9P1Pr+Hv93l6/ogoooryj3yW2ne2lEkZ57j1rprO5W6\n\
gEiZHYg9q5Srml3X2a4G4ny24PXj3xUyjcynG3vI7nTb/ZiKY/J2PpW1XJA9CDWzpV7vxDIMEfdI\n\
6fSvBx2Dt+9pr1OGvR+1E1KKKK8o5CG7t47qIJMu4Lnae6/T/DpWHaXM2i37Kw3xuuHTOA6nj/Gu\n\
iqvf232u2MWXyDuVVIG58EAHP1r28ozR4aXsarvTlv5ea/U1pVFH3ZfCype6VFzeRTXrxzfPHKkw\n\
UKSc8jb1ye+c/oKNnoOhNLu1C1llkZtxlaU8k+oGP0rU8G3/AM76fMQyMC0eenuPx6/nWze6PFLl\n\
rciJ/T+E/wCH+eK+hr4X2UnFHTTxiw03Sn7r/mWl152X39LmbJ4N0C5hBjtBECMh4pGB/nXnviyw\n\
u9E1CK0luZJYAmbdycfL6Y7EV6LYzy6bdeTchljbseg9x/n+Vc38X8eXpDgDO6Tn/vmuKlzwrKnN\n\
3T7ndhPaVcRGlUlzKSdm9el9/wAGY3hjWvLZ7K/QzW02P4iCCCCOn0FejR6dpetwwzC3RPL+b90N\n\
vbHP9PSvJNDtJbi9Tyo2bacnA6CvVND0u5i0aZDO1vI53ZHTHof/AKxrhzCMadS8JcrPJzWnCCdS\n\
DtL+kcjq2jw/2xAl04mkspTLbs7AKrEY6fgMjnvivNfGfwvSaFb22vQt1OzyE3BxuBYFSzdAMHHQ\n\
ckV3us6ja6TpUt/qDSsgLbxDEXaMA43HnryOen4V84eJvEmoeIL0z3sxJAKjaNuRnjI6ZxgfgK+h\n\
yqhiZSU4ytFL7zysfVoxilON2/k35/f1+4q63o95ot0Le+RA5G5THIrqw9QVJBrOpSSeprV8PaJc\n\
a9PNa2DI16sZkjgY4MuOSFPTIGTg9ccV9LzckL1H8/6ueFyqc7U1/X4GTRUk8EtvK0c8bxyKSrK4\n\
wQR1FR1oZhRRRQAUUUUAFFFFABRRRQAUUVs+HvDepa/dyW+nwF5Y1DuvfaSACB36ipnOMFzSdkVG\n\
Epu0UY4GTgV2HgbwZNrur2seoGS0spEeXzSmdypncB754+pqh4j0O/8AC/iB7ZVmWWABhKFPJ2gk\n\
j6Z/CvoHwZLeavomkyS+VPcXMG9GQKDJ94vu4HO4sfxrzcfjXRoqcNn17HoYLCxnUtPp32/4P5Hn\n\
ngTwhrXhzxKt86v9kLSWwEbEGTcu0fXBIyMZ9q9s/sudI1vJpYgZUUhUlBQKDnoQPQYPPfIqoki/\n\
bbaK9mWACYMwVAWVVBH4MSCMjoN3NYni3VHe/lt4iVjjPlhR0UDgAV8ziMTVxVWLslLr6f8ABPaw\n\
uFUm6NJ2ju33NLxV4jjuLkpG/mheCRwCa506rKTwqYrKzk+tHT2q6eChCNke/Sw0acFBdDo9M1ny\n\
7hGYbG/Q+1dZ/a9v/db8q8zRs8HrVj7RN/z1b865q2CjJ9jOph1Jnf6zrNrF411aWwaGVrS+l8wI\n\
mOQzhkJ9cljnGM4J9T3Qt7V9suzDMAcD3rxU6qdQ8d+KtPNvDBHb63dpvUqvnMZmwMfez6npjitf\n\
XNT1MadJbW943nKhKQ5wSdpxlcjI/wA+4rNMC6uI5VKzu/ubPm40XUoqrTly6L56fLW5J46klv7q\n\
9t3lcLzbq8bcRRcMxA4+bjggnJ9BXm3h3xxYvPBpd1E73v2pLcFpMIQG+/k9OigdTjPbiswePrY6\n\
Nd2Wqp9oliCxGL7qOQ2CwPJJ6nB4xgV5nc3aRao11phliAcvGZMFlPrXuYPLf3bpVFaysmvz/r9T\n\
nrYuNFRVJ6L7/wCv87Hreu+Nm0bxLeKt4sllJbSJEsR3qsgyBkA+vGP/ANdef+KfF8niF2kuNO09\n\
ZnA3zrFtcttwTwccnJ/KuXZixJYkk9zSV6tDAUqNpJa2tc8+tjKtXdhRRRXacgUUUUAFFFFABRRR\n\
QAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFAFu31G5gtZrZJSbaYYeJuVPoceo9ajs4F\n\
uZxG00UIP8chwKgoqeXe2hXNtfU9u+HWiaVpUETHWYZru7IBjt5SAxTLbDwD0Kn04r2bwl4m0VNP\n\
nsHaOOaAlpQoJ3sec8fxe30r450vVLvS7qO4s5Sksedp64yMHFeg/DzxbZ2VvdQXZme8nikd5SQG\n\
dhyqDnknn5uCOgzxXzmZ5TOvGUpSctb9uv5JHq0MVTnCNGSsl23+893vtWhktSqQ29pLIQfMdmIx\n\
129AckDt/Ouf1fSVnsl1LTlYxkL5nA2sSPvL7HGfxrynw94+vtU1ew0++mWLT8t5zNktIM7uoGQT\n\
gDjr+tfQHhCzg1C1u2Dstr5QWONmGNuPlOAfQcH3PTnPm4qg8vje1uvX0/pdDvw2MVN+1g29de1j\n\
zEqobLIAw9quWFjc38ojtYmYnuB0rtZvDJW5KsCRnpsyfzrWvtLOm6NHcW0rxbPldFbG7JHIxznt\n\
XPLNOa0YvVnuYjMuWK5dW9FqReC7CPTZdr3MSy7N5RWy2BWfqGpNe6qlwywI00b+XvcAAIM+uGIy\n\
c5+oHy1kXfiHSCJbWa5s7e4ijL3ALZ5jVRuAPXkkAZyfUYrxj4p+LLbV9R01/D+pXJtreHGz5k8t\n\
yMEj6jA61vgculWrubW/VrT/AIP/AAPQ8KviVB+1qP3treWn/D/LU/QPRyzaTZF87jAhOfXaKt1k\n\
+EXaTwporuxZmsoGLHqSY15rWr7aCtFJnzkneTYUUUVRIV8EftW/8lv1v/rlbf8AohK+96+CP2rf\n\
+S363/1ytv8A0QlAHkVFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABUlvNJbzxzQOUljYOjDqC\n\
DkGo6KGr6MabTuj1bwv8SZgNMsdRsrfVrueXbNd3abpk3OMBW64wOnqa9HstX8HaVrmpjVYM6gt0\n\
WnmmywEm0ndtPOBtI4B5/Cvm/R9QfS9QhvYY4pJoTujEgyAw6HHtTC89/dbpJDuduXZuFye57CvM\n\
rZdCalBe7FrdNp3v0tsenHHOULT96X6JW38z6sv7XTtc1SDUpl85DEpi83lAvDKwRhhTwOeKu38P\n\
lxmZAPIRM/LzgAfrWDYyS2Xw2sXaKY6uALeKIKsr4EhUMQvVdo6/rXGeBfEeoWtvqFtrF7BcCBmi\n\
ihhZXlyhAYhSfmAXJ6c4znivlKWErqLbekXZJ31Sdrr+u57EMTCmk6cLNrt1/DqekaHqpsZRdQ7Z\n\
bUnzdwYDGeuc/wCRXpuj3kN/bJc25PlyDIDDBHqCK+ZvD3iPTrGCPS4b4W5SSWeOZwHEhP3CN2cb\n\
g2cYyGH5ezfC/VLf7I2nLOZp4wJNxILMvC5Y/wB7Iz75yK582wLUHUtqvxXmc+YSWIiq1rOO/wDX\n\
9P5GvrNu0y7kBLITkeorlNT05br50ISYcZPQ/WvR7q0Lt5kPO7qKqLpplfLwoPUsBXkUsRyK6Z0Y\n\
fGRjFHkV7o07ZLQtuH8S81kS2FxG33c/pXrHilZbHUdPXT5mUEOXhXaA+0ZHBHOScYyPr65Wk6hb\n\
X91La65FHZzkeZE52hWQjgnBIAPBH1x1HPtUa9Z0lVSuvx08v8jrpZrdX5fd/wCH6b9Dzn7JP/c/\n\
WporFicysAPQda76Ky0a/wBVksoA4IOEuAR5b8dBg8HrjjkDI61ag8MxK7tbCKfYcE7920+4qquO\n\
lHSaa0v950LNKc9L2f3GP4R08x3cMxTaAf3Y/rXU3XhVmtk+zXssgMe3ZMco3pwMAfjnrVjTdNaJ\n\
9zDdJ0AA4FdEF8uCOM/eFeRVxtSM+aD3PGzHE2kqkXqvxPL7O8ltbhmuIm+z2syqzqwX5yxUryRn\n\
1/nwchbCBxpluzW0PkEyCOMuuWPynJJOD8wOPbH4xSxw3l7dGVI3i+0y7ZZR/qi6tgpx79M5HtXK\n\
fE+58V21jCmj2Q8nBnmu2Chh85wF5wFIC9skgHGTXuQpKs/ZNpN2f9X2/U7pyUVzLfta+nktNde+\n\
3kdrpl1JpWopcTR/OY2LxEjJUDcxBJHQc+vt1x6HZXVtfQJPCFlU9GA6ex9D9a8mGoaraaNbC9ij\n\
SRrdFnTCkpKikMno2XKDap49jir1hNNDbW8lhI8E8kO+eDzVJjIAVsgtkc5OPfr1rjxeCVZKV7S/\n\
ToYYnCzxDVRvle1/81/VmdT4zuzcSW+m2yq925M2N2AgUd/z7AnisAQWRtprnUYID5BZbea4QHyp\n\
OSWRj90FgOeMk9elUleTzHmuW81jyR645wAfpVqFg+1WjWSGANiIcZEhQhmHOBkEjj064NaYel7C\n\
0Y9L3t6f120Te5Twyw8FSvdLX73rv32RJeLKPDl4iQPHOlwY3kLbvNUcjHovPT6+tcVoFwltrUEt\n\
0PlVjuJ7ZHWvT/CgtJ4NSt3YmLz96Bz8wBReuTk/Wue1GNUuL9LS2tXt1JJljzu2jBxnoeeffHGe\n\
lPDVeWtOko7/AJO23+Rrgsa6ClBw977t/wCv6R2y232vT7qBSGmVxIvPXjj88EfjU/w9MsfidIX3\n\
KAj5Rh0OOv8An/CuP8Iaytv/AKHJOBJEB5Pmcb4iAQp+nr9O3X0nwpOLjXLdza7H2N+84IxjoD6V\n\
6WDly1405q6ujPH05KlOS1i1f8DvqKKK+xPjwooooA5T4q/8k+1n/rkv/oa18u19Q/Fb/kn2s/8A\n\
XNf/AENa+Xq+ezf+LH0/U+v4e/3eXr+iCiiivKPfCiiigDotHufPttrHLpwa0VYowZTgiua0aYxX\n\
qrkBZODx+VdJWM1qc/Ly+6dDp10LiLBJ3r1yOtXK5i0nNvMHX8RmukikWWNXQgg+hzXzmNw3sZ3W\n\
zPPr0+R3Ww+kPSlorjMTmbuRrPWXmiKZSXzFCHgA84/DpXokMizQpKnKOoYfQ151ralNSlBIJwp/\n\
NRXZ+GJvO0S3JOSgKH8Dx+mK/SJXnhaVV72X5IrMIc1GFT5f19xdv7RLyAxtwRyrehrzrxpb/bjp\n\
IuZ1gSHzImZwcKRtIzjuR/I16aelcvqOlJrltrFozAO0m+KT+64LYP8AT6GvOrNQtPt/wxeU15Ru\n\
nKyXXtfRmPZGNHWH+0I9OTkLHCFMmMDBbHHOPrVrVtQu1TZeXbRrgpG0Y2rOO547nA9uvTt5kyz2\n\
d1LBNlJ4HKMPQg16RoEp13Q7a1jmiWWLB2OGBLZ55GMDFcGIoeykpzd49+34MvMMBLCNSvez3t87\n\
9fL/AIB518ULvWrXw5c21nYCe0uVljnnRsBAoU7sjB74ORjK188V9fXFml7LcabqHlmFwbcmFyTz\n\
12nr6A4HTPtXy/4y0my0nXZLTTL5L2Lr8oIMZz9wnoSPUcV9LkuJhKLpJWf6f1+p8/mlKTaqf1r/\n\
AFr/AJGDWz4OeaLxJYy27bZI33bsMdo7k45xVWHSNQmvTaR2U5uRnMZQgjHXOelepfBjwwMR6+t2\n\
yTRvsMYRjtUnDbgByCM/lXpYzFU6NJybX/D7HJg8NOrVWlkvlt523/zO48XeE9P8SWl1Lb21vDfT\n\
4SJ+f3Sg4bAyMk4H515dqHw8+0eMJNI0kmO2hj3GaZsl+CQ3QDnHA9COa+idB0GPUtGNz5zwliRE\n\
QeVHuPXOaTV/Dh06wW5WZblwoRzIg6dBg9epwe/NfI4fNpYdulGd3qlfXX16/wCZ7Falhqs1FvXb\n\
rv2X/D+R8jeJNCuPD98tneyRm6CgyRLnMZPZveqd7p15YuVurd4yMdRxyMjn3Ar3bxL4KtNb8Q29\n\
3PayxwQK32h1wRMCRsJbdw3J49gBmt3XfDdtqei2lp0toJI5Vl8hYzNs45YDrg4/Ej6e9/a6p8im\n\
tXv5HC8tc5Pl8rf16nzEVIOCCD0oIIPIxX0j4rg0LSNCv9c/s2xnull8yJmUHMoG0gxsSCOBnPPJ\n\
Ir51vrua+unuLl98rnk134PGfW4uUY2S0+Zx4nDLD6N6/wBf195Bg4zg4qSK3mmz5UTvgZO1ScV3\n\
/wAJdSjm1A6Pqljb32nyKcLLEWZCePlYDIyWHpyByK9isdA0eC71C4gtYo0v4xBLGXIiSEDHybeR\n\
xz/WsMVmaw0+SUf8t/6ZrRwLrQ9pF6dT5q0/Rr/UIhLawM8RlSHf0UOxwoz6mr/iTwxdeHbSzbU3\n\
SO8uct9l/jjUcZb0Oe3419CeEPDsvhvRLpIYEkshcO7PHAMlA3ylmIycc8jpkcjFZnjjwfZ+KJbc\n\
SfaIbiJ1WW5UFwFOQcZ5OPlyfb8a5FnN6/K1aC67/L+vyN/7OSpu2svX8f01+48g+Gq6Ve6zHp2r\n\
6fDMk2f37SMrLweOuOfXqO1e92fhuzl1Nb7SraUXMVv9nzAxwqdiT1JxjqTwMelcJ4M8Ejw14ium\n\
1GJZbK5gZLSR1Yu7g/dUoeMkEfSvafDGqWum6LGbpghlldgmwoEGQAB7AAc/zxXm5zjG3z0btW+T\n\
vudWGpSpU0uXmnf8vT5/1c5WWFGkllvY/tM5LI0c7LsAdl3Dn7owB37D3qzpbHw3BcSx7kihLlFd\n\
ON5YoRGegUHdwM+ueeLdxPEmpO067LeS4eYyjLl13bgU5wMDaMYPI49+c8b3CvPA1tuFiE2woT93\n\
HG3GT7Vxwftf3bW+/pb/AIe2n+R6WHpLFVo04qyaWm+3T+vUZe+KJp5jNLbwMxP3iCCec8+tVbTR\n\
da1x2uLWzkZZSW818Kpz6ZrpfAfg8z+VqmsRgxkboIGHDf7TD09BXpQAUAAAKOAB0FFTEwoPkoq9\n\
up7E6uGy+ThQgpS6v7K8kuvm9jxW58FeIokLm0L+oSRSfyzXOzJPbSmOdZI5F6q4II/A19G1k+IN\n\
AsddtjHeRgSgYSdQN6fj3HtRTzGV/wB5sdeG4g15cRTXL5L9DwuKXcQG69qm8xvT9Kk8QaLd6HfN\n\
bXie6OPuuvqP8KzvNf1r0fcmlI9mrl1PE2q4dqz+75GpZT2ulfEH4j6pqb+TarrF2quAC0jickKM\n\
nr37fWvMPFvjaTUdSF1Z/JeRM8Yuo2IE0J6Aqeh6+n0qb416xc3fxF8S2GRHZWurXYjhToWMzlnP\n\
qSc9eg4HFcBXu08DD20sRP4n+H/D9T8cnipKCpQei/MkuJpLiZ5Z3Z5HOWZjkk1HRRXfscYUUUUA\n\
FFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQBu\n\
+E9fHh+/+1LZW9xKAwVpM5UlSB3x1IPTtXpJ8cx6jd2Wn6aT9tkSKNZwAItxQbvk6jB4x6E9K8Zq\n\
7pOpXOlXsd1ZSGOVCCCK48Rg4VX7S3vW0OvDYqVF26H2r4K1wXmlpBqcsJvYx1bjcnY8n6jHXiub\n\
8X655WoXdzKzXcVoC0UERGDGMb8Ljk9TnPbgcV4/4B8WpdXrG+aW61K6cho0wiRxj5i3IAHcnnnA\n\
roPi7dtZ+FnNnI3lzhVEsLkAhsAg8YKkAccHIB6CvlI5WqGNSlvL7vO39I9emqPspVoP5dF5/Pt0\n\
6Hj/AIz10eINfuL+OBLdXAUKmeVAwM5PoBWDRRX2lOEacVCOyPAqTdSTlLdn6eeDP+RP0L/rwg/9\n\
FrWxWP4M/wCRP0L/AK8IP/Ra1sVZAUUUUAFfBH7Vv/Jb9b/65W3/AKISvvevgj9q3/kt+t/9crb/\n\
ANEJQB5FRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFdf8N9St7fXrWz1CxsrnTppFa5\n\
E/ynauTkN2x1x0OOQa5ClVipypIPqKyrUlVg4PqbUKro1FP+rdjuNY8b6k3iz7XY6gsMCMqgQ7vK\n\
wOM7Tz2pvijxVpWryu9vpbWt5v8AMbUIn2STMFI5jHyqCTng1xFa3hnT7bUtYt7e9u/s0DOAzBGd\n\
iPRQAck9PxrGeHpRSnK/urz/ACW/odNPF1pycI2959f829PvRnqk004AVmlc5Hqc19MfDGa50qbT\n\
FubdR5UQgup8gnd2XIPPDKeK840/T7Sbxz4g0/y44rsgx2EY/eMHjwVYsvGCqlTzyT0rt/Dk+r3G\n\
o3UN3bww2MWFiMchJDYBG4HpjtnHTvg15GZ1liKfI0krdd9Utv66eR6WDwsIVHFtu7a/Nar8T39d\n\
2A0R3KeQR3rI1jxJbafMlqWaa8k4SCIZY/XsO/5VxK69cW8QjZZg3T5GwpNUYoprlzLu8m9kbKTB\n\
QWj5GevsMV8jRyyKles9Db+xHSUpuWi2XcWTxDF4uu5hbMXWFWTZD1BGMgHIJ9zx1qhd6jZTxQpa\n\
3Ty3xGVilR32sQcptT5jnac9QARwRSro+r3OoXtrpzpYWzhsyDb8xPLc9cElQFbjG7HQVgeML4+F\n\
9NuE0ayRdRvGQvdLG0oZ2BBVSejYyRg/w8ZBr2sPTjK6o26JK+1+/wCZulCPuy2XRdtdPX/PfWxX\n\
XxvpkmpfYJvNF6oIP7pQokzzuz0HQ+2Op613ejasml6pNNYIivJDmWBpTtRBkoxwOeFJ6nhh615f\n\
q3hOHw9qlrqgsdQfTpIInjnQr5kE4IUhs5DEv1AxgnrXT6XrQvLVoNDtdSjgeICSeZAWZtpDA7jl\n\
On3gcMVx6mrxMKdSPu3cWtb976r/AIH4mvsef3ZpJ389vP07r8D0Ox8cXB1T7NPCs9sEUtPCCNjM\n\
CcejHAzgHOCDXR3Wt2otGe3k812Xg4wAPWvP9La21PSI/scjkRI0bg5UhgxGBz2BKg+mcdaZPbM2\n\
5d8iDqy5OOfavJqYPDzn7q5bGVLLcPUlzS0t+PyHafPhMLyqkrzzx+NKtpbT3YmnE10VkdpIzhUV\n\
sghTgDevC46dBnriiCERoFjBIz1rbt1KWqiTqB3revU5FJx6noV4QUk4aenmZniTUEuLBIp7OOOP\n\
YzxXLSAHzBz5ar3OACM5HA4yBTDqtuYCtxc2xFvtjlnjChHkyzFWIx9QMcE+/Lzay3l9H9nto5zb\n\
Sh2EjYG0jsCR83HBByMnqK4uy0G0sNMvp1tpllurzfcC5fO+JPmcKcHnJHXn68VWHpxnStL13163\n\
vrpvdaa9jCNOK0XRv5dv62O+fy7maNRBG553I4GHUjkenNZVpZpDfahNbC3kii2x3jJF96ZWYqcg\n\
8YXC9vvZPPFafhnVLFrK5dLxr2eDlfMZFKsZHQKTgYxhTz79Kq6Jc2Y169Wa6bY4Alh3Fj82GRsb\n\
RhQoxxxnHQ5pU416UZxUXLWy89Lv5fdqZ+9JyklayWnfXou9tSVbETXKqj5jBG5gBk5z8vJ9v1z2\n\
NXtMtRqWoR2ZmVbeFGcYAEiFtuVOOM469fr2qnbzx62WmtI5SLQk27R5QxMSM9sE8Y5PqMdSY40M\n\
l5GsW+KZz8uJAGxkZ5PI/AH/AAHKfI6L+K2/rt1/4f7iKsZTbcpWdtOttPT7/u1IfFPhW6fVVNoH\n\
kiwq7ydxOOMk12fw60qPS/HdrF5LCQ2rvuaQk9FBP6n/AD15uX7dZuI9Mu5rgMqyeWhHmHryfb69\n\
foK6/wCHllcp4ujmkhmEaI6PJPKHZmxwR7bePz6d+nBOrDE041Jpq/6nLicXUlh/ZOVkk9nv66/5\n\
nrtFFFfcHzIUUUUAcp8Vf+Sfaz/1yX/0Na+Xa+ovir/yT7Wf+uS/+hrXy7Xz2b/xY+n6n1/D3+7y\n\
9f0QUUUV5R74UUUUAKrbWDDqDmutt5VmhSRSCGGa5Gug0KTfZ7S2ShxjHQVE1pcyqLVM0q09Hutr\n\
+VI3DdMnv/n+lZdORijBlJBHoa5a9FVoODMpwU42Z1lIehqCynFxAGGcjg5qxu2AuQSEBc7Rk4Az\n\
x+VfM8klPk63seZJOLscpqkvnahcPvDrvIVhjBUcDp7Yrq/BLE6XKv8AdlP8hXFNgMQvTtXZeDWE\n\
OkXEshCoJScn6Cv1DEU40sNGC6WR146FsOoLyNnUrsWlsWz+8PCD39fwqn4fiK2zytnMjce4H+TW\n\
VczPqF5kkKvbJwEX3qpq3jjTtNi+zaYPts6DaCOEGO5Pf8K+exKlUtTgrtlUMBUjS9nTV5PV9l6v\n\
oc58QLLzfF0i2UZkmkiR5FRcndyMn8MVu+DNBu7SWCWdDGFJYjOc57cVyeiXl3eeIftcxM0srfvM\n\
8gg9h6dsfSuxvNaOhapJBbPHHbTSRxIsjEjeU7E9OVOc9+vtz4z2jisPDVpf1/VugZlWqQSopppJ\n\
K769P10H6xFb6RqxOksq70IeMEsEbJ+bk4B+vTB4rzO8+Fen3PiuTU7y9dbN5NyoihSzIQHZsk4G\n\
c84Odp9Rn0KxtnuBM8UE08h+dm+8gOMMCFxk9PlznOeuBTtIt7fU9T/06R1EoKljjMrA4HbA6Ht6\n\
Cqw+JlhoNqTdt+9t35/1fzPL5KbhaWtur11V9e/pf5pla4Y3AkvPLeQYaHzmTHqRyclTjn8RjGBU\n\
yxpcTRjTrSJY0RZp9gDI3QEYB5GRjj/aPPbRGv2WmlNKugklvH8jMygBuf7vPFZuqTyQ6HePaPtu\n\
C+XjTA8uLkqB6jknP9K541pyunHfRN9v6+7Q15Z80Y8tr7P8v68+gzW9fg0u+ktdNMdvAjZKRLwW\n\
7mrMmrrrmn2qkyNBHJi4CHDLkqAfy3eted2Frd6pd+RYwSXM55IHb3JrqLbwb4ks1ke2kt1ZkwVS\n\
bBPt0rongqVO3NL3l3PWrZVGFOMZSUZK1ruz/wA/vN29vNHg1FNkJuZImYOZHDeZkYw2euOMD2Fa\n\
mtavB/wjqC1iUtMwhjXGADjgcDr0A/wFeR3CT29xJBco8U8Zw6OMEGug8L65LaypbzASwhw6K4zt\n\
YdCPeor4GSSqOTlbXf8Arqc2Jyn2cU4r3o2er/r8Cxq9rcXen3dhbW4ku5EMO2eI7YVOFYtzyV3E\n\
4xjv6Z8G8dfD7U/CKCe6lt57RyAksTctnPbqOVI/CvqvWZ9Kv9FN/f7vMx5cW0nO7BOAOnr1rmJN\n\
Lg1Wye1vxAUCHh8EHcDnYD3OcfQjFdmWZnKlZKOl9V3/AK/D7zyMRh3iYt1NGn+fbul6Hm3wi8JP\n\
pSW/iGS/MZljBRY84ZGxlXBABA6nn6cgivbLW20pPDsN1cRsDKGdJF4cg8D16jHHNZENlFp8kEEg\n\
D28e3dEpYFiMAgYyM4wfvAe3Bxz3iXUjDcPp1l5kVvBI33nLMTn1NZYmdbGVtHZ36dlpY6cPhI1L\n\
UaV+Vb9L/j13tsekaRrVpcxJZxphEQIFcZ3DGOar+MrW0trWGaOOKKRHACouCy9xxj25rzzwpqcs\n\
esWwkYurNjlsfr2rrtN019Yklmlu2SSIB3DrvZgQM8Hgdj3xnHTFeZUwv1WrzSdl+YYnCxwtdNXS\n\
Wr316W+9lWWGSWB3SOKNY0VsMx8wB9wwM5ww5yfx54rmtY+2ahqZsLGKadbYeWFj+bPPJPYck0eJ\n\
7ua41I2USFB5mAveRzgbj/8AWr0rTbe08N6VFaphptuXI+9I3cn2r0lOUIxk1dvZdv6/4c9HDUJY\n\
eMa1Rc0ney/Nt/gcJpui+LLcxLFaGNYm8xPMkQhT7c1qWuhWv2yO51pkl8lVSO0gO5BgfxNxnnt+\n\
ea6LzL3VXKJ8kOeQOFH1PetG10i2iAMgMr+rcD8v8c1tGE5aysvT/Muti6dCXPJKMv7t7/e2Z02s\n\
zMMQRpGvbuR/Sqz6lduMGYj6AD+VdOLeADiGID2QCoZ9OtZhzCinGAUG3H5VUcPCO0UccMxw6dnC\n\
33M59NTvEAAmJ/3lBq9ba2c4uYwB/eT/AAqO80aSPLW5Mq/3T97/AOv/AJ4rJIwcHrSlh6ctGj0Y\n\
LD4iN4WNnxLpNv4k0V4UZTKMtBJ/db0+h6GvI/8AhE9c/wCgbP8AkK9LsbuS0mDJkqfvL610X9r2\n\
n99v++a506uG92Kujpw2OxOXRdOkuaL116Hxl8XP+Sq+Mf8AsMXf/o5q5Kut+Ln/ACVXxj/2GLv/\n\
ANHNXJV98fl4UUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQA\n\
UUUUAFFFFABRRRQAUUUUAFFFFADkdkYMpwa9ETxJL4q8D3Gh3jodQsx9otmY4aZVxuTPQnAJA68A\n\
DNec0+GV4ZVkidkkU5VlOCDWNajGpZ21Wq8ma0qrp3XR7jKKViWYk9Sc0lbGR+nngz/kT9C/68IP\n\
/Ra1sVj+DP8AkT9C/wCvCD/0WtbFABRRRQAV8EftW/8AJb9b/wCuVt/6ISvvevgj9q3/AJLfrf8A\n\
1ytv/RCUAeRUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQBPZJDJdxJdSGKFmCtI\n\
BnYD3x3xXqHhvwx4WQSa9BrLXWn6YU89SrRvvJwDjb0ZunXHevKK3NF8SXui2bQ6aIo2lcNM7xh/\n\
MAwVUhsjAPPTrXLiKdSVnTfy2T9dGzrwtWnB2qJd72bfpuj6A0vVPCM8EGtaZEkV/ctKpnkQ7x5a\n\
gtz2yOc4GTurpbOC3urBbqyQKbkiZ2Iwzkjq3vXyQZ7iWRBE0oGcRqGJxz0H4n9a+lvh5eyf8Iva\n\
pNdLdXEI8udlYsVf+6xPfGK+XzbAvCfv1Ntt9Xey1t8k/wDgHtZbifaz9mlZ737s0tXnfSzCZLeW\n\
VHOCYxnb+A5rnx470qLxCulwXKSTvII1kVCwVmwAvBwSCccZ6Vra7aa7c3C3FpMg00xlZdzqm0kj\n\
k5ySFALYGCT05AryCOz8OXXjTUnu9Xawt1lNzb3MK7lkh4+XuUfHTgkHrSwVKnXpOc9dOmuvbvdd\n\
Trr1qjlyRlbW3b18vS56nBqL6v4U1DZqZtLwOsclzLH5YMZYhtuTgkYOfb2Oa8f8Uay0kuk6RcZt\n\
EsdrrcpOX3Bxv8zjjnII4yBgZ4FdpdeIfCWl6VpugxwT3Wl3UfnzXvnLljnHzRggnGDkEgng14pc\n\
uXmclzIAcBic8dq9XLcFCLckmlvquu34Wej7nnYzESoqzd3dfhZ/dtZrXzPo3TNa0yHwjpOjalPb\n\
6sfMkieXzEaEy7sjAJznDZzgd++a6qzs9Age9v8AVJg2oXULCVpJCyIp5wo/hIH5cnPNfNHgu40K\n\
3mvG8RpcGNYw8D25G8ShlIGGyMEbs5BrvfFPjvSr9Rp9olyLiMJBBem4JDxso3GUYAOCOVxye/Ar\n\
DE4KTvQjzd+Zab72f5m8cRCrSU2+W/nr6PZ6/wDDnsJil0+CUwRFYIUyAqlvlHtnn3OfU81yup+I\n\
rOCa1urlljv13+bBJII9jYIXDAkEgLnHIw34Vd8BT6/peli31qPzbBYzmZ8MZl4H7vPG3Azz1z75\n\
FKwv9BltbubTIIDcWMflJNOSqROz/KHY4yQcNkjHy8YwBXkUMH7NSlUaa6O71v3+f3/gd0eebs1b\n\
Zf5+f46B4b8U2mpX09taLcAWgJeX/VoGIGPlycjIZsnnnHXJrd0y7m1S/uBZ3SzxR5+XIPyj+PIP\n\
cnaAP7p5POOD+H82n+Jm1O11bTHa5W6urqW8jY4iLgMF3jJOQr4z17c13/hfWtJzfHw+1m9zIEJY\n\
IPu44DA4YduRkewOc64jBuSnGEVzJdfl2+b2T2RLvCKnT/4G9uv4/ka+lWd0tzvKMMGrnibSba+0\n\
j7EqsJGAjdI25IYgDdkjPQcn05z0PlPiq+1+1tY765jfT7dJUaYTvtVtzbW8sA/Nu6kgcDNaum6t\n\
pwR5l1NXvtWUmKK3RyFjVsOOOv8AESMYJGcdhx0cC6FVV3NtK+iWjsuuvnf/ACKqU5V5qTaW34k8\n\
ei3djYWbeGLC1M7Tv5oZAcxEkgsQMluSDj149Kj1DxDpS3Ut1azNYTXcK2qm5hEckT7wC+eT90kj\n\
5dvy55NZPhrXtf12yv8AT7e+g0vUYpPISZlCsNu7gAA9QDlhznHUdNfXfDI1bVhDcF9VmsYzcyPJ\n\
KUjDNtKRAYyAQGPALcjnvXdV5YVLNtJN+b+96O+h0wUW7Pt/V9trM0QbeOSJCIrG2t0WNS86CfPB\n\
37R93BOe7EgnvWqYLVkUacn2iJI1JZeWLHcu5y3JONwwfesopHdpH5NvZ3lpJG0ku6ALKmdhWNh1\n\
yDhex5GccmtWVEge3WwJjZIsbNpJTndtcfhxk+uO9c9Vtxg5t369rf1pp89TCq7T93/gf12voaOi\n\
anZWVhdRSsyXRkZXkbHyjsc56e3rnFS/CGO7l8fzSG7822iiJ4YkPuHynB+hrM0+wLadNe/aFE0M\n\
4eRWjBbaFx8v4dB0BHtWj8Db0P4ru4JgEkdFKL3wilce/BFbZdTpxxPNT1d18tv69Dm5W6WIaWln\n\
9+m3y10Pe6KKK+3PkgooooA5P4q/8k+1n/rmv/oa18vV9NfGS4+y/DPXZ9u7ZEpxnGf3i18u2N5D\n\
ewiSBsjuO4PvXgZvF+0jLpY+t4ekvYyj1v8AoixRRRXkH0IUUUUAFamgS7biSMn7wyB71l1PYy+R\n\
dxSZOAcHAzxSauiKi930OqooorAzNDR5vLudh+6/H41rX8rQ2Nw6BSwTGD7kKf0Jrm0bawYdj64r\n\
cvZRNo8rg5ynUDHO4VwvDKWNpSezav8ALU48RC01Lvb80czXUbxp2n2ljJHI8koMhjjcKzPgHbz6\n\
ArwM5z7Uui6SljANQ1JfnHMUR7HsT7/yrL8SPeXkEEVqN12bkXSjj5QAQWwe2SPbg+lfT5liVNKn\n\
F6dWbuXtm3F2Uer2v/wP1Klu1zrd0yXdulppfzp5Zfa8jAZGSeSc4OBxVeTRtHRxayMY7hOoEgLn\n\
8Pun6cHg9a1Nd1GTTNJhuYPJlkl2xq4O5Y2GQ+z+6MgdDXOaD4Zv9dlF/eyLa2UjFjNJjL5P8I/r\n\
XjU5uonNy5Y/Pf8AMdCNXFKVZz5ILze68tbt/idVYhNHhthpVvAQS3myXLBW3YyODz+veq/2iwsr\n\
cS6rLKt7NKTw3oeeQO+T/nNSX/hPSZLVI01W582JdsZch1HtgDp+NTWHhmaS+gu9WjN39njCRopw\n\
r4zgtuwfTjBFZRoRl7139zu+2/8AwDleHhfmnPe9+j7rfuYc/jOa31Kf7Iii0ZmwqYXIPce9arNY\n\
z21lqNqPsyFiziVmK/JySD1B56j0x61r+IobPVbJrW/tZLeUZMUu0ZQ+o9q5G5tpP7CbTZZRDPEg\n\
l77HVegU45BJz16549K9jCysnF9f8y62GouEZJW6PrptfTTr942Hwzf+I7y5v4ZoktZJG8uWTJ3g\n\
HHA61ftvD13GklpNqpuFZQgW3jLMAD0B4xxx3ro9PhlltbfTrUlLa3jVHcd+Ofr347/y6G2t4raP\n\
ZCu0d/U/Wuumpta6Lpp/WpWKxsaEfZNJ22VlfTZt+fZGBpkcWg2fk2mlSQxdWcnlj6k4rTtdUt52\n\
C5MbngK3f8a0aw9Y01Qhnt1xjl1HTHqKipg4S16nLSxdPFTtVVpPrdv77nJ/FywRVsdSQASljC5A\n\
+9xkZ/I1y3h3T5r29BiX5I+WcnAX6mux8Vs2o+GHglK74JUdXc4wCdvX/gQqPRrBJXtNMuGEtvbR\n\
NPcLHgbic4GTz0x09azlUdGhyS6X+7+tj1MRivY4WFKXxK6+XT87JHQy2tvpXh7y7pBI7E+W2Adr\n\
kHBB7VzmiG1ImuNQvLhbE+WfL3YCybc4C447nuM8/SnrOt6bazlLSKZxEcRwsw8pOuRjGcc8/j61\n\
ZsNDufFFnFeXciWFiASiRjIc5OWA6KOw+lclClKEG5Oyl16/Ja/h8zy6eDqP95Vdk3q/8lrqP1+6\n\
bSLK5GmtviuXSNG2hs7QOSMdhgD1z7VqaV4W06CzW515I572YbnEhwq+wUelRaR4bhjuVFvcS3ax\n\
MGEk6jYhA4wMZJGOOcfzrpv7IgYlpnllkPVmau2NFuNot+b6s29rTwa5Oe0r7rdrp2t/XQ4jWvCm\n\
ku3n6JdG0uF5CHcUP44yDTPtD2ckCXUN3YiZRE0tqVUOTjJZgSM579fyruH0W1b7plU+zDH6iq0+\n\
mW9vDItxeKsDjDJIBhh+fX3HNXPDucVF6/1/W6KrY2hi4qNWTbV0rrXX0Tv8/vOVa3jutfW4zLNH\n\
Zv5okfaR3MY3DqT8px2ANdBY2E1/KZZywjJyXPVvYf5x/KoLe70ewiCNcT3rhi5yvDN0BxwOgA/D\n\
606bxaANttacDgF2xgfQV1UMFVslyh7StGmqdCLv3eiXpe3rsdRDEkMYSJQqjoBT64eTxVftnYkC\n\
D2Uk/wA6Z/wk+o/3ov8AviuxYGr2PPeW4iTu7X9Tu6K4ePxTfqfnWBx7qR/Wr1t4tU4FzakerRtn\n\
9DSlg6sehnLLq8el/mdVWZq2mrcKZIQBMOo6bv8A6/vTrLWbC8YLFOBIeiONp/WtGuaUGtJKxjTn\n\
Vws+ZaM4hgVYqwIIOCCKdW7rlgHQ3MQ+dfvj1Hr+H+enOHg+lZM+nw+IjiIKcT5Z+Ln/ACVXxj/2\n\
GLv/ANHNXJV1vxc/5Kr4x/7DF3/6OauSr7E/NgooooAKKKKACiiigAooooAKKKKACiiigAooooAK\n\
KKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigBQSCCOorufC1j4d8Vyp\n\
aajN/Y2pbT++QZhnOeMjoh9ecVwtOR2RgyEgjvWVWm5x912fRmlOpy6NXR+oPhuFbfw7pcCNuWO1\n\
iQE9wEArRrJ8IO0nhPRHc5ZrGAn6+Wta1aRukrkO19AooopiCvgj9q3/AJLfrf8A1ytv/RCV9718\n\
EftW/wDJb9b/AOuVt/6ISgDyKiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKAClHX\n\
npSUUAd9peoeFtP02zhntZ7ySSJpJJTJ5bQyE52gL1+6pBJ7+tfQ3hS78P3/AIJbVdIEFlbYeaYb\n\
CcSc5YjOTkj1ycV8iWK2plb7a8qxBSQI1BYnsOa9/wDAEsLeB76Dwjd3V8sRb/RrtAMtjO0LyBnJ\n\
5HcA9hjwM1y6OIhGEpNWd2+m+3b07Hs4SrKrJWaj6b6K235eZyPiDxp4nuNdsvKv4rSyZRIihTFG\n\
ADhiVbk45GDnIzXB+OZtPn8WanLozbrF5iYyE2A+pAz0zml8Va3f6xOV1kK17buYwwXG1Mn5OOoB\n\
yR9TzWBXpYTCxopOKtZWstt738zlxeIUrwS63u9+1vL72OZ2bG5icDAyegptFFdpwbhUkErQTJLG\n\
QHRgykjPIqOigabTuj1fwT46d4fEM/iLUHupLmDcbOSIeTKwIG70Q9DwOcfgeB1TxBd3k96YNtnb\n\
XZUyWtvlYsqMDC/561jUVyUsFSpzc4re2nRW7L+vU7amPq1Kcad7Wvd9X6mtoevaho0qtY3EkShx\n\
IVVsZI9faup8M+PjY67c6jfaXBeXFzciZmxsMa/NuCY4U/NkHHGK4Cuu+HmlTXmoTXdncpDeWMZu\n\
4keEyCUR4JXAB5P+NTi6NHklOounp+K87GuAr4iVSNKnL+vmdrf6B4n8VWF7/b0zwwRv9rhuJwGQ\n\
h8dZemANuAB3IAHNaHgSSLQIvsNjZwX+p2szebNcBdqPzt8lzg/Mqn73QkYBzXZaBpN1qGiRWut6\n\
mRezyLcOVlZkG7JXZt4VQduccc+3PT6jp+nWHmxi1ieSTKu6qFPbjC4A6Dtn3r5jGY32CjSns9Uk\n\
tPW//B3+49+Kgqtoq8rbve3T+l0KbaWNOsDqL2v2WRgrArsREBIyHI9PUE/pXPeE5Y9U16+ksLWa\n\
Q3TItxd+azLtHBCEgKRjkccAdznHX39/LdaHJbxWguQ5SMoWUBfmGM7uCPbnOMd65rQ7i3ivZI9E\n\
uVa0MpDPbxkeV5aqWjZz6sAMYPBOMcg4UsXVq0faSSTTdl08r/8AD9LlR5/ZyjJ+8v8Agaf8D/Mv\n\
2sI0HxCtpDNtW5EjqvzED5QoXv8AKSu7rwTzwOZ7yQFlklVfOE2XJQD0B46N0GPYnBw1SyrvmiS5\n\
EJlwSJHUN5RPUHOODx9OvHWk0uZoru21CSLNqPLUlzlUDKMtuPX5iSO+Dk9zWUXOolWa961rLbrp\n\
+dt9GKpNK8pb2+/TS3rtbuibSr7y9VFx5bXFvPGY5kVQMnPHA6txknjr2xgdR8PniuvHMU8VvtiC\n\
SrFhR8q4HJIHfJ79xx0rI1/VNK/tV7eUGC6CnbLERuk44Un3wKu/Ci+LeLIrZo4xI8bu8hkYu+Mh\n\
eM4xjPr68E10ZdatiIVlFp6f1/XkedWjL2UnNWutPS3lp5XPbaKKK+4PnQooooA4X45/8ko8Rf8A\n\
XFf/AEYtfFFndTWcwlgfa3f0Psa+1/jn/wAko8Rf9cV/9GLXxDXBi0nKz7Hu5W2qba7ncaTq8N+o\n\
UkJcY5Q9/pWnXmqkqwZSQw5BHaul0fxAMCG/OD0Evr9a8avhGvegfR0MWpe7M6WikUhlBUgg8gil\n\
rhO4KPp1oooA6qxm8+0jk4yRzg5qesfQJ+HgPb5hWzWMlZnOlbTsJWzp8rfYX2+W7oVIVzgdQAD+\n\
IHp1rHrT0mPdbXm5fl8vcM99oY/zFYVZKDhN9JL87fqY4hJw1JdXu9WTzJbjzoApbDIsbiEZxuII\n\
3EZHUADA/GsnTLFba/e/uNVW7uNyxO24OBuIDE5PQZx0xkjjANb2l6kNTt0s7p9t4n+pl/vH0J9e\n\
KyJNNsLLxTHKjxREWvnzQudqq3Qk9gCOcf411YuhKheM3+G5nZqlOLdrLVJLX0fRfrvqZmmyf2nr\n\
j6abSKGxi3STRgclU/lyAOMdTXTAS3cyqq7mPCovAUeg9AKyvB8TwaxqkmosomvIX8mXdlZB95tp\n\
6HjB/CujnvIdBtlUp5l9KoJU8bR6H/PJ/CtKEPaT5YK+i/LX8TplVhTilRV20rebtq79lt+Bq6bp\n\
sdooZgHm/vY6fT/GrE95bW+fPuIoyOzMAa8/vdYvrtiZLh1U/wACHatU4opJ5VjjUvIx4A7168cB\n\
yq85WOCWAnVbqV5nc3ev6VsKO/nj+6I8j688Vhzaha3E0YsdOmleNt6KWJx74GT2B4I6D0FR2Gjq\n\
o33g3N2RW4HHcjqfoe3U1rRxpGpWNVRTyQoAH5CvCxmbYKg3GknUfe9l/m/l94kqdD3abb9Xp9xU\n\
bU9ZSFRBYrCh+6qxEsPw6/mKqTeINWhfbNiNsZ2vFg4/GtjA9KbJGkqBJFV0ByFYZGfXBrlpcRRT\n\
SqUVbybv+Ioyhe8oJ/n+bM2HxXepjzYoZB9CDWxY+JrK4wtwGt3P97lfzrJ1DSophvtlWGUnJ5Ow\n\
9c8YOD9OPYVg3MEltMYpl2uACQCD19xxX0WEr4LMI3pOz7dV8jVYbDYhaLlf9fI6HxLYiHTr7y8N\n\
DPCVjI5+YkAD8yOaoaVHNbwaet3IJHhLiT7OuSV2fKu7jptbPPT61FpWoi2PkXSiWyZsshGcH1H+\n\
ean8RaN9ntrmWxf7M/ltOkkA2rLtGeQOnGfu46854rgx2ClB2b0/pGtSnUrctCclfo316b9NN18z\n\
jPE+lSWVxI0LJLbtIVDowYA9dp9+a9IEn2iGysrPAt1ijChTwflBz9K5/TTKukRy6hbSRNM5BWGH\n\
c0wLKd20d+vuR7cVsWF4ml6XFcTkyXRj8qNGUqTt4yQeRwB+orGgpVpRpvVq9jVYqcqSptXcW7Nb\n\
NvT00/I6lFgsbQAsscSDlmOPxrHvvFFpDlbZWnb1+6tcjfX1zfS77mVnPYdh9BTbW0nut/kRl9gy\n\
xyAB+Jr3FhKdGPPXlZL5L7zjhl8FepiJXf4Gje+ItQuchZBCh7RjB/PrVCK2ubwl0VpDnBZm78nq\n\
fof8mtyx0qG3+aYJPJ6sPlH0B69+T+QrQxwB2AwPYeleHi+I6NB8mDhfze3+b/A09vTpaUYmHHoT\n\
Z/e3KAdjGpb+eKsrolsFwzzu394YUH8Of51qUV4tTP8AHzd+e3ol/wAExdeo/tGJJoWAPKussf78\n\
e0D8QT/KqkmkXiB2WMSqveNgSfovX9K6akrejxLjafx2kvNW/L/ItYqoutziqK6y8sYLos0qfvD/\n\
AMtF4bPqfXp3/SsG90ye1QyHa8ION6np9R1H8vevqcuzzD420Phn2fX0fX8zsp4mE9HoyjWxpWv3\n\
dkypIxngH8DnkfQ1j0V606caitJGlSlCquWauj03T7631CDzLZ9wHDKeqn3FL/Z1n/z7J/303+Ne\n\
dWF5NY3KzW7EMDyOzD0NdR/wl8P/AD6P/wB9V5NfAyUvdV0ePVwVejL9w3Z+ZxPjT9mbXPEHjDXN\n\
Yg1zTYotQvp7pI3V9yh3LAHA6jNY3/DJ/iD/AKGDSv8AvmT/AOJr7Cor6I+PPj3/AIZP8Qf9DBpX\n\
/fMn/wATR/wyf4g/6GDSv++ZP/ia+wqKAPj3/hk/xB/0MGlf98yf/E0f8Mn+IP8AoYNK/wC+ZP8A\n\
4mvsKigD49/4ZP8AEH/QwaV/3zJ/8TR/wyf4g/6GDSv++ZP/AImvsKigD49/4ZP8Qf8AQwaV/wB8\n\
yf8AxNH/AAyf4g/6GDSv++ZP/ia+wqKAPj3/AIZP8Qf9DBpX/fMn/wATR/wyf4g/6GDSv++ZP/ia\n\
+wqKAPj3/hk/xB/0MGlf98yf/E0f8Mn+IP8AoYNK/wC+ZP8A4mvsKigD49/4ZP8AEH/QwaV/3zJ/\n\
8TR/wyf4g/6GHSv++ZP/AImvsKigD49/4ZP8Qf8AQw6V/wB8yf8AxNH/AAyf4g/6GDSv++ZP/ia+\n\
wqKAPj3/AIZP8Qf9DBpX/fMn/wATR/wyf4g/6GDSv++ZP/ia+wqKAPj3/hk/xB/0MGlf98yf/E0f\n\
8Mn+IP8AoYNK/wC+ZP8A4mvsKigD49/4ZP8AEH/QwaV/3zJ/8TR/wyf4g/6GDSv++ZP/AImvsKig\n\
D49/4ZP8Qf8AQwaV/wB8yf8AxNH/AAyf4g/6GDSv++ZP/ia+wqKAPj3/AIZP8Qf9DBpX/fMn/wAT\n\
R/wyf4g/6GHSv++ZP/ia+wqKAPj3/hk/xB/0MGlf98yf/E0f8Mn+IP8AoYNK/wC+ZP8A4mvsKigD\n\
49/4ZP8AEH/QwaV/3zJ/8TR/wyf4g/6GDSv++ZP/AImvsKigD49/4ZP8Qf8AQwaV/wB8yf8AxNH/\n\
AAyf4g/6GDSv++ZP/ia+wqKAPj3/AIZP8Qf9DBpX/fMn/wATR/wyf4g/6GDSv++ZP/ia+wqKAPj3\n\
/hk/xB/0MOlf98yf/E0f8Mn+IP8AoYdK/wC+ZP8A4mvsKigD49/4ZP8AEH/QwaV/3zJ/8TR/wyf4\n\
g/6GDSv++ZP/AImvsKigCjoNk+m6Hp1jKyvJbW0cLMvQlVAJH5VeoooAKKKKACvi/wDaS8BeKdd+\n\
L2r3+kaHfXdnJHAEmiiLK2IUBwfqCK+0KKAPzg/4VX44/wChY1P/AL8mj/hVfjj/AKFjU/8Avya/\n\
R+igD84P+FV+OP8AoWNT/wC/Jo/4VX44/wChY1P/AL8mv0fooA/OD/hVfjj/AKFjU/8AvyaP+FV+\n\
OP8AoWNT/wC/Jr9H6KAPzg/4VX44/wChY1P/AL8mj/hVfjj/AKFjU/8Avya/R+igD84P+FV+OP8A\n\
oWNT/wC/Jo/4VX44/wChY1P/AL8mv0fooA/OD/hVfjj/AKFjU/8AvyaP+FV+OP8AoWNT/wC/Jr9H\n\
6KAPzg/4VX44/wChY1P/AL8mj/hVfjj/AKFjU/8Avya/R+igD84P+FV+OP8AoWNT/wC/Jo/4VX44\n\
/wChY1P/AL8mv0fooA/OD/hVfjj/AKFjU/8AvyaP+FV+OP8AoWNT/wC/Jr9H6KAPzg/4VX44/wCh\n\
Y1P/AL8mj/hVfjj/AKFjU/8Avya/R+igD84P+FV+OP8AoWNT/wC/Jr1b4aeEvFVr4R8Qabqnhm8t\n\
IpYVHnW0AS5dQfmUZOCSuRmvsmiufE4dYiHI3bzOjDYh0J81r+TPzjk+FvjdnYr4Y1XbnjMJJxTP\n\
+FV+OP8AoWNT/wC/Jr9H6K6Dnep+cH/Cq/HH/Qsan/35NH/Cq/HH/Qsan/35Nfo/RQB+cH/Cq/HH\n\
/Qsan/35NH/Cq/HH/Qsan/35Nfo/RQB+cH/Cq/HH/Qsan/35NH/Cq/HH/Qsan/35Nfo/RQB+ccPw\n\
o8cSSqn/AAjWopuONzQkAV3PhT4f/EPwpeWKnTryO0luRLMsEIkZGjPy7v8AZO7seme4r7jorCvQ\n\
9vHkk9PT+tjqw2J+rvmite93t2t5nzLfeFfEWs67dQXtjc2ulrKv2aMwiTLoch9wwVXkdTnrjpWt\n\
p3hDWbcmO7gu53R2YuqPscnqcHqepJ7k+1fQlFeVVySNWPK6j+5Hd/bE07qC/r8T5/1Hwtr88bQ6\n\
db3NtK4yJdrDaw6Z9R/9aqmh+ENV0+3uVi0WWOJ42J8qLymkl4bLDkdc8gjg4xkV9F0UU8ipQhyc\n\
zf3A84qN3cV/XnueGWPg/ULjWZI72yuRZBSy8tjsANxOT3OPequt6HrFpC8UVheX4PAQQnY3IPzd\n\
+3QV77RTWSU1PmU3a1rWRj/ac3JOaul0u/8Ah/xPnHQ/AGqXbfbNbs7rLciIZBx2z3/w+pxXpfgT\n\
Qm03U1kWx+yR4YbVi2546k9T+Neh0VvHK4xqKo5t2d/6/q504nPKtem6XKkmraXCiiivUPECiiig\n\
DjfjDY3WpfDXXbOwgkuLqWJQkUYyzHep4r5E/wCFd+L/APoXtQ/79Gvu2isalFVHds7MPjJUIuKV\n\
z4T/AOFdeL/+he1D/v0aP+Fd+Lv+he1D/v0a+7KKz+qx7nR/ak/5UfEuleEfGtgQv/CP6jJB3QxH\n\
j6V1EPhLxDLGHGi3657NEQRX1lRXPVyynUd72Z0Us9rU1blTXzPlH/hDvEX/AEBr3/v2aP8AhDvE\n\
X/QGvf8Av2a+rqKy/sin/M/wNf8AWKr/ACL8T5WtfCniO3uEkXR73g8/uzyK6QeG9aIB/sy65/6Z\n\
mvoWiplk1N/af4EPP6rd+RfifPf/AAjWtf8AQMuv++K1tM0TUYrdo7iwusNkEeU33SORwPc9K9uo\n\
rCtw/TqpL2jVmnsuhFTO6lSPK4r8T56s/DWtNfxBNNuk/eAhmQgLz1zV/wAS+HdTkmeSLS3vYr6Q\n\
w3MTxEHZng7vTAXr6e9e7UV34nLoYhxcpNWCpnc6nxU09LdTwqx8J3y3xVra9GnWRjit7cocEj7x\n\
z1xz2xnp04qrruga1Nq9y/8AZ13IC3ysIyRjtXv9FLCZbDCttSb9bBTzupTtaC0Vvy1/A+doPC+t\n\
Svg6dcovdmjP/wCs10FroV3aRmODT70KTklomJb0zxXtNFY5jlTx65HVcY9klr6hVzyrU3irerPH\n\
P7M1D/nwu/8Avy3+FH9mah/z4Xf/AH5b/CvY6K8f/U+j/wA/X9yMv7Vl/KvvZ45/Zmof8+F3/wB+\n\
W/wo/szUP+fC7/78t/hXsdFH+p9H/n6/uQf2rL+Vfezxz+zNQ/58Lv8A78t/hUc+jXlxH5c2nXbp\n\
nODC3B9favZ6KuHCdOnJThWkmvJB/a019lfezwG48H6mcm0tLlv9iSMqe3fAHr6dO9amj6dqk2lz\n\
affadertRjG/lnkY+7z35I+hr2qivcWAcqXsq03Lzsk/wNJZ3UnHllFO229zxLS/DV+v2jUdTsLl\n\
5eCIlQnnGCFHYH/J4rIvdE1/ULxpZNLuwzkADyyAo6Aewr6EoqsNl9PDJ8j1HTzupT2gtNFvojwO\n\
z8JX42vd2V2T18pIm/U4/l+dbI0u/ChV065VR0VYCAPoAK9jorzMbkMsbK9au7drJL7r/nciec1K\n\
jvKK/E8c/szUP+fC7/78t/hR/Zmof8+F3/35b/CvY6K4f9T6P/P1/cif7Vl/KvvZ45/Zmof8+F3/\n\
AN+W/wAKP7M1D/nwu/8Avy3+Fex0Uf6n0f8An6/uQf2rL+Vfezxz+zNQ/wCfC7/78t/hR/Zmof8A\n\
Phd/9+W/wr2Oij/U+j/z9f3IP7Vl/KvvZ45/Zmof8+F3/wB+W/woOl3+OdPuiCMEGBiCPQ8V7HRT\n\
/wBUKK/5ev7kH9qy/lX3s+f9Q8K6krb7PTrwp1KmM5HPbI6fmao/8I3rX/QLvP8Av0a+jqK+kw2G\n\
lRpqE5uTXV7/ADOmHEFWKs4J/Nnzj/wjetf9Au8/79Gj/hG9a/6Bd5/36NfR1Fb+zRX+sNX+Rfew\n\
ooorQ+eCiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiig\n\
AooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKAC\n\
iiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKK\n\
KKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooo\n\
oAKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooAKK+fb39oyO1vJ4DoDkxSMmfPHO\n\
Dj0qFf2kUZgq+H3JJwP34/wrH29Pudf1Gv8Ayn0RRXk4+LwwM6U2f+un/wBaj/hby/8AQLb/AL+f\n\
/Wrl/tXC/wA/4M2/snF/yfij1iivJ/8Ahby/9Atv+/lT2vxXSclRppDDnHmjp+XvS/tXC/zfgxPK\n\
sUvsfij1GivOIviUZJoo103l3VeZfUgenvWleeNntYwz2KnJxxLn+n1rJ55glUjS5/ee2jM5ZfXg\n\
0nHV+aO1orgx8QVWzmuZ7Py4o8fMXJHv2+n5gdSKw9R+MdnA6xWdhLczscY5Qdv7wB/Sur+0KF7c\n\
34M1hlOKqfDH8V/mesUV5vB8TDLDI66Y7NHgFVYklurY46Dp9cCnf8LOikCi206WSQrlgWAwR1Hq\n\
ce1RLMsNF2cvwZgsFWey/I9Gorgx8QAYVlNg4RjgHcMe55xwCCPXpxg1DcfEmK3SdprJo2T7qM/z\n\
N82ASP4R05Pr3qf7VwvSd/QuOX4iTUYxu2ehUV5xc/E2OB9n9nSOe5DgAckYP5frSR/FK1MLs9of\n\
NBYCJJATwAec4x94VX9p4b+b8GL6hiLc3LoekUVxWgeORq8MssdntRJDH9/PI61rHxEo6xAf8Crn\n\
qZ9gaUnCc7NeT/yMXQqKTjbY36KwR4hB6Q5/4FUL+JgjEG3PH+1ULiHL3/y8/B/5ESpyjujpKK86\n\
1r4mRaddNbpYmWUY434qunxR3ED+zDk9hJ/9aulZrhXFSUtH5M7Y5VipRUlDR+h6bRXmlx8Ukttq\n\
z6Y6u0qxjbJuGDyW4GcAZ7dqxbf476Rc61/Z0NvsbacNM/lktuAUBcZOcjGM559KqOZ4aSupaejI\n\
/s7Efy/key0V8+eOv2jYfCurrp/9im7kEYaRkm2hWyeBkcjGCCOxrnP+Gsov+hZk/wDAgf4V10qs\n\
asFOGzOarSlRm4TVmj6mor5Z/wCGsov+hZk/8CB/hR/w1lF/0LMn/gQP8K0Mz6mor5Z/4ayi/wCh\n\
Zk/8CB/hR/w1lF/0LMn/AIED/CgD6mor5Z/4ayi/6FmT/wACB/hR/wANZRf9CzJ/4ED/AAoA+pqK\n\
+Wf+Gsov+hZk/wDAgf4Uf8NZRf8AQsyf+BA/woA+pqK+Wf8AhrKL/oWZP/Agf4Uf8NZRf9CzJ/4E\n\
D/CgD6mor5Z/4ayi/wChZk/8CB/hR/w1lF/0LMn/AIED/CgD6mor5Z/4ayi/6FmT/wACB/hR/wAN\n\
ZRf9CzJ/4ED/AAoA+pqK5H4U+Mh498E2fiBbQ2guHkTyS27GxyvX8K66gAooooAKKKKACim+Yn99\n\
fzo8xP76/nRcLDqKb5if31/OjzE/vr+dFwsOopvmJ/fX86PMT++v50XCw6im70/vL+dLvX+8PzpX\n\
QWFopN6/3h+dG9f7w/Oi6CwtFJvX+8v50F1HVh+dO4WFopN6/wB5fzpN6/3l/Oi47MdRSbh6ijcP\n\
UUroQtFJuHqKNw9RRdBYWikLKOrD86N6/wB5fzouh2FopN6/3l/Ok3r/AHl/OncLMdRSbl9R+dG5\n\
fUfnSuhWFopNy+o/Om+bH/fT86LodmPopnmx/wDPRPzo82P/AJ6J+dO4WY+imebH/fT86XzE/vr+\n\
dAWY6ikDqejD86A6now/OldCFoppkQdXX86TzY/+eifnTuOzH0UzzY/+eifmKdvXGdwx9aLhZi0U\n\
m9f7y/nRvX+8v50XCzFopNw9R+dL1oEFFFFABRRRQAUU2RxHG7t0UEn8K8N/4ae8Cf3NV/8AAcf4\n\
0Ae6UV4X/wANPeBP7mq/+A4/xo/4ae8Cf3NV/wDAcf40Ae6UV4X/AMNPeBP7mq/+A4/xo/4ae8Cf\n\
3NV/8Bx/jQB7pRXhf/DT3gT+5qv/AIDj/Gj/AIae8Cf3NV/8Bx/jQB7pRXhf/DT3gT+5qv8A4Dj/\n\
ABo/4ae8Cf3NV/8AAcf40Ae6UV4X/wANPeBP7mq/+A4/xo/4ae8Cf3NV/wDAcf40Ae6UV4X/AMNP\n\
eBP7mq/+A4/xo/4ae8Cf3NV/8Bx/jQB7pRXhf/DT3gT+5qv/AIDj/Gj/AIae8Cf3NV/8Bx/jQB7p\n\
RXhf/DT3gT+5qv8A4Dj/ABo/4ae8Cf3NV/8AAcf40Ae6UV4X/wANPeBP7mq/+A4/xo/4ae8Cf3NV\n\
/wDAcf40Ae6UV4X/AMNPeBP7mq/+A4/xo/4ae8Cf3NV/8Bx/jQB7pRXhf/DT3gT+5qv/AIDj/Gj/\n\
AIae8Cf3NV/8Bx/jQB7pRXhf/DT3gT+5qv8A4Dj/ABo/4ae8Cf3NV/8AAcf40Ae6UV4X/wANPeBP\n\
7mq/+A4/xo/4ae8Cf3NV/wDAcf40Ae6UV4X/AMNPeBP7mq/+A4/xo/4ae8Cf3NV/8Bx/jQB7pRXh\n\
f/DT3gT+5qv/AIDj/Gj/AIae8Cf3NV/8Bx/jQB7pRXhf/DT3gT+5qv8A4Dj/ABo/4ae8Cf3NV/8A\n\
Acf40Ae6UV4X/wANPeBP7mq/+A4/xo/4ae8Cf3NV/wDAcf40Ae6UV4X/AMNPeBP7mq/+A4/xo/4a\n\
e8Cf3NV/8Bx/jQB7pRXhf/DT3gT+5qv/AIDj/Gj/AIae8Cf3NV/8Bx/jQB7pRXi2kftH+CdU1Wy0\n\
+2TU/Pu50gj3W4A3OwUZ56ZNe00Afnrrn/Iav/8ArvJ/6Eaf4ft/tWtWceMjzAx+g5/pTNc/5DV/\n\
/wBd5P8A0I1t+ALffqc85HEUeB9Sf/114eJnyU5SPsaMeaSR3tFFFfMnqhVrTHC3W0/xjA/nVWpr\n\
Jgt3GScZ4/E0Iip8Jv2pIvbUjtMn/oQro9QWO4vtss0ccUKZY5ywzyR+WP5+lc3C2y4hb+64bH05\n\
rW8QxG4a4BYL5B80DGSw2rnHofl9PfgVlRhfGKXVRdvvS/U4KyvUT8mZOu6ra3z2VnZrKY2k2tsV\n\
lMQ5HORycnJ+g9jUNj9iiMpv4jdXESqbTCgMw+bhsdOmTnOAO3SmRX8llcIkMk0F4T5Y81B5TA52\n\
4LcjGFB/HvzVva7STJf+dK8TOHJZVA3AjO0ZzyT3A59M42m3UajLRPz/AK9PmZ1ZuUl7rjp531/q\n\
3n6j5LuGK/upriBAZVJ2REqr5GGb2BXjnruyOhNVNTtbG8t5rIi4leaIm4e0YtJHtYEEEKO556fd\n\
I4INafhi0tL2/CXUUUiPGzqjD7oBHUdDkEYPetWbUbLS76X7JBBEXwH6LnHTjp3rCpivYz9nGOq1\n\
/p/L8NLGN25clJNtJeS8l/XU5u6udixhkeWFVbaxD/Pz1y5POAO/f8tGaQtb+ZK0IMoVQyAPuORu\n\
zkEemcdcc9ABa8VXa6hbWaQKArHezcEE5wFHOepz07VmR3EEdkE86OTy8gRugjXkH7ueeoBPzDgd\n\
cddKPNXjzO6k+t/6/wCB+VwmpRStZq91/wAHpcoQwx3GoRKx3QM/lk7tyqAcY9MDJ4r0G20bT7WB\n\
gLaERgFTuQMT6jn1rgrgC4injhhwHzGm4A5CtwFBzubPJIz7ferqIdft5tJZRI3m2oCSM5+82Oue\n\
/OefaubMIVGouDduu/8AV+nUzxcp13CnF2S6J/5E73tvpsQtbGIRxrnCJwBk55NV11bLfvIuPY5N\n\
cvNrUQY7EeQ/3jxmnRaxbu2HV4/c8iuX6vK12jtjhIxWx3Npch1EkDnH+etTavdTrpMtzaRh7hFI\n\
Cnp9fy5rmtOuhFMrqwMT8Ejp9a6q0GYZPTIrmnFQkpNHl46iqa5rbanmLSqqCe4LNIzfvmJ25ckl\n\
RkjqQRxjt7itT/R7aeXy2SVVPDqQ2zP8Jx9D19OpqpqEAjvZ7C1TzrSNmiADc7GB3DJzz8x//XUW\n\
n3RtNVOm3TSfZZ41aJyqhWjAAUnA7BTyccbfXj35r20f3a1tdL7vz6Lv6nox5vik7q17eX+a7fLo\n\
WIbazuzcS3jnFuXmUiTDAkA8DnPCHscYyMEV4x8X720D2NxawXkF8ki3CzXEIDSg9PnGCAuBwRzu\n\
Jr0Hx1q6qHXSPNFzaSJmKOcqXjA3sG6ptYKcZ5JzjOa5XXPCmp61YajqXie8Vlgt99nFC37pAcbS\n\
x4J+8Bk84GecYPdly9jyyqyvbp20tayWu+t9CakJTjJQ059u3fd9fR3T0skeT+LPEl/4l1OW7v55\n\
HDHKq2ML9McVh16l4N8CReIvBl3cx2kj6jbSOsJikBWcDAOR94YLDkDuKwtJ+HGuX2qS2c0QtFSU\n\
wG4mz5Qk2hgpIBxkEYOMcj1r6SGMw1NSppqKhp/w3c8KvgcVVlGo/ectfTyfby6djiqK2PFmlpou\n\
v3enRyrKbZzE7KSRvXhuoHfNY9dsJqcVOOzPPq03Sm6ct0FFFFUZhRRRQAUUUUAFFFFABRRRQAUU\n\
UUAfev7KH/JEdH/67XP/AKOavX68g/ZQ/wCSI6P/ANdrn/0c1ev0AFFFFABTJ/8AUSf7p/lT6ZP/\n\
AKiT/dP8qT2Gtz5oYksSSc5pM0N94/Wkr4I/RReaM+9FJQMXNGaSloAmsyRdQ8nmRB/48K6muXsV\n\
3XcPs6n/AMeFdRXh5p/EXocOK+JBWdrsojsWQqCJOOfQYPHvnb+vtWjXP+Ipy0yQhyVUZK+hPf8A\n\
EEflWmSUPbYyN+mv3f8ABMqEeaokTeGLFMy6jOgMVvyg6Zft/T8xTJ9XmfU5rqbdLBA/l3MO0lki\n\
IGH/AO+uRjsfxrpoLHyPDkdug+cqrN9SQT/n2rljINQu9Rlm2WemXMCwI0jBXbH3Wx/njFfQ5hXb\n\
ld7L+v8AP7jT6wpKVa+t7fK60XXXV6dkarojwi4s5lntj0ZGzioQzA5BOR0NcpDo2raJNJc6fdpl\n\
AWCqxzKAcYKd/wDDkV0Ok61Y6gY4r+M6fesOFb5Ef3BIx+H86zVVJXT5l+PzX6o9GM4SV6b5l+P3\n\
dfVGrFqd5EMLO5H+18386srrtyMBljI+hz/OmnTF/wCejflSjTI+7ufoQP6VP1qmjmnHCz1lFfcS\n\
/wBvSY5iH5mmNrtwfupGB7g5/nS/2bB/01/77H+FH9m2/wD01/77H+FH1uHmZKjhF9j+vvKNzf3N\n\
wNsszFf7o4H6dar7j6mtYadAD/GfYmoL+40rSlD3ksEJxwrHczfReSaX1qLdoptnVCpBe5Sj8kin\n\
DHLMcRKze/YfjWja2G0hpm3n+6On/wBeuV1L4gW0alNNtHkI4DSnaPwA5/lXPjW9a1+9itBdtF5z\n\
BdsXyKPy5P51UoVpR5pe5Hz3N50K3LzVPcX4npeoa1Yaav8Apl7HGQPubst/3yOa5nUPiHaxgrY2\n\
80zdmkOxf6muN8RaUmmTQKkhm8yJZWYjGSe4rGwD0P51ph8Jh5pScm/wNcJhcHNKUm366fkdDqnj\n\
HWL8Mv2kwRH+CH5f16/rXPMzMxZmJJOSSetIQR2NABOeDXqQpwgrRVj3aUaVKP7uyXlYMn1pVJ65\n\
PtRt9eT6Cr+n2L3U6qeB1PsKyrVoQic2JxsYxcYsSxinmb5N7Htz0rf07TnSVS7GSXPyqDwDXX2d\n\
pZ6TZW0dzEghnjzuAywcEbs56jB9c8dDW1BDp9hZi8IX5hlQF5J9AB3/AJV85Xx8pfCt9j5OtmKX\n\
2X2XmLo0cen6eZbmZFEQw5LdDwcH3OR+YrL0i9tNPjuRIswt5j8shJY4Gcn3x3xnv6ULZP5n9oaz\n\
LiNkyv3d2exOBgZB7duvPSaXXLC7hFo0Ki3wAFI2jA6DjpXDZar4r72OBRlUba96+9tErdu5n67o\n\
731stxbSCSOVeNrYLY6ED1HcV5nqFvc2lw8cvmAg9ya9Zvoktbm1l0aImZ0Z/LznGMLnoT0bH4Dp\n\
VW7sLbWLJRczL9tL4xKvllc4AUcD0/M/hXZhcS6K7x/E7cNjHT+Pb8Vvvv8AeeRuTnJJOa9Y8Fag\n\
2o+FBEzky2waEj1GMr+hA/Cue1fwrbWmm3c7zsZIjtUoNybh/CT6+vpVP4e6qNN1hraZtsN0AmT/\n\
AAuPu/zI/EV61StHF0W4bx1/r5HuTxUMdhrR+KO3nb/gHYbj6mpbdTLcRxliA7Bcjtk4p99b/Z5z\n\
gYRjlfb2qXRVDalED/tfoCf6VUZqUeZHJOaVNzXY6kE4613Ogf8AIItv90/zNcLXc6B/yB7b/dP8\n\
zXrZZ/Gfp/kfD4r4PmaFFFFe8eeFFFFAEN7/AMec/wD1zb+VfljX6nXv/HnP/wBc2/lX5Y0AFFFF\n\
ABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUVuf2VjwV/a++P5tQ+ybf4uI92fpzWHUQqKd7\n\
dHb7jSpTcLX6pP77/wCQUUUVZmFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAdB\n\
8PP+R/8ADP8A2E7b/wBGrX6aV+Zfw8/5H/wz/wBhO2/9GrX6aUAfnrrn/Iav/wDru/8A6Ea7bwNa\n\
+RovmsMNO5b8BwP61xuqQvceIruGMZeS5dR+LGvT7WFba2ihj+5GoUfgK+WzOpaKh3Pt8JG75iWi\n\
iivGO8KWL/Xw/wDXRf8A0IUlT2H/AB+xj6/5/SmtGTJ2VzXlLLGWTO4dMV1euLtENwmQwIXeOo9O\n\
fr+prl87SGP8JB/Ku3tmW6sIXKnZLGrYPoRXm4vEPC16Vborp+j3PNxknFxlbuZN3ZQavo5ICrNA\n\
RIRjhWXncB247d+a5vTrmOGXUNP1GxUzRR+WpUlyzsMhh7njkc9O+K6e036VeBbhgYJdy5BySueC\n\
R64Izx3OK5nVomh1O8e4DtBOyB1VGCSBYwCCwHIDYIPbivYny1Yc1N3i9V+BTaqU3pzNfDv3/wCA\n\
TwxSW8Ud1N5lvbLwtwsuNyKffkk8/UHHQAniNV1aa9u5ZgxUOxPvW7rd7LqmmwQfaPNYOFgwPldC\n\
Ocd+Md+g707TPCYeMNLE8zEcsW2J+B4J/wA8UYeMIJzr79l/X/AO7LcPGMHVqO3TXy/r7zG0TX7z\n\
TblGWVni3AshOa6afW9Mgnnu7hYbtnLPFFkvtZick57YIGOMY/GrQ8JwEcx2gPpl/wDCs++8JxxJ\n\
lEdFH8UL7h+IPP8AKlOOHqSvZx/r5GtbB4avUUlKzXyuVj4vEkCQz2xaCNt6bGIZG7NuzknJzz1q\n\
hqfiJrtYoo4PLgiUKqDjp3NVbzQbmFS8LLOgGflGG/L/AAzWQQQSCMEV2UsFQnH3JX6/M2jl1GnL\n\
njHX+v67l86lJ2RBUsWpKTiVCvuOazAc9aSlVwqho0aSpRR12l35gYENugbqB/Ou2upbq+0WKO3b\n\
FqGDXUiPiQIpB+XPsD/nNeUaZOUm8sn5X/Q16H4QvjFFtY/KrbT7DtXj4ul7KSqJXseVj8O3G63W\n\
pQiexjubaOJj9nDZYSpvJwT0IHGdwx0wP0bd3M50xZJIWiaEsIJIjuIyTkbdobGB0PBxz0Nd/qNg\n\
mo6O0MaojKRtAGAp9R6VxSyMZI42iANsBG0eC6DAOfk6E7VI6c9Kuji417ytqtLdfKz/AA18tTzs\n\
PVTv0aet7efmt9ej7alHTP7PS/lsJ1WMSwhpbkN/rSWUFi3cgZyOg59TWhqGj28VlMloRcXW7zJG\n\
uzu37ST0A69sAc8cZwRm7PP1ySe8snuG3sI/KUKWJ+crICTxyB1x14+UkX5Y3mnlkyfvHGD+vFOv\n\
WqUpQnTlorrpZ/hd+uzsn5HZKhzysnbRP5mX4U0aayjjso7A2sjqQ1z5RBILliuRjgZ4xgcdiDi0\n\
ssHh+fVGu76RrRlW2lcYITcu7dknAIXHJPRe5NaelXn2Scm4lKkDCjqzD0A6nkdB6ZrkPiTDpGqa\n\
frU19PE0bIHs8ysu5/Ruck5Bwp4UdBW+FrzxEuWcPdS333dtP0Xr2I5qqm43urW0XXTdnjHxSttO\n\
g1lnivbi71OZVluHYqyFmUEMrDggg9hxXDVOxmupVQb5GUbUXO4gDsKZJBLEiNJGyq+dpIxnHWvt\n\
8PS9jTjTcrtHy2Lqe3qSqwjZf1u+5HRRRW5yBRRRQAUUUUAFFFFABRRRQAUUUUAfev7KH/JEdH/6\n\
7XP/AKOavX68g/ZQ/wCSI6P/ANdrn/0c1ev0AFFFFABUdycW0p9EP8qkqO5/49pf9w/ypPYa3PmZ\n\
WDjcMfhS1U0p91qQcfKxH61cr4NqzP0SO2olLRRSKCikooAvaQm+9UenP5EV0Vc7ozY1CMf3gR+h\n\
roq8HM3++XoefivjDk9OvauTnm+1agHbJVmGAf7ueB+XFdRcP5cLuCoYKSuWxk44GcjqcD8a5BXC\n\
3Cv/AAhgfwzXtcNUtKlX0X6mmEjfmZ6nKgeJo2yFZSpx6EYrz7xB4bh1WKRrNFt9Vj+8gOElx146\n\
A/5+noYIZQRyCM1yV25S/mdDhllY598mu+pF/FF2aObJ5yjKSj6/pqYXgxb4adJbzskiTMYIopmz\n\
sYHnOemMcd89qwvHk9y+qGKfd5MPyRBjnj1z61d1u5h0fxleySxuYJ0D7EOMFgOfqDk59ea39Ss7\n\
fxDp/wAhRnaATxynh+uCGxweSOQBXntuhWVZrR6/f/lsdsr4bEKtJaS1T7X/AMtmcHpHiTU9JKpB\n\
cF4R/wAspPmXHsO34YrstP8AiBZyKovraWF+7RkMv9DXCXWmzW7lWUn8KqPbup+ZHA+lem4YbEK8\n\
tH5aHuS+qYlXqKz7r/gHrB8a6GFz9pl+nktn+VUbrx5ZgFbKzuJ5MfLuwoP8z+learEx6DHua73w\n\
TZRQ6cJpIz50spVWEZJZcYOCAcYzn3xXFXpYeguZXl87Hm4mOGw8eaEXL1f+Rh6n4x1e+3LE4toj\n\
/DDwcfXr+WK5t2kldncs7nksx5P1Nams6ZNZ3csboQVYjOODWaI3JxtNd9GtTjG9OKR6VDFwhH93\n\
FIsaXDHJfQrOC0e8B8eme1ek2uk2lixls7aRJZyEt5j80YDEDOeoOM+uBzXGeG9NlnuFZUyF5z2z\n\
Xpgsrh/D7wQvIAhUgKAS+OoGa8nMMVzVErniZpiXKSlKXl5HL+O9KU3CC3Ujy1KAE5zznGfxrz2W\n\
MxsQRXsiNaaxZWtsY7hrpkG5hztIA+Yknkc9f68Vyeu+GJxIzRqGcHnHf3qMJivZ/u6hOCxSivZz\n\
0a7nCU9I2fp09a020udHwbc5FWYdKmbG8qg/M16LrxS3PRdZdDNiiAICjc54r0TwppMdlp32y4gM\n\
x5aQofmQY4IHf354rCsNORJFWBC8p4yf88V2t5cro+ki0kj+aWIAuTwAeCMdc4rzMXXdS0I9TzMb\n\
Wk0oR3bM/wAQXsVzNCIEY21ttAJBCqzHqTjjOBjoeoo0G0tHsJ7m7BEf3FKHBLdSx6f5zxjFas19\n\
BpOlWtrcQp55QNJHjcNx5P6k1xvibxHbLavb6ejI8hBkGSVBGeQM9eR+QrnpKVRezpprz+ZyUIVK\n\
sVCCaTe991ff5i+KvEJkEVpbzGbyhhpXGMn8zzXKvqcwP+ucn2rOkkZ2JY7ifWm7jnPH5V71DAKE\n\
bH0uHytxglsdDp3irULJlCTuYwfuntXb+H9ch1t0t7uON8k4AG088k5HOa8nz6j8RW94OnSDW7eS\n\
WZIooyXLMcDGOlc2MwCUHOKs12OPH5dGEHNx1XVf8A9Hu5LGOyubC7O6ES7Y9mGznqMjuMc//Wrm\n\
NW0bRbPTruULNLtICSbiGyenykdOD19KsS+JNNtpYrVoo7r51eSUdA3BwCOoz+HtWxexwXUdzZSB\n\
TbyP5qIGCyjIGcKcDAPA9lyM5FedDnou+qvr6njx9pQabuk9d/S77+Zk+D/EseoxJpmqv/pHSKVv\n\
4x2BP9737/z6S0jaz1SHdyrHap9c8f1rzuXwnc+aGtZkaHcVDOdrIwzlSBk546DNdPpGqXUEsdnf\n\
3MN7JH8ySRZLIVOQH9sZ5x1xnrXp81PmvSe+6PUqzo1PdpS1kndfqu34eR6DXc6B/wAge2/3T/M1\n\
w2McV3Hh11fRrYowYYIyD3DEGvcyz+K/T/I+JxXwfM0aKKK9488KKKKAIb3/AI85/wDrm38q/LGv\n\
1Ovf+POf/rm38q/LGgAooooAKKKKACiiigAooooAKKKKACiiigAooooAKKKltYHubmKCJS0kjBFA\n\
7kmk3ZXY0ruyPQNZsYrX4JaJJ5Lrcz6m8zuem3ayj/0EV51Xv3xg8PNpfws0fcz5iaMFCcBTt4wM\n\
dhkHnrzXgNceBq060HOm7pt/f1OvGK0opO9kl9wUUUV2nGFFFFABRRRQAUUUUAFFFFABRRRQAUUU\n\
UAFFFFABRRRQAUUUUAdB8PP+R/8ADP8A2E7b/wBGrX6aV+Zfw8/5H/wz/wBhO2/9GrX6aUAfDegW\n\
Pn+LNSuXXMcE0mD/ALRY4/TNdlUFtYDT3uYyB5jzvI5HqWP9Knr4bGVfa1W1tsfoFCHJBIKKKK5j\n\
YKu6SuZZG4OAB16f55qjW1YxeTbgEklvmPtQZ1Hsid/uN9K7fTkEenWqDJCxIBn/AHRXEP8Acb6V\n\
3Nl/x5W//XNf5CvGzj4Ier/I87HfDEZqFoLuAoWKsDuVgeh9x3H+eOtZ9hcRJMbe9yCjbVlUkEY4\n\
wT3Hof6dNmsHW7byroTj7kuAf94D69wP/HfeqyLFe88LUej29f8Ag/oc2Hm78tzXTRLRJ2njG2d/\n\
vShE3N9TjNNn0+dSWRlmHXH3W/wP6VQ0nVTBiK5JMPRT/c/+tXSAhgCCCDyCK9ypGVKWp1utUi/e\n\
dznu5BBBHBB4IpQSDkHBrXvrQXC7kwJgMKx6H2P+eKx+RkMCrDgg9jQmmjpp1FUWhm6rYK8bTwKF\n\
dRl1A4YevsR/n35TVdLjvkLKFS47P6+x/wAa74HBzXMXsIt7yaIcKrZX2BGR+hFJSdOXNE9PCVW0\n\
4M85kjaKRkkUq6nBB7U2t/xTahXjulAG75H+vY/l/KsHsK9eVRVaKmdNRElsCbiMD+8K7jw6Di4P\n\
biuU0u3IPnOPZR/Wu30i3a3sxvGHc7iP5V4ePmrWPOxEk9DqrS6uRolw1qnm3KLhV9SOn9K4yBPL\n\
soWaaYksyyxu+wswHzE4Gdw3gj9TXe+HYTFGFccsCxFUNT8LWs91cSxySxPKxcqD8pY9T6/rXm4X\n\
E06TlCWl9b7nzrqwpYhqTsm1/X+Ry8U9pHEyW5lDlsOwJAbkkhhnpySPyz0qeK9hUCNY9kYGABxg\n\
VQ1Ozk06V1ycowDqzZznoQaiRgyhh0Nel7KE/fXU9mnh48vNe9+pNqKpdvd2RtFm86MbGkIUc9Sp\n\
P8Q9OO1cnPpFjqostJvruVrSFXngjGGM2xgcux5IAJA/hIweTXdhGOnd94GR6iqMOhw32vvf3lzC\n\
UKBYliPzxKAOFOByRw2QegFVh8RGi7TlaMfPf+ulra+tzmdoNt7enbTbZ3MTSfCGk2uv3N3Np7wF\n\
roXduygLJE64yoBTbjvge34eOfGO7uX8R/ZbnTobKOONTAqxeWwQ5PIHfcW5r6Q8W6ZINNim0t5g\n\
YUKh9w+RQMjOeMcD8M+1edSeBdP8Wyvr+tX5ef7TILkGb92iInIXaCMBuccAgEDqDXp4HG0JSjio\n\
ptWa7tPtv5dej+ZyVlLE0XTptRu1f+rX7fM+dKK6n4h6UNP8YalbWscYt0IkRIQdsSEBguT1IBAJ\n\
9a5avqqNVVYKpHZq581XoujNwfRtfcFFFFaGQUUUUAFFFFABRRRQAUUUUAfev7KH/JEdH/67XP8A\n\
6OavX68g/ZQ/5Ijo/wD12uf/AEc1ev0AFFFFABUdz/x7S/7h/lUlR3P/AB7S/wC4f5UnsNbnylor\n\
jzblM/Nu3de1atYekuV1GRQMh8/hg1uV8JLc/RVu0LRSUVIxaSiigDT0EKbl8/eC5H8v61u1j6Ai\n\
kyyfxgBfwP8A+qtivncwleu/kebiHeoypqrbbCbnDYG05xyCD/IGuSrpfEEgWzEZByx3A4444P8A\n\
6FXNV9dw9T5MJzd23+n6HXg42g33PStBuRdaNbyZG4Jsb6jiscxfatSlGMKZGZvpmofA95/r7N26\n\
/vEB/X+lUfEF3f2t61pYz29r5xbbJKDlzuI4PQcdjzz71WMTpyaWhzYaHsK1Vbdfl8rnMfEZ1n8T\n\
MIiGaOFEfHZuT/Iiuh8JQyxaFb78eesqtbo2c8tyeOdpGc9uKqWq2GkSrZXN1G1+7b7kzDcjN15Y\n\
8jH696pa/wCJ4pI3TTlxM7cyhMFFAACqeoHB/M15s3OvGNOC0XX+uj/I6KtSWKUaVOL5VbVrprr8\n\
9fkdpOI3uvLWTThLIuHkClWTPUrzyQM46dfao2jL6ytlOkWxwzb0TCyZXAJz9egPXPpXlcOqXEUg\n\
YM5Oc8nNdZb+KdOvHiOo2rM6xiIgn5QASTgD1z3/AMa56mCqU+l15I56mBqU7ON3v8u3X+vXU17r\n\
wpbQXAM0tuiEjg/e5OK1p5rTTrvTooJIysTHey84yQMDt03ZHXj88pdX0R4dkUK3EhbduOcgZ4xn\n\
pxxxWzo+q6eUaOC2EZIwwIyxH16muWbmled3b5HNU9vKN5pvy0X+bIrzS7bWJTJayqScnnhgM9wa\n\
o2vhG2meVjtfy5DGflwCRjP8/wBKvW/h/dPNcWF0Y1lJJCZQpzkKAD06enSqOpwXukoXed/IfALR\n\
SMDn1bnP49+/FKDv7lOYoVpuXsqdTXomtf69C8bm10a7FvEkUkSJ86xEbgeOvvxgDjrU83iiziXC\n\
RTleoO3qfp19evpWBbiNra4mZmmliUvsdmO4dQSM4OM4564z3rlfDvjnw/4o1CGx09pbe9ljkYRu\n\
h4IxhVAzzjcePTp2HTHA+1jzpOVt7ETpUXJRr3fz3fodVpWpvZXgnVCUkJDRYHC5BOPcfjnn61u3\n\
WuWEltP8rxXO0iJZFG4k9CMZ4z69PSuA1vxhoWlG9UXSzXNtG0ywuyKSMHHqGfr3GCOmeKg8D+II\n\
vE3hwXcslvb3O6UkMQDtU8MQOF4IGeAT9K1ngJzj7aUGrff32/p2NaioVKnM3Z+uunlrtt0fqek2\n\
Vqmq2DXNysRLnCKijC4JB985HrVGTRoVcg25z7E4qv4f1r7B+6nRXgmcNvDc/NgA4HGOnfpyM119\n\
xdwWsDTSbQgGc5yT7Adz7V5lX2lKdls9rHPUrVcLPls2m9LGbpGmRwPuMaxnGQO596qWxtLrxLcb\n\
1ikgkXMZJyHYKB9CevT0J7ZrPW2vNdm+1u/7hXZCJRgKvsMDIGSPfOO3GkbbSlt0gw0ZBBM4wHYg\n\
55PpknjpVNKDfNLV6adAmpOTbbbtbTp1+Zynj6SWC7YgkGX5QfQCuAmbMh9F6V6rrNiNTtWhu3zs\n\
b9xcKN2STj5sHjORj+dedabo82paz9ggZSd53SDoFB5avay2UVG0umr9D38rqQmlGWlt/T+vmQaP\n\
pF7q8/lWMJkI+8x4Vfqa7Ow+Hibc6hfNu/uwL0/E/wCFdppthb6bZx2tnGEiQfix9T6mp5ZFiQs5\n\
AUdzTrZhVqO1PRfidGIzarUlajovxOch8EaHGBvhnlPq8pH8sVLJ4X8PQjEloiH3lfP5ZzVq61B5\n\
MrBmNPX+I/4VRohTrS1nNr5mcZ4iWs6j+8zNR8G6Vcr/AMS29a3lxwsh3L+ZGf1rmNX8P61psnmX\n\
EckyDpNCS+B29xXdVZtLyS3OPvR91J/l6VvepBaPm8n/AJm0as4qztJee/3r9TldOmutT8L3W+c/\n\
aERlVguWcDaQC3X1wPc+lbOg2NvaaHZi0QNc3saySydWYn+HPoDxj2pdWtFj1O31LToy0coMV3BG\n\
mdwwcEqPyJ+laGiWUek6ZBcXpRIoVyFU5BYkthfUAnr3PPSsKUbytFaN3t+j9Hqef7T2PN2eqXnr\n\
7v369ups+I9UGnWbMhH2iXIjGM/U/hXcfDf/AJEvTsnJ/ecn/ro1eG6tfyalevPJkA8Iufuj0r3X\n\
4eRmLwdpqtjO1z9Muxx9ea+qy+EaV4vdo8HM8OsPhIp/E3r9zOiooor0z50KKKKAIb3/AI85/wDr\n\
m38q/LGv1Ovf+POf/rm38q/LGgAooooAKKKKACiiigAooooAKKKKACiiigAooooAK7j4SaMmqeKI\n\
ZJtvlWxEhDd8cnsR7fiK4hQWYKoyScAV9EfCHw+2kaZuu4bu3ncBp0mUAZPIK98EbfxU15mbYh0M\n\
NLl3eiO7L6HtquuyNj4u3cupeBr2PypHkDhsKCcAhhnA7dK+Xq+qfH9gb7Q/KtlEjSNtCifyST1H\n\
zdO3evliRSkjIeqkiuDhqKhh5QStZnTnEIxqpx2G0UUV9EeQFFFFABRRRQAUUUUAFFFFABRRRQAU\n\
UUUAFFFFABRRRQAUUUUAdB8PP+R/8M/9hO2/9GrX6aV+Zfw8/wCR/wDDP/YTtv8A0atfppQB8ral\n\
/wAhG6/66t/Oq1WdS/5CN1/11b+dVq/Ppbs/RI/Cgoop0MbTSBE6nqfSkNtJXZNYwmW4U4+RDkmt\n\
mo4IlhiCL+J9TUlJmO7uxH+430rt9OYPp9q69GiQj8hXEMcDO0tjsO9d5BGsMMcSDCooUD2AxXi5\n\
w/dgvU4Mc9IokrP1qLzLIkKpZCGXd29f0zWhVe/bbZze6MB+RrzMDNwxNOS11X5nBBtSTRzFa+h6\n\
h5Li3mY+WxwhP8J/wP8AnvWRRX6NOCmuVnpyXMrHd1marCFdZlHDfK+PXsf6fgKdol2bm1w5zJH8\n\
pPr6H/PpVy6j862kjABJX5c+vUfrivKadOdmZ05ckzCrA1r/AJCLf7i/yrfBDAEHIPIrntXcPqM2\n\
Oi7V/IDP65pzPawi/efI57xPj+yhnGfNXH5NWX4f0aXVJfkKBVOBuONx9Kn8U3QaSO1U/c+d/qeg\n\
/L+davhv5PCt3KyoQsoKbzgFsjI98gdK6JydLDqOzky8xryo0bw3/wAzZ0zQIYtSjtbmdTdkEiNV\n\
JVcDOCegOMnHtXUwaWsLglGdx6iuWW2uYnjuLWeJriLLH95ucLgdVxyOOmBjJHpV241fXkjiaKW2\n\
2Eg8RkufmxtK5+vT07Z48nEYOtOXuu9lr/wPL8T5urWrSfxJ3+X9f8OdraReSheTAY/oKa7b5M9j\n\
VDTtUt9Rtlmik5PVGIJU+lN1DVLezjPzB5McIDXj+ym52a1PHq0cRXq8nLbU5XxuwbUFiTG9kUt7\n\
Y/yKybVMNtJkULGWyEB3c4G3PfP86Se6W7vjeXjRlWdgu/HIIxgH6Z7Z+lNvsJpaKzSyX32j7OEB\n\
BfBJztY5xkZ6n+E9QDn6KnFwpxprV9fuZ9O3KnBUJaJW1X4/5Gk93mFWO0xkkK6nKnHpx9D9CKjs\n\
fL8/zJpkhjJADvnGcgdfxFadlZxz2MayXlvIofbHtAjGDjHy8clix4z1xWRrKXsl7NplhJFGsToS\n\
zOVHYnIwcjkcj0PbryRw7q15UrNJeu3ldd9OxKxMXH2cd+vkjRh1uLUbK6s5YYVCNtdJJNvmL6An\n\
HI47g9+xWqFnJALiTT0eMxyCQQRBdpePnccADscnvzn1rkND8TWVpe3On6hYw27aenm3cnnI5lLA\n\
sCpAwSRjIJ747YrE1vxvB4T8T29xZubqxvLNmkuFKyPvO4BVKsQOiZ54xkAcV7uHpQow9jhoay1t\n\
+OnqvP8A4GcYQoqU5O2urfrb133O61zwxFaeDL7T9Ne0nv7jcrRNENyJIwODznOR19QOOK+evHvg\n\
6bwvq9xaxs89vBsUzsm0MzLuGB9D+hrevPifLAdeh0q3Kw35VoJ3bM0JwMnPfPPuM5zmsvVviRq+\n\
qiCPUNlxBCkaJHJyAFUgnPUk5PJ5r0cvw2Lw83K1ovdN6/0tv6Rx4qvga9P2dWeqvZpf8NocPRTn\n\
ILsVG0E5A9KbXvnzIUUUUAFFFFABRRRQAUUUUAfev7KH/JEdH/67XP8A6OavX68g/ZQ/5Ijo/wD1\n\
2uf/AEc1ev0AFFFFABUdz/x7S/7h/lUlR3P/AB7S/wC4f5UnsNbnyLYuU1NdqlssVwPT1ro65m2Y\n\
LqKE9BJXTV8LPc/RX8T+QlFLSVAxaKKKAN3QlX7K7AEMWwT6/wCc1pVW01ClnGGxu5zj/PpVmvl8\n\
RLnqyl5nlVHebZi+JJQY4ovlyp3j154/L5awa2PEvNxAcY+Qr9cMT/Wsevv8ohyYKmrdPzuelhUl\n\
SVi3pV0bLUIJ8kBGG7Hcd/0rrvElpHPGC48y1mKtweQw6FT24H44NcNXoPh6RdR0COOXJKZibnnj\n\
ofyxWmNp8yUjnxcvYzjX6bP0Zy1l4b0ma9knvpbieWRi+2Vgq5PuOv6VrXPhTRZ4yhsUi7boiVYU\n\
28tpLWYxyDPcMOhFWLC9MZEcxynQMf4f/rV41aFRe9CT06HXKdRxU6M3by/4B534r8KT6KPtELme\n\
yJxvIwyHsG/xrmQxHc175cQRXVvJBOoeGRSrqe4NeIa1YPpeqXNnIcmJ8A+o6g/iMV2YHEuvF06m\n\
6/E9fL8X9bi6dXVr8UMhnIYAnDDowrptG1BmdSTiaPnP94VyA6CtLSpGFxCR13bfwrDFUU00cOJo\n\
qLa7HtGjMx3Op+UgEVS8bhmitlLbYGLbxjOWwMA+2M/pSxaj/ZVhaF40eJ485BwykcH69Rj8a5/V\n\
LyfUbkPIzlc/LCCuF9OuDn39fSvAoUZe1VR7I+apUpTxKq2so31/Ailhjm0e/iunWGMw/LKucJk4\n\
HOQQfmPOa+V9dgXw54muoNH1Jp/szNGtzFlD0IYD8yK97+KWq6xpHh8y6bZQS2TJ+/lnbcfmUqfl\n\
PB6kZ7Y7Zyfmmvs8goS9nKpJ3Uumj+/+up5+bVbSStrvft6ev4eorszsWdizHkknJNPhnlh3eVI6\n\
hhhgGIDD0PtUVFfRWT0PFTadz6e8A66/ivwot9cJDDJE4t2WNQiLtUbQMc5xk/oK6jS7abULuCJZ\n\
m2DJBkywAAOCAen6V4b8KfH+neHdNbRtQt5EhupvMkuR8wVuAMr/AHcZzjk5/P33wzeJaahHPhTB\n\
dKAHweVJyrAnHHH+TXwmZ4ephqk+WNovWP8AX36H1OFxbqYZxi7zSNef7RommXMbtDJCxJjKkhgx\n\
65X6knr/ADrzjWtXfeyLIS+fmbP6Cu/8ZOsmn3DW0qyGJRuCnO084z+X6V4/cZ805riy+kql5zWp\n\
6WWU1OHO93v0LtprF3Zy+bbSspHXJyD+Fd78NrAxabPqMo/e3T4U/wCyp/qc/lXmIBdwqgnnAA7m\n\
vcbWNNL0q3h6rBGsf1OP6nNeljIKlBRitZfp/wAE9XG0lQpJRXvT/Ja2J7m4S3TL5JPQDqaxpZZb\n\
qUZBZjwqKOnsBS/vb25AHLtwB2A/wrpNPsY7SPgbpCPmb/PaooYdQV3ueVVrU8HG71kzJt9FmcAz\n\
MsQPb7x/w/Wr0ejWyj5jI592x/LFadFdXKeTUzGvN/Fb0KH9k2f/ADyP/fbf40n9kWn9xv8Avs/4\n\
1oVl6xrVtpiEMfMnPSNTz+PpTjDmdkiKeIxNSXLCTbHXEWnaZAZ5Y0UL0LZYk+2e9cRreqy6pc73\n\
+WJfuJnp7/WoNSv59QuDLcPn+6o6KPQVDbwvPKscalmPYV6FKjGiuaX/AAx7eHwzpfvK0ry8+ho6\n\
FZCZzNKoaNDgBhkMfT09z+HHNe5eCf8AkWbP6yf+htXldtEILeOIdEXH17n9c16p4J/5Fiz+sn/o\n\
bV5mTY543M5y+yotL0utfmeHnFR1IXff/M3KKKK+yPnQooooAhvf+POf/rm38q/LGv1Ovf8Ajzn/\n\
AOubfyr8saACiiigAooooAKKKKACiiigAooooAKKKKACiitDQdMk1fVILOHG5zzkgcd8epx2pNqK\n\
uxxi5NRRt+AtDj1LVIZNStrl9MLbHki/hbjGT2619AWiW+nQLAGI2jbuc5Z1XIUt74xWV4O8M6r4\n\
ds/7ClMDs8gkik8ohjntnjjAHPOCpz7+n2/g+3SHM8iPcsPmLDIz7e1fHZtmNNzSm9OlvzPpsv8A\n\
YYOKnV0b9Pn8kcD4hEU2hXCSWYv4iVJgDY3jPQH15r5o1+HyNXukFq9mu8lYH6oOwNfUfjLSZbC3\n\
mhgma0yjMGUA7SMcjJ9/0r53+ImmXen6yft939qmfOX2BcDqAffBr0ckqRafK9/69DnzmCm1Vhqm\n\
l2OUooor6E8AKKKKACiiigAooooAKKKKACiiigAooooAKKKKACiiigAooooA6D4ef8j/AOGf+wnb\n\
f+jVr9NK/Mv4ef8AI/8Ahn/sJ23/AKNWv00oA+VtS/5CN1/11b+dVqtagrPqVyEUkmVug96mttP4\n\
Vps567f6V+fS3Z+gqolFW1KcEDzsRHjjqTWxbwJAgCjnue5qRFCKFUYApalsh3buwooooGWdMhNx\n\
qVug3YDBmI7Ac8+xAI/Gu2rn/C9qQJbpx975E+mef1AH1Brfr5nM6yqVrLZaf5nk4ufPUsugtUNa\n\
k2WbKG2sxAH55P6A1frn9YnWa52LuxF8p54JODx/L8/xvJ8O62Lj2jq/l/wTKjHmmihRRRX3x6Rq\n\
eHpSl/s5xIpHXuOc/ofzrpx1rjdNYrfwFTg7wK7KvOxitJMwqLU58hRK4JAVXK59ADiuA1zVxbFy\n\
MNcyktjsuTnJ/Ou21q4FtZalcFciNZSR+Yrz+y0y1lKXeoSzyGVDIoEfyu2Pu5HPXA/EeopR5E+a\n\
psvxPXpV4YeDqVOun4XOdVJJpDjLO5yT7+9ekeCdIhntYEuN4MbMyOhwcnjr6VBFHorIoMLLcCRo\n\
zGg2LgE4JPbgZPQ9eOldR4c1HT3haONfs80PDK5wM9Dg9wK48fiqs480YtWZ5uPx6r0muV99jm44\n\
hZ6hdRwTSNaRNtdnPOAc9Rht24HBXrip783UgR5oZJCikq0RPBA6kYGDgfd9TiqKzA67dMkkUkb3\n\
ReIGLIz1PTPOM84zx1qSwMYvb2W0M8Vkoy5PWUliDjuDlQMdOO+a1klyRu3pZvTy6W83r18jJQnH\n\
WS1st15L8f6065rGWCTfAPkI5UdP8/SpPMmmGHCxqeuCSTVprRzH5oUlmJLZOSfTP4YFJBbu0i7h\n\
tGep4p+0i1dHqRqJwu0kxkcey2ilYrKp2nMcXAYjG0EtjOSevsfSore2m1Kae/s3vYvvhXCBlAD9\n\
gT84IByOufQ4rWuZjbuWi2HIIIZQc5GK0tOmQ6ZNDm2hMiHashGC7AgHB5OT+fNYfW4qSSi3drTX\n\
v89t9vuPPk50YOe7el2/8lc86GsX1prOj6VfQoVvWmVhBKXLALuG5AML1HA6fNx1FM8T+PdO0DUZ\n\
1vrlNQJQxoI2JaMqo+SQcEc/nyTzVrWvBkPiGSCW0u/supwSki/jckoiA4GCQPQk88jOepPjnxN8\n\
KW/hxLP7OLqYyRqz3TptSUnJJHJ9RXu4WnGrUVKpJxb6dfvvta2nW2oYuc4QnWpxTt37adN/P0ZH\n\
8SdQ8Oanetf6EbkS3IG6NlCIhXC5wCTyADzzzmuFycYycdcUlFfSUKKowVNNtLufK4rEvEVPaNJe\n\
gUUUVscwUUUUAFFFFABRRRQAUUUUAFFFFAH3r+yh/wAkR0f/AK7XP/o5q9fryD9lD/kiOj/9drn/\n\
ANHNXr9ABRRRQAVHc/8AHtL/ALh/lUlR3P8Ax7S/7h/lSew1ufHcu7zm2HDb+D75rrK5Rv8Aj5/4\n\
H/Wurr4afQ/Rn8XyClpKKzAKcn3hkFhnkDvTataYhe9iAYA5zz3HcflmoqS5IOXZEydk2dJEnlRJ\n\
GOiqF/KnUUtfKHknMa7JuvmTai7MDKjBOQDk+p5x9AKza0Nd41OX/dQ/+OLWfX6XgF/stP8Awr8j\n\
2KKSpqwV13gObi8hJ/uuB+YP9K5Gun8Cf8f1z/1y/qK1xGtNnPj1fDy/rqdbeWqXUJjk4PZh1Brl\n\
rqB7aZo5Rhh37EeorsKo6vaC5tiVGZU5X39RXlNdTysvxjpS9nL4X+Bl6Xc7h5LnkD5T7elcP8Ur\n\
TZqVncqP9dEUP1U/4MPyrpkYxurL95TkGqXxF8ptO024lTdELgblzztK5I/SuaC9jiIzWzv+R9FQ\n\
boYhTit7/l/wDzJVLHCgntXUeF9Hkmu4S6nrnHf61vaVo2i3RE9tIywt9x2PygjqG44Pp61to9jZ\n\
abKLGYm7LLh1yCuGGTkj05x3/GuXE4yVT3YJ3ZxV8w51aKd33X5nQ2UKQ2pNwqDYC24j7o7j9K4G\n\
UF7+eaKJYULFgjYIU884H4dK2L/Xrm6iaHKW+flbb8xYEdcHGB/nNYesXdnoulS6leiSSCFFMjRR\n\
iQx5I+9znI4+mR2zXJhaNWDatdyODDRnRcqlTRy6en4GJ8V9GuNT8BmO3S4SaFJLhoQ5HmkEZJUc\n\
ngE9MDA9a+Xa9A1r4qeIrrVXnsLw20AdiiBB8ylifmznOc8jOOvrXBOzSyO+OSSxAHAr7rKcJVwl\n\
H2dT1+etzwMwrUq0k6bu1fp8xlFFFeqecFfS/wAL7mC78E2hW+N9dIo89Hbc0R6BPpjbj0JI718/\n\
+F9BvPEerJYWCjeRvd2+7Gg6sfYV9PaBo1l4b002lrYQW905jFy0WX3uAMgdT/Ccj1PQV4Ge1qfs\n\
1Sv71z2Mpp1Of2kVodpDp1u2gh4wJHlQh3BPHPIx7Hj8K851Xw7deey28LOc8BR/L2rv9Lk1OG1g\n\
so1SKKQMscrxEEcE88kZ6kZHPv1pZJpRb7Lm4hmZMkpGMHPZgeNxHBxgfmBXx1KpUozbTTu/6/y3\n\
PYoV6lGUlGz1739Nl8tzy3w3ZtN4nsraQFWE4LA9flOSP0NepavLvnEfZBn8T/kVyPhbTZrXxuy3\n\
bB5UiecMDncDxn9TXTXnF5OPR2H617U6irVYy7R/M9+tXWInCa6R/P8A4Y2fD0G2J5mHLHaPp/8A\n\
r/lWvVLRsf2bDj3/APQjV2tktD5LGTc68m+9vuCgkAEk4A70jEKpZiAoGST2rhvEmum9Zra0YrbA\n\
/M3/AD0/+tWtOm6jsicNhp4iXLHbqzQ13xME3Qacct0M3YfT/GuQkdpHZ5GLOxySTkmm0V6VOnGm\n\
rI+koYeFCNoIK6Pw/bmKB5T1kGB9Aef1H6e9ZWk2oubxBIMxj5mHqB/+sD8a6pQFUKoAAGAB0FfO\n\
8Q4/2cPq0N5b+nb5/kYYur/y7QV6h4J/5Fiz+sn/AKG1eX16h4J/5Fiz+sn/AKG1c3CX++S/wv8A\n\
NHgZn/CXr/mblFFFfoh4IUUUUAQ3v/HnP/1zb+VfljX6nXv/AB5z/wDXNv5V+WNABRRRQAUUUUAF\n\
FFFABRRRQAUUUUAFFFSW8YlmRHkWNWOC7dBQ3bUaV3ZDY1DOqlgoJwWPQV7x4T+G2m/2Ba6ibvbq\n\
VvG0qzQuSrAklXAwDwMHr+Xd3hD4b6RNosNvqgjui8yTC5t8/c252kkgEY646AdfT0vwL4Us7YXD\n\
M1x9ltXKRK0gIDHO5RjnABA9Ov4fNZnmsFFqDa5Xr5+X+fkevQwjoxdSflbS/wDX9dDf8G6Ei21n\n\
qFzcSTzeVmMlyVUN3Ge5B+nJrqvLjPCsM/Wuaa/EEKW1opEMQ2ruJPA/nTrfUQWAmXb/ALQr4bEO\n\
pXm5yfp6dDolgJVFzTX/AACr8RdNjvdBkEx2lAU68FWG0g+3Ofwr5l+IvhK103SrbU4LiMyzoCYB\n\
PvK7TtY88nJPGM8Dk+v1brNh/bWmeSZ5IpImEiOhxk88H2r5t8QfD+KfTftkFzcSC0DrJagmSZiT\n\
kALj1bk+nbivo+H8QqcVGU7We1u+y+bMPZ/uXSau1+XT7jxuinOpRyrDDA4INNr7s8YKKKKACiii\n\
gAooooAKKKKACiiigAooooAKKKKACiiigAooooA6D4ef8j/4Z/7Cdt/6NWv00r8y/h5/yP8A4Z/7\n\
Cdt/6NWv00oA+db5Qt/c4AGZG6D3qCrGof8AH/c/9dG/nVevzx7n3sNIoKKKKCgqxYWcl9ciKPIX\n\
q7f3R/n/AD1osrOa9m8uFeB95jwF+v8Ah/8ArHWadZRWUGyPlj958csf8PavOx2OjQi4wfvfkcuI\n\
xCprljuWIkWKJI0GEQBQOvAp1LVS/vFtIwdu9z91Qcfn6D35r56lSqV5qFNXbPKScnZDNWumtrb9\n\
1/rXO1Txx6nn0/HnFc9+JPuTk06SR5ZWllYNI3UgYH0A7D/PXmm197luAjgqXLvJ7v8AT0X/AAT0\n\
aVP2asFFFFegamjoMZfUUI6IpY/lj+ZFdVkDk9ByayPD1qYrczOMNJ09h/8AX/wq7qUgSzcdTJ+7\n\
A+vX9M15uJlz1LLoYNc87I5nWcSaVOkoOJ8Iw+pyf5GuI0ITR299YuXLLKgjA6KxJBOCOhHH4j61\n\
2+t/8g8+zr/WvPvEqtb3sNzC5jd1wSpwcj/62Pyp005twW71Xqj2vYe3wzpp2d7/AHWOvvLK50aK\n\
1uQw8liQY1cARkYKgsx6YGP05zyi6fDfyXUcc0Xm+VvjXHMRz0Izg46dfwxnOb4Num1OQWt8guYG\n\
4ZJBnDdAR6HmtjWLSDR76OKzmkc7XMgc7iu4569j/LFckK7jP2VTWWr/AK/4O+h4k6U6dT2V/etv\n\
39f61KKQeSkcp3xtnMTJgqSOuME5+hrSSNpr27iI8sbW81owDvJADMo/hJ2nufunI6YhsBtilERf\n\
gh5MODHjA5y2QO5PU59e1OG8vBq90ySSyzlmGDGrBVbklV3ZOCADwcYx2xVU1J8zjJPot97f8Nf/\n\
ACN0pVXJ7NL06rftbX8yaGWYKI1R1OcZAzii5R0dlcyyMqt80kWF+XOSSPmUfKeQPwPFJcX17HdW\n\
k5DFZsrhY1ZlBVVBUgDJznpwcL0BGc/W9T1CK3XUhDBNb2sTSPE0haR8o+2PpnJwp9eTnnNTRoOn\n\
8Sv8n6Pfo9l1v2NXTcpJytbyfVX/ACsdBJpSyW8V1GFWIwiRwpO0nHrzgH9KwL/XUSUTaxJ9is7g\n\
vAGUhgvRt2QeFO3b257c8VfDWrtq+jJrC3klpDcF0jhdQDF8+AMg8jsFPTIPpXN/EXxRfaNFc6TZ\n\
WMeoyPE001wQXESnchJOOvOc5IyT/smunC4XkqO0vectNlZJ9en+ZnGLj79TVLa1+vy32LGveOtP\n\
0a5Zrm7kutM1G0JSe1IZiwcjaeeCRuyxyeTjqa8R8c6zHq2qsbG8vJtPUn7PFcuWMKZO1BkngCsb\n\
Ube6tJRDeK6HAdVJ4wRkEfgap19Vg8vp0H7RPmff+v0Z8/jcyqVYug48q09dPu08mFFFFeieSFFF\n\
FABRRRQAUUUUAdFonhmbWtNe4sWLSxk+YjDAVQMl8+gFYlzazWwUzRsqvnaxHDY9K9F+BN7e2/id\n\
4NP+xq0qBZGuDyY9w3Ko7k1654p8PaPrKQ+JtcktZ9GWNbWKMEpsLOVLAqP72OpPU+wrx8RmUsNi\n\
HTlG8bX03PoaWW0cThYVIvlltvo3f/LsfK9FegH4Z6rKrXgktUsTJJmTcdqIvQ5x3AOB145xXBGM\n\
mYxx5Y7tq4716NHE0q9/ZyvY8evhKtC3tFa+3mMoqa4tprdsTxshyRyOpHWoa3Tuc8ouLtJWZ96/\n\
sof8kR0f/rtc/wDo5q9fryD9lD/kiOj/APXa5/8ARzV6/QIKKKKACo7n/j2l/wBw/wAqkqO5/wCP\n\
aX/cP8qT2Gtz47kDNMwQ4YscH3zXWVzdqu7UkGM/vDXSV8NN9D9Fb963oLRSUtZjErW0BMySvlcA\n\
YxjkH1/nWTXQ6Km2yDcHcSQQO3/681w5jPlotdzDEytAv0o60lFfPHnHL69/yFJP91P/AEBaz6v6\n\
3/yEpj/uj/x1aoV+m4D/AHWn/hX5I9il8EfQK7HwHCRDdzkcMyoD9OT/ADFcdXpXh+0+xaTbxMMO\n\
Rvb6nmqxUrQt3OLNKnLR5e5o0UUV5x86cjfx+VeTIAFAYkAdh2/Ssfx5k+ErY9xOP5NW1qLGW/mw\n\
MndtGO+OKyfiV+68OW0eR/r1XjvhG/wrnb/e015n2eGbdSknv/wDB8Ma/aWOnx27RSGTzN7gkeW/\n\
pkdeK9B0PUIb6fz/ACIjI3BcKNw/H0rw9SVAIPevRvh3NctBci2CGbAEfmZK+/6ZrizPCRjzTi/6\n\
ZyZrgaUOeSV/n/X9I3vGg/0u0wEDKCysfvH2H6Vxvj/UItN+HOpNcCXyJt0BWJsMGYBRwfoc49e+\n\
eOhvHub26le5LPJAxRwMbU5wdoGf554+tMuTayxxrNbmRQhGyQ5ReCME4IfBZiMjg89DgZYb9zyS\n\
lqo/i+y+Tvfb8jzoQ5aUaG7Xz72/M+OJbeaKOOSSKREkXcjMpAYZxkevIr1T4EeGLm91+a6vLISW\n\
L2zReXOjbZd/TkdBwTkemK9nl07R73Tmsr+zQ2piaIDyx8iemANygMCeG6nknJNOYwWdvHaW3lJF\n\
Gqwpxjeq9PoOeAPxyTmvfxWd+2ouFOOr9f6/z8unHh8r9lW5k22vL8f+Bv8AmeZa98GrSWf7Tpt9\n\
Hb2hZ/MXeW8vhcBcgE/xE8cD1rC8J/COfUYFuNVuPskaXMkUisQpKJkZGeclhjgHjntz7d5N00b3\n\
KWoa1i++2OFHBx+Hr2p1tBeXtz5VvteXYWDlsDAI7+5Irijm+LjTcXJevb1/4c6JZbQvzO3W/wDX\n\
l/SPGLr4bappPjSW+0cIml2tzHKhjuMHyyc4VjjOAD0r22Jo01W3LOERGjZjGhITAU9h0J/nRNYX\n\
2nQq8sXkh/3YJZTyQeDjPHb8BWxommxywzX18iSpJ8yRtkqvzNkkdOvbnGOtceMx7xEIyqdFbTr0\n\
/q9xxVLDwbhqpX2e7ell26vt+sHjTXDZWYELfLKAVI7j+leU3mozXMn3sDPArrfHzedOmwFY4/lC\n\
5ztBya4VgV3DuOKvLMPDkXdntZZhoqEYpas7j4ZSSXGr3Tyuz7LfaCxzgbh0rqtQTZdvjOG+YZ9+\n\
v65rjfhdMF1q4iP/AC0gJ/Iiu91eLKJIB93g/Q//AF/51vWap4rl6WR0YtKliuVbWRoaBKHsvL4z\n\
GxGPY85/Mn8q0q5zQrjyrry2OFkGPx7f4fjXQTSLDDJK/wB1FLH6AV0x7HzGYUXCu7ddf6+ZzHjP\n\
UyiiwhbBYZlI9Owrjqmu53urqWeT70jFjUNevSgqcbHu4agqFNQXz9QpQMnFJW1oFo3mi4kQhVGU\n\
JGMn1H0/nj3rLF4mGFpSqz6f1Y0q1FTjzM1dPtRZ2yx/xnBfgdcdMjqBz+p71Zoor81rVp16jqTe\n\
rPHbbd2FeoeCf+RYs/rJ/wChtXl9en+B2V/C9kyEMpMnIP8A00avpeEv98l/hf5o83M/4K9f8zdo\n\
oor9DPBCiiigCG9/485/+ubfyr8sa/U69/485/8Arm38q/LGgAooooAKKKKACiiigAoop0aNI4SN\n\
Szk4AUZJoAbRWrb6FqE9rcXAt3EduqvICMEK2cHHpxXf3Pw2EXgNr+0liur6ZlkjIfGIwCdoU87j\n\
kH6A5wcVzVcXSpNKT1bt/XyOiGGqS1tY5Pwz4J1bxBbPc2UcZgRGfJcZ+Ujt1HUc9PWvUZPhfp1/\n\
YaUN81t5MYWQiLl9wLZJzhjuYdOw6Z4Od8K9A1Lw3qN22rRzWgmiUwsWxHKcH5CMEnkjI4xg17HJ\n\
YS2WnQ3LoJUkCPGFJ8sD/aHHbp2/SvAzHMatOryU5Ly/Vf19x6uGw9KFLmqLf8f00M/wTojW9rLa\n\
S3+xbEbY5FQA46LuQjAJG4EcHj8TfudWt9FtJrWGUSbiDkZAHHoSeaivNXSDw5CsamNw7B2PV26l\n\
vc5P55rgrmdp5WdyTk8D0rxeSeJqScvh/wAuvz3Z7GEwntv3lTpsvQ6GTxA0r8zMo9hgVattUnXD\n\
rL5insea5DPsamtbhoJMqcjuvrWk8HFLRHqSoq2h6tp2pXF5o1zFp6sboqFUBgGUZ5xnjIHSvEfG\n\
w8RHS9QCPHbvHKGVEd/N2BsAr/tbuDjjkcCvUPB1xm+DRt8rAH9al8SS2Nvrby2pEkFxhp2WIsC4\n\
yMBxwOxOeKxwNT6tVklG9tfu6N/keBiqCjWcdlJHyRrVhe2F0o1JClxKolIYc8+vvWfXY/EGfT7u\n\
/klgmumvxIxnW4OevRVPoMe3XpxXHV99Qm501JqzPm68OSbSCiiitjEKKKKACiiigAooooAKKKKA\n\
CiiigAooooAKKKKACiiigDoPh5/yP/hn/sJ23/o1a/TSvzL+Hn/I/wDhn/sJ23/o1a/TSgDw+90F\n\
5LiZ4rhTlidrrg9e5H+FUW0O+U/diYdtsmT+oFaE+qXKXki4hMYdsjadx59c4/Snxay3nfvbcLF6\n\
rJlh+GBX5dPCZpTbtaS9V/wD61TxEVpqZ0ehXrEb/JVT/wBNDkfht/rV+10CKNs3MrSn+6o2D8ec\n\
/kRVo6vbYPyTe3A/xqqdYlaRlSBdpOEO8k/iMf1rB4XNK3utW+5fqS54iem34GxFGkSKkSKiDoqj\n\
AFEkiRJvkdUUd2OBWLNeX8gkURmNWPy7IzkDPqc89s8VQmEu4eeZCwyR5hJPP1+g/KrocO1JO9ea\n\
Xpq/v2M44dy3f6mncax8xFtGGXg73yM/8B6/njntWT/EzHJZjuJPUmiivo8LgqOEjy0Y28+r9Wdk\n\
KcYfCFFFWILK5uMGKFyD/ERgfmeK6W0tWU2luV609I003TiSUEQA/wDfXt9KvWOiIhD3TByOdq/d\n\
/H1/z1rZUBVAUAADAA7VyVsSkrQMpVL6IAMDArI1GYTXG1TlY8rn1Pf+WPzq7f3PkRhU/wBa+cf7\n\
I9ayAMDFckF1Zth6f22VdW/5Bs//AAH/ANCFedeLHBltk/iClj9Cf/rV6HrDbdPkH95lX9c/0ry/\n\
xBN52qSjIKx4QY9uv65rqwi/fcz6Ht4TSm2zY8Hl3tL+2tn8u5kTKEDJbA5X2rcuWmsZ4o7+1dZ2\n\
UyJJK4b5iepx97BK/TtjHGd4K0i7Zo7kRuAWyhxjNdf4k12wktG08AXNwcoQcAIynrzzx2wK4KmJ\n\
axNqcbrr5f8ADbng4xJ4lcuvNv5dLmQZ4nZZ445EEWGPOCDkEfNk54yPqSedxzYkiddYsIrO3+zk\n\
wvKCjYI5QgEZHGScjnjGOwGXpDrI37yWNIFAdpXyFYqw4B6Z6Hg+tW4CkNxcXM9sxa1lCxtygJAx\n\
uIxnPPPJ/I86ycotym9FsraWfl116W69CZRjqo6pX/HRdl/XQffX0tzLJuBO11IYN/dOR7dTn8BT\n\
Z1s547OGFjDdLsdQw3CRQG+QgY5bIzxjGO2BT0e3hiUEryM/L0piR28kTxLbrNC773G7aRxjj35/\n\
Qd8Y5MPKVPlUm+RdOnzX6d+xc6aSjKCs11X3af1qcjqHhqz1O4m1ES3ljNLL9pt7aHCEFYzsYgfx\n\
bzkH0HetrRdHtdE0qSzuYp7+W7+ed5AxkdiuD97I/hOAR9Aa2dMvreKBxJFAVbMao2SQvHVTnr39\n\
do9OJtbkSWOztbSPyvNGSyRkKgz1yCABlRnjGcE4OM9sa8J1lhpXtbe6t+V9NNNe712r2zVRWjZX\n\
tf0/r5u55F8QvCz+K9cF9sjs7GG3kLXsrndKUA2hkx8uAVHA5xmvDr+Bba7khSTzFQ4DgYzX1Z4h\n\
8R6XpNjc6fPqRsr6LdcxFSjFpCr8FWByxbjkfiMV8r6qLs30z36SrOzHd5i4Oa+hyapUadOT92Nr\n\
fje39WPMzqNKUI1FH329XvpbrYp0UUV7h84FFFFABRRRQAUUUUAdB4Fu9OsvEtrPrECzWi7twYsA\n\
Dg4Py89fSvpvTdb0yXT7bT9OEklpZWcRd32mNmIBAAJyTnJ6dq+evhRMi+KYLW6s7W5hnV2AuBgK\n\
yqSCG7HI/wA9a+hithDKdS09IVhmZn80yeWAWBCsScdCQQSM9Oa+fx9pYtJ9u6tb0/M+oytL6sk9\n\
Vd+Wvm/yK3iLVYLfTmtDpclxHOA8uwCNYyX8sAngljyMAg4PXnjhNJ+F2jT6Za+bO41BJ83O0FSg\n\
5O0Ank4x6devGK9pSPStSs/MISWNmAIIGTjGCTyecKc59Ko6wujaVHO8RhhldfOO4jERJba3sNwA\n\
49BnIrx6GY0pYl0KfNF+llp+mv497Fe0jVtzw+9bf1+n3/Pfx0SCPWrSKOHa8UXliUSqwdF4T5Rw\n\
p2gE+ua4rwnpS6trNvBJPDFGHDP5jhSVHJxngnAPHevYfGnhm38RXumvotrFeTTYlvbgz9ETtnJ2\n\
53AYxnhcDrWtZ/DuwtptKmsdMlm8kvMVkIJdGHC/KM8Akg9QQMY7exSxscPhVSW6ur6WT17v7vLU\n\
yr4X2uK9vUa5dNO+nl6fp5n0V8F9Fg8P+A7fT7Qy/Z0uJ3j81NjANKzAe/Xr3613Ncx8NYpIPB1h\n\
FLGY2QFdhOdoz0/DpXT17OGbdGDbvote54OJcXWm47XYUUUVuYBUdz/x7S/7h/lUlR3P/HtL/uH+\n\
VJ7DW58i2Efmamozjaxb8q6KsPSE3ahI2SNmfxya3K+Fnufou7YUUtFQMBjIycDvXWQIY4UQ9QOT\n\
6nvXO6WnmXsYzjBz0yD6j8s10teLmk7yjDscOKlqohRRRXlHKc94jH7+Ik9QfT19v6/yxWRWx4kJ\n\
a6i9EjA/NmNY9fpGVO+DpN9v8z1sN/CRp+HLI32qwoRmNDvf6CvSK5/wbY/Z9ONw4/eT8j2UdP8A\n\
H8q6CoxE+adux4OY1va1mlstP8wqrqNyLW1dwRv6L9f881NcTx28Rklbao/M+wrmL26kvrgcY/hR\n\
M9K5pOwYHCOtPml8K/qw7S4d8/mEfKnT6/5/pWH8T8yadYQICXeYkADk4XH9a6+2hEEKoOcdT6n1\n\
rz74iamE16yjiIZrNRIRnjcSDg/gB+dcNGbqYjmj0v8Agme/h5ynX54fZTf4f5s5S106ee4WPy2B\n\
zjBHSvTvDdq+j6RLcrGpZSFw3GAeM/mfyqPw/ra6wwEMcMNwq4Mci5Vge4Ixz0rY8lby8uft0SRL\n\
ZhSIVwQ2c5ye4OOnpjI9eLF4idR8tRWS3R52MxVSouSpG3fXz+W/chTw7NNukurkKZfmYbQTkgcH\n\
nB9c9u3Ws600dTq8dpfnGFPCNkOcZHPYdevp9Kmv/EfluzK5bb1OcKKwLnxpKJJTDDHmQgu4GC2B\n\
gc/hWNGOIley3+ViKVHF8rSa1Xpb+v6sdlP4btWgKwSyecuNrtg4APTjHX1rK8OWkDapcJcxhmCl\n\
UBOVJVsNg/5zjNZel+LncsoG1mBGM8/UZ71sTJby6XBPpCCGS35dujbMc9O4ODzwBntxRarBOnUb\n\
12ZnOniKcZU5ydpaJ9v60Onlmt7MLEqoiKMBVXGB9B0rmbjVNP07Vri8+0LvchUQAdNozn8RnA7j\n\
Pek8YXJitxcRuGilGSynPAHSvKr26eWZmJ+Y/p7UYLB+1Tbe+5eBy+FSHN3Wvn6/M9bXxFa39pNA\n\
ZFHnKU3N0APBP5E1Oitpvk/Z5hPYSHZMDgBM/wAXtzn+vrXjdpeS28gZW+teleF9TNzosyZ2u7CH\n\
2APJ/TNa18G6C93WL/r8DTF4GNCPNHZv/gX9V0J/E+gyT5eDEqOoB29fY15xrGl3Ni+LmFkzxkjg\n\
+9d9Pr+kG4SC3h2rHhVmjchuD1yep+tXbxYpILpJbeS6tl/eCWQZIyoySR1A9Pb6VWGr1MO1dffo\n\
aYfE1sO48y/R/nY8v0LUH0jVre7AJEbfMB/Ep4I/I17TFLBf2aywuJIJVyrDuP8AGvMfEfhmez1G\n\
VbOGQwljtAGcCreh2PiDSYVlgljhgc5eOQ5Cj1K9snjjqa9DE1aOJjGpGVpHpYvE0cVGNTmUZfn/\n\
AF8zqpEe2nIyQynIYfoRWv4iuseHJZB8pmVVAz0zg4/KuSF/rAmX+2IYFh81YQwBDDccbsgngdeR\n\
W14gLR+GLdH4YzFSPoWrqwkueS1T9Dz8QoVnSkmnaVtDkaKKUDJr2z0Czp1qbu6WIMFHUsRnAFdX\n\
DEkMSRR52KMDJyaraRbfZrNQVZZH5cMe/OOO3B/P6Vcr4PO8w+tVvZwfuR/F9/0X/BPKxFV1JabI\n\
KZNKkMZeRsKKZdXMduuXPzYyBXO3d1JcuS547D0rgw2ElXd9l3FSouo/Is6hqDzFkT5Y/wCf1/z+\n\
de0/D0k+DtNJOTtb/wBDavBq95+Hn/Im6Z/uN/6G1fa5BRhRrOMF0/VHHncFDDxS7/odFRRRX1h8\n\
sFFFFAEV2C1rMB1KMP0r4G1L4cWmn+FY9QunuftcSYe3RDudiSVPIGBxjv1H0r78kGY2B6EGvmi9\n\
hSHVLy1tLlniViq7mViuMcYP4g+uM9q8fNMXUoTpxg7Xu36I9LL6VOop8/Sx8xeGPDV54ke6i05W\n\
e5ij81I9pPmAHBAx3GR+tMuvDOpQNqAMBZbGQRTEdmJxx69ufceor6V8IeHJrHTYbXTbFEI3N5iD\n\
C7myTljz1wMdio47l0FgmmXd1F9mMVwX3zKir1x1AGAegA64/Q8VTPXGcuRXStZX18zphlcZqyeq\n\
vf8A4bV/gfMN3oOpWdm13dWkkNuG2h3GAxzggev4VU0+zmv7tLa2UNM+doJAzgZ716D8d7vUbnxc\n\
BfrMkCxjyUkxjoNxGOvI6+1ebAkEEda93D1J1qSm7Jv8P8zy60IU6nKk7Lc2rnwtrNqlw91p88K2\n\
6h5S642gttBPtmph4Uv49esdKuRsnutpBUF9oYZBOPbB47Gvd/CYe/8ABemDURDcRXEYJ4DeaVOO\n\
eOT82AeT1Fbp8Ppr2pWjNbTGa2ZnR5HwsePlxjHT8+CvB5NeLPOpQk1JWSvr6Hqf2bCMFNvT1+b8\n\
jx/T/hcbK31K/wBclzb2PmfukODKQm5OewJBB7ivMoZp7O8EkDPDcRtwV4Kmvr29srvTXKTWZlt0\n\
Vk4z5ZUj+8Oeh5z6d+tcdcfDLSdVhlCQtDPuef7UhLO53dDnAyN3Y9vU1lhs7WrxGqlorbf1rr/w\n\
CquXqUU6D269/nf7v+HL/hn+0dQ8O2sGoxA396n7xHi/1ncH043qfT7w9TW5eaZPpVzbwzxR7fLJ\n\
iAbeoxjOAe/v1qfwzbS6ddaa1/Ksv2eB/klbLKABjnOPTp2Ue9XdW1i31p4hbzmK5gZioQ43AjkD\n\
keg//XivCrV5yrONrxd299+npskehGU6bfLFSitG/wAn8upmrpsuoRO76h8ipjd5ePJUEgYfByT6\n\
ZHAznnFZeueKriW6kSydkgQ7U+Y9B0rTl1G5g0Sa0uoSkLIZvOYndnAAyT1ORt/D6E+fySYOB171\n\
vQpOu71do7f13PRyrB/WZvS/btb+v61LV/qM944a6lMjDt/nvVPzj6LSxW085/cwSyf7qE1M+l6h\n\
GuZLG5UepiNdyqKGkbI+0pZfhaUVGVr+tvwuRrICcU/rVZgyNhlKn0IxT45NowelaxqKWjMMVlqj\n\
Hno6+R0XhLURY6jtkbCSKVDYztJHXFO8W6NNDdQXFxdzywtamGP7Ooy6nhiSQQpXoTjofrWEGKsr\n\
LwQa9M8O2kepaQ4upPK8vLRTk48sd+/TtXnYiUcNVU5L3Xvpr/X9bnx+ZQ9k/rEd1v6f1954BqHw\n\
z8vVdRka7ddNtImkM8q7TMQP4cnvx1PrXmEqGORkbqpwa+mfF5sG046fqtxJc2RkCNcIDjap5cgc\n\
gfKRnpXgnjG00yG9EuiXcc1o7MoQAho8HA3Z65GDnpnNfR5ZiqlVWq7+mn/D+qR8xmGFVJ3j6/f/\n\
AF/Wpz1FFFeweWFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAFFFFABRRRQB0Hw8/5H/wAM/wDYTtv/\n\
AEatfppX5l/Dz/kf/DP/AGE7b/0atfppQB4pfafEbiVor2Dlz8rnBHPtmkTTbcY82+jHQkKP6n/C\n\
uf1TW31HW7jS9Nma2CM26YEB5SD91D/D3568du9CaTUtNEjadFJHcwuI5rYpuQpjhsd+SRnivip1\n\
5J8rdn/X3H3PsVGcacpNN/h2/rp1O8it9LgAO4SsPXLn8hx+lZ+qeIo7SVrSzgk8wEKUj2qQcZwc\n\
8LxzwDx6Vzl9quvi3KxQW0dyu1nSGNiyKw45LEZ/Wqeg2Ygjum1qZ5HkUuYEch1YKSGJH3fT05FY\n\
TqJR55O/lcHTpQg6ikm76Lf/ACNIazeQm0vZ32Wck3lv5bbvL6jlupA4JzwTnAruLG8Zm8mc4k6A\n\
jjd7H3rzPVbxbfQJHWNWunm8syeZuBXYO2eenetrwtqqXWk2sdydrhdgcnrt4wfQ8ZzSV50+dqyv\n\
b9S6dGVek5SWz/r5I7t4IpMeZEj46blB/nUZsrYn/URf98L/AIVVtr9ozsugSB0cDn8R/WtCOWOV\n\
d0bq49Qc1HNOPU4p05Q32Gx28MZzHFGh/wBlQP5VL396KjlnihA82RVz0BPJqbtkJNvQkqvd3S2y\n\
dN0h+6vr9fQVUn1ItxboQP77j+Q/xqgcklmJZj1J6mqjDudNPDt6zFZmd2eRtzt1P9B7UlFL65IA\n\
AySew9a0Osy/EEojtolZgFLGRvYKOv6n8q4rw1BFeyS3MlmbuZZg0ihiAiH+LA5PPYA9K1vFN95l\n\
pdzD7rL5UYb+6eP5Fj+Nc54TnaDW7fY+zcdpOe3f9KtQk6E5o7K9KSwrinZ7nZ2uqXKfaZbfzIIZ\n\
5SgUkYQYUAAk4B4b+vOKZDbRRwJFHNBFNC21jFGTuIB6vwN5zjnHU+uKbp9j/aV6LTSnmjtFmaUZ\n\
YPsX5lySTnPJwO478Vqax4bm0+FLjTpW8qHDGIJuIwcgrj37fWuN1qNN+z0TaV73/G1ux81CpSg0\n\
27N+X5v+vLzpmGFUtpYw6SgsUjmXkDPJbJPRgGB6njmqt1fKbYRKgtlI2yCJtqNjPYdD/MdcHGLd\n\
/BqtxG7Tac3kYIiWNcupz8pwCTkc8cDk89qt6b4YnljE90fLkP3UIztFXPEU6Lc1NJeXr/Wv5HTC\n\
rSa/fS27O/Xb/M5sTo5/1gJ7npmrdlIIpwzMFQfeJOBirmt6JLBHudQw/hkX19DWTYBnWMhunI3H\n\
gjvnr2z+nampQqQ5ovQ9FyhOi5UtUX76SFpGClS3fFMvgo0zeUkeWYCNwjDoNoDEHjA4z0GMk84N\n\
T20ot5le4tQ9rccB0UbgQOF4OAc5AySSTx77NzqNvY+XaWn+kPK4VkCnPGSRj1wpHOOSPWuNQqUq\n\
seVXi92nZW63e3mr76dbo46ladoxjH3r3Xy/LzOZ07RtKu9XspJba1klQlHHljLN1LJu5ByAeOgH\n\
GK8/+L3hbUdSsjetb2UMVpu814G3SzS7guSuB1yPUjBz1r1N7KWZJJyog2kSJuZvkZdu3bgDPTAG\n\
RgGvAvir4j1eG5j0jUpbSa8tJHcXlmxG7cQSGHtgAjjkc19BhqcnjEqGnL36q2un9au9mOvVgqE5\n\
1n7r3S/K/wA/TTc8vdSjFWBDA4IPam0pOTk9aSvrT4kKKKKACiiigApR1p8UTy7vLUsFGWIHQete\n\
iH4ayQaDPql1dwpbfYo7qJw27czYJXjvjP5H0rCtiadC3tHa+x14bBVsTd01t/X6HR+FvCGj+NfC\n\
lle20zWl/ZoYZkBYq/zcAnbjJB7eozXb6dp8LzT6LZmdra1Pm2sMp3rkofuA9QPmwSeMVg/Cuz03\n\
T/B9k+oyJa31wWeMSSfJICWQMQeARlRnjkj8PVNFjtbrRhe24gMxDh5Y08sAdDnGB/D1r5HH4qNO\n\
M5Nt8stPv/K+nXtY+mU/ZxjKSXNJK+lun9dtupnXMiRTSQ2CLFbqxIUcDJ9qqX9laaheWtxfQNsh\n\
AMgUffKkYy3Hy4L5HI6VYkjaC4ydsm5ypCHcQQMngexB/GrdxcJDCu0BtwyK8SlGpGXMt31e/wCJ\n\
u405RjTg727ehzdnoiRIri6aFmLF5IMrtHGzaEIGPUMc4APWuktNWubayjiuHV5Afuou0KAMdB6k\n\
HjJqpbXYjwnlIsfooxVq5SNYdyKACMgKK3xspVU4zSs3f+v6/DQJUk5r2mx7L4Ck87wzbS7g29nb\n\
I92PFdDXL/DSN4/CFqJFKktIcH0LGuor73L/APdaV/5V+R8fiko15pbXYUUUV2HOFR3P/HtL/uH+\n\
VSVHc/8AHtL/ALh/lSew1ufKWioPNuX7hsfhWrVLSV22zEjG5yfrzV6vhJbn6KtdQpKWkqRmxoCf\n\
NK+TwAMY4Pv+lbFUtHTZZLnPzEnB7dv6Vdr5nFz560meXWlzTbCiiiuYzMfxICIISTwWOBn0Azx+\n\
IrGsYDdXkMA6yOFz6ZNbviBA1qHPVOBz6kdse3r/APWh8HRK2qmZyAkEbOSe3b+tff5PUtl8ZX2v\n\
+bO6lU5MPKS6X+/+rHdoiQxKi4WNFwPYCs271iKLKwDzW9eij/H/ADzWa99/bLyLa3MJSM8w7iGH\n\
oTxz9enp61Wktnj/ANY0K/70ij+tYOtG9mzmw2XQWtd3fb+txLm4luZN8zFj2HYfSr2l2xX9845I\n\
+Ue3rVMPp9sBLe39qFHbzBj/AOv9Kwde8dxxhodHjLt089xgD6Dv+NYy56/uUlfzPVVGpVXs6MdP\n\
uR0niPXbbQ7MySlXuGH7qHPLH1PoPevHby6lvbya5uGLSyksx9yaS7uLi8nae5keWVurMas6TYSX\n\
95FBECS55x7V2U6EMHTcpPVnpRo0sDRld3k9/wCux0/geyne7hlQMNzAZ9h1rrr95RY61O0gBM/l\n\
sMAHanGePbj8KiklubHZYWCB8Rrgonzx8fMMjORkDnH8fXgVj+M763stPW2tSr+emTOR87gnJyev\n\
Ud68CXNXqXtva3pvqfMSlLEVotL/AIa9/wDhv8jkdRvjMTziIfdX1rJd2c8/lSyuWbkc+npUZJPU\n\
mvoaOFsux9RQwMnG70JI5GjYFSRivQPBWoS3NneQkAjaN7Hsh+8cdzgY/GuCs7a5u5hDaRSTSH+B\n\
F3V2mh+DdV8pxd3S2UUuN8afMxHocHArmxtGny2lJX/rscuYYNKDUppev+W5R1bxRFcw3kUVhDEs\n\
w2hk4xg5zgcE+9cqiyTNtjVmY/wqMmvU7fwtoWnYNxG11KO0pz/46OB+NakN5bWy7LWySJR02YX+\n\
QqaNaNJWowb82LDVqOGj+5g5N9Xovle7PKbfQtXuADFp9yy/7Sbf54rorGy8S2OkT2VtpjATZ3uW\n\
Xdgjp1ruRqqn70Lj335/pU8d9bv/ABlT6OMVnXr1anx01b+vMxxOJdb46Ktv16eh4xf2N9p+Ptlt\n\
cQ56F1wPz6VY0zXr2zYBZmdApUxy/MpB6jHp7V7M6R3ELI6pNE3DA4ZTXnfi7wb9mV73R1Zogdzw\n\
Dkp7r6j2rSliKNf93Wil/X4G1CvhsSvZVY8rfXp/wP61N3w5qo1Cz3xBYP3o8xIjtDfKcY9DkDkY\n\
4/CuVh1nUNT1eOzszGiSSFIkKgiP/aHfIGTnrUnw+Zlnui5C2pCkuxwobPy5P1NaHhu0jg8Q6tcQ\n\
xvGLZNsauOcs2N38/wA65oUoU6s4tXtt6/0/uPPpUKVPEVIzjey09e33/h2NJ/DdtBIQdQv7i5kw\n\
jqGU7u2DkH+prT8bAx2NlGzAtuYsR0JwMn88/nV3QLYSStO4yEOF+v8A9b+orL8dzBru2hBHyIWP\n\
4n/61engqbU1d3MJ1ObFQpL7Or27eXY5etzQLMHNxKh4x5Z5HIPUc9sY+v0qnpNj9slJc4iTBb1P\n\
oB9cHn/9R6dVCqAqhVHQAYArkz3M/YxeGpv3nv5L/N/kaYqt/wAu4/MWq97dJbRknlj0FF7dJax5\n\
b7x+6K5yeZ55C7nJNfM4PBuu+aXw/mc9Gi56vYSeZ55C8jEk1HS0V9BGKirLY9BJJWQV7z8PP+RN\n\
0z/cb/0Nq8Gr3n4ef8ibpn+43/obV7GTfx36P80eJn38CPr+jOiooor6c+UCiiigBspxE5PTaa+e\n\
9N1W30iOaQvb3Bk2mB1HzAY5yD09Ov5V9BXH/HvL/un+VfFscmcZHX0rwM8w6xChFu2/6H03D+XS\n\
xsasltG1/wAf8j2PQ/E0Mkwh3oqOxJGABknJ/WsifTdWvL29vRCZIVlb5SwUuOxGBkqB+Jxx1xXn\n\
cUjRSBkOGHpXrnhHU55IrZZCWDfKc18liKLwbc4a37nfi8H7D95Rttr/AEjzDxB4J0rxNNPNevcQ\n\
XJQKjE/KmMMQoPGSQyjnvzjvwnhH4dXEfjeWPUrCZ9LgJeKR8AScnaQD97O05HH4V7fr9w8ur3Mk\n\
sZtWOIkDsmWPQZGec59+Kju1tNv7nzfOSBoxIrDYVyN2R1yCc9B056V69DMK6g43smvkvT+ttOxw\n\
yo0p8s2td9r2duvdXe4/w9JaWuu20CRxw27yvIBGgCqxwAq47cA9M9ya6O41yCPUXaAQK/3SeNzY\n\
965u+vbjRNAurXBhcMmzvnKjJBHHbPH/ANYcFHcyrLvDktnnJ61531OWLk5/L1O7D4GOIbqtabf1\n\
07HuWo63bWunJcTAO7A4iGMv/wDWrhbVfNiaAB0RyCFjYhRuyvzdsYbB+uewqql+17pds4LvHAm2\n\
Zd3QlsBSewO4cnI4rc1mWwn0V4dAlijlc7HRTh2JUnB9eB9K56EHhHZLVv7jkjRVFuna15avtY5r\n\
X9Rtre3vLexujOZXADbcFYxnj0/LrXJxl5JFSBGeVjgKuSSfbFanh/QLvX7zybcbIkwZZW6KD/M+\n\
1ep6ZpGleF7QNGgacjmRuXc+3oK9V1I4b3Irmkz6imsLgKSi051Ja2/zscnofg3Vbuz2alcG0tnI\n\
Yxfeb/61dLYeHvDuk4ykMkq9WmO8/lVe/wBUuLskFtkfZFP8/WqFHsatRe/K3kjFQrTTvLkT6R0+\n\
97s7O3u7HaFglhUdlGF/SrgweR0rgKs2l9cWjAxSHb/dPIP4VjPAv7LOWpl/WMvvOpv9KsdQQreW\n\
sMo9WXn8+tefeKPADW8b3Wis0ir8xt25YD/ZPf6V3ul6pFe4Rv3c/wDd9fpWlXLGdShKxnh8dicB\n\
O0X8ns/68j52g+dlToSccn8K7a+eRYvLsw04t4B5NuRgSucZwR1OFzg/pT/iboCWkyataIFjlbZO\n\
o4AY9G/HoayNA1h2cWGoP5tncYRi2Mj059a9N1PaRVZK9t/6/r8TpzWisXCGJor3dW15rdf13OO8\n\
axeI9U0hrfS7VUtJhiaMctnGSWAA2nK8D0PvXkuk6Bd391LEyGJYkd3dhwNozj+lfTTb7YvHM0kI\n\
ul8wJ0bIGzHucEcAEfKOuSKwddh/4Rbw9NaNZXdwJo/LaB1B3qTzkjnqc9e3sK78Nj50V7JRV3a3\n\
6v8Ar9T5mthFiP319F5nzYRg4NJWt4h066sroy3Np9lSdi0cYOQB7e3IrJr6WMlJXR4E4uLswooo\n\
qiQooooAKKKKACiiigAooooAKKKKACiiigAooooA6D4ef8j/AOGf+wnbf+jVr9NK/Mv4ef8AI/8A\n\
hn/sJ23/AKNWv00oA+V9C02aTxY0jgoiXDH/AMerdtLi80zV5ppIA0swYtHIrKX55bGOucc+ldPP\n\
JpdmDdRqPMd2CwpyzPk5H5jH4j1rndfvTqV5FL9mEW1Gx5p2s+Dz9MbT7jrxX5rUrTxNWXMtNd/I\n\
+uqYj6zNXVlbW+m35/L7yO2uJrKZry2aBppomDyMnVs5JAB5I4wOeMdARi14f0tdXkla+XfErNI8\n\
gG0Fzg4A9uv1/Wnc3SyCP7zNgM424ZiM8HjggHHQnj6ESW19d2Ek8NhOqwuTIvnLggeoJwOgPscd\n\
s5pVKUuRuDs9NfP5Xv5f8MKcJcje0nt00X9aaGX47iOIrSFMJCMqT95vqe55rmNHvbm0kaOGJpVb\n\
kx89favSZzaa5dxWNzBPBqAB3ZXCjA6/Sp7rQYdK0a/YRK7tGQC3Y+vUdOvWro472UFRmr3/AKud\n\
lDMY4emoJa9v63OStvFpsmEM0E5UdYnAO0exzkfyrodM8QaZqLgJJ5E/QJMMH8GrGkS2uVjlmsoZ\n\
44I1hLhvnZ+cZx6AAe5PUVQ8VW0lnpkEjRxRtcy+dGIuiJjjDdepz+VdcZ05NRScW/M6IYuniJqD\n\
hZvqn+nU7/a20NvkZT0PmEg/rikVVUkqACeuB1rg/DmsTTRsnmtHcL97Y2N49cfzroo9YuV/1ixS\n\
+7Lg/pinPmpycZI6p4Scfhd/wNuispdaGPntQT/syY/oajfWZipEcMKH1OWNTzmaw1V9DZJCoWYh\n\
UHVicAVianqHn5htyRD/ABMeC/8A9aqVxcTXDbp5GcjpnoPoOgqGR1jjZ3OEUZJ9BUtuR1UcMoPm\n\
lqzB8WTjbBbg88yMMfgP61gQyNFIsiHa6EMCPWpb+5N3dyzHjceB6DsPyquK9qFL2dDlfY6KlmrH\n\
eaP4llQ+c0aF5FCPIB82B0B9a6e31iYhZEZXQ9McV5Vpc2yXyz91+n1rrvD853PA3Qjcv9a+bxmG\n\
iryX9I8Wthacb2iekabqCXEalwMHgn0NXp4ht3KOlcrorHzJV/hwDXT2z7rM7u2RXiVYcruj5zH4\n\
aEb2RBPEtxC8Ug3Kwwa83iWSy1SeFsOUkwobjHPHrxz6dQOo4r0l3WJGdyAqjJNeZ6rLv1B5wMs4\n\
Yke27jp9TXpZbf3l0N8li6lKaqfDv9xoG7nfTJGSXltshUblSIKT/D2GFznjJGOKxtVsLyWylVdQ\n\
NkiNuR4rQBZNpO3lmO4E468cDJ71pvBmGeGO4jS2ZsTFPk81SMbcdgcct168VtRX9rc2r27o7WsK\n\
5GT8w28hs9iOue1enVxH1dKHLdydrJ/jZWi30szujVcY3grpPX0/z7fizgLvw94mfTr2N9XhLBA6\n\
tFEu7zCBlh8x5BLDecYGT0rwLx1o1/o2uSRapP8AaLpgGeUZIJIB69zgivqW1c3RQ6QzxW0hBaTz\n\
GVdmWyeOwUqMcYxj3r58+MNrcRa1bR3GoS39y0YL/cKqeny7OOgFe5lknRxPstLNX2X6EZnH22Fl\n\
KV7xa+V+jV7fdqedUVqWeg6leRl4LWRlEhizj+IKWx+QNbnw/wDBd34svJ47d1i8gZ3MMru/hU+m\n\
Tgfn6V71TEU6cXKUtFufOUsDXqyjBRevfTbfczm8L339gjV1RjZhfnkx8quTgLnpnHNZd/p11p7I\n\
LyF4i4yu4dRX0/4e0m3vvC8umX9tBpM06hbm2jQSiUjqScjDcK3U4z2zWB8R9MtNS1/RIGsUuka4\n\
MVxLEgSTPlr5YOM4XO44/ujtXi0s6bl78fdu9b9lf06flY96vklBq1KTUrLe/dK700X5dTwSz0e9\n\
u1RoYWKOrOGxxhetUXUoxVgQw4IPavriaxstJ8O3FvpEwhiMLm3cQYWESKd3zknHzMMA+w5AyPLf\n\
EPwzs7Dwyl7EJb69a2DlrZt6SNubfJn+FQNvX9M1rQzmEpuNVcu1vn36Lp1MK2RXivYSu9b3027L\n\
c4r4VTTWviiK5WylvbWJSZ4Y4RNlCCMlTx36ngda+hYo9NuNGktEtZ4rN2dpcIoJXaQ44B2J+8YY\n\
4x+deQfCHwxqE1s+t6ZdPFcQvs8h0IjkGdpBft1OOCQRnjGR7dot5ezak8s9qkEKIJLtfNVlMmX+\n\
6MEldxznPcfWuDMqtOWIlNtWirdVdr/LujswSqUcEl89++23fs1v6nC2vw60hbW/ukRgrvIlv5rb\n\
ltuV2sNpPI3ZxzkgHpkV0kd1dwWU1hHJ9nmVggaK5ztVcYbpkAg9MZ49iK659RuNQtbhLKRVkj/e\n\
AN0Yeh5GBzkkc4BxziuWFtElrDcxPvlCt5kTgGOXLgld2CR/F82cgjqD08yjjHiIc09HtZu/a3TR\n\
vv5dzeLVnGpFLXt6PX5X/wCGTFsbKa2uhJfXM0rRndujdNrBgRgBh06H0GWxzTPP+U7lYsSW2DLF\n\
R6fT8qfcBhcmCGNwxO2MnkFCSVwc4Ix6f/WrqNN8NP5CmaQR55wByT6n3rKtWVL3qu/9dr/5FQqU\n\
6EFWrS3OTSdHbaAQ3oRVxbrELy3Md0FCgxLEhY5GQcAdxwR69O4rZ1zw1JHbNc2jCaSIZ2ngkenF\n\
c+k6SW0bPJtG4N5RypIBIzwecE/eHoR0zVUnDER54apfh126/wDDiq4qlWUXCWn9dT3H4X+cPBto\n\
LhWVw8gAZtx27zjJye2OpzXV1y3w0lebwhavISWLydf988fSupr7jCfwIeiPkcX/AB56W1YUUUV0\n\
HOFR3Wfs02Ouw/yqSmT/AOok/wB0/wAqT2Gtz5khQRxhRnAz17U6lb7x+tJXwR+ixVlYKVcbhnOO\n\
+OtJVvTE33sYBAwc89x3H5ZqKkuSDl2FJ8qbOihTy4UQnJUAE+tPoor5Ru+p5IUUUUgKOto0mnMF\n\
HyqwduegAb+pFReEVIttTkT76xqM+3JP8qs6oP8AiXXJHZQMeuWA/rTfAhVjfRNg7lU4Pccg/wA6\n\
+yyWXNl8o9m/0NlNxw8nbZr9DAv9PhtPJF3sS3mUx2t2uQ8L88NjqOSBj07VSh8Hzfblk1W6h8kE\n\
7iGyxH1PSun8TaTcmWzSGEXNvFK0qxs4Xe2PlBJ445zzznjvjltX8MeIry6kuJ44pHY5wkuMfQUl\n\
zxlyxny3/rTt59DupurUd6NXljJd/Ppd6efS5p6d4csLS+AZZLxZHCxy7cxjIOBx1OcDH41yeo6D\n\
e293JH5DjDED0P0rc0+e48O6dcwaxptw8czAjJ+TjpyD3/WtTSPEdvLpUxY/ZlhbIXhmAOSNpI9c\n\
ZyDxn61i6mIpNzu5La+6fnv+Bk3iMPJyd5LRX7+at9z0ONg8PalIRutpQo7kcV2XhTSJNMd72WAy\n\
hV2bSPvljgKPzqS28T6abtXhneGTBU+cplUjI45OQOPWtmCU38Wba7Nw8LrNFEyKoJU5Offrjp/W\n\
ufEV6s1apon6/wBfiY4jEVpRaqRsvn/Xzv59CjqurNo9hBbx7lkRPMkY5B3Mc4+teba3qM+pXzT3\n\
LF2x09B6V2HxDPmXFtPHzFMu7Pv6H3FcA7Z3nuf8a7MtpRdqjWrO/LKMJOMravf5vUaoLEAAkn07\n\
13Ph3wLJcIlxrDNDGeRAvDke57fzq58PPDypEmrXiAyN/wAe6EdB/f8Ar6fnXd1vjMc03TpP1Z35\n\
hmcoydKj03f+RXsLG10+EQ2MEcMfog5P1Peqt9fkEx2557uP5D/GnandbAYYz8x+8R2HpWUK5qFD\n\
m9+Z5lKk5v2lTUPrWlZ6TNOA0h8pO2Rkn8P8at6Lp4ULcTjLHlFPb3+v+fps13JXOLGZk4P2dHfu\n\
ZSaJbgfPJMx9iB/SmyaHEf8AVzSL/vAN/hWvRVcqPNWYYhO/N+RzNxpl1bHfGN4H8Uecj8OtRQ6h\n\
cIRuYSD/AGuT+fWurqjf6bFdZYfu5TzuA6/X1rOdKMt1c7qGZxn7tdfP+v0OC8Qf8S6aLUtOMkNp\n\
LKBewLyuT3x7jI+tIlzLFq9vqUPmXGjzweS2OWjXvn1IPNdDNaG2do76IPbSAxyZGVZT/nPrWHo+\n\
mI939lW0EtvZvOi+byoJcbXYdCNmT6dD3GeeVNKSsv8Ahv8ANdH2PRkotxqw87vo0133urJXvsd3\n\
p6La2A8wqAm4s3bGTz+VcJOX1nWZHBIR264ztQcZ/L/OTWtruqG7EemaexkXhXkH8eO36cmpbC0W\n\
ztxGNpc/fZc4Y846+mf6963xWNWX0bv+JLZfqefSTpOVaXxS28l3H2duttbrEnOOSfU4GT+gp1zM\n\
tvC0j9B0HqakJABJOAK53U7s3ExClgi8YPFfJ0aU8XVcpvfVsdODqy1ILudriYu1Q0UlfQxioJRj\n\
sekkkrIWiikqhi17z8PP+RN0z/cb/wBDavA5HWJC8jBVHUk17x8NJRP4H0qRejI2P++2r2MlX79v\n\
y/VHhZ8/3MV5/odNRRRX0x8qFFFFADZRuicHoQRXyn4s8GXGiobm1Y3NiPvEj5o/r7e9fVk3+qf/\n\
AHTXkOkXa6jZvBcgO4Xa4PIdTXz2eznT9nOO2t/wPquGcbWwTqVKesdLr7zxnRbR7+9hhXaCcsxP\n\
QAcmvTNG1LTNIKRS+azIWBmwNmcnp+Nc7p9na6Xr2rWUcLzXSq6wDkjaw4GByThhmtv7fDp/hS3S\n\
FY52LFZGKD7w6k+p/wD1V83mEvbTs07O3lutzvzCo61X2cfhe3Te7v10t+NyneXU+rTPdmBZbWRg\n\
i7lGF+YHGT3AXOQetD63o1zbHTkWNFiZQJiAGZQecHsc81x2oa/qFyz/AL9kRsgRpwMH2FdF4d8G\n\
otomo6+WSPAKWwOGb03H+la/Vowivau3ZI3hlMY0vaVpcvSNtXf062+4yZ9K1TxDrNz9jjZ4lfZ5\n\
jnCIB0Gfp6V0Nn8NUKA3mosZO6xpwPxNaE147IIoFWC2XhYohtUD8KgXezYXcWPpXS4VWlZ8qR6k\n\
K2Ip0lSpSUEvK7fqxtx4Lu9NtZzpF0twX2loZRt3bTkcg4P0NZq6nNJpX2ZrCMalE7Js2FXLMSBj\n\
nPqa6uztNUOMSvCv/TRyP06/pV4aYzuHubqWR8bTtAXj0zUexnJ+/aXnr/TPHrVKN71pJu97rf0d\n\
tNSnpZt/D+jxW42yXrfPKF7ueuT7dPoBWVdXEt3MZJWJY9uwHoK6iLTbSPpApPqxJP8AhVlY0X7i\n\
Iv8AuqB/KtqVDkbk9W+plHMaNNuUYtt9dv8AM4oRu33UY/QUGNwcFWB9xXcl2PVmP1NAdh0Zh+Nb\n\
2Y/7Z/ufj/wDhKK7WSGKQESRxt/vKDVK40e1l5RWib/ZOR+RpWZvTzelL401+JzCsVYMpIYHII7V\n\
1WjamLxPKlwJ1H/fQ9axr3SJ7fLR/vox3Ucj6iqEUjwyrJGSrqcg1hXoqtG3U65xp4uF4O/mdR4o\n\
s1v/AA9f27DO6FiOO45H6ivComLJnPOM9a99tbldQsGZeGYFWA7GvCtIs/tN15Tt5aqGZieuFyT/\n\
ACrDAtwU4y6F5fJU8JWVTTlaf5pnovgK5kuVjNyiShcBXdQSuPQnoKrfFHWbe3vrezkWJ4Y1LuzF\n\
htB55IBwBgH8RURu2tNNnWzVTYJtZYym5pFUjPA5IJHJzj5l7Zzw3xJ1eHw7pU0SRRzfaUa2E8RG\n\
4Hb8xwc9iAfX+eeHwbniYzfXZf0/XRHzVaUXVeISslft17/1+JxPjrU/Det3EqvK0GoEYWeMmWLa\n\
v3F9uDyR6V5gRgkUrqVYhgQw6g1fbSZxoKarjNu1w1ufYhQc/r+lfb0KMcNBQT02R8/VqSrycram\n\
dRRRXSc4UUUUAFFFFABRRRQAUUUUAFFFFABRRRQAUUUUAdB8PP8Akf8Awz/2E7b/ANGrX6aV+Zfw\n\
8/5H/wAM/wDYTtv/AEatfppQB823rxNf30yttmWYlFjyOc5JJPTHJAzx+HG9ZaB5tjayS3jwiVFa\n\
SNV65HQDoCPWuK1bxXqS313CVRYt7qYivBBJqTTPFU7uFMaxhBwkfAA9hX51isLXV2tNfJ6an208\n\
DiHFX0/HpotVsd+fDOmxWpZVbcoJWctlhj1PtXJWRkfbFgk7SqgZIIJA6c8fd+nA9q6W91qNfD2x\n\
0kZ7xHRGVRtBxjnP1Fc59vttL0u4utQ8mCGGINLKykb1BGVIOd24DA4/vHsQcMEqs7qUndvR9vPd\n\
f1sjkouqlJVPe1srtadycD7bfL9luVhnEYkChTuHHDKOSQcHnHp3OKV9T1CWyNrPMBCTtd5Bzjdg\n\
gt3HWvnrw742hg+JN3qt5eXkel3MjZwN7hM5jzz1HHOfzr6HlSFowUd2RizsBGQG6kE9AM5UbRjk\n\
46g16mNwLoON46aPbVd/u6936lUatGqueO0dF1tbZr16EWnadJeaiLH7QyIu8lnAZZCGA+UAjt78\n\
jP41vFlgLDTriCe6SfIBgVE2iMgkkAdhz61saCbaXxGruB5pgbaQw5lJJY4B789R0x+HPeJ3afUp\n\
A54K4H415cZyddJPRL9TXDpzrXelrPzvd9d+hxcEr28ySxHDKcg12Wm6hFfRAoQso+9H3H09q4t1\n\
MbsjDkHBoRmRw8bFWHQg4Ir6GcYYmKu7SPpozT0Z6BRXJ2+vXcYAkCSj1YYP6VNJ4imK/u4I1Pqx\n\
JrkeBrJ7fiaWXc6R2VELOwVQMkk4AFcvruqi7AgtyfJByx6bz/hVC8v7i7P76QleyjgD8KrYrrw+\n\
DVJ89TcTaWwUvSjpSVdespLliZSlfQdG22RWHY5rsNF/5CUf0P8AKuStozLOij15+ldv4ZtmudQy\n\
B/sj6mvJxrSj8jjxLSWp2WjREQtIRy5wPpVrX9Rk0jTofKWNpZJVQiQkAA9+Pw/OqI8SWdhM1v8A\n\
Zbn91IYnl2DapGenPoCfpWD4k1iDUp4ZrdfNt4Uch2+XLZ5x3HSvGpYeU6qdSPu7nzUqdTF1Ph93\n\
V39Nl/X6hq+rarMZIbqOKLa2Ni59ARk9M89Kyow5LPMcu3H0HpWrJAhikJj3yiLMkhYl87sdTxkj\n\
0yBjI7ZRLFZEVmYKSAWA6Z74r15ezoe5G1n2/r9T1cNVjGHLy2+Q61KGxy4VVTgcAYFS6VHObmZU\n\
iKiSJl2uv3vTg+9R2iWr3BZgTGq7FLLnLctwOvRSfcDr0qbT72eC3kiSWJ7qV5JPMKqrL8xJJXsc\n\
YHI4xnkZxzvDynacLJ3Vr6ddf6RnUnNxkqav/X6WMLxJvtba7v5b2S1ktUYvAwEiyZywU4+YBshe\n\
MZ3EHHSuE+HmjjUPENzqfigxJq8o8w20qqY3jcEH5MYJzg44564yK7xCdX1G43xrJDaTSPa3K7EE\n\
0qjJIwCA3GcnjKg1uTWNxa3KSs8UbRFUDr3iY4ZccjHCj2x04Ge1V4whLlaXNbd620vby769kbTm\n\
qbiqstUr+V++33Lz2MaxjWDVtWaNilveyZwsqocjChguMDIUAjqSxI6CsjwxBY6L461OxtbGC2Mt\n\
vHcwGQAHqEbnnkFdwwMHlsgYNdppdrDNC1vcTtLKH2o6HAK7tw4GCeT0JxkHAx1xLnSIzqlp5jxy\n\
T2VyrPOXLvKHJTqTlfvD5QfTr3mNWjPnjQbbVr/hZ7apPTvv2IjX524z007ff6f10ubUFpNfLdbX\n\
njwMxlGwhOD1bknknjsD78ZcsF3O1u4iCqpMtpLsZ+UcAyHB6lcYXHTv6bWkXFpBafZ4i0V5I+Cn\n\
lOBkknbnHYseScc9hisu8kuJrtllLb4yeW6jt17VhWxtSE3QnC0Ft0vZa27q/wDw12ZUZVJ1Jcrt\n\
6rXtf5/NF3T7J5pdQkvFaRoTgGOXaGOCfl+b0IznvXH+ONRk0/wsq2gAs/PSK5kKLjyiSHYHnqD9\n\
cOD3rqLW5urSGRoE86cMAqMex7kZHHv/APqOdrFmdV0W7tJvKjFw0hnXaW8s7TyvY4O845xwc8ZO\n\
1CvWrK9W1rqy3bto1+t/vT3LpqSnNXva3lb5f15WIdJtdM0nw9FJpdqy6c64GCy+buC7WHU55Tk4\n\
z9CSd+60pbSxd7aTzUYDdcTMM7M5A3HoMk/5FcPcW2t6PfG2tbpr/wAOaZETcQS487gECPft5IAB\n\
A442jkAGumRbqZ9ORYJ4rMur+QCHTBQttPykMPugZznIxjg0VYSrxVNSst31cvXs9F1t66WKsGpK\n\
Udl322v3+7/gE6Qx/ZxKXKcdVb9OOtUrm62wRqI4YwoxiIEbiSSSfxJ4/wAcCzcq62/lkfLG+3I7\n\
8D+uR74zWbdIZISF6jnFY4amktToowVVqpI6PwVZCW7e6kUAhRtGOmc4/GuzALNgDn0rkPC1/HFO\n\
QzBUmAwT2I7V2trjcT7cV5GYOXtW5Hzmc05SrpPRf1/wRGjWNd0j4+lZUWn6VHIxWyiyW3bmQMQf\n\
bPT8Kl1a7WJmZydqnaAO5rCm1OblgVjUVjSjO2jauaYbA3j7ul/Nnr3hgKNGh2fdy3b3Natc38Pb\n\
oXnha2mDh8s4yBjoxFdJX6plqccJST/lX5HiV4ezqSh2YUUUV2mQUyf/AFEn+6f5U+mXH+ok/wB0\n\
/wAqT2Gtz5nb7x+tJSt94/Wkr4I/RgrV0GMmZ3KgqBgN6H/9Wayq3dBQC3kcE5ZsH8P/ANdcePny\n\
0H56GGIdqbNOiiivnDzgooooAhvYTPaTRhgvyhsn/ZIb+lZfgy48nWAhIAmQpz69R/KtiY4hkP8A\n\
sN/KuPs52trqGdPvRuG/I19lw6nPDVIef6HTRg6tOdPv/X+R6lLGksbRyKGRhgg1zl/FcWEoVJpf\n\
KP3SGI/A+9dHFIs0SSRnKOAwPsai1C3+1Wrx8buq59f88fjXVOCe6PNwWJdCfLL4Xv8A5nOLeuyN\n\
HdIs8LDDK4HIri/FPhM20bX+jlpLMjLRdWjHt6j+VdURg8/rV7SZisxi6q3I9iB/hWDvQ/eU/muj\n\
Pp4VJYf36e3VdH/wfM8XBz6A+3eug8LalLa6jbtuJjLbXUngg10fjXwlHJFLqOlpskX55YEHDerK\n\
PX2rmfBsEF1qoS4coNpYBRkkjsB9M1VedOvQdSK9Ua4qVGrQdeHw9V2/r+vL0HU7aC4tZLS9CrAk\n\
ZuIZl6hC2MHPcHH1FeWWNmbvU4LRSf3syx5HUDPWvUjsuby4ge0n2NCFAlfY0aAqDwfcA/jxnJrz\n\
2126R4vg3sGiguApbPGMjn8q5cubi5Jb2v8AOzOHKHabinra9vk/1/4B7DHGkMaRRKFRAFUDsBxU\n\
V7OLeEt/GeFHvU59uawr6bzrhiDlV+Vf8awoU/aS12MKMPaS1ICSSSxJJ5JPer2kWgurn5xmNPmb\n\
39B/n0NUK6rS7b7LaKrDEjfM2fX0/D/GvVS6F4/EewpabvRFyiiq19fW1jHvupQg7DqT9BWiTeiP\n\
mIxcnZK7LNFcje+LjkrZQADs8h/pWLc65qNwfmuXUeifL/Kt44ab30PQp5ZWnrLQ9GZ1QZdgo9Sc\n\
VUn1Wwg/1l3ED6Bsn9K80eWST77u31OaZWywi6s6o5RH7UjubzxXZxZFukkzdM/dFc5qGsXmpN5S\n\
jy42OPKiB+Yn19ay0UuwVQSScACum0mwFopeRR55yM5ztHoPf3/D1zzY3EUMvp+0kry6Lv8A8D+t\n\
zo9hRwiuldkthYRWSLty0xXDvk4OcHAHTAx1q3RTJ5RDE0jdFFfB1q1TE1HOo7yZyNuTu9WZ+tXW\n\
xPJQ8t97r/n/ACKwqkmkaWVnY5JOajr6DC0FQpqPXqenSp8kbBS0lFdBoFFLWdq135EflIf3jj06\n\
CmlcTdilq155zmKPHlqeSD96vo34Uf8AJPdG/wCubf8AobV8w19PfCj/AJJ7o3/XNv8A0Nq9vJ1a\n\
q/T9Txc+jy4eP+L9GdZRRRX0R8mFFFFADZBmNh6g1422mNbTC409yHXny3PBHcZ/x/OvZJDiNieg\n\
BryiyvIL2ESW0gde4zyPYivIzWHOo321PWyutUoqThtpft8zhb8w6d4gutUu7e4eV5MxttOyP5R9\n\
4gdQRjH+NWIJo5LGWxgjhvYy/wAscJCsmf4zgc8f5FdZqAeA/a4RuZRiROzp/iP5fSuGNpaweKL/\n\
AFNJDbWNvsk2qmMllXIGPc/zr5evSUb83TbztsvL/hz6GXLWpuvd6fPXRJLqvK297lXw/osVp4vs\n\
EndJrdmcxH3Vdw3DsRkfjXaaw02oX5trZSyQ8HHTPcn+VY+mafPd3FrMwjiVSJbfGfNAxyzZ6A/m\n\
RgV2FvAkEQSMcdST1J9TW9ODqTU5dFYutjJUlGVTWSTSXz3/AOB3My10OJMG4cyH+6vA/Pqf0rUh\n\
hjgGIY1jH+yMfrVfUdRttPj3XEgDdkHLH6CuO1bxDc3uUhzBD6KeT9TXpUsNKpsvmckY4nGu8np+\n\
H3dTqNS12ysSUL+bKP4E5x9TXO3fiq8lJFukcK/Tcf1rn6K9GGEpx31PSo5fRprVXfmX5NY1CTO6\n\
7lGf7px/Kkj1bUI/u3k3XPLZ/nVGitvZQ7I6vY07W5V9yN618UX0RAm8uZfcYP6Vvad4ks7ohJs2\n\
8h7N90/jXB0VlPC05bKxzVcvo1Oln5Hq4IIBByD3orzzSdautOYKp82DvGx/ke1dxpmoQajB5lu3\n\
I+8h6r9a8+rQlS32PFxOCqYfV6ruW6zdS0uO6DPHhJvXs31/xrSorBq5jRrToy5oOxy2m3T6belZ\n\
QwQnbIp7e9cs9nHoXiO5VfJMzMWgWZMoyMDyDnHfHPoa9A1mwF1CZIx++QZGP4h6f4Vivp1t4i04\n\
2F2dlzCMwTAfMvqPce3+FclaKg3J7PR/5n0EK0MVScr8qdlK2u2z81+NvQwWt4DaLFK0ElrJsMk8\n\
QwYTwSrjP3c/yyap3enadd2bwSW0cW5yDKVJUj7q8dOxGck5B5qjc2Oo+GNUEd0uYXbG5c7JVz29\n\
/wBa3L2IzPJNFGpaZyx2qAFQHgA++AcYJ4GOQKmUb2bd77Nfgvl1OPEUXhJKLleD1Tvprv8An/nq\n\
cFqXhDSda8VW7z2rQwo5e6Mbbt+RgDGAf7vTgA+vNN8UeF5JfB9hpmmrZMikyPLOvltH8gyeuOi8\n\
59BXvtq+lqsbrbxRSMo/gAZQccH9K8n+Jel6rJrDrYQFLUyPiTGPlaLB2Do2cnj2B9cRg8xqV6qp\n\
6x5ddX2/rv8AeeS+SSleFrrRu3fr8j5mv7V7K7kgkKsUJG5TkH3BqvXc+KfBUOiaML3+0opnmcGF\n\
CpWRk28nb67jjrxiuHIIJBGCK+2o1o1Y3i7nh1abpys0JRRRWpmFFFFABRRRQAUUUUAFFFFABRRR\n\
QAUUUUAdB8PP+R/8M/8AYTtv/Rq1+mlfmX8PP+R/8M/9hO2/9GrX6aUAfOfiXTfOuJ1u4v3bOdsg\n\
5wfY/wBK47QbBpdcFpKdrjcpwMk4B4HrnHFev3Fncb5SY0kjYnKq2cjPcGuL1fTjpWqrrNnG7RKA\n\
JEVctE3rg9sce3618NGUuWdNPfb1P0hYn2lFwj8VtLGncX9o66YlpJHJZQgmVZ0Kgbvl5Y8ZwTx7\n\
VyvivSLDxVoc1ndKgu2AEEqkhIW4GTjjaOAM8nI9K1ND+y6nJatHKPLMx81JEUEAAMQx7g49+vuc\n\
dRrMen39pLJahvtkS/L5HVuehA6jp+XbrXnQqPCVUopp/wDB67dfuseDJKEnCUW3s3216+vX0Pmu\n\
8+C2uQ/Z5Le4tLq3Zd00qSBRGM/7RGeD1HGeK9n0fSLfSbFNM+3zvHbfu1kupPNODx26AFRgcdB1\n\
4xcgR1gcXDOk6gMFd+YxuXghsEA5znjG3GT0qteb1lRXUpEGCsV+4oBG4A/Q/lXpYnHVcXFQn9/n\n\
/StruvMeDw9ODapuzfX/AIf+vwOx8IWMH9jRXbRD7SQ+WPUfMePwHFYniDSRLLu+71Ktj9DXa2bR\n\
xQosQHk7QAB0x2qKa0D5C7XQ9jXzKxElVc2zlw+O5a03J6t9e3Q8jv8Aw/PKcqoLf3lOc1lz6DfQ\n\
f6yIqPUg17Jf2EVtp1zJEVjnWMsrgbtuBnNc3pF7Ekk51WcyR3C787CSHHpgdNuMcnr9K9OhjKso\n\
OUVex6tPNHL4FdL+vyPOV06fIBK/zq0vhzUWjDpDlT0ycE/T1r0WwvNIQXU9wjpJbkYjZQzOCoII\n\
x16/h3xWZZW92dctYt7ZM7Nbm5y4AAyRjp079ckcd66oY6tr0saSzOf2Vpvr+h53NazxEh4yMcHi\n\
oTnvXpfijRXjuHkgXJBPT+If41ykkKMSJI1J9xzWlLHe1jdnfTxKqRUjnqfHG8jbUUk+1bf2aD/n\n\
ktWba2eVtlvH+Q4q5YhJbGjrFTTrMxYAG6Z+OP5V6D4Ws/s3uyjJP+0aytO09LQb3w0x79h9K63w\n\
9b5i3vwpbcc+lePi8Rzp9jy8bXtTbZj+INPk02/k1F5BLFPKCyYxtJGBkc7gABj3A6cmqMUYuHM0\n\
cq/aWYgwGJVBOByCCexH6fWtPxtcRtqFmkmZIgjMY1IBHI5+pGR+PUVRjSFLR1t1lkkSLMu/5nAU\n\
HlSTjJHHTPzV14WpKdGMKjXvadrdE1+Xnc86heNKNS2rW9tLX0uORLm31CCGScptjBERhLADGSQQ\n\
epIxg44z1zzRXzzK0UUZPJ2gDgD+gqzJLNbStd2sVuZHj80Fo2ZnB28ICc4ww49TgAYJp899NNdC\n\
a0doI4tyhEPLSFSVDDnjI4Jz3+gVXDznKMbpJR/rTz9WejBzi/dinpa/S9/v3fXsySytYUsmeeJD\n\
LFhECkJ85xtyRg55HOehrmPEOjrq7xDQdSlsbqY4e5gJO2HIxGQSOeecnPStLTr83EBuLK9jupDt\n\
iEaPlJJBg7Rs+6Fy3HBwD6mr2mxw3F3dR3JVX3O0hIVWm3A4ztOCQo6/jxjFdMFKnDWbklq9Nkul\n\
tbvy1/AOV0Oec3/Xp69U1r87U9Env4RareWSi4hjwsLkoGIPDntwBu244B74zV/U0+0X20OrED5t\n\
gIHbtk464wT2NK7WNpfmWzQZkQIkIHAIzu55wCNufXHrVS6nkiyBkO7M5JOTySf61hVdPEKPLq7a\n\
N9Fv6b3v8uquTFyqVueKs7fj/XluTWkf2V7htqPtj3+WwJDDow4+o/OoLiC1MT2TE3MkrEOdm2NQ\n\
MnIAOBhlB+XGfQ9apSXbRlZGkkDr0KuVPuOO1MilmuG/0aNnkMZiB2HIU46HH9R9RWlKm6cbdNb/\n\
AHaf1p27msqdZN1L9v69L6lm4Szt90llHHJdxqrNN/qtr5yW2gDI4Bxz09c5uM620ixztuIViCWJ\n\
LfN7knGCv51Wl07UmLSyQGJTzlgWP6VUnE8MeW2yIvZRt2/hRpUjyt3/AK/r/gh7J1GvfT/F+id9\n\
N/QvvcrMy7CInB4LAkHgjnBB70QRrYXscyhlEaYVFUshwRtxnIUj5h24Y4xWfGwkAKd61zIJIkiT\n\
55D8uACec4PT0wfyNZVb0laDte+nroKtRimk9uvoRa0RcWD3FmrxMyZdo0BCPu64Y7SSSOAM55zT\n\
oJbgaWtrKo3bSAm7dtCg5JzwfQ44BYDAxViBYbGJvtc8QeUERlXXKlgVBBzkEgkgjnGfpWVZ3zWN\n\
5K7RQvbzRkKEcDL5I5AyO3QE4B6/MSagp1KfK1qlZXdm7app3vvu/Qzik6bjBXs009dddu2hbiuY\n\
0tirRuyKOdqk/h9aYLQXDO8YmSNFyf3eRntx97PX16Uy5NxfQFJEt7CEBtsuzcJskfKM8ENjODng\n\
DOTgCzIJJY4BLN5Vr5ccaRQMThhgb+DwNvB64wDzRGjKmk29t+3b8+opTV/iUb+ev/Be+nS2vnRk\n\
sCJipCYCqxkRxtYEdeD/AD/WtfQtRfSLm3e4kleymiAbneI5Mknp0wOD+B9qZJKkIMlzAvnKysZp\n\
VaUSDBLOvIBA+X0x0wOKi1l5ZbP5nE1v8kjGPO3lsKRyO+RnP16A1pKk6ylGe332XR32X33MMRzV\n\
kqcnp/w3/At+S6bviA7p42U5RgWB9c1w+sXxmleMNthQ4PPX3rtb/V9N1CNIUlZLk4VFZDye3PQ+\n\
hryrVpyCYVPOcvXFgaDbtJWOnLf3kFFqzR9GfByUS+ArNl6eZKB/32a7auD+CH/JOrH/AK6S/wDo\n\
w13lfo+FXLRgvJHyWPVsVUXmwooorc5Aplx/qJP90/yp9Mn/ANRJ/un+VJ7DW58zt94/WkpW+8aK\n\
+CP0YK6TSlK2Sbl2tzkfp/SubUFmAHUnArqrUFbWEN97YM/XHNeXmkvcjHzOTFPRIlooorxDiCii\n\
igCC/kaKymdMZAAORngsAf0NcdXWaw6pp0ofdh/kGOmeoz/3z+eK5Ovt+G4Wwrl3b/Q9DBL3Wzuf\n\
Bd8J7BrVz+8gOR7qf/r10VeZaLenT9Shn/gB2uPVT1r0xWDKGUgqRkEdxXfiYcs79zyMxoeyq8y2\n\
l/TOZ1qHyb5iOj/OPx6/rmq1l/x+Qe7gfrW34gh32qygZMZ5+h/+vj86xLL/AI/IPZwf1rhqaRZ7\n\
OEq+1wyb3St9xvqehrx3U4E07xZcRRP5SLckBhxsBOf0zXsOQq7nICgZJ9BXh2rXn2/VLy5HSWZn\n\
X6EnH6YrmwMXJVO1v1N8DCUo1O1l+Z6fqJY6XelJC8kqK0TggiQIg3DjvnJwe3Toa8oucmVs8sea\n\
9A8FXTjTbgyEN9nJeNXPDAjBX8e3vil1/wAO6VK5drtLSbPILAgex5/lWGFrLC1XGX9f0jkwmIWC\n\
quMu+9v8jV8Jav8A2h4aEjsTPbgxOe5IHyn+X4g0lY/hOy+wS61DFMJrfyomWRejZbqP/Hh+FbFd\n\
1OMVKThs/wDK53/u3OU6Wz1+9XL+jW/n3ilh8qfMeOvoP8+9dPVHSLX7NajcMSP8ze3oP8+9ZXin\n\
WzZr9ktT/pDDLP8A3B/jXTTg5uyPnsVKWMxHJT2Wn+bHeIPEK2TNb2mJLj+Juyf4muKuJ5biVpZ3\n\
Z5D1ZjUZJJJJyT3pK9SnSjTWh7GGwsMPG0d+4UUUVodAU5FZ2CqCWPAA70IrO6oilmY4AAySa6XT\n\
dLW1GbhUacEEEHIXjp9c59enFcWOx9LBU+ee/RdWY1qypLzE0rTfsv7yXBlI4A/h/H1rSoor8+xe\n\
KqYuo6tR6/l5Hlyk5u8twrE1y43SCFei8n3P+f61r3EohgeQ/wAIrlXYu7MepOTXTltDnn7R7L8z\n\
fDQvLmfQSkopa907xKKWkoAbNIIonkbooz9a5e5lM87ysAC3pWnrlwcrAvQjc1ZFawXUIau4V9Pf\n\
Cj/knujf9c2/9DavmGvp74Uf8k90b/rm3/obV7GUfxX6fqeNxB/u8fX9GdZRRRX0J8iFFFFADJ/9\n\
RJ/un+VfMFtczWswkt5GjcdxX1BL/qn+hrwryLf/AJ9bb/v0v+FeNm+Z0sByqrFvmvtbpbufQZHW\n\
9mqicb3t+pWs/FjgBb23Vx0LJxn8DVe5l0m6uo5FkaGEoySI8ZLFSQQoIPTIPHXk4PetHyLf/n1t\n\
/wDv0v8AhSG1tGILWcGQMcAr+gOK+bq51gZ/Yl+B68ZU4t8sGk/NW+4dFr2mWSN5RmnkY5Z9uC35\n\
9BWff+KbmYFbVFgX+995quSWdm6kG0iGR1UsD/Oq/wDZVnz+7bn0c8VrRzzAR3hL8H+THFUObnnF\n\
t+epzcsjyyF5XZ3PVmOSabXTf2RZHqJx/uyD+qmopdEtzjypZk9d+G/kBXoR4iwDfLdr/t1nasXT\n\
2s18jnqK6CTQoCzGK6kVc8K0QOB9Qf6VUOh3AZQskDAkchiMfXIrop51gam1RL1uvzRSxVJ9bGVR\n\
V6XSb6MEm3ZgMZ2EP1z6Z9KpyxvE5SVGRx1Vhg/lXoU61Oqr05J+jT/JmsakJ/C0xtFFFalhU9nd\n\
TWdws1u5V1/Ij0NQUUmk1ZiaUlZno2i6rFqdvlcJOv34/T3HtWjXl1ncy2lwk8DbXQ/n7GvQ9H1G\n\
PUrQSx8OOHT+6f8ACvKxGH9m7rY+ex2C9g+eHwv8C9XMaijafqYkh+UE+Yo9Pb6dfwrp6x/EkW62\n\
jl7q238x/wDW/WuOaTWoZZV5K3I9paF6+s7XXNKMU67oZVyD3U+o9xXicn2rS9QuLbzHimhcoxU4\n\
zg16/wCF7jdFLAx+78y/Tv8A5968p8YuG8XamVOQJcceoABrhwqcKkqT1R9Fl1HmdahPVJcy/rzX\n\
5F/w/q0v2tUkYnceefvf/Xr0bUpdNGjJb6vKnmLho1BPmAkEAqBznmvPvCWh3VxqEM0kLqisDyOt\n\
WbqN7++uHspYpoN0jo8yB2BA+UcnPO3gcAe56c8sNTrVm4yty66evfoeHmfJKain5/d06mLq66Pd\n\
XKz6qFM1q3lo8oz1xzjORjcDkD1rxTxh4chtpri90fUIdSslIMkikK6k/wARTsCcjjio/HPiDUdR\n\
1E218Io5LRmjJhG3d2/kFGPauXVmXO0kZGDg19bgMFUorn59+nT+v6sfP47F0682uX/hxtFPEbmI\n\
yhGMakKWxwCeg/Q0yvWPMCiiigAooooAKKKKACiiigAooooAKKKKAOg+Hn/I/wDhn/sJ23/o1a/T\n\
SvzL+Hn/ACP/AIZ/7Cdt/wCjVr9NKAPL7a9huJZY4yQ6MQVbr16/SotVgUxecFBI+Vx/eU8c/wCe\n\
lc1JOUvpZIJMMkjcqehzXQwXovdLuGwBIsbbl98Z49q+Ir0OSXNHY+xgnCSZ5d4vsl052e3ZoyXC\n\
nYcBwRkE+46U/wAFS3D3sLKWyrYYjuK0/Flo2sapFaR3EcSwRpv356sxxnjjAOf+BUunzPYW7w2G\n\
1YUb93cqhYyFc7sHGDk4/P8ACufESi6Kh9r9Oh6OLxUeRRteTWv9WOm8SaVugm1ISmORU8xgR97A\n\
xxzwSK5yWVJ0ijhUhhuAIA+ZfQ8Z+9ng4HTFWJ7m71kPNcNPIirysEZaNBjPI3cnr3PbsOascyBh\n\
stzNGwAJZiAAMn5dpPJJ4JHfpXJhYyjHlb1+5L5/L7uh5VFNRSlq0+2i7K/+Y2GXUreJkguJkj2k\n\
KQSAvbG7tz261pyy6ikavHfXEiAkLuJBUdixPBPBznpn885p2tJ3eGMK24quIxuU9gD9CB6fhU0s\n\
k9taIt3BJGk4AZ5AecdBk5HTOc5/w2cYSl73XrZeu2t+xvWTnao0rfL5/cifUtY1G4t/s0wtVVsi\n\
R4zwwBOR+Q9arQJ5kaozxnaAEReyngfNn+8R9N2c4BFIL+2STzo3EgLN5quTtbJyvU8HjJ65Ofap\n\
re8d7fbCIoVTJVUBY9TggkDnacZ6nv2woqFJbaJ62W/z0++yt06omEGoKMIWS67a/wBfgJcQSEq0\n\
rk3bEFT5QILAnJPIzyAQemD0PZdIv47XWY57reI/mHyksAx7nuf/ANXpUmoXFrZWiyapdCNJHEa3\n\
D4/dylgBGAfm654GOPWnWqWs0ReVreeMLkgqdyDO089G6jODzwR2rSpBzWq91/hfv/XZK10JqPI+\n\
aN7q3/DdvI1rnxDb3OoCGK1kuItpLsinecDqFxyOnNUv7MtNXshe2sLiNiQBINrH34rP1RbaEqbU\n\
p5jMBGVymFOflUg+oTsDjHJrs/D2nGw0wWkszSs2XyeiknoPYV5mJhDDRTg9fX+ujXbscbqfVoqc\n\
G0m7au/r/wAP8jjTpFvC/wA8DA/7RNWEVUXaihR6AV1U0W1ikig49RUQt4Q2RGmfpWDrOW52rF3W\n\
qMWzs3uGBIKx9z61b8WLJaWenrFdS2ytOEfyzjKkHOT1wAPb61v2VsSwdxhR0FM1i0hv4jBMDgcg\n\
qcFT61nCulVi5bLc87EYtOcb7XPPILSKVpGDBmVtynzcKFzkZfqeM8kY45q7KLWC5mtjIXQqROrZ\n\
/ffOcgkcghRjjAOazr6F9PuzEZGZAzR8nHX6eoH1q1ZXWcpLgjBJY/mSa9+VRqKlCK2/r+v+GPV9\n\
hP4ua66d+n5dLGtZX/28y25hjII+RJTkdf1+nH4CvNfjHcxW/gK8W1n8xQ8cHmRgoW+Y539Cfug9\n\
wTnk4GPQrO1Eeb24YxQBW3BgUIXpnPqe3f8ASszxHpyeIvPstTi32ZkaRYpMKGYEcDoeOGOM5Bxk\n\
4yYy58ru1f3lL172e3r+IQUF7RUtE1a/RaNa99z5m+HF3qNp4r097BJJY3mVJ4wuVeNiAwbg8Ed6\n\
+ntMj33w+3xxmfywYimcKAGzkE8NyM8dQCPu8VfD1lZ6TF5WkWaRq0p8kRALuVjgFgMvxk/eGB6Z\n\
wK0dPvJ9LAS+maV5HEbKz/MMgE5HJ3Y34552gY6V6WOryxUnJQs2mkr6ve1/0e3nqZ08PLDYd0YS\n\
5nv/AJ8u/wA+5UtmEUxUqxbPYEk1Ldql0Q0JJkGflA54GT+gzWjLLAVvFWOJbfyyDOp+YscjZgjG\n\
SMnP045zVSxuljbbdzM1wikF3VcOoIUYHXafvEDPQ49/Iw9CSV3JJ9tNrX+/8PMueJk3zJWt3/X/\n\
AC3MmKASXoDrkgDap6E5/wD1fnXoemWEdjAFVQZCPmYjkmuCuGh+3BrR83Er7kjX7/mHBCkevXn2\n\
7mvT7dMQJJPtDkAsM8A1zZpKUFFPr+P/AADizXEVKkIQg7X3Is/T8q53xXp8X2KW6jQBlHzgD7wN\n\
dQZrcnGR9cVheMWeHRJDGC6MyhmUZ2r1J4+gH415+FnJVY20PNwXtcPXjd6M4KGBkhbzFc/xELnj\n\
pjp29fxrdubiVL2KGwhhO4kLICCVXbu+YYJA6DJx/KqUEEbabF9mmJJ/1hAbCJuwCQQc4OfTIU+h\n\
xYeYwSvJuaSYoNsiP8sSkNtUE9Rlj2OeOMDA+jcWrznby6/1r/me9Uq+2/eNXe1v6t/XRkdrbWgv\n\
HN1H9suZZgGk3naTjGfTJyVO3jAA9aW1DGRmuHMUgmwGfcqvg8bgfmGAqHnrx0yc0Y73CiJGXBbC\n\
7xxkt9ORzj6cVq6p5u4SxrK4j3S7NmMcFcDnB55zznI5wBUQ9rHmk3rpb/gee+tvO46t4y5aj1a7\n\
/ptbbTbQfqMbNNLdxMjcZBIOTweVzjkngY65HY5qHw9o0OrRXUcsskKx4wI12jaR1Bxz35HtUmg6\n\
VqUsZurUwCGQMQk0jFSeBu2jjt/ntW8+60m8nu7t3TbEyO5A2S7TgAd+S2ckc84xnFYS9nyShRdp\n\
f8N/we5yyqyjehCV3orr+vvNeLTLKWdY73UJ53ViFwdoxjAX17Z+tZFtMttb3EKQEwMWCqylVBQk\n\
oMAcscA9QcYxnqeIu9YuZpWdJWXJznJzVmx8Q6guYXZrlH6JjJyOQRweRjNdVPC4hLnn7z6X6fgd\n\
ksqrctqbv5f5djodX1ODSYLdChkvtu/h8KM/c4HoP5muDkdpJGdjlmOSa6A6TeapdNPdnyi2Aqfe\n\
YAcAY+lbVn4WEI5s3dvWc4z+BwK6qE6WGV5O8j1cJhaeFh7zs3uevfA//kndj/10l/8AQzXeVzPw\n\
3hNv4Rs4mjEZVnG0AAD5j6V01fW4afPRjLukfn+YtPF1Wv5n+YUUUVucYUy4/wBRJ/un+VPplx/q\n\
JP8AdP8AKk9hrc+Z2+8frSUrfeP1pK+CP0YfEGLjYMsOR+FddXLWBIvYcDPzgH6E4rqK8XNH78V5\n\
HDin7yQUUUV5RyhRRRQBkeIZwsAhGCWOW9R6Y/I/pXPVo65Lvv3XJIT5eRgr6j8Dn86zq/SMroew\n\
wkI9bXfz1PVw0OWmvMK7/wAI3v2rShG5zJAdhz6dv8PwrgK6DwVcGLVjF/DMhH4jkf1rpxEeaD8j\n\
HMKXtKDfVanaX8XnWcqYySvA9xyP1xXNadj7anphv5Guszjn05rh9Tum0qzv54/vwrsT2JcLn8M5\n\
/CvHrJuLS6nJlLcoTpr+r6Gb8QPEaRQyaVZsDK4xO4P3R/d/HvXA2Fs91dRQoPmkYAf41uXPhq5f\n\
dcWc0d5CcOZVOW5J6++Qa3vB2i/ZlvL64RS0ETMm4cZAz/SsniaOHoONJ3b/ADPaeNo0MK40de/e\n\
/wCht2ENtokUsCR+Z5UfmTPINpAU/wAI6nnnPTB715bqF093dMxyxZiQDzjmvRPFUxttHAUb57uB\n\
XmmdfmOQBj2HsOK43wZbpP4qsI5lDKHLEH1VSR+oFY5copTrS1a/TcwymMferVdXb77J/wDBO78P\n\
aUdG8NNHMMXNxiSX2ORhfwH6k1paNbfaLsMwzHH8x+vYf59DU2sN+4RT1Z85+g/+uK1dLtvstoqs\n\
MSN8zZ7H0rbDtzTlLqzlxeLcKMpv4pP+vuQzWb9dNsHnIBf7qKe7V5rLI80rSSMWdjkk9zXQeNbz\n\
ztQS2U/LAOf948/yxXOV7mGp8sb9WLLqCp0ud7y/LoFFFFbnoBSjmkrf0TT18tbmYHeSGjw2MYPX\n\
j9P/ANVcuMxdPB0nVqf8OzOrVVKN2TaJYfZ08+YKZHHyqQDsHBz7H6dPrwNOiivzvF4upi6rq1N/\n\
y8jyZzc5czCiikdgiMzdAMmuckyNcuOVgXty31/z/OsipLmUzTM7Hkn1qKvp8NR9jSUep6lKHJFI\n\
KKKWtzQSmzSCKJnboozTqzNcn2QrCOr9fpTSuxPyMeaRpZWkbqxzTKKK2NUrKyCvp74Uf8k90b/r\n\
m3/obV8w19PfCj/knujf9c2/9DavWyj+K/T9TwuIP93j6/ozrKKKK+hPkQooooAbL/qn+hrwM38A\n\
BIJOPoP5173N/qX/AN018z18vxHho13T5ntf9D6DIqamp38v1Nn+04vQj60HUoh6H6Z/wrGor5v+\n\
zqPmfQ+wgbaajCxxhh7kgf1qVLuFwSH4HUkcD8a56lqJZbTezaE8PHodMrKwypBHqDS1zazOrbtx\n\
JPUnr+fWrkWpSLgOMj35/wA/rXLUy6pH4dTKWHa2Niiq8N5DJ/EAffpViuGUJQdpKxi01uFOZi8b\n\
Rvh0IwVYZGPoabRSjJxd4uzJtcq3OnWc5yYfKbGMxHAPTnHToO2OtZ9xoTGRjazIydVWT5W+np6c\n\
5H4VtUV6mHzrG4fad12ev/B/E0jVnD4X+pyNxbT2zATxPHkkDcMA49D3qGu1JyhRgrRnqjAMp+oP\n\
FUL7Sra5y0AFvMTnAz5Z5PbqPw446V9FhOJqNRqOIjyvvuv81+J1QxnSa+a/r/M5mrmlX8unXazx\n\
cjoyZ4YelQ3VrLayBJl2kjI5zkZxkVDX0alCtC8XdM62o1I2eqZ6laXEV3bpPA26NxkGq+sqG02f\n\
PUAEfmP6ZrjvDerHTrjy5STbSH5v9k/3q7m4TzraRF+YuhC+5I4ryMRRdJtdD5+pQeExEX0urfec\n\
3oc62140jnEYjYsfQAZ/pXDaZoV/qmriaWPAmk819xGcFs9OvtXWTjytD1i4PRLZkH1bis/w5CdU\n\
0d5o5XS5tVXarNtUgYz83UEhR9MV5VebhzSj1sr/ANep7WLr1KEJTpdbJ/df83+Ro2V3eaVe3ITB\n\
kRtkkbM0iZyDwcjBIIx+Xaue13Um0e2n1G7tma2CzGRYdvygDHf0LdAeOODnjWsoopB513JJKDJh\n\
mVSCTnGCQeTyDnHY5xg1maxpB1u2ew1aSZNKuFExt4FBZGBAyzHn+Hp1znPSs4RgpKdRKz3fz/Hy\n\
PDhFRjJR3/yW3Xrr+p8uazPBd6nc3FnC8NvI5dUZtxXPbNUq+iIPAOhx6bqlrZqzNcuxVWG5UVXb\n\
aQ3GTgqMdQQc9xWJafDGyh8aQoqvdaSkUjNtJJLKARn06444yPevqYZrQScXpZfp+fQ8ipl9Rvmv\n\
6/f08jl/h94afV/C3iET7YxJCr2/mcbnUkjBPTuM/hXAXUHkTMm9ZADgOvIP0r6n0LR2tdJlitLO\n\
B7KJXRvKTKlWO45JJOOfXoevp5H4w0O417VvKsLSOytLcMATHt8zblmZR6YycfkOaxweY+0rT5vh\n\
+WmnU0xOBcacbatL9fw3vrqeXUVNdW8trL5c6MjYBwwxwRkVDXuJ32PIasFFFFABRRRQAUUUUAFF\n\
FFABRRRQB0Hw8/5H/wAM/wDYTtv/AEatfppX5l/Dz/kf/DP/AGE7b/0atfppQB5Jf2UN5uEoIZWb\n\
a6nDLyen+HT2rI8ufSZhIxWSJvkYgYDA44I7Z7den4VT/tGewv51jO+HzGzGxJHXt6fy9q6K2nt9\n\
RtGMfzRtlHU8Eccg/gf1r8lhicTls7T96m3/AFbs/wAGfVNToWvrF/18jl7rS5iXnsiksc2TK0hI\n\
L+ik4IGOMA8AfnWXdtrT2dvb6JBdLbQqytlQByTwM/e4PX2rq2aTSbzMIZoXAyG6Hk8Z9R6+/wBa\n\
1lW11GLzYCqS8ZYD5h7MP8+1e6+SpGNaC5ovb/go6qdSlzKc43/L5r/KxwHhvXtTtxqEV2XFygVQ\n\
rIAQScZI9hznmtm20aW4t5EluoIfIy4Afd83PzMcDscE89Prl/iXShqNpIko8u8gG5JB1GOcZ7gi\n\
uW8MTXtlYalLNMI04j/eMCfvYbAzzxmsK9FWdSlo+q/yNMRh42dem1HVaW6/r1toadtc2dvqdhcX\n\
QVIlzulbpznAAP8AdOBjHcGu9vLq2jxHKUcnBO/kVxZjFjFb314sSWCZZbZkX5jtwGHHsP8A61c1\n\
e+KnmnYplVJzkDmuSpQnimpLp/X3nHTwX1qSm1pG/wCf6eR6hqklk+mz3VzEsiquGwATjtgmuLsP\n\
Ito4FkukWcuq7Q3TGSM9xnAHfkkY4qpouvlz5NxtntZSFdD/AFrodfsrC30u3+yxv9oupQqAMTkH\n\
rkemOPqfxoox9hL2VRXv/X4de4/YvCv2TbSk/lt110XocV498IQeMZrS4bUpbIWX3Ylj2hlGCOpP\n\
z4JCjoQO3Irq2aQpDbkxlFwygKo+TaCD8ufvMAcbj0qvAW8yJfM/eggfK5DkN26cZ46+o98WXMMk\n\
iNfCSJ/+Wm1WL7j82AAfu8kd+F69cenUqValHlbStvdrZ66LdXe/6ami5YvTX03dtv6Rj3vmhuFC\n\
srhsAYzg5/pXSWvi+KNI1voJlPA8xAD3xkjOep/Ws+Kzs52C/aWRm5z0CtuUEe5yTzjuQdtI9iUe\n\
JHjTZOUCsG3A5O4Eccjgcew5FYVMPGqoxlG+l01f8/kGIlRxNP2dSO3y9Ttf7WsHgR5bmBkbhTvA\n\
Jq1byWkiLLCA6MMqw5Brzu701bUK0uxnYFAWUYZsfeYYxwcnH0q14b1ldMDWk4/0TI2MoyEPf6+v\n\
415lXL+VPkd2un9f16HBLBPkboSflfr5LbY757jjCD8TUBbaGZjwAck1QbWLFVDecpz2Ga5zxFrk\n\
l1Abe2BjR+Pcjua5qOEnOXLaxx4fLcRXqr2miRj6tP8A2hqM08f+pRi3AyT6H8hVkQLbK5lJEhTg\n\
FeOR+vXpxRptuk5Y3L7BDwu5tpIYZO31HAP4EdDWjdTwERHy3KsBJFiMsoYgkkEY39F44/nj3JU5\n\
yp8sFovyvZ+vR3XpvofQe3m2qUY6LTT8NfzK2pQlGWOJ7eUCIErKApGM5YgDIYLtGec5BxwSLlvd\n\
LbWtyk7/AGadzwqligOOeOhydxOM9R6gVFqJaKAiHcIpWdBjDKYzj+7wAMEAdgT61QuZpIpi4laR\n\
5Bu55C/7v/66VWpGsnSer28tN+uj0W2/XZkqEqkFTT07+nl2v+Q9DcpKmGCb3BYImMk9SQBkn8zW\n\
hqAW9VUmnSOS3wGjbgOGyCjccAgHn3/PMgvS08PmsE2MH3EgDIIxkngCpNTeGGSImWKUMhbhThsA\n\
KSW5ycg9ST79Kyp4eUVKol7y0Xz3/q/5FTX71JKzXZdf10/rte1CeMRm3eExnbgYbKKAeDyRzyDk\n\
c9s1U8P6eNW1e4jczyWsK8yEhd7cYHHTv6/nVK61EXVu4M7s0a7mJjJXOO7DjPf065HSut8KXmNJ\n\
eAQtFJbnyySpUE9c8859fpV42UqVNzh1t2uvX+ttTjm6lGm+W6k3b7+uv9aipo1hpUyTiWUmIlgh\n\
b5cnPX161Fc6zJI52L8vbd/hVDWtRjDnzHxGvT/aNc7PrTEkQRgD1avOhSqVfelqzfD4PTmnq/M6\n\
+HVOQJkwPVa27GUSxsFIZCNwry4axc7jyh9sVqWOuedbT2U0rWqzqU81Bnbnr1p1MHKwYvBc1N8q\n\
JrqFhqclhEcWwmLBlIULkAnnuRgL/nFPitF1ScW1jAsUMbPBJKOQiAkAr6Hjj6n0qreWH2O8sbSH\n\
yLktESnBXduLLt3D5sfN3b+VOt78eHYWMt3ETLGRJChLEPxjGew5/T0r0nJqiuSzk9vkrXOduVRK\n\
NNO+3+bfm/uOo1TTrYaBLBZxxl4Y8pn5SMd8jnpXIQX0K6fcqiO/mIh4BUj1BOcdz0/vde4yz4sm\n\
e43JIUHuM5+tdBdXmn6hoBvbiCM3rAQIUO0nkZ6Vlh41MP7s025fhe39bqxrUws8PH9424t/NN/p\n\
/VizoktzZ299aKBtEPmxojhhGRg4wPXcOnv9T5zrV9NdXLiZ2IU8gnvXaLqVwszyW84t18kieVoz\n\
t3KTyeADnpjg8HpXPadCl/qk18wDIhHOMBpMDJx9efxFdtGnCFaVZpW3X6f8Hzud2VJzqSbj53/T\n\
/IrafoMkyrJdsYkPOwD5j9fSuy0jQ40iVggghPp99x9fT6/hV3TNOC7Z7pct1SM/zb/CtRm6sx+p\n\
NVUrVK7956Hp18Vb3aY2COOBNsCBBjGR1P1PenUinfyiu49VUkfpUnkznpby/lUpJHA3rqz0jwR/\n\
yL0P+8/8zW7WF4JBHh+EMpUhnyCMHqa3a+0wf8CHoj4jGf7xP1YUUUV0HMFMn/1En+6f5U+mT/6i\n\
T/dP8qT2Gtz5nb7x+tJSt94/Wivgj9GLujEfb0BGcg4+vX+ldFWBocW+7L/88xn8+K368DMnetby\n\
R5+JfvhRRRXnnOFMnk8qCST5flGfm6E9gfqcD8afWT4huFS3SEE73O4/Tkfj3/Su3L8M8ViIU+l9\n\
fRb/AOXzKhDnko9zAlbfIzZJyep6n60yiiv0o9pK2gVpeHHKa5Zkdd+Pz4rNrY8JReZrtueyBmP5\n\
GoqO0H6GWIaVKTfZnoZ6VxuoWLavo2pxBcSTDKE/3h82PzxXTatL5NhKcgFhsH4//WyfwrP0n5LY\n\
M5wuS59h3/lXz+Km4xuvI8vLealTdaO91b5anF+CporLTiv9pQJNM4eNfvhemQV4zkDGPxrU8S/2\n\
iLYSWl0syFgY5NgWNcn5lwM8hRwTnqfc15x5gm1Vzb5xJMdgAxwTxXq1kfsVvbQMys9vKLiYsMoi\n\
4IwT/e54HtmuPGU3Qq8+7eu39eh05jhvq9Rybu36f5dNPvEt4TNo7C7sp7tFBaEgrwoA45OSM5I4\n\
PB47Vy2p3FhovieySxtPLMUqsZi+dyNwRj6GquteJ531SaS0c7AxCc9qW1u08UXlvby2m2/8wESo\n\
eNm7LZ9OP508Ph6kH7SafK97enUvDYapTmqk03HqlfS/l2/XoehOBPrEMRztTk9wf4v5YFbwrA0V\n\
hLqcz4wCrMPbkf41vjrXoUY8sEjy8zbU4w7I8t1KUz6hcynq8jH9arVJcDE8g9GP86jr3VsfQQVo\n\
pIKKKmtIGuZ1jTGSe/T8f89qUpqEXKTskDaSuzQ0Sw85xcSgGFDgA4O5hg4I9OR/k5HRVHbwpBCs\n\
cY4Ufn71JX53mePljazl9lbL+urPIq1HUldhRRRXnGYVna1P5duIx1fr9P8AP8q0a5nUZ/PumYEF\n\
RwpHPFduAo+0qpvZam1CHNP0KtLSUV9EekLSUtJQAtcxfzefdyOM7c4Gc1vahJ5VnK3PTAxnvXM1\n\
pBdQiry9AoooqzQK+nvhR/yT3Rv+ubf+htXzDX098KP+Se6N/wBc2/8AQ2r1so/iv0/U8LiD/d4+\n\
v6M6yiiivoT5EKKKKAGTf6mT/dNfM9fTE3+pf/dNfM1eBnm8Pn+h9Jw/tU+X6i0UUleAfRi0UlFA\n\
BS0lLQAAkHIODVu2vXhwDyvpVSkqKlKFRWmrkyipaM6G3uo5gMHBPap65lWKnKnFaVnqHRJenrXk\n\
YjASh71PVHNUoNaxNSikVgwypyKWvOOcKKKKBAQrACREdcg7XUEZHsaxtQ0bgyWIJ6kxHk9f4fXj\n\
t1471s0V3YLMa+Clek9Oz2f9d1+JcJypu8WcY6sjsjqVZTggjBBrqvCmtY2WN03tE5/9BP8ASi/s\n\
Ib8M7kpc7cLIOjHtu/ln+eK5eWOSCUpIrJIvUEYIr7rB42jmlJ8ukluuz/Vf09TsfJjKfJLR/wBa\n\
r+vU6jxDalIlsyjmyaVppdiFsqANoOO2c/kPWsR54Rp/2q4ugbOJlaO3tgArnnOc+nHHoOgrptD1\n\
BNXtBbXTlLuLlXU8kf3h7+o/yKWo6asUu6/sbe5jJzvZOGPqSO/15rzMRh5Rlyy/r7zmjSVafJVf\n\
vK113816mLZXdpJ5lzZeU0MboRDPku7HJ54Pfd6nnr629XU2UEh1FWEq4dG5ZjnJI444z0HoOuBm\n\
zceHrC/tZZNDJsb4Lnygfkf2x/UViWF3cXmmQw6g8jxwzu0uYy7BgOBxyD97ntkVyu6XubLdPf8A\n\
XtvYxr4Z0k6lN6Jrfdb/ANeZ1Gl6Ppl3oCy30ZEhdgX+62QT+n1rHS20+yupDd6i8mYwn7olSxwO\n\
o7Yx/LpiprvUVttFu47gyLdhvNLkrtbIGAAvT0+ufevPJZXlkLueSfWssLTxEnK0mlf+rdgwuEeJ\n\
5p1JP9O/3Hs/hm6sEt1tbKNVBJYsDyzHqT71534suJVh1W6spI7KeKUvwBkbeoHqRnPGe9VvC2pG\n\
21GOOWRkR8ruB5GRio9T0u7uZbeR8LYzSSpKsgZGdPlUZI9cDIOBhR61eGwvs6s3U1vbfrrfro7m\n\
FbDRwtZqLsmuvXX7/u1Pni7mvtc1SNLid52kl2I79OW9fSqepWM+nX01pdxmOaJijKexFfScXhix\n\
uZ7eWz09oILFmnc26nZnOQSzL1xz+f1rzT4j2jalqaWul2CG5mcyXIX5n3nB359CD79D719VQzJV\n\
KnIlZW7r+tjxauCcYOV7v+v6/wCAeW0Vc1bT59Lv5bS6RkljOCGGD+VU69VNNXR5zTi7MKKKKYgo\n\
oooAKKKKACiiigDoPh5/yP8A4Z/7Cdt/6NWv00r8y/h5/wAj/wCGf+wnbf8Ao1a/TSgD521D/j/u\n\
f+ujfzp2mXhsbxZCf3TfLIPb1/Dr+Y703UP+P+5/66N/Oq55FfnNWnGpFwlsz7vlU4cr7HZ6nbfa\n\
rQquN6nehzxn/JI/GsC1uJLeRZYWKt7jqPQitvQpTLpcG7GUGzA7Y6fpisrVIvKv5AAArgOMDA56\n\
/jkE/jXNkNdwnPBz6Xa/X9GcFB2bpSNiKdNUgBAAuoxynZh3H0/lXCXME2lRtHLaXctsJ3kMsQB3\n\
ZPcc4OM8cYNbkMrwyrJGxV1OQa6MqLuBby1yspHzoD1/+v8Azr2a1JQ6aM6ouK/d1Ph9bHlnibWI\n\
7vTLS3SZpXjyC+eCmSV/HBA/CuZwdm7b8ucZr2mWGC4BM0MchP8AEV+b8+tYep2X2Vg0ZLQMcAnq\n\
p9DSp1oUVyqH4nrYN0oRVLW/yPNbeZoZA0Zwf5121pqFjqs1tNc3MkOwoJIsH7q9gc9zg/hVfUNL\n\
t71DlRHNjh1GOff1rkWWS2nZDlZEJBq506eJi5Q0ki8VhI1ldOx6rc6THeSRyeH/AC1Xad++RuDn\n\
IYdfft1waxw5jiYk/vHcfKVJIwrDhu5zngnPBI61meEfEBt5zDM2wOpUN/dyOtdZ4a0hbfUlM9zD\n\
cWsUf7lsENuJzyM9sfr7ceU5Sw6lGo76aef9aeZ4FaEsK2nqlZrvp0uYM8VxCFnvLRhGcYdvrwCe\n\
3547VrWRjNtcgrBJKsfmwF/nEYyckc5wAAeD06DNdtcQQ3lvJCWEiOpUq3vXn95aXemrtvLdvJ34\n\
DAhlf5hjPoOAcY9evSowuLjVle1mu1/81r06ryMY4r6zo48sl07/AJPysvyJ9LuZm0rZrEtpNqEb\n\
eaVhJBLEA8AYHI3ZIOOhxnNVbx2lt42LJtYn5VwAe+cDAJ65OK0vtsojgSP7PLlAxU4O3DZVSRx2\n\
4GMjH4iF4rW58kxusLTyqQFjIADD5AMdBuxyD27HAHbKKlU9yXnZq3Te69Vvt5m0JJS53Hfb9f8A\n\
M59UuIjtikKp256fnU8MHmsEkcszkZY89+n0rQe1DMnzgiRQwO/cQcDcOOMbs9/bpTorTy5VUSfv\n\
W+7gZwMgE/r+tKpVs3B/Ftp3PQliYzg2y3pvkrcpbzQRxhcEmMkKccDIJ5PI69+lUjaINTtb0jUG\n\
uLVvJdSm5H3YK+Zg4YAHj05PGQatQE2c6RSQSNcKoeZuRwy8r/tYyx4zyMcYAp8E0kM8u44t/MZc\n\
QkDb83JHrxx649xRzTpWVXW7+Sto3dLfU4Yv2bk4dur6fjv0JLq/E1kr4TzZUQq822buNwwOB26c\n\
fK3cZrEVJr2URRdRwSq/MTj3J57k1Y1TUpZFdSY5Dlim8birE4G0+mMduRxXU+FtNSysFmZf9Im+\n\
ck84z2/lWOIxLpwU5fJdtNf628iJVI4Km6016dtf8jmz4b1RI2kgQzfKf3chHP8An0qzo2iz6jeq\n\
15GyQwALIjdSQRtGcAHgc/X6Y7mKMyNz0HU1FeSYbyo+FHXHevNeYVZpx69zgjmNbFu9rdmUdV0i\n\
wv4EimbyyhBVoflYe2RWBe3EOiafPb28ry75S5ZjliSAAM+uB1rQ1G9KkwwnnozelcPrc5luzGD8\n\
kfH496rDwlP3JPTc7sJg9U5tu3czdTv2yZZTudvurWJNcyyn5nIHoKW+kMly5zwDgVXr36VJRij6\n\
GnBJDg7A5DEfjU8V5OnAbcPQ81X+tIMkgD8q7IYbnV5bGvs+bc2z4ju/JjQiIvECI5CMsufQ/wCe\n\
9ZmJ7uQlUklbOOATj/CtzStDRVWW9BZ+oi7D6/4VuIqooVFCqOAAMAVzSqUaLtTjf8iqeHpU22lq\n\
zizpt4AT9lk49FNSWl5f6YVaPzIgGDAOvAPrg967SKN5nCRIzueyjJrWtdIx814//bND/M/4VLxa\n\
lpKCYqzoKPLUV/Lf8DkmnvNdgeCxt3Mt1tabIIQEHOd3QAk5x7mut0TSINJtYlJEkyjr1AY+nqf8\n\
itSGPAENrEBnoi/zJ/qa2LSzS3wx+eXHLnt9PSsJSSXLay7f5nkOrDDwdOkrJu9uv/AX9alKCwml\n\
+aVjCvp1Y/0FXobK3hIKxhmH8T/Mf1qaSRIkLyMFUdSTisW710AlbWPd/tv/AEH+fpRCE6vw7HFK\n\
rOeiN2kyPWuSk1S8kBBnZQeyfL/Ko1v7tWBFzNkerk1ssG+5Hs5Hsfhj/kEp/vN/OtWuf8BzPP4a\n\
t5JW3OWfJ9fmNdBX1+Ejy0ILyR8xif40vVhRRRXQYBTLj/USf7p/lT6ZP/qJP90/ypPYa3PmdvvH\n\
60lK33jSV8Efoxp6AT9qkHYpn9RW7WToCLtlf+LIX8K1q+dx7vXl8jzcQ71GFFFFcRiBOASSAByS\n\
ew9a4++na5upJWGCx6eg6AZ74GBn2rf1y48mz2DO6Q4B9AOevY5x+ANcxX2fDmE5KbxEt5aL0X+b\n\
/I78HT3mwooor6Q7QrsfA1mVinu2H3z5afQcn+lcpaQPdXMUEQy8jBRXpttDFY2KRKcRRJyfYck/\n\
zrmxU+WPL3PMzOtywVJbyMjxDPunWAdEGT9T/wDWx+ZrnvGGpPZ+F4reDImugyEjsgY7v5gfjV2e\n\
QyzPI33mJJ9qxvF1xdafb6Xf2+CiiSJtwyOTkZH4H8q8ia5pR0vr+h34eg6cYQgrtfi7X/M5zwlp\n\
xk1KOeeNzbwgyMdp7AkfrW/4z1OGzt7mytAxmmb97JuOD82ThenUkeuKXwx4o+1zx2d7GqMz/K6c\n\
DdnI/Wsfx1aTpfG7kiKRXAVgM52kjlTwOc57VxylOrif3ysc7nOvi74hWfRX3s/kc/p1lcanfR2t\n\
qu+WQ4AJ4HqTXrOjaJa+H9MlEI33DL+8mPUntj0Ge1Y/wy01YrC41B1HmzOY0Poo6/mf5V1GrPtt\n\
gueXYD8Op/pXRi6zqVfYx2TPRx2Kc6iw8NIq1/PYg0F9t8B/eUr/AF/pXS1yukuE1GEn1x+JGP61\n\
1VdMT5vNo2rJ90ea+IIPs+s3aYwC5YfQ8/1rOrqPHNtsuoLlRxIuxvqP/rH9K5evXpS5oJnr4Sp7\n\
SjGXkFdF4etykDTMCC/yjnqM8/qP096w7SEz3Mca7cswHzdMk4GfxrsVVVGI12oOg9BXg8RYv2dF\n\
UI7y39F/mzPGVLLk7i0UUV8UeeFFFFAFfUJvItXYfePArmCcnJ5JrT1yfdMIh0Qc9f8APp+VZdfQ\n\
ZdS5KXM92ehhocsb9wooorvOgKKKWgDG16b5o4R0+8Tmsmpr2TzruV+OuBxjioa2Ssh09r9wooop\n\
lhX098KP+Se6N/1zb/0Nq+Ya+nvhR/yT3Rv+ubf+htXrZR/Ffp+p4XEH+7x9f0Z1lFFFfQnyIUUU\n\
UAMm/wBS/wDumvmevpib/Uyf7pr5nrwM83h8/wBD6Th/ap8v1CiiivAPoxKWkooAKKKWgBKKWkoA\n\
KKKKALdpdvCwH8Pf/P8An+lbUMqzJuQ/h6VzVTW07wNlTx6Vw4rBKr70NH+ZjUpKWq3OioqG1uFn\n\
QFeD3FTV4couLs9ziaadmFFFFIQVBfWKaiiozrHKvCSEf+On29+1T0Vvh8TUw1RVaTs0NNp3WjOQ\n\
jeW1uA6Fo5o29MEEV6Foupx6palgAsi8SIef8iub12z+0QG5jwJYl+cY5cZxn6j+X0rG069l0+6W\n\
eA8jgqejD0NfoNCvTzPDqrDR9V2fb/L/AIc6q1JYynzLSS/r/hjvbjSreQ74d1vKOQydPy/wrndW\n\
0ZJLiRr57i3Mx+ea2I2ydOoI64A6Y6dM11Wn3kV9apPAcq3Ud1PoamkRZY2SRQyNwQe9cM6XyZ51\n\
LHVKUuWtql33X3/qclbeB9KngXbfXc8Y5xvGM/TFYPiTwDPZQvc6VK1xGg3NC33wPY966W9gm0u7\n\
DwOwRuUb19jW1pGqrefupgFnHTHRvpXDUdej7yldHt08VXw9q9JqUX5L/L8TweNyDjmt3S9buLYG\n\
GZjNbSDa6Meo+taHxL0VdN1iO6tk2wXeWIHRZB1x9ev51zESl9iqCS3ArrTjXp8z6HrY+FDFUIV4\n\
rSW6PYvC1/a/YltraJVhGflPPXkisPxD4OttNnfVLFQyfI8wf7x2jC4PoAcY46DnrR4YhlsLS5vX\n\
jJjgj3BTxuIHSqPiPxVLI4t9RuYbW3uXJjAkAAwSAGbHqv8ATivHw9KtKtJ0no373n/wfPQ+Jq04\n\
UsSuTZavz8vU851z4dveWt9PEwuLueWONXkOPKj4z+P+fp5H4k8PX2g3jQ3lvLGOoLr2ycZ+oGfx\n\
rvfFnxCls7+W00siX7P+6WckMHB+8cc4Oa5Obx7r1z5gvrpbyORdjJcIHGOeBn6mvs8BDFw1nZx6\n\
LqeZjZYaUrQ3+/8Ar/hjlaKlupRPcSSrGsQdi2xOi57Coq9ZbHlsKKKKYgooooAKKKKAOg+Hn/I/\n\
+Gf+wnbf+jVr9NK/Mv4ef8j/AOGf+wnbf+jVr9NKAPnbUP8Aj/uP+ujfzqvVjUP+P+5/66N/Oq9f\n\
nj3PvY/CjpPCX/HhP/13P/oK1Nr6ZiicBiQ23hQQAR1J6jkAfj9KTwzEI9MDjP71y5B7H7v/ALLU\n\
uuYFgzEAkMuMjplgPw614GGqcuZqS/mt9+h5cpXxDa7mDW54amw0sJPX5wP0P9Kw62PDUbG6lkH3\n\
VXafqT/9Y19pX/hs6p2tqXtTtxG/np91zhx6Hsfx/n9aoTRC4heFgMOMDPY9j+ddDNGJonjPAcYz\n\
6e9YCEkKSCCe3pXnxfMrM3w9RuPmjkh0rk/EqhdVYjqyqT+WP6V2N1tFzPtwEEjY9MZNcHqlyLu/\n\
llXO0nC/QcCurL4t1G+lj6FO8bldWKOGU8g13nh+9ZsQsxBA3Ie/0rhoYzNMEXuefYV1Okg/b4An\n\
Y/piuXGxjKNjzsQk1Y9J0+dpbdJM4ccE+4rS1C3jurcxyj5JV5x2PqPeqGg2pa1QtwpO41dur+1W\n\
domuIQ8YG5C4yM9MjtXzUrufubo+Qxycp8tL4k+nQ851i2k0u68qQ70yArZOcY469eB+lWdJuPIZ\n\
sq8udxAzkqSQfl7DkDt2Hvl/ii6h1LUY1tzvjT5dw7nB7+mM1DZRuNrxK7TMuUjKnkHoT7cjn8Ot\n\
e9CbVKL2l/X5nvPklQiqmkkv6/D8zUdhqMTPKFWVFZ8h9uMbRg9x/EeOBwSDkVWW2e3nWW8aMqAd\n\
u4rtYcDPJGRyO/8AQGayhJlcSmQicCNo1Vk6oxycjkcMMjvWkqPG6eVEwkk+Y7hlVOcFh83GQxPH\n\
J5yCaFD2lpVVZru0ubz6W1tr1vucsqvs24R2/rv+P+Zl3EsZDW0EYPIdMAFFO7cDwfTb9cVlXJkU\n\
rFI27y1C5AwCccnFaU8IW5YwOftBG942ZSS2PmUDPJHU89x1zVPUNxkjBgZZGk8o8ZOe/wCQB9e1\n\
HPV506y3vbbbd/h+FmdFBwhaWvzM+1Xfdyu/VAMD6/5/WvUICpgjKY27QRj6CvMctFLvjAbIG4eo\n\
7YPqP61v6R4nFtAIrm2naJP4+PlHvz0rHHUZVoqUNbGea4aWKpXp9DvoBiIe9YepSmKOdx97JA+t\n\
aGj6hb39sJLZyyZK5IIOR1HNZ2vQnypQB0IcfSvFppxm4yPIwK5ZKElZrRnO98nrXHSsXmkZupYn\n\
9a7CuRuEMVxIjdQxr18Luz6Sl1OZkzvbPXJzSdqnvo/LunGOCciq5r6LDxU5JnqQ1sFbnhqxEshu\n\
pVysZwgI6t6/hWHXcaZD9n0+3iIIIQEg9ieT/OtMdVcKdl1N13LVaGn6a1wBLOSkPbH3n+nt70mk\n\
2QuHMswzChxj++3p9PWt4nNeOo3OPEYhxfJDcbEiQx+XCgjT0Hf6nvSgEsqqMsxwB6mitLSoMKZ3\n\
HLcIPQev41ekUebUnyJyZYs7ZbaMgHc7cs3r/wDWqSaVIYmkkbaijJNSVzWv3hln8hD+7jOT7t/9\n\
b/GlSpurOzODWctSpqF9LeSEscRg/KnYf/XqpRRXqpKKsjdJLRBRRRTGeu/D3/kVrb/ef/0I10lc\n\
38Pf+RVtv95//QjXSV9Fh/4UfQ+QxX8afqwooorYwCmT/wCok/3T/Kn0y4/1En+6f5UnsNbnzO33\n\
j9aKG+8aSvgj9GNrw+pCzk/dJXH61rVnaESbNsjoxA9/85rRr5nGO9eXqeXWd5sKUAk4HU9KSqmq\n\
zCGxlJGdw2Yxkc9c/hkZ9SKjD0XXqxpR3bsQld2Rz+q3Ru7otkFFG1MDHy5yP55+pNUqUkkknqea\n\
Sv06lTjSgqcFZI9mEVCKigooro/C+iNdSJd3K4t1OVU/xn/CnOagrsitWjRg5yNPwfpP2eH7bOpE\n\
sgwgI+6vr+Na+tSeXp8nJBchR/P+QNXqxPEcv+piB9WI/kf515NWbm22eDh5SxWKUpev3GJWje6Y\n\
upaA9jKRmRMqf7rZ3D9aq2UPn3CqRlB8zfStySVIY3mmYLGgLsx7AcmvOxVRppR3Wp7leo4yiobr\n\
X/I8e8L2Xn62IZpBAYcs5btt6/l/Suj8dSyXelpNHLujjnZZFC4wcnaf++cfn61j+E3N54uFwjiJ\n\
nkebB75Odv61q+Pbq4gt4bHdiN081gBj5i2T9BuJwO2MU67vjI99P+CGMvLHpLpr/n/wDf8Ah5Kk\n\
vhW3VCC0TurgdiWLfyIq/rDEyRJ2AJ/P/wDVXm/gzXTo2p7ZmP2K4wJB/d9GH0/lXpOrqpEMqHcG\n\
BGR0xwR/WqqUnTxN3s7tHRiaPs8Tz9JaopQSeTPHJ12MG/Lmuy6cVxQ4NdfZyebaRPnJKjJ9+/61\n\
1x3PHziGkZ+qM3xXbfadFlIGWiIkH4df0NeeV6y6LIjI4yrAqfoa8su4Tb3U0LdY3K/ka9DCSunE\n\
eU1LxlT7al/w9Ekl07OMlF3KM9eQP0JB/CujrG8NBTHPkDcCuDjnB3Z5/AVs18dxBUc8Y49kl+o8\n\
S71GFFFFeIYBSOwRGY5wBnilrO1uYJbCPu554zx/n+Va0qbqTUF1KhHmkkYczmSVnbGSc0ylor6l\n\
JJWR6qVtBKKKWmMSobyUQ2sj5AIHGTjmp6yddmwiQjOW+Y8cYppXZMtVbuY3160UUVsbBRRRQAV9\n\
PfCj/knujf8AXNv/AENq+Ya+nvhR/wAk90b/AK5t/wChtXrZR/Ffp+p4XEH+7x9f0Z1lFFFfQnyI\n\
UUUUAMm/1Mn+6a+Zq+mZ+IJP90/yr5YtdTt5woJ2Of4T614Gdpvk+f6H0eQSSVS/l+pepaQEEAgg\n\
j2orwD6QKWkooAKWikoAKKKKACiiigAoopaAJIJmhfcpPvW3aXKzr1G7+dYFPhlaJgymuTFYWNdX\n\
W5lUpqa8zpKKr2lys6Dkb/51YrwZwcHyy3OFpp2YUUUVIhyMUcMpwRyK5bWLYWt86xjETfPGPRT2\n\
/DkfhXT1T1i2+02DEEB4cuuTjI7j+R/D3r28hxv1XE8kvhnp8+j/AE+ZtQn7Opd9dDK0HVG0y7BO\n\
TbvxIv8AUe9ehoyuishDKwyCO4rymut8G6nuBsJmyRloif1X+tfa4ujde0XzDMsLzL20d1ub2q24\n\
uLGRcfMo3qfcf/Wz+lcojtHIrocMpyD6Gu4H3hkZGelcM4wxFeVJal5PUcoSg9l+pZ+IarqHg+K6\n\
A+eOVHGOxJ2n+dct4c0wQGa6nki+0RJmODcC5OR29810vieUweAJs/8ALSRVUd/vj/A1zWkzvc6J\n\
vZQPs0oV5AQCyEYxzwx/Ef0rhguWm4305rGuKdWGE5YP3OaS++2xuahrEk+k/YZAqorbjc7ghUJh\n\
skdjkZ5x9K8p+MfieyvfCkNlatZ3En2kiQxEBo3xnOMDOcdcda9V1GS0mtEiksoXKgyGFmLMCQVx\n\
25HI59PWvm74l+FbfwvewR20zzedlySAAowCAOTnqef8DXdleHouty7OLvbo333/AB/BHzuJTjR5\n\
oLTX/K/n+nQ4vr1pKKK+uPACug8JaXba7cSaZI5hvpFJtHAyHcf8syPft71z9bngkyL4p054R+8S\n\
UOpz0xzn6isqztBtdDWj8aVr3My+sbmxneG7heKRG2srDGD6VWr6L+ImiLrmnLfW9ub28ZCqp90Z\n\
bgSEAfMcYrxjxb4ZbQbuytllM01xCrlduCGJIxXHgcwjiYLmVpdvQ6MTgp0X5HN0U6RGjco4KsDg\n\
g02vROIKKKKAOg+Hn/I/+Gf+wnbf+jVr9NK/Mv4ef8j/AOGf+wnbf+jVr9NKAPnbUP8Aj+uP+ujf\n\
zqvtZ2VEGXchQDxkntVjUP8Aj/uf+ujfzrR8NWfmTm7cHbHwme5xyfwH8/avzXFV1Qpym/6Z9zOo\n\
qdPm8joreIQwRxAlgihcnvjvVHXXRbMI/wDy0cAfUfN/7Ka0qxNdlzJFED0BZhz9B7ev6V4eUUnW\n\
xkPJ3fy/4NjyqK5poy66vRbX7NaAsMSP8zeo9B/n1NZWiaeZ5BPMn7lfug/xH/D/AD610tfYYqr9\n\
hHZUlfRAOvPSucMqpGZnGFUbyD+eK09Sul2NBEcueHI/hHp9TXE+NNY+xWos7c/6TN1wPugY4+v/\n\
ANb3rnhFvRbs68HRcnZ9fyOY8Q6ltVrSE/MRiVh29v8AGsOztZbqdYoELOf09zXUw+GYL28mgguZ\n\
PtMalnUjg89M9yetdHonheSy029lRhFN5ZCsVzxg5/OtZ4+lh4ezhu/1OuvmlJQcob+fmc/Z+F7q\n\
BeilmA+Yc5FdT4f8OGOUNNnJ6k+lJ4avrfTTFFMCba7UbJGyAhHYg+u4dPXH0seLbxw9nBp1yyEk\n\
u4gb5j0xk+nX/Irx6k6tWfs+j6nkzxdaq/ZxWr69CLVNUvrfVruKxuIRaxAAKxU9gDgeoJ/n6AHI\n\
uLVJoVkdQZGY73ZM73PPXufw/iFW7CKRUEw3l3iJD8pHk5xubJ65xxzyMZ4IZJMlvPG13Bb7hDtl\n\
ELBR5hIyv+7uwMDOPmzkGuulSSStZNL5vTT79dNDOk1T1huvS7tp+ZFYW+x0aIlZh80SOhKEY4J2\n\
8hSc8nOAOwODZuNQCSuIpiJFIjV2K4w2AGwuM8jIz0yeOmMku0skUcKrJcS7QVU9TggZHYYB+Xpx\n\
+NbF34c1FLYyi4DS8syYPfnua2nWhTtF6Po3vv5L8dreps6cW1KpNa9/62KyvJcQCNrlpPL6IiBB\n\
6DAH06fWrOozFoo42uN7Rxqko3HMZOSRgfLgYxnAIxznJrFt3ZWCs6xy8gAsBkjkYz17Vt6g8k0c\n\
Do22F1+VBht6DBJJ7dAMeu4dOTm6cL1HOW6/G/p5f1Y0rR9nUio7b/PT+v8AgECzSWbtJHcguQEI\n\
cZwOmc9Rgd/QewqaVGhgP2VvMtgS8qZODE2d+35RyDwACO2c5rCeQmUIil5G5x/WpN88UwY5ilYg\n\
iRGyc9cZP48dOTWtFOm0m7rT8O3yuaVMLLmUo29Gat9E7qhkVvLQsCVLOyryVDZzznJyMjGMHBpt\n\
hbQLLM0jlvKVWQA4BYtwTxnAIH506It5IAJSKQfKOrbgc4QfXnJ4yvJwKfqOqweHLCGRrR5lnlEG\n\
+PnYzdSVz90ABuvTPI7pKc5Kolo276WSdvxV+q1v5nK23F0Y9exH4e1f+yjIlwjNFKRIxXkozZP0\n\
5549q6uy1S21kOkO8SpnAcY3D14yK5y6twNOtxBFBIRIWVtrbdpUZLEDhTgDrjpk4o8PXjx+JXW6\n\
j2zTxAK529OGH3SeOR/9fk1x4vB2i5uNpJd/6/pHJXhCV61NWkk+u9uljQvNMdHJhGR/cPUVzeta\n\
XK7edHGwfHzKR1r00iKcfvMBh3rF8TTpYaXM9s8Zusfu1cg7jnsPzrz8PXlzpJal4fMuaySu2eP6\n\
rAWj34IdOo9qyDXpl3/Z97bKl3uS+PdYiBIpYgMPbGM5+lee6naPZX01s/VGIB9a+ny+v73LI9/A\n\
4uFbRborxo0kion3mIA+tegP95sevArz5HaN1dOGU5H1r0myAOpW4xlTMv5bhWuY7x+Z6bdo3/rY\n\
6GCEW8KQj+AYPue5/PNPoorjSsrHitt6sciGWRI1OC5xn09/y5rfVVVQqDCqMADsKydLTdd7iAQi\n\
k/Qnj+Wa16zm+hx4mV5KIyZxFC8jDIRSxHqAM1xMjtJIzucsxJJ9Sa6vWmK6bNg4JAH5kA/oa5Ku\n\
3BxtFsikt2FFFPghkuJRHCuW7sRwo9T/AId66ZzjTi5zdkjRtLViRI8sgjiXdIQSFyBnH1rStdHZ\n\
1Vrp2QnB8tCPyJ/w/OtKzs47WNQAGkAwZCoDNznkirPavksdn9SbcMN7q79X/l+ZxVMQ27Q0R23g\n\
yJINAhjiXaiswAznue5rcrH8Jf8AIFj/AN9v5mtiv0jKpOeCoyk7txX5HzlfWpL1Ciiiu8yCmT/6\n\
iT/dP8qfTLj/AFEn+6f5UnsNbnzO33j9aSlb7x+tKgBYA5A749K+CvZH6L0Ok0tStkm8YbnI/T+l\n\
WqZCnlwomc7VAz60+vk6kuaTl3PJk7tsK53xBMHuhGrlggwR2B749+x+ntXQSuIonlKhlQbiCcA+\n\
2fc4H41xs8hlmeRiSWJJJ6mvo+G8NzVJV300Xq9/wOnCQvPm7EdFKASQAMk9q7Lw94cWNUuNQTdL\n\
95Yz0X6+9fXVKipq7OvEYiGHjzSKXh7w61xsub4FYeqx92+vtXaKoVQqgBQMADtS0V5tSo6juz5v\n\
EYmeIlzS+4K5bWJvOv5OcqnyD2x1/XNb2pXi2kBOf3jcIPf1/CuctlQbri5ZUtouXZzgfSuepNRV\n\
2elldJxTrS9F/X4Gnp8HkwAtwzfM2e3p/n3rhfHnihJ4n0zTXDoeJpQeDz90f1/KqXi7xXPqTyWt\n\
izQ2Y4Yn5Wl+voPb86wdG0uXU76O3hIDOfvNwBxWdHDqH+0Yh+dj6DD0adD/AGnEPVa27ev9fiS+\n\
HopX1SAw5DCQYI7DNeh+INBXVoGSMbbiJ3+YjCtuO7g9/vY+uaqRnS/DEJWeLMiYCurAtIcfMcds\n\
fhXOSeL75Jw9rhIlOEj7KOwrhn7bFVPaUlt1PIm6uLqKrRVrbN9TDu9KvLacwywOHBwMLnP0rt/A\n\
2ove6dLo90cXFuN0O7jKjt+H8j7U3w14ntZhb2k9usbrlUOcjJ6cnOOap3Wgarp2pnUtOdHkDmRF\n\
JG8gnBBHfrg/Wuh4lyvSrLla1T8/8jsWOk08PiUo21Tb6/5d/U6RgVJDAhhwQe1b/h+ffA0JPzIc\n\
gex/+vn8xXM2XibS9QcQ6iPsV4PlYMcDI4wG6fnW1DbyW0qXFo4mQc4HUj8OtaqtytKaszLGUnVp\n\
ck1Z9O3yex0Vef8AjCDydakYDAlUP/Q/yrvYZUmiWSM5VhkVynjyIZtJu53If0P+NejhZWn6njZd\n\
J08RyvrdFbw8P9DzheWIyF5OPU9xz/P1rUrK8OsGtXUbsq2T0xznGO+flP6Vq18bnX++1Pl+SOqs\n\
mqkr9woooryzMK5zVpvNvHHZflHHp/k/nW/cSCGB5CVG0cbjgZ7frXKMcsTzz6nNerldK8nUfQ6s\n\
LG7chKKWkr2juClopKACub1KXzryQg5A4GDmt69m8i1kk5yBxjHX8a5ckk5PJPJrSC6hFXl6BRRR\n\
VmgUUUUAFfT3wo/5J7o3/XNv/Q2r5hr6e+FH/JPdG/65t/6G1etlH8V+n6nhcQf7vH1/RnWUUUV9\n\
CfIhRRRQBHcf8e8v+6f5V8Z9q+zLj/j3l/3T/KvjMdK8TOPsfP8AQ+o4c2qfL9Sxb3c8BPlyEZ65\n\
5rUttaUkCdNox94GsOivEcUz6J0Y/Z0/rtsdhBPFOu6JwwqSuMVipypwetaEGrXEeA5Dr7is3T7E\n\
OM47q/p/kdHRVG21SCchclG9D/KrqMrqGRgynkEHINQ01uJSTHUlLRSGFFJRQAtFFJQAUtJS0APh\n\
laJwy1vWtws8YIPzd656pIJmhcMhNcmKwqrq63MqlNTXmdHRUVtOs8eVPPcVLXgSi4uz3OFpp2YU\n\
oxn5lDKeCp6EdxSUUk2ndCOQuoTb3MkTHJRiucYz7/jSW8z288c0Rw6MGBrT8RQ7biKVUIWRMFuz\n\
MOv6bayK/VMHiFisPCr/ADL/AIf8bnr0Ze0pps9StJ1uraGZPuyKG+ma5OGF7y9EcY+Z259vetLw\n\
PP51gYGP+qlAH0PP881ljV5rFTBptm0t1Kdr3MmBHH/+rv0FeLi26TcY7nm4RfVpVYrpa1/n/XmZ\n\
vxSv44o7DR7c8RkTSe3ZR9eprH8Iz27yx2d9u8pX3jb3JGOf05+vrTdS8P6rPetcy5nMwEgmkIUs\n\
Djt+IFXdI8N3kNwFljKyEjJPYZrgqTpQw/IpXbPRrVsPVwsKEXe2t+rb3Z1HiXStOh0cyiWRZ7hs\n\
RkvksSeRg8d/SvJ/id4Ut9a057uzWKPUhyWluBghQPlA45PrzyMfT1TX44l1iyhupJWT7MdsQwMH\n\
1Hr0/Qd8V4l8f5L/AMrS3WUjTnBVEBwc4yCeeSQRz/XNa5OqjlDlnq7/ANen6nzNS3sJc6ckr216\n\
dvkeMupRyrDDA4NNrp/h74dHijxEmmuJAskb/vF/hYKSOpA7etb918KdVhvrSITxNBcyyIkuR8qr\n\
wHbnABJA619fUxtGlJwqSs7XPEhhp1EpQV7nnNeh/C7RopLm4uNRtJwWhzaXGPlSTkg9Rz8px9O9\n\
D+A9U0TxJZsbF7ywiaN5ZWQ7OTzkcHHFe+2NrcSOLHT7cCGMKu2NAqoVOVBbkhSBnr0J55rz8wzC\n\
MYKMHo+t9vX+tTtwmEcJOpU05f6/VGj4X0K31XT5ZxcMGEjInkkYT69iea5HU/Asmi62dZ1OWGSM\n\
sAp2BlTaOPlwMHAzxxxXa/2rBolpFZwRgSgBptpyC5HJqDWr5Nb0Y5lG+AhthHX5gM9eo9frXyVD\n\
EVvrDSfuSdtvyt3f+Z6NSFdpVZq8ei7I+Z/ifbva6tHaR2UMCNl12fNI5JyST15zkD3rn7vw9e2+\n\
j22p+WxtJY95crgKd23Ge/Ne8SeGpbrXfNvrIztHmK0RVYEpwTgNyAPmHTAGO9W/E3gb7RoVtaPb\n\
Gzs1f92pwSBuzg88Eivp4ZpGiqdN6d7/ANf1qcc8Aqk5csk30/4Gp8yMCpwwIPvSV634703wlp6X\n\
Ek73E16siwJFCdqqEUKRz6nPOeoryeUoZGMalUzwCc4r18LiViYc6TXqjy61F0ZcrZu/Dz/kf/DP\n\
/YTtv/Rq1+mlfmj4Ftprb4g+FxNGybtStWUnoQZV5FfpdXQmnqjJpp2Z8+PaveaxNDGODI25v7oz\n\
yf8APtXW28KW8KRRjCKMCobO0S0ads5lkcs7fiePoMn8zUc+p2sYG2QSnOCIzuxyM89B16E1+OYq\n\
VbH1uSjFtL+rv/gn01WpKs0orRFi6nFvbvKwJCjoBk+1YKmEzG6v5Fjikc7QzBS5A6AnHAAxn2q1\n\
ZR3GqzKbg/uEJztGB9B79OazdfuRLqcdjabfkWR3UDIjRVKr07kkn6HJ6172Away+D5neb38l2Oj\n\
D0eXmv0R0K6hKYlNvDCIiBsYNuBHtjiop7i4aPNxOI4+5GEB/Hr+tcLNp622jz6ho/2mGTjLK+07\n\
jgkYHOMA9fUVz8fiG+z/AKQVnPPzPndmuylTdZN0rO33nqYbD0q13B2t3Wv6nfahrEVvE/2YgKoy\n\
0zDgf7o/rXnguJtQ1yKWNGaQuPLXGSADkZ/nVjTpp9b1S2tblwIXb5kQYHH+fWuntINP022uIbm1\n\
ktNRKFN6sCAexGT0/nzjPNKdRYe6esn+CNcRiaeF/cxV2/8Ahi7qumwQrp7vF9n86J4iyg/u2yCH\n\
znI7/hThruow2MlhKiPIybUcDG0EYHHf9eQarCW6vzCl28kkUIJVnUBgmOuQPmOB75IPbpm/atUb\n\
xdLHLpscfh2WE5ljkEn74YPzjj2JAAOFznrXJSoOqnztPlu/ne+/e3+R4aUU1zpS627a6fgtemhc\n\
WCNoQskbCU5OQMswPbHcDGaryxrbrJE8eY3XbtVVYq+eCCDnHTOO5x2xVq3uQZ7nyRGiSY3pwq7N\n\
uCOSccE8A9KbOkk+0hTFIys8LyHasrA9s8ZyMkjjnntnRSUEn1+9eVv+G2V0jfmlF2npHfzX9fPu\n\
X7XQNS4jWzhRXH3i+NnOeQPfnGMelWNN0T7TdSpqsZihgIJAkOJG4HXGTwM545NbX9srLocF7CcL\n\
KpPTHzA4P4cGuI1DX7meYmNjs7E964IVq9a8Xp09Nfn5/mYUadfEXk7R9Pu7vsdtY6TptnetcQJI\n\
STlQWJCcY4zW2I1aPdGdy+hrzfR9bmMwjkbDH7p7H2rtrDVIIrCSe4kWNR1z6+3rXFiKVRPXVnLj\n\
cC4rnbbf4nE3EJh8Rz2ksbKJJCUbGRjGVOM+g6YOcYzyRU9xloZn8ia3kiIUpKQ3zE4yvsduFAAH\n\
U5FO1i7S/wBbWe1D4VECE/KGZdxBwR7j8R7VS1BmDp+6KAqFIlOW5G4+vBLk9fx7V7lGUnScZLVp\n\
eev6bX2OzlqS5VJe80vv6/I3/BmnxvBJeTAySM5RS53HAPv7n+VbupaPb39u0c8OAf4k4YfjUnh2\n\
0XT9LhiJBKJknGOvP/1qL3VPJ5LbQeg6k14VWrOdZyg9tjzakq2IrSlTk0k7K3kcTdWc1hqU0T+b\n\
MwAMRVG+bcew5GMbgV6E/Wp7G6lWYwyoYIxGTIu0RH7uN4Hb6c9Bxnp0MWtqzgSKdp7mp9T0ex1V\n\
FuHDLIAF3oRuxnOOR0zzXdDMJU2udW8/P0/r7jpnUlSVq8bLuum3T8d9zlIzLfh4TIJJDHleBgYI\n\
yMfj6/nWU0myaGaLaqhy8SowyQMqSPxz0z0qaeJ7TVZLeKVyYn2hw20jJ5AIHBwB+daNwZrtWlZA\n\
Id+GYIB5Z5XGcDOSevPUdO/fGNOMLrou26/z1+49HWjUurcr/UnbxdL9mKxWxe4A+8y4H6/yqnbx\n\
i9glvrycmcn5sy4xkEbT024I64z0xz0qxWu668gSJ5mN3IO0L3JPAHAJ61fvIo7exuDMyyAsiOxG\n\
ATjdjA7Dg45znnpUU6VOm+aMfd6vyfbv5dLmNanQhLlpKze9v8yXwvpM8pTUPtP/AB7bo1QKMEFR\n\
n6Dkce2etcb4stWa9mJUiRTn68c11ui65LpZu4pYWnEkjOgVsYYk5B/+sPwqeOy/4SL7S11CkM8O\n\
Auz8ev5dPrWCnUo1XVn8P+f9MdGpLC1XOqrJ27f1ve55LXd6NdlrWzuuSybSc9yp5/lVPWvCyRXE\n\
sdncxvcqokMWRyORx78dKpeG52hmlsZwVbJZQfXuP8+hr151o4qjdbr8j6HDYiniE4xdz004zwcj\n\
sfUUlUNHuhNbiFj+9iGB/tL/APW6flV+ueLujz5wcJOLL2kZ82bPTauPzOf6VqVkaW+262kgB1I+\n\
pHP8s1r1nPc8/EL3zO17/kGy/h/6EK5Wut1pd2mT4GSAD+oJrkq9DCP92KlsxyI8jBY0Lueijqa6\n\
Wytxb28a7VEm0Byvc/5zWXocDNM0xA2KNoyOp9j2wP8A0Kts181n+Ncqn1aOy39e3y/M5sRO8uXs\n\
LSfypaSvmzmO78Jf8gWP/fb+ZrYrG8IMG0SMqQcO44Pfca2a/aco/wBxo/4V+R4tf+JL1CiiivRM\n\
gplx/qJP90/yp9Mn/wBRJ/un+VJ7DW58zt94/WrmkxebeL6L8xwf88dvxqm33j9a6DRoPKty7dX/\n\
AJf5/pX5tja3sqL7vQ/QK8+WHqX6KKiu7hbWBpXGQOAPU+n+ewNeBTpyqzUIK7eh5qV9EZfiK5VU\n\
S3XBfO8n04IH6E/gRWCASQAMk9BUk8jXFw8mPmdicAdyewrsfDOgi2C3d4v7/qiH+D3PvX6JhaMM\n\
Bho0+q/F9T0JVI4Ol72/5sd4a0FbVEurxM3J5VT/AAf/AF66Oqk+o2sPDTKzeifN/LiqE2uLz5EJ\n\
Pu5x+g/xrmnUc3dnjyoYnFS53H9DarOvdUih+SDE0x4AHIB+vf6D9Kxbm/ubkbXc7TxsUYB/x/Gr\n\
MUcOn2r3N46x7RlnY8KPT61z1a3IvM66WWxp2dXV9Eipq08djayahq8jHHCxL1Y9lFcZFcX/AIsu\n\
niaeK1tYRvWHoqjPf1P1qxJqkfinxNFbvC7aeQYolHDL0/efU/youtatPD00tnotqC6th5H65FYO\n\
VRP2ajeo/uS/zPSqTqUv9nhD95bytFf1v1NabSNI1S6nuJFkMkTFZtikIQM4bPTkAfjVTS9f0TT7\n\
sW9rbOFLFPOxwATwf5Zpkd/q3iO3hNgTbDLG6lb5Y+gUc9zgdB3qfS/DWlWLrJdNJfSjsRtjz9O/\n\
41hDD3i41m/JLp69DCngueDjiJNdFFN/8N6Xe3Q5yLQNU1y8nkgAaHzCBO7YVhnt61fPw+vgARdW\n\
+fxH613wuptoENjLtAwPlJH6Cq0t/cqcFViJ7FOf1rqjWxCtGFkl6Ho08ZXguSnZL5P7zhl8G6xZ\n\
zJMsdvceWQ21ZOWx2rTtfE4j1RY9R08w3hcoz88ZG0EjvwR+VdD9tuc580/TAxVLWdOi1+EI+2HU\n\
EH7mYcA/7JqasHV1rr5rp8uqMa0FiH+/SXmrq3quxzeu+EbhbqWSwdLiMsTtzhh3qO2sbjRLQTaj\n\
fzW8ZHy2sMxVm/I8VkyS6pompsJmlhuAcnJyHHqPUV0PisJenRNRvCyrOFWZSPlAzyf50/30HCjO\n\
ScX1W5D+tUZww9SpeMuqWr0v5rXuvQ67wtfTrZWj328falLZfGQc8E4/2dv8z3qx43TdpEbd0lH6\n\
g0msAeVCyAbATyOmCBj+VS3JOpeHLiMkGVFyc9yOQfy/rXRg6t+WXmcGIppVIYqKtrr+SOa8NljN\n\
KoJ2hNzDsTkY/m1b9cfZXDWtwsiYyPX/AD+H0JrsAQVVhnawDAkdQeRXkcR4aUK6rdJK3zX/AACs\n\
XFxnfuFFFFfOHMZ+tS7LXYGAZz0I6jv/ADFYFamvOTMiYG0DIPoe/wDSsuvosvhy0U+56OHjaAUl\n\
LSV2m4UUtITgEk4AoAydel+WOIHqdxrHqW7l8+5klClQx6HGf0qKtkrIqC0v3CiiimUFFFFABX09\n\
8KP+Se6N/wBc2/8AQ2r5hr6e+FH/ACT3Rv8Arm3/AKG1etlH8V+n6nhcQf7vH1/RnWUUUV9CfIhR\n\
RRQBHcf8e8v+6f5V8ZjpX2Zcf8e8v+6f5V8ZjpXiZx9j5/ofUcObVPl+oUUUV4p9OFFFFABU8F1N\n\
AwMchwOxPFQUUEyhGXxI2bXWSFC3K5P94f5/wrVguYZseXIpJ7Z5rkaVSVOVJB9qhwTM3Sa+F/ed\n\
pSVzVtqlxDgMd6jPB5rXttUt5zjJRv8AaqHBozcuX4lb8vv/AOGL9FNVldQykMp5BHINLUFBRS0U\n\
AJRS0lAEtvM0LhlNb1tOs6ZHXuK52pbadoHBU8Vx4vCKsuaPxGNWnzq63OioqK3nWZMr17ipa8GU\n\
XF2ZxNW0ZQ12PfprEKCY3DZxyB0P5kr+Vc1XaFBKrRsSFcFThivX3/z+NcbIjRuyOpVlOCCMEH3r\n\
7jhnEc+HlRe8X+D/AOCd2Clo4fM6fwDJtu7le2Eb8j/9es+93Lf2rRF1S5jeKbDYCuqgKwPbIOPw\n\
PvWh4FT97eSeiqv6k/0qRdMTUZb+wl4BVip/uODgMPpz+BNa5kl7Ryf9bGdoyq1U+y/4f5GRdwpJ\n\
pDGzvWuL23BZo2b5FbPUdcdgcfpWloviP7DFNFfJJdyowLyfxDIHGD16E8cV53pc1xYakgQ/vA/l\n\
uuMhucEEd69GvLKxg0aKeItb3hyqxr8xYN1AUg4HB7Y4rxMTRhBqlU1T12/rT/hzlx+E9hPkl713\n\
b+vL9NyHxJqVvql9ai1j2uCUeWVdnHXb9Bg+vJ79K57XtA0vVZtPur+0luI7VysKucbh6MGwVHyE\n\
he3OOTWpE3lRrKjqZ4+HJwDv5wccdfT2HTnFrQ7a2vNckiv03uF2gtnLH+6T9OR69q0hNYaleHT5\n\
6X/4fs0vI504xhaPwxXe787d/wDhjEtNE0rS5bqSxthbzXexRbxDcxwSpCn7wyPoMc8443E0q7Gj\n\
Sak8/kqiFzE0TZCr19PTOMehrU1O003QUSa0gbzomZkZnJ+Y8Hqfeubm8ZSGO5guHJWZGjJQZK5G\n\
Kx+s1a9nRv0u3+OnoFOnWrR54LTzW9iawtI5lZZhH5TYcL5xjAYEbeo6HavAwMD6VLo13cWVy8kE\n\
eLaV9rNlikmCckEjPqB298dMGK90yeyFtFujuU6NIMJKAc7SM4HAAz1OOtUL17zVL6SPR7eY2qkr\n\
FFCDtUHr+ddns/aLlcbLre9v6/pWZtSwFbEVHTfu6a3Vlv8A1221Idd1BrrUrho3/dbztwetU7a7\n\
uLeQPBMyt7GtZPBGvyrk2iKPR5Bmqd/4b1nTUMlzZSCJerJ8w/Suim8OlyXufVQwVBw5I1YuXa61\n\
Og0DxNctdReeweRflDMMkA+hrofH9zcXPhy1kWLcDMASpAffnAwTx3PY9q4HwwizatG7uqxRK0jl\n\
jgDAPX8cV3Go6jdXekCyubaGHby4z8+OoIAPy5Ax3JrgrYb2eIjOmtF/wdv6+R8tmVGnTrKmkk73\n\
fTy9T51+LlrqD3lpd3EcS2zRb0EcWxlBxkv3JzkZPpXnVfRfxO0i7v8Aw3cLZTLsxGqRBCGdiRnn\n\
uOQeR1yap+FPhxpemWyR67ardX8TMXZCSjKcBRgcnHPT09iB9PhMyhTw6clrtZHh4nBTq1XKO39b\n\
fIX4T6G99aaBbX8IivLS7t7iCdxkrGZVcICPXB69MmvtSvnH4ZeG7m11Wya9CQ2FvIPIjOVZsvuU\n\
YJPAz+uOa+jq2yyv7WVXW+q+V1t/Whz45Qi4xitlr5nhep2stxdSCaaO4VWO0NIoA5P8JwM++Ksa\n\
fpkUuHmuYdg/hjcE/TPQfrWDLA7X145uZ7y2hLN5EjErCVPTrgnsPaqHhnxNbGFbLVD5TR/LFKwy\n\
AvZT9OgPtXz6rNpxp7Lstvl/wD6ulQ9qnGm3pb8fL+vI9CluoLaHybPaXHAC8hPcn1rzPxJqTWOs\n\
TIY0kidweeo2DZj3+6K6jUdbsbK1MiXMTPj5dvIHv7/QV5jq16b28MoBCL8qA+lGHp+0k29urO3D\n\
4KHI/aLTz7ndzS/6Xa3ll9njSaAO0AQBT8p4x0549+faqmoeG7a/t47qyKtPtBnSPgKx7Y7f/Wqz\n\
4XtbnU9AFhE6BopVf95yMDkjoc/lV/w/fNoss0FzHutclZGCDKPk8DHX8PfHQ58iVSUG1B6r8f8A\n\
h/zPIdSdGo1T3XTuv6281YzPDugNYXH2u6UQW8XLOxrS8Saja31xF9l3AQgr9oZTtbgEAfn+AOem\n\
ag17V2vpJkje4Gn8FUVQm84HB3ckZPOMkcdDVmG0hs4jeavC8YRllhAcYdjnJ2jjpjrk44NKXNdV\n\
Ku/b+tyKlSdSanNa7Jfn6vv0RQvLqWRI45oHEylUiRkAPI44Iz+Pqx6VPqNjd6ZcW8V0VkjnG1WB\n\
wExgnAPI/DqOPTEGveJLK5mtbgEwTwNnKoCzr1A/A4PNZzeN5bieZbyNWt5gUwQG2g98VtTo1pRT\n\
hDTW/f7zSGGryhyxhZL+tH+P4M3Tc6faeFLVrgFJZMyCVAMhgx6Z+nTtWVH4ztZoVsri3LWioIlZ\n\
xkgAYB4rJvPtusxW+n6ck11DDz5uMgk/gOBVm18GzqA11FNK391Bgf4/yrdYOlFN15a3v5/1/Vjv\n\
oZfSnHnruzeur1+7dFXUNdMOlJptnKZAPvSdFAznAH8650yy7txkOf8AerspdHtYwYpbQIfQ5Dfn\n\
1rE1fRVghae1LFF+8h5IHqPau3D+wb5dU36HpUcJTpRtD/hytY37CRVlPIPyt6GvR2n086BKt/KF\n\
M4EsYHUFec+3P9a8lr0bwULTV7WG11G3Wcxj5CSQRz7fSuTMsPGlab2XY87MqVocy2XYWwhYXEK7\n\
DGiHlCmwkAsSQMZ4wO3QACn31pBE8kPmDag4AiYjd/dJHpgA8ZP4Gq8IntppkELW1wshVCMEI3IG\n\
RjLA8ccZBpbrB0/yZdjXpVC7QuPLLYG4quPunt7HqDxWT+BNW36b/wBLX5Pe9jzUpqSabt5f8F7a\n\
9za8M6heh5Y715PsixMEypIGMY+bryM9T27ZFYuq660tyxgAODjJ/pW/4su5bfR44zIrFol3Mp4J\n\
wOf615ZdXzsxWE7UHfua58NQWIm52/yOjL6HtE6ttzqodacPidVK+3Brp1114dCV7ErLKW2kMjMF\n\
X1OPTIryEsTzuJP1rT0XWLnTbkFJG8tuGGeDXVWy2y5rHXisB7WFkdeI3tFSS5gmMk58zdMxCHPJ\n\
xjqeuTx16Gr0EsLRPtt5DCsQMqF+r7wFw2cjOe/UDOOKXWNTe/j0gRLvmcO4T1bHyjqM5ORTrzS7\n\
m2aICY3Ty9Vjyu194OTjjHJ7c89KyjWXL76V3f8Arp2XW273PH9ol8btL1ff7lt5FHVI5rvw9qVv\n\
pURS7MZESnLHfhepIPcn0OBwDXN/DKfxXrVldXfiadLW2EgiVXXJdgQpzuJGMnIGOSOozz1lxZXe\n\
k36RGaMSsNyPg7XyQApHXnJyPQZplzqkjwJAski+WW/jO7nsc8jAzgc8HqetdMMSvZ8sIrXZq/ze\n\
ui6XXXZWNlFzl+6d0/u16u/a2n4kslg08gSEwK8q78B93lYwMHaMc9fxPXGaz5maNJsXe1nYoRGQ\n\
DIvPzAbgNoB6knnjFXYJFgEspURI8YPTvnBP0yy5J9xzzjOkTK+SZcfKsalQSSQNuenDHj269TjM\n\
RcXHl2vr5duz83boupVpapvReXT8f6Xc0pdJtrSwbUbhXVjK0iW5AwVG4Lnj3Jz7/SvO7y6kfUZL\n\
lW2yb8ggdMf/AKq9Huru61DSbyO7EhEKEo7R7SOT8re+MdPevL3BV2U8EHFaZdOTm3P+kzsyiPKn\n\
J/FsdtpGoi6iSeF9k6Y3Afwn/A11dhfx3QCORHP/AHegb6f4V5HZ3c1nL5kDbWxg5GQR6GuostZt\n\
blR5jCCTurnj8DXRiMLKlLmhsezVoxrLzPQAWjcMvDqcjPrW7BKs8KyJ0YdPQ9xXA2mstboolkjm\n\
g7b35H0b/wDXW1out2c8jGxuI5sjMkIcb/qPX61yv3keTisFUte23X+tjpLiPzYJIwcF1K59MjFc\n\
RXbxSJNEHjbKn9K5LU4zHqE6kAZcsAPQ8j+ddWDe8TzqejaZqaHGUsdxDgyOzFW7fwjHsQoP41o1\n\
W0//AI84v90VYr4bMJOWKqN/zM4Jvmk2xaqapdizspJcjf0QHux6f4/hVuuX8TXHm3i26n5Ihkj/\n\
AGjz/LH61ODoe3qqHTr6GlCn7Saieo/DRmfwjbM5JYySEk9Sd5rqa5X4Zf8AIn2v+/J/6Ga6qv2b\n\
BK2HppdkeHjNMRP1YUUUV1HMFMn/ANRJ/un+VPpkwzC4/wBk0nsNbnzpp1o1xPk5CDkkHH+f8+ld\n\
EAAMAYFRW0SQxBUHuT6mo9QvI7EL5ysXddyoOM+59BX5FN1cdWUKav2R9nUm6srL5E8kscSlppFR\n\
QM5Y/wAh3PtXO6jdyapcpFaxMY1yEQDLHOMk/XA9qtWlpe6/MrNiO3TCluijpnA9TjNdPHa2uiWh\n\
+zx7pW+UE8sx/wAK+mwOX08v/eTfNU/Bf13/ACBSjRkl8U+3RepkadpkGjhbi+ZJLsjKRk4VPcn+\n\
tUJ/E63GoW8dw27T7iZoVkUFMEBfm9CuSRyCferurQTDSdSu7ltsgt5CN3XO0jn0+lcv4ft38R6T\n\
cW14ik26s0E2NoU45yfypYjE869pJ6J2flfsdbjGnH28/e1s329PS6/4J2U2mOD+6cMPRuD/AIVW\n\
mtXgXdcPDCvq8ij+tcXc614k0eEWk8rKq5VJHj3Egejd6yLK3vtd1FBI01w5OXeQ8KO59qIRmo80\n\
prl77ndCKjFznUXL5L/hkvxPQG1vSLAbluRe3PRI4AWyfTP9TXB65q9/r13ibdsBIS3jBwv+J963\n\
k1DQ9L1KSCztZJSx2+chyyt/sZ9zVuabXFaaWz0JYDMnyMu3eD68ms6dSUZc6hq9nJpfcjCjiKql\n\
z0qT12cml/w3y1K2n2T+HvDc9/JCy3kh2r22jtn8fzqj4P8ADZ1ueS8v2c2ivjGeZW69fTnrVyxk\n\
1iO5EPiCKYWFx+6dplyFJ4ByOnNbHha6EHh+Sw5W5tpWjfPGQxJ3D2xkfhRGVWHPreUrart5egUJ\n\
V6MqnNbnlbVa6Pt6bfO5quoleKysUVIE+VUXgcf0HNdBY2MVoo2AGTu5HP4elVNEs/IiM8gw7jjP\n\
Zf8A6/8AhVi41WxtziW6iB9Ac/yrqpUrKyR4+OxE6kvY0rtLe3Vl2kdVddrgMp7EZH5Vm/29pn/P\n\
2n5Gp4dTsZhmO6iP1bFbOD6o872VWOvK18mVr3R45AWtv3b/AN0n5T/hWDJG8UhSRSjr2PWuxR1c\n\
AoysD3BzUF7ZxXaASAhh91h1H/1vas3E9HCZlKm+Stqu/VHO6tZQa5oUqXKgyojMsmOUcDOR/nvX\n\
H2hbU/BVzHHia7gKhhtywjUnGPzNdXrkN7Y6RfQwoXkmTZGyZPUgH8cEn8K4+y1aPw5AYrO3aZ5c\n\
eZO4IR/ZfpXDKnNJxhq1JNfqenOM6lJew960rq21ut30X6rYZ4Z1vUUb+z5IZLu2UE7MfPGB3U+3\n\
oa7zQrpVKXEbiS0l+UuOin39CDxz6msuOWS5uY591naWF9bcA4WUsffHoeMY6CufS1uPCzEjUWDT\n\
/dgiQP5vYZBBFOniVOVrJN9NXfv6P+mT9bhi3KlUVm9lvd9dtLrv95r+JNMbTr5tqnyJCWQ46e34\n\
UaPqQtwYrhj5OCQduSp/w/P+eepsguoWAsdSj/eiJGYd1JUEgdeQTj/HmuQ1nS5tLudr5aM8pIO/\n\
/wBevXtSx1H2VVXv/V15kU5qp/s9b4l+Pmjp6KxdE1HcVtpiSSQsbdeegX6fy+nTar4XHYKpgqvs\n\
5/J90ctSDpy5ZHOauSb6TJ44wPwx/SqVWtTbdeyD+6SP1qrXu4ZWpRXkj0aXwIWikpa2NBKpatce\n\
RbEL99+BV2ub1O4+0XRI+6nyrVRV2S9Xy9yrRRRWpsFFFFABRQawNY19LcmKzxJL0L9l/wAaunTl\n\
UdokzqRpq8jT1HULewj3TN8x6IOpr6h+C9wbv4Y6FOV274nOPT941fEE8sk8pkmcu56k19r/AAJ/\n\
5JL4d/64v/6Mevey7DqlJvrY+azqu6tNLpf9DvaKKK9Y+bCiiigCO4/495f90/yr4zHSvsy6OLaY\n\
+iH+VfEulalFfxDaQsoHzIe1eNm8W1FrzPp+HJJe0i93b9S9RRRXhn1AUUUUAFFFFABRRRQAUUUU\n\
AWLe7nt/9U5x1wea1LbWlJCzpj/aFYdFJxTMnRjvHT+ux2MU0cv+rdW+hqSuMR2jYNGxUjpitO11\n\
iVGxOA6e3UdKzdN9DNqUd1f0/wAv+HN+ioLe8gnA8uQZPY9asVAJp7BRRRSGS287wNlTxW7bTrOm\n\
VIz3Fc5UsEzwuGQn6Vx4rCKsrx+IyqUlPbc6Oud1+JU1BnTP70CQg9ic5/UE/jW1aXKzr1G709aL\n\
+1W7tnQrmUKfKOSMHg+uOcY5rHJ8X9Qxf73RPR/o/kzmpT9jO8i34JiC6XI5wDJKefYAD/Gsu98S\n\
rpPnrBaTTX9w5UMy4QNn7vqcE+lSadqqWnh4QEbpzI0YjHBIPJ57dcZ9M+lZunXTNd3S3lxB9sSV\n\
5fLY/LCpJLc9MgnP+cH3swnepJNX/ry6bCbdKc5yV7vbXZddOl7b6FPT7GPTpbVr60mm1K8kZMo3\n\
+pZicFvT1q/JPaS3LT67dZkysYiQrtKj3xnHUEcfjmquqXN5da3b6dpshht7sBjKwyzDklmb2wTx\n\
xUupeC9N+zP/AGfqTG7UcCUjY5+oHFcDgqmtR2b7K/8AnbtYqGHliGqteXxbaX/HXlV/60L4tLN/\n\
EUtsihbFokfcsmSiBfcHgkgde9V9VsoLCa1e3lSWIlmQ52FGyTuJHGcDA4H8qgNtf3tl9mtLOdbk\n\
wpAHYbAig8jecZGc+vtWI7ax4ZvI4L2FWVjuQN86t64NRDD1H9rW219yKeCq1U2nquje/d9zrtZ1\n\
O38QWVwlhFN5scblm4IVlPKkjjt1ry6RiuRjmvRodKsYr7TZLXdBJcsWm2t8yMR0I7A9OlYen6PJ\n\
J42gF1DiA3RbgAqSAWA/TpWuDlTpcyp7Wur/ANfcdOTVaVKTjV+FJu1+19NfQ0/CvgyNbRdR8QFl\n\
X7ywE4wO27/CuifVxAgh02CO3hXgYUfy6VJrE8uoXf2a1VnjjP8ADzk9zUcWhXLf6x4o/q2f5Zra\n\
EHV9+s7+XY6KleNR+0xLSvtHol6f5ka63eq2TIrD0KitfTtZiuiIrhRHIeP9lqz30CYLlJoWPpkj\n\
+lVJtKvIsnyS4HOUO7+VOeGpSWisZv6pWVoySf3Gd4+0FdPA1rSwISjDz0UcHJ+9j69frWdpl0+o\n\
aNcS29s32mJw0jq7cLj6jgnrzXUJdLeadcabqBISVDGsjfw8d64+wl/s6wbTbudbY8mYKRnKtnr7\n\
jkH6VEY1OTk3lF+e3/AMcXTcqK51eadr9479nftr5Fu5P2qO3Wds20XE3mOqkfLyuO4Axxgnjr6z\n\
srz3jGGK4Kq5ZyEDJG24Bc9z05BI6d6yL3WI/PWX+ypVTcrKr5woBzkNjvgd6mk1eK2tb+S0k2i+\n\
UkIpJYEY2j8Pm/StHGT1UNfP5X1W3477nFPCYmLhFxavovvvfS//AAbeput4nkm8TaNBwJPOgSRV\n\
6BiwzX0RXyP4Tsr648SaU6Ws7ILyFmfYcY3jJJr64r3MkoU6MJxh3RxcQ4P6m6NPyf5o8Ad7WSW8\n\
u9JmJMLP9oifhZMtz+tY76XB4lkcRQx2cqAybgRjacEAj1APJ+tJ4Qs1/ta9nvnhSzaYnbI4Achj\n\
jjv3qPxZqFlYWeq6kVjS1twTESdyuccAgHJUk/TJHXFfKypyjiXTpt3vZP5/ids37CbUJfDbX9H3\n\
6/0hkXha2nvZtOgPmTKpdbhXG04PT+WRyRmn2/hCGyubf+052Vpn2RADgn3rivAnxIg1/WNN0sWt\n\
xbXxibZKsmfMmIGRzyoIB716Fq93d35iW7VpRbhnbyxkpgjcSACM8H25/LTFrFUKip1Xa6/pr+kT\n\
Sx9Stfknp+Py/pdjdintPDZKJ+/mCsWSPPyADqeD+J7Vz1xd/wBoaq80gCCRgDjGQAAM88EAgHg9\n\
R071Y061sra3up9T+0K4Xcis2FIJ6ggfh2yCauXurWN3o0jWcMCz+aoG0dGIIBwPy/GvPiuSWibf\n\
f8SLSu52vfRv8fz7feZ+n6gtrqSXEcTSomTyAzbecYyeoH9eOpOr42Zb3SY7q2lWSMqZEweoFUzf\n\
6XY6TY2OsW6bm/eFc7iAWypz+X5VmQY0+68yWN7mB4tgeI5DBhwCScZzt5/D0q40+aSnZ6fj/THF\n\
OM41ErW281f+vP1ONsrWbULny0PJ+Z3PQD1ruNB8M2fE00W+MdC/Jc+3YAetYtlGmma5dae3ytIV\n\
VCex6gfr+lel2dsssqwqCII15+g6D8f8a9erVk0oxdo2+8+iq4nkoxlDS6vcS0tZZYwtsiRQDoei\n\
/gO/1qY6bcAZE0TH02Ff1ya1ugHGB2o7Z7VzczWy0PCeKk3oc/Ojf6m6jyMZ2vyD7g1h6ppyxK0s\n\
ILQHh0PO3P8AMV3FzAlxFsk+qsOqn1FYZXBaOVc4yrr6+tPSSutztw2Ja1XzR4rcxeVdTRDJ2OUH\n\
qcHFd54FsZvNIDNHmJkDjqGPf8Ko2VnEuv38MUCz3sU4CBzwQT8xA/Xn1rpbTxFHa3h8qxROfLMA\n\
fMgbPJHsB7Yz3ozGvOpFRiun+QZliuZyoxX5df60KmpWUmmXxjebzDHEZHfYuXBJ3AkDIzjrnjIN\n\
Ms4/tt/Y2k+5bUEgFQSo2gk43Z7fLz0GMc9ItYvvt17PcEBGkjZYkJ+blcZyOD3/AF68Cuy0iNT4\n\
Xt0j2jfHnj35/ma4atR0qMVLd/nbfz/4c8ir7kV7Rauyv0vZ3POfGLwWNoLCxkkeFpC5LnOM8YHt\n\
gCuONdL4ttp47iYSoQVfPTtVPw7YpczvNKuY4sYUjhif8K9nATjToupLVn02BpxjTSiU7PS7u7UN\n\
HHhD0dzgH/Grn/CP3Yjz5kG7P3dxx/Ku50/TTcKJZyUh7Afeb6eg962Ire3iGI7eIe7LuP5mlLG1\n\
Z7WsbVMVTg+VK55ubvWdNt0UbfLhGFcANt7/AIfWq1pr97FciV53Y5ySDXp09lbTrholjbs8YwR+\n\
HQ1554s0Y2MjTIoGCN4X7uD0Ye1KmqVZ8lWNm+pjShQq35I2bOnlu7vWpbG4ik3wrhIivBjZl2sW\n\
5zgf59+lh8MWIs3VwtxOR80rdc+v8q8d0y8ltZl2SMqscZBxg+teo+Fr6eZYRIWYSAqwrysfRq4e\n\
0YSsl2/r/hzxMZgqlH3qcrW7af1/VzAtJGNs8TRloJQFbLAYAYAP6kZ4ycdvpW34Kkt1v3imC/aJ\n\
RmOT++B1APr9O1VdRtY9F1SSyilulgZFkU8kHLcjI79cZ4/XNdbi9smW9tliZkdjh1I+8W4/A5yc\n\
8ZFaVH7ei0pb7fPX/Jfoc9SXtqcktOf1V/6e50fimUyF7VeFKkY/lXk2o2bFjJGPm/iWvYNQtJ7u\n\
2guZEEdwyAumeA2OR+dchqmiTNK0kKEMeSpH8q5cDWVLS52ZfVhCmlHQ88I554NGPpXZDw3c3L4k\n\
t8f7VX5NA07R1tX1CEyLM5ViGOUHrj6kV7azVRXKtWelPMIU1rqcn4e043uqWySIfKZxnjkit2/h\n\
FrHqU9lGkTWsqGORRhwc8HGTwRk11egnQoZ7qaOUx/ZWwTINuR6qOp6fWsgFpb24udPjaGFo3YRT\n\
oF46cg9+c+oAHXIrieNq1Kjk07ee39WPLr43nqqeqUbb6df66Ndzb8O6x9utVubcqJcAzRDof8P6\n\
fTFWteCyiC6jztcFT7H0Pv1/KuMSztJJo7qymuPtUMBMu2TYC/P8XHU/5611OjTPqmi3G8q7oSVZ\n\
QQHKYy2PfOOOMg/QdVGSupx22+8qrUp1HzQTT32/r5GjoRH2HYoI2OwOe5J3f+zVoVgaNOkN0Vfg\n\
SgLuzxkZwP1P6Ct+vk85oOji5N7S1Xz3/E82vHlmxGYIrMxwoGSfauDeRppZJXBVnYsVJ6EnJH55\n\
rr9dlEWk3DNnayhDj0Yhf61xy5AGeveujJ6ekp/I68DHRyPaPhl/yJ9r/vyf+hmuqrlfhl/yJ9r/\n\
AL8n/oZrqq/VMF/u8PRHzGN/3ifqwooorpOYKbL/AKp/oadTLj/USf7p/lSeqGtzwDUdV+z7oYBm\n\
VeC5wQPp79ufT8RT0TTpdXvz5hbygd0r/wCe5rKUFtoHJIAFdpa3MGjQQ6cksMd5IN7tLkAsewPQ\n\
nqOvY8V8tDD0ctpctNavr1fn/WiPvakHSjyUvifX9Tf/AHFjagDbFCgwB/nqa4vxhqT+dpoNxJbL\n\
dF1BR9pjwV2k+o5OfXI9BT9S1O2gmP8AaN/GZB1RD5j49gOn6Vga1bXOs6lDe3kZstMiQACVsMkY\n\
Pp6muGpVTs5PTX/gW76kUMJTwvv1ZatPX5aWT1euu35kkum6vdI8Wu6oYrNRlSWGJPyxn8al8Sx3\n\
1p4ehi8IsrxrE56Elm7hsDpyPxzisLV5bzX9ZaCxR5ooj5cSxj5VUdye1aMWl654egF0+2WzB/fw\n\
o+8BTwcj+tYunU92U5K+/L0+7v6mlTCYitTUqs0m9VHRb9ut/Pa+xd0+7SDwbaP4rR2vpFDqh5LH\n\
aMgf7OMdfeq1r4ltIroW9vY/Z9OnwhkxhueM5o1JDq3ibTb3cZ9PmZXVSclVB+YEenBrsznVN1sl\n\
pE0B4bzFyAP6fSso0IzXM1fmu2r2S129UY0sNS9ipVbu++tlH5d0/wAUcn4K0VLae7vrlRLcQzGC\n\
3j6/NgHcB34YfrXVf2ZezkySL8zf3mGa17CxtdKtlSPaiqMb2OOP8/8A181VvvEVhahgsnnSD+FP\n\
X616MKU5vmerIqZlVqztQjfpe39W7lZ9KvJrOa0mCPBKhQhn+7nuOuKy4xZaEhNzIl5f5+YJnbxw\n\
Mk+g7VV1PxJd3gaOLEEJ4wvUj61ickk8k110sDFPmkdNKnWmv3zS8l/n/kaWpa1e35IklKR/3E4H\n\
/wBesylwe9PSCWSPzEjdk3bdyqSM+mfXkfnXelGC00R0xjClG0bJEdFaA0e+KK5t2UN2YhT1x0JB\n\
qdNCuCfneFenV/bPYH6f/W5rmnj8NT+KpH71+lyHiKS+0jNjnliIMcrqR0wxFaFvr+owcC4LD/bG\n\
astoIDkLcKy4OCUOc8YHXp1pBoRP3pkX6IT/AFrllm2Aejmvuf8AkYyrYea95X+Rfs/FayAx6jbg\n\
o3BZOfzBq9qcEd1p5eEx3diw+ZH+Yr+PX9cj+XOXOh3CbzAVmVTwFPzMOex78DgZ68Zpuh6lJpV7\n\
8+7yGO2VP/reoqvZ4fFx56DTt/XqjONOEf3mGe3T+tmVNU8Ly6ggewuHaWJcCCU9F9FPYdsH25qs\n\
LlIrHQ7+9Bc2NyYJwwO4EHIHvjGa9AezWGeO7tPntnGWC9gR1Ht3rzi5nSGzul1KzuZRdTm4kABV\n\
YCc9CR1rzpxldK17ffrdNdDojU9vySpK9nst9bpr+vxO4e7AvIry2kWSORQ6Mp4YdK3rq3t9Tsdk\n\
g3RSDIPce/1rzrS549KgYSebJorhZIplwzQswGQw9z29cV1ej6pbpDvgvbe4tieRvCsp/H+VVSqx\n\
glZ6d/62fkc2Lw/t4KpQ3j/Vn2a/rc5TUrGbTrtoZhyOVbsw9RW/o1y1zZ5dtzodpwp4GOMnpnr+\n\
X41tarHZ6nahJUm3DlGWFsr+mK5fSrdrfUECSxywOrESxnKsAM4/PbWmZezxuEkr+9HVfL/NCdR1\n\
qV6itJFO/wD+P2f/AHzUFT6gc3s3+8ar1wUP4cfRfkdkPhQUUU2WRYkLuwVR1JNalPQp6vc+TblF\n\
OJH4H0rn6lup2uZ2kbjPQZyBUVbJWQ4LqwoooplhUc80dvE0kzhEXqTVfUtRg0+LdKcufuoOprit\n\
T1GfUJd0xwg+6g6Cuihh5VddkYVsRGnp1L2s67LdlorYmODoT3asSiivVhTjTVonmTnKbvIK+2/g\n\
R/ySXw7/ANcX/wDRj18SV9t/Aj/kkvh3/ri//ox67ML8TPKzP+EvU72iiiu48MKKKKAIrv8A49Zv\n\
9xv5V+d8MrwyLJExV16EV+iF3/x6zf7jfyr87K48XrY9jKtOb5HYaNrKXgEU5CXH6N9K2K84BIII\n\
OCOhrpdF1zdtgvW+bosh7/WvEr4W3vQPqMPi7+7P7zoqKByOKK4TvCiiigAooooAKKKKACiiigAo\n\
oooAUEg5Bwa0LPVZocLL+8TPfkis6ihq+5EqcZavc6u1vYbgfI4DdwatVxYJUgqSCOhHWr1pqk8L\n\
KHbfGOCMdqzdPsZOM4+a/E6Wlqra3sFwPkcBvQ1ZrO1hJp7D45GjYMpwRWzZ3qyja5w3qaxKASpy\n\
Dg1zYjDQrrXfuROmprU6GW2eaWRolhk85QJoJchZccg5HRvy/nmL+0dDmg2S2zx8k7dgYZPXg5FV\n\
bPUMYSXp6k/5/wA/lVy5tLW/YSTA7sY3xkAn6+uPz7UYXGrDtUsam0tpLdf5/mttUc1nTdp3t5f1\n\
qVbefRoGXM1w8aLsRBEBsXJ4BJJ6EDPXA68mtix1TRAQsYSNvWVM5/E5rAn0CUZNrNHKAucN8hJz\n\
0GTjpz1rOu7C6tP+PiCRFyBuI+U59D0NfQ4eGBrK1GonfzV/udn+BpyUqy5VUa+dvw0PRfKs7tMq\n\
kMg/vJgH8xWLrWlyGEKXeS2Vg6OQGaFh0OPT+ftXLGK+sNsrR3FtzgMVK5NXYPEeoxAAypIB/fUG\n\
rnlzqK9Oz/r5k0sPWpu9OanHs/6ZXKzkQLMsMt6JngTadq4BbMhPccH3wM963dI0i4klhlmvDOkW\n\
cSCLy+SCDjk5OCRnjFZsevBZXlaxtmlfG5snBx0+XOOKnk8V3hAEcMK9uhNc8ctrJ+8gdCpFP2cF\n\
fu7aeh2UEMcEflwoET0Hf3PrT64CXxHqTjHnKn+6oqjNqF5N/rbmVh6bjiuuOBn1sjl/sytN805L\n\
8z0tnRQSzKAPU4pFljb7siHHowryxmZjlmJJ7k0mT6mtPqP940/sj+/+B6nPBDcDE8aSe56/n1qm\n\
+nNHg2c2wjoko3AfQ9q4GC+uoDmK4lX6Ma2LLxTdxEC6VZ07nG1q56uXNruP6piaK/dyuu3/AA//\n\
AADZvbzUYFxcwRlegcpkH8elZi3exy621oreogUH+VdDpuq2mopiBxvx80b9fy70l3pFtPkoPJc9\n\
16fl/hXA8LGDs4l0cdTg+StDlfz/AC/4ci0PXJDqVpFJEhVpkX5eMZIr2avDLKwns9asfMXKG4jw\n\
68g/MK9zr2cnpxhGfKuqPG4gjTU6cqWzT/M+dr/S7aw0wPebXuluWUBWBwCzHkfXH6V5t8UNP8T6\n\
tdWui6VbKNInRUlu2b92zk7txbsMBevoBzgV7InhO6/tmZtUgDxlWdAkgPfv0x24GenWobnw1fQX\n\
0FtZq/2echpJJJF3ZORg46jnPP0r5uhUqUKzm4OT1eq067ehtUqQq+6579fxf4Hyp4e8H+I7fxZY\n\
W62k9rOZ2RZihKZTJcZ78A8V9L6VqBsdP1FJd0lw6khzHtGFU8EHsew9+1aWreE9StI0a2AmDYXO\n\
4IFOc9N3I5PHuc5NVfGlnqU1lBFpdrtjGYn3MgbpzznvW+Mr1cylBez0/r5meEoU4WhCV1J9fKz1\n\
ONtrfXPEoZldngDctI21AfSrtpo99oLXL3catbzRGPzUO9FbIILc8cjHpz+Fdx4d0e9h0SyiMARy\n\
g3ZcEZwOeD6YrSvtMlhjVYbQXDsMl5WUgf8AAScf571Spzl+7UbL0/U97EYqjBOlG3L5b+t9unY4\n\
R/Dyaxefab2SS2UIE8sKGdsdyM/Lxj3zngUyKxOl3s1jLceZYTQkxb2xiTkDHoQcZ+o9RntFt9bV\n\
ty719g6hfyzimajY32pWrWd5YiV5VIV0ZN3TrgnBI6jpyKqWEqOPLbTt+P8AWpyvFRlD2La5fk7e\n\
fT8zj7u3GqyK4sVe+RMSGMgBcDC9+SeoHX5TgV1k2otb+ZHbALIzZd+Mj/ZHbj155zj1qTTNB1Cy\n\
txDDbrCZMmSVnG4cAfKoJA4AHB6DrU0PhmcbTO7uQ2cIFUEehySfyxXO6tKgrT1t0Sb/AC0/E5fr\n\
FJR5ea/zb+S8v62MJ3aRi0jMzHqWOTToJ5YG3QyMh/2TjP1rov8AhG4ySWgkOf8ApsRj8mFNbw0u\n\
0iOKWMnuJskf99Eil/atF6ck/wDwH/g/oL61Sen+RFp2tbmEd3gE8CQcD8fSp9TjAuI5AcCQYJ7A\n\
j/6x/Ss648P38GMKJk7tlVI6AcZ5/wA8Vch029udMuLO6icLsJjdZFDL2wD26nB7Vu6Sqx9rRWno\n\
/wAjSnVpxkpKWh5mLe8v/FM99ZqyQPNuaXO1VAHIz+Brp9Z1O1vobdIo3EsIBaR/lLLnjHrzznoM\n\
dRTbvQ7+xtnt57UTwIn7tYZRGsuTwWBPBHPc9e9bXgqwuHMhfSorZtoUkOp6D61xYujVsqvK3bRW\n\
7FYzEyqt1ZL4drNdrfPTysc1LPFLZLiEhkYl3D85wOTkEc7jzjqDyabJbX8DqYortICRJDhj8oLD\n\
GRheucY69Px3f+Ec1ea1kQ20YZZizIrrtK46YPrk/wCPatbUrbVLrw1I0ERjuEUq6h1wSB2Oa53S\n\
rQsowdm/P/I5XVgmowejdnd/doc1dXF5bkW9/bCRrhspLKRIwHAbgADHf2rO8J2iXBvXaIQ20dy2\n\
Uz7D5f8APSm6VoPim+wjSGGBXwSZFOCcZ4BrvtF0L7HEqeWSkRyNxBLueSzep/z2Fd0MLKlFxa1e\n\
9j0qVsGm3NO66Pz7bK//AASKKzuJwGCrEnYuP5L6flTzplwBkTRN7bCP1ya2vJl/ufqKf9ln2hgn\n\
B9xQoVXoo/gcssY1rdJHMyxyQsFmQoT0PUH6GsTxTAJLHeR/C0bH2IyP5Gu/ks5XiYSRAoeCCRXL\n\
eKNDu5tLnt7YFg5UqWK5HO0jr6MapUqjaXK0zrwmNp86lJ7Hk2maTd3s8SxQuFY/eI4r0vStQstI\n\
c27RSk27FJZiBtDYzxzz3PtiobXw/rir9j0+NIYZrfa/msrYZQASOeCRgcVo2Hgq6YhJwI8AuPLf\n\
LI3pkk5A9faufHQqVW3Ui7fP+vT7/I4sXj1X0k7LyZla/qY1m4gFvE4jXkSEcsDxkdscevb8qepl\n\
FuIJiFWMojL8q7lHByevHI/I+mTry6NqiXFyk4eeFN+GJRieflwrE4xnPX+HvxUUnh293pH5FwWL\n\
fO/mRbM4A4HXHHTjiohh5QVlHReT21f9eenmKlVp0+SPRdtdHr1sddZ39rdW4ZZo3jfkYYGotVaO\n\
zsLi4RWJiQvz04rmP+EYuJfL8mBzMQVUmRV2t1Jz1/iAHbjn3jn0rxA8H2dg5hUf6syqM4/hJyfT\n\
3riWWS5/dvbrp/X9fjyUsNBytGpaK3T7X6WIodbv4rr7S0iSGXl7dRuXAIGF7g8+/OKr3M326/n1\n\
KRHMWcBEAdchQFx2JBwenH0xnO8YQajo2kXNvZWElxqUkQ8hS8YjibjDZLf3QARjnHWrfhFdY17T\n\
7ZL6xkhuoI085vOjI3kqmV5bsCefTOcnFeq8sqQj7SMOy7dn+enytc6FKinZNXt+F/8AgevURmj+\n\
3hxEwcMuUj2kOQBjACjPA55HfArXfw5PBpizCbEkgXzI1ATK9+vfnv098cutdE1Wy1P7RFAkrwMe\n\
rrgqccnp64yB2zitHXYNXvNHjeO18qbdsZfMU4GOoOa4alKs2lTV11/q35DqSjzwhTlZNa3187HG\n\
eILe8uLC0sLmOOCdJkRWjxtkDEhfqRXfaNEkEohhGI44tqD2BFebafoOuza1byTQMdsmRulU7cdO\n\
9epWFpcx3CvJDtDoQQGB2k4Pr7Yr0pYepTiota2v16no1FGnQ5OZPd/kc1fw/Z7yWNcrtbKnqR3B\n\
+vSuhspvtFrHJxuI+YDIAPfr70muaTcXGyWCLLrww3Acf/r/AJ1X0nT9QgnKNB+6fJPzrwQOvX0G\n\
Py9K5s2wU8XhVOMfejr/AJr9Tza0ozhvqiDxNIsem7WB/eOEH1wT/SuXrr/Eul3lxaW6Qw5YThj8\n\
yjja3vWL/wAI/qX/AD7j/v4v+NefldCpGhrF3u+hvhKkI09ZLc9S+GX/ACJ9r/vyf+hmuqrmvh3b\n\
TWnhW3huUCSLJJwCDxvOK6Wv0jBq1CCfZHy2LalXm13YUUUV0nOFMuP9RJ/un+VPpHUMpU9CMGga\n\
3Pnvwdppu7xbiVcwQ469C3Yf1pmsWrT2M+o798luhaSJwNkqck54zn5mwa9qsvCumWVskFujrGvQ\n\
bsn86qy+CNJksZ7RhL5UyFG+bnBGK8DF5fiK8rq2/fofUwzqg6kpVL2dunTqfPytYaXpC6tpiSNP\n\
I5hQTYIi45478Vo+G9Le907+0ddeWeFmzBA7HDH+8fbjgema9dk+Fnh2SytrV0uDDAxYDzD8xJyc\n\
+vStifwfpkwRWWQKgwoU4Arm/sjEeTbe7etuiRrDOsJFN6uTb1a1S6W8/wAvXU8nhlaFBHbBYE6B\n\
IRsH6VoQJfzxtHJAZYnBVvOGMg8Hk8n9a9NtPCmmWq4iRwT1Ynk/jU//AAj9l6P+dU8nqPRpGNbP\n\
aTfuR+b/AK/U8Zj0rT/D8Qa9kEswUrEi8sEBOBnHHXkgDPr2qCTX72c+RpsIhjOdqRrub/8AXXqd\n\
z8O9FuZnlmN07sckmU1LaeAtGtUIhSUEnO4tlsemfT2rq/s2dKDcEpS83ZClm+HlG9S8pemn3XPJ\n\
Rpl5dKJLy55YA7XJYjnuOnTnr6D1xYi0W1T/AFjSyHBHZR069Cf1r1n/AIQzTPWf/vuj/hDNM9Z/\n\
++68mtgM6q7SjFeTt+lzN5xB6Xa9FY8tGm2QP/HuCOeDI/8AQ1I1laED/RYRgBfu56DHfqeetenf\n\
8IZpnrP/AN90HwZphHWf/vuuOWR5xLep/wCTMj+1KT3b/H/M84QKi7Y440XO7CIqjPTPA607c20K\n\
WO0DAGeBXoH/AAg+mf8APW7/AO/n/wBanp4K0xf47lvrJWE+F8wnrKSfrJ/rcn+0MPvr9x51RXo/\n\
/CGaZ6z/APfdH/CGaZ6z/wDfdR/qrjv7v3/8AP7So+f3HnFFej/8IZpnrP8A990f8IZpnrP/AN90\n\
f6q47+79/wDwA/tKj5/cecVV1O0W9gO4fvlHyP3+h9v5fmD6j/whmmes/wD33R/whmmes/8A33Wt\n\
DhzMsPNVKbSa8/8AgDWZ0U1JXuvI8w8Lai9tMdMvfkIP7sseh/u/4Vr6rbPHC0tsSoHzOnVSO5x0\n\
rsLvwDo90yNN9oLIMKRKRgZz/WtOLw3YpCkf7xgoC5Zsk/X1r6SpltWrFSklzdV0uKWZ0Y1FVp3u\n\
91bT+v1Pn7xBAbJZNQtbZHt5h5V3DjCc8hgO2cY47896gTTFe/e30awV3SJXkluX+WMOM4Pvg/zr\n\
3p/BGkvZ3FswlMc6FH+btjH9aSDwNpMCzrH5wWZlZxv64AA/kK5nlOJvdW+967Wv6a/gd8s8wzld\n\
J/jrta+vTX8Dxyz8Hy3NtGQ1vFGpJ2rFuBOeSGJBP4itLT7O40//AEO4kgkVGMi4OG5B3HAJx8zJ\n\
xnoOletXPhSwnthAGnjQADMblTgds1UtvAej227y/tGWxktKSTjp/M062T4iVGSi1zNW37+ZhPO4\n\
VItS26afrc8VvQReT5/vk/hnioa9qf4eaI7lnFwWPU+YaT/hXOhf3bj/AL+GsqeS4mMVHTTzN453\n\
hkktfu/4J4tWFq96JW8mJgUH3iO5r6Ef4b6EykbbgZ/6aGqf/CpfDf8Acuf+/prWOUV1vb7w/tvD\n\
N63t6f8ABPnWivon/hUvhr+5c/8Af00f8Kl8Nf3Ln/v6ar+yq/l95p/b2F8/u/4J87Vj61rUdiDH\n\
Dh7j07L9a+oH+Efht0Zdt0MjGRKc1lH4DeDWJJivCT1JmNbUsqqJ3qWMque0GrQv9x8h3M8tzM0s\n\
7l3Pc1FX2B/woXwb/wA8rv8A7/Gj/hQvg3/nld/9/jXesLNaI4XmdF6u58f0V9gf8KF8G/8APK7/\n\
AO/xo/4UL4N/55Xf/f40/q0w/tKj5/cfH9fbfwJ/5JL4d/64v/6MesT/AIUL4N/55Xf/AH+Nei+G\n\
tEtPDuh2mk6cGFpbKVjDHJwST1+pNbUaUoSuzjxuLp14KMO5p0UUV0nmBRRRQBFd/wDHrN/uN/Kv\n\
zsr9FZ1LwSIvVlIH5V8k/wDCgPF39+x/7+1y4mEpWsj1Muqwp83O7bHkFFev/wDCgPF39+x/7/Uf\n\
8KA8Xf37H/v9XN7KfY9P61R/mR55outNbbYboloegbuv/wBaurR1kQOjBlPII71sf8KA8Xf37H/v\n\
9WnpHwV8ZWLBGexeAnlfO6fSuOvgZy96C1O3D5pRj7s5qxytFei/8Kh8R+tp/wB/aP8AhUPiP1tP\n\
+/tcX1Ov/Izu/tLC/wDPxHnVFei/8Kh8R+tp/wB/aP8AhUPiP1tP+/tH1Ov/ACMP7Swv/PxHnVFe\n\
i/8ACofEfraf9/aP+FQ+I/W0/wC/tH1Ov/Iw/tLC/wDPxHnVFei/8Kh8R+tp/wB/aP8AhUPiP1tP\n\
+/tH1Ov/ACMP7Swv/PxHnVFei/8ACofEfraf9/aP+FQ+I/W0/wC/tH1Ov/Iw/tLC/wDPxHnVFei/\n\
8Kh8R+tp/wB/aP8AhUPiP1tP+/tH1Ov/ACMP7Swv/PxHnVFei/8ACofEfraf9/aP+FQ+I/W0/wC/\n\
tH1Ov/Iw/tLC/wDPxHnYJByCQfUVoWmqzQ8SfvF9+v512n/CofEfraf9/aP+FQ+I/W0/7+0PBVnv\n\
BkSx2Dlq6iv6mRb3UNxjypAT1x3qatOP4SeJY3DI1orDnPm1r2fw58SAbbn7IfQiSspYCutoMyeY\n\
YeLs6iZy1WLa7khYcnFdX/wrnW/+nb/v5Sf8K51v/p2/7+VjPL601yyptr0B4/CvRzRm291HMBg4\n\
Y9qsAkHIJB9quL8PNdQ5U24/7aVft/BWupgSC2Zf+unT6f8A168nEZFio604No5Z4jDfZqIyPPmH\n\
/LWT/vo0efN/z1k/76NdB/whmrekH/fyj/hDNW9IP+/lcX9j43/nzL7jB18M92vw/wAjnmmkb7zs\n\
w64Y5o81trrhCHG1gUHzD0P5muh/4QvVv7sH/fyj/hDNW9IP+/lXHK8fFWjSkvv/AMw9vhv5l/Xy\n\
OVe0s5ERXtIsLnBXKn8cHn8apXGiW0ik28skTk5Ak+ZenTIGRz9a7f8A4QvVv7sH/fyj/hC9W/uw\n\
f9/K7qMc5ou8FP56r8bmkcdTj8NT8TzO+025s13SKGi/56Icr+Pp+OKpV60vg3V1OVEAPT/WVRu/\n\
hxd3ALLHDBJ6xuNp/wCA/wCGK+kwOPxc7QxVCSfdLT5q+nyujrp5vRWlSS9V/keZ0V2n/CtfEP8A\n\
ctP+/wB/9aj/AIVr4h/uWn/f7/61e3yvsdf9o4X/AJ+L7zjYpHikWSNijqchgeRXaeHdeF5i2vCB\n\
cfwt0D//AF6b/wAK18Q/3LT/AL/f/WpV+G/iNGDKLRWByCJ+QfyrKth/aqzWpz4mvgsRG0qiv0dz\n\
qbDm+tweQZUBH/AhXpVcPo3h7U41tZL7yRMjgvsbIOD1/Ku4pYClKmpKSsfIYySckou9j//Z\n", 
    "Base64"], StandardForm],
  ImageSizeCache->{653., {212., 216.}},
  TrackedSymbols:>{}]], "Text",
 CellChangeTimes->{
  3.513619689593544*^9, {3.514287340779661*^9, 3.5142873539855356`*^9}, 
   3.5142874918286157`*^9, 3.5142875804853144`*^9, 3.5142877119328723`*^9}],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel",
  FontWeight->"Plain"],
 StyleBox["\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Magnified views of the Mandelbrot set."
}], "FigureCaption",
 CellChangeTimes->{{3.509219656680394*^9, 3.509219694547472*^9}, {
   3.509220005381826*^9, 3.509220038615546*^9}, {3.510882797467863*^9, 
   3.5108827999478703`*^9}, 3.514287340779661*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization", "Subsection",
 CellChangeTimes->{3.514287340779661*^9}],

Cell[TextData[{
 "To visualize the Mandelbrot set, the limit at which points are assumed to \
have escaped can be approximated by ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "max"], TraditionalForm]], "InlineFormula"],
 " instead of infinity. Beautiful computer\[Hyphen]generated plots can be \
then be created by coloring nonmember points depending on how quickly they \
diverge to ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", "max"], TraditionalForm]], "InlineFormula"],
 ". A common choice is to define an ",
 "integer",
 " called the ",
 "count",
 " to be the largest ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]], "InlineFormula"],
 " such that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", 
     SubscriptBox["z", "n"], "\[RightBracketingBar]"}], "<", 
    SubscriptBox["r", "max"]}], TraditionalForm]], "InlineFormula"],
 ", where ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]], "InlineFormula"],
 " can be conveniently taken as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["r", "max"], "\[LongEqual]", "2"}], TraditionalForm]], 
  "InlineFormula"],
 ", and to color points of different ",
 "count",
 " different colors. Drag the small circle to see the paths of different \
points dynamically. Drag the slider to see the progression of iterations."
}], "Text",
 CellChangeTimes->{{3.5060441171557827`*^9, 3.5060441175578227`*^9}, {
   3.5091203552683735`*^9, 3.509120372179099*^9}, {3.5091204373571525`*^9, 
   3.5091204508202105`*^9}, {3.5091246869929852`*^9, 3.509124694113243*^9}, {
   3.509124821246437*^9, 3.5091248218864927`*^9}, 3.509124878913841*^9, {
   3.509128512676168*^9, 3.509128569492915*^9}, {3.5091286191295495`*^9, 
   3.5091286205023584`*^9}, {3.510876513649396*^9, 3.51087654632632*^9}, {
   3.51088705184743*^9, 3.5108870525621443`*^9}, {3.5108876343533344`*^9, 
   3.510887639182402*^9}, {3.5108876854878726`*^9, 3.5108876935336533`*^9}, {
   3.5108880362305193`*^9, 3.5108880709836125`*^9}, {3.5116308083687887`*^9, 
   3.5116308101794558`*^9}, 3.514287340780662*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Dynamic", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Graphics", "[", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Inset", "[", 
          RowBox[{
           GraphicsBox[
            TagBox[RasterBox[CompressedData["
1:eJzs3Ql4leWB9//f9ddWShFwR0UgrAEkC2QBoghCBOICiI0okkY0WkRR0aDF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              "], {{0, 1334}, {1334, 
              0}}, {0, 255},
              ColorFunction->RGBColor],
             BoxForm`ImageTag[
             "Byte", ColorSpace -> "RGB", Interleaving -> True],
             Selectable->False],
            BaseStyle->"ImageGraphics",
            ImageSizeRaw->{1334, 1334},
            PlotRange->{{0, 1334}, {0, 1334}}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "2"}], ",", 
             RowBox[{"-", "2"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Left", ",", "Bottom"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"4", ",", "4"}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"White", ",", 
           RowBox[{"Dashing", "[", 
            RowBox[{"{", 
             RowBox[{"0.02", ",", "0.008"}], "}"}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Dynamic", "[", 
            RowBox[{
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"init", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"-", "2"}]}], "}"}], ",", 
                  RowBox[{"Offset", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"-", "9"}]}], "}"}], ",", 
                    RowBox[{
                    "init", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Offset", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "9"}], "}"}], ",", 
                    RowBox[{
                    "init", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"init", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                    "2"}], "}"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", "2"}], ",", 
                    RowBox[{"init", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                   "}"}], ",", 
                  RowBox[{"Offset", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "9"}], ",", "0"}], "}"}], ",", 
                    RowBox[{
                    "init", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Offset", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"9", ",", "0"}], "}"}], ",", 
                    RowBox[{
                    "init", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"2", ",", 
                    RowBox[{"init", "\[LeftDoubleBracket]", 
                    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], 
                   "}"}]}], "}"}]}], "}"}], "]"}], ",", 
             RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
              RowBox[{"{", "init", "}"}]}]}], "]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"Dynamic", "[", 
           RowBox[{
            RowBox[{"mandelGraph", "[", 
             RowBox[{"1", ",", "n2", ",", "init"}], "]"}], ",", 
            RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
             RowBox[{"{", 
              RowBox[{"n2", ",", "init"}], "}"}]}]}], "]"}], "}"}]}], "}"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRangePadding", "\[Rule]", 
        RowBox[{"Scaled", "[", "0.01", "]"}]}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"Dynamic", "[", 
         RowBox[{
          RowBox[{
           FractionBox["1", "zoom"], 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "2"}], ",", "2"}], "}"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{"zoom", "-", "1"}], ")"}], " ", 
               RowBox[{
               "pan", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}]}]}], ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "2"}], ",", "2"}], "}"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{"zoom", "-", "1"}], ")"}], " ", 
               RowBox[{
               "pan", "\[LeftDoubleBracket]", "2", 
                "\[RightDoubleBracket]"}]}]}]}], "}"}]}], ",", 
          RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
           RowBox[{"{", 
            RowBox[{"zoom", ",", "pan"}], "}"}]}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"400", ",", "400"}], "}"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"FrameTicks", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRangeClipping", "\[Rule]", "True"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"PlotLabel", "\[Rule]", 
        RowBox[{"Dynamic", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"init", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "+", 
           RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{"init", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}]}], ",", 
          RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
           RowBox[{"{", "}"}]}]}], "]"}]}]}], "]"}], ",", 
     RowBox[{"TrackedSymbols", "\[RuleDelayed]", 
      RowBox[{"{", "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Row", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Grid", "[", 
       RowBox[{
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\"\<interation\>\"", ",", 
            RowBox[{"Control", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"n2", ",", "20", ",", "\"\<\>\""}], "}"}], ",", "1", 
               ",", "20", ",", "1", ",", 
               RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
               RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], "]"}]}], 
           "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"\"\<\>\"", ",", "\"\<\>\""}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"\"\<zoom\>\"", ",", 
            RowBox[{"Control", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"zoom", ",", "1", ",", "\"\<\>\""}], "}"}], ",", "1", 
               ",", "5", ",", 
               RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
               RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "}"}], "]"}]}], 
           "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Alignment", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"Right", ",", "Left"}], "}"}], ",", "Baseline"}], 
          "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Control", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"pan", ",", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1"}], "}"}]}], "}"}], "]"}]}], 
     "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"init", ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.404", ",", 
          RowBox[{"-", "0.15"}]}], "}"}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "2"}], ",", 
       RowBox[{"-", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", "Locator", ",", 
     RowBox[{"Appearance", "\[Rule]", 
      RowBox[{"Graphics", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"White", ",", 
          RowBox[{"Circle", "[", "]"}]}], "}"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", "18"}]}], "]"}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"AppearanceElements", "\[Rule]", "None"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"SynchronousInitialization", "\[Rule]", "False"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"mandelbrot", "[", 
        RowBox[{"n_Integer", ",", "c_"}], "]"}], ":=", 
       RowBox[{"NestWhileList", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["#", "2"], "+", "c"}], "&"}], ",", "0", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", "#", "]"}], "<", "2"}], "&"}], ",", "1", ",", 
         "n"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"mandelGraph", "[", 
        RowBox[{"nVec_Integer", ",", "nIt_Integer", ",", "init_"}], "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"tmp1", "=", 
           RowBox[{
            RowBox[{
             RowBox[{"mandelbrot", "[", 
              RowBox[{"nIt", ",", "#"}], "]"}], "&"}], "/@", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"init", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], "+", 
              RowBox[{"I", " ", 
               RowBox[{"init", "[", 
                RowBox[{"[", 
                 RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], "}"}]}]}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"AbsoluteThickness", "[", "1", "]"}], ",", 
           RowBox[{"Arrowheads", "[", "Small", "]"}], ",", 
           RowBox[{"RGBColor", "[", 
            RowBox[{".8", ",", ".7", ",", ".3"}], "]"}], ",", 
           RowBox[{"MapIndexed", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Arrow", "[", "#1", "]"}], "}"}], "&"}], ",", 
             RowBox[{
              RowBox[{
               RowBox[{"Partition", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Re", "[", "#", "]"}], ",", 
                    RowBox[{"Im", "[", "#", "]"}]}], "}"}], "&"}], "/@", 
                  "#"}], ",", "2", ",", "1"}], "]"}], "&"}], "/@", "tmp1"}], 
             ",", 
             RowBox[{"{", "2", "}"}]}], "]"}]}], "}"}]}], "]"}]}], ";"}], 
     ")"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, 3.479582210490807*^9, {3.4796599604808245`*^9, 
   3.4796600892465725`*^9}, {3.4801897659918222`*^9, 
   3.4801898113115644`*^9}, {3.4801903201601453`*^9, 
   3.4801903400152535`*^9}, {3.4801903863230433`*^9, 
   3.4801905072629566`*^9}, {3.480190540952693*^9, 3.480190724905846*^9}, {
   3.4801907666487703`*^9, 3.480190770657713*^9}, {3.480190888289772*^9, 
   3.4801909677078133`*^9}, {3.4801929704659896`*^9, 
   3.4801929843808327`*^9}, {3.48019354591311*^9, 3.480193561588798*^9}, {
   3.4801936411214705`*^9, 3.4801936788707743`*^9}, {3.4801938396350985`*^9, 
   3.48019388866307*^9}, {3.480300827981048*^9, 3.480300835516045*^9}, {
   3.4803012521275043`*^9, 3.4803013494731207`*^9}, {3.480301424861806*^9, 
   3.480301448147593*^9}, {3.480301530622794*^9, 3.480301538754551*^9}, {
   3.4803018562204857`*^9, 3.48030185628465*^9}, {3.4803019290443287`*^9, 
   3.480301930082344*^9}, {3.480301971623102*^9, 3.480302012547941*^9}, {
   3.480302146424663*^9, 3.480302163281682*^9}, {3.480302286916411*^9, 
   3.48030228781358*^9}, {3.4803023194270267`*^9, 3.48030232160037*^9}, {
   3.4803023690848846`*^9, 3.4803023846413717`*^9}, {3.4803024262691917`*^9, 
   3.4803024290791397`*^9}, {3.480302472562668*^9, 3.48030255581091*^9}, {
   3.480302630884008*^9, 3.480302637699417*^9}, {3.480302730479607*^9, 
   3.480302744776381*^9}, {3.480302827476515*^9, 3.480302861279668*^9}, {
   3.4803029125954*^9, 3.480302929411767*^9}, {3.480305155619122*^9, 
   3.480305162828253*^9}, {3.480323383745922*^9, 3.480323434752315*^9}, {
   3.48036511982502*^9, 3.480365231479075*^9}, {3.480366338379237*^9, 
   3.480366366436512*^9}, {3.480366457778294*^9, 3.480366462116555*^9}, 
   3.480366574686967*^9, {3.480366652658825*^9, 3.480366656846609*^9}, {
   3.4803666924494267`*^9, 3.480366694117145*^9}, {3.4803668909075937`*^9, 
   3.480366911690014*^9}, {3.480418040691018*^9, 3.480418112588894*^9}, 
   3.5054453919002914`*^9, {3.5054454353866396`*^9, 3.5054455279468946`*^9}, {
   3.505445639549054*^9, 3.5054456503871374`*^9}, {3.505445826875785*^9, 
   3.505445840922189*^9}, {3.505446018233919*^9, 3.5054460198810835`*^9}, 
   3.5054462615582485`*^9, {3.5060428462876945`*^9, 3.5060428471437798`*^9}, {
   3.5060429078038454`*^9, 3.5060429121980543`*^9}, 3.5060429500110545`*^9, {
   3.5060431005130544`*^9, 3.506043131391054*^9}, {3.5091282922116356`*^9, 
   3.509128307819236*^9}, {3.5108836379615307`*^9, 3.5108836542520123`*^9}, {
   3.5108837093579607`*^9, 3.5108837142869883`*^9}, 3.510883747236803*^9, {
   3.5108838293339515`*^9, 3.5108839044169064`*^9}, {3.5108839479484863`*^9, 
   3.510883965400503*^9}, {3.5108840361302*^9, 3.510884040580419*^9}, {
   3.510884081876894*^9, 3.510884082681572*^9}, {3.5108841161261883`*^9, 
   3.510884133842099*^9}, {3.5108841850366135`*^9, 3.510884185150568*^9}, {
   3.510884332323675*^9, 3.5108843656623344`*^9}, 3.5108844377554855`*^9, {
   3.5108851610930347`*^9, 3.5108851611730022`*^9}, 3.5108854652053413`*^9, {
   3.5108855186699467`*^9, 3.51088554080309*^9}, {3.510885620513193*^9, 
   3.5108856596315393`*^9}, {3.5108857011799135`*^9, 
   3.5108857393486395`*^9}, {3.5108858976103096`*^9, 3.510885911648692*^9}, {
   3.5108859716936646`*^9, 3.5108860023613925`*^9}, {3.510886051367782*^9, 
   3.5108862353911433`*^9}, {3.510886273098055*^9, 3.5108862731780224`*^9}, 
   3.5108863816836033`*^9, {3.510887302150269*^9, 3.5108873279209566`*^9}, {
   3.5111873273391876`*^9, 3.5111873396711187`*^9}, {3.511187370984609*^9, 
   3.5111873750601587`*^9}, {3.5114658826871805`*^9, 3.511465891484684*^9}, {
   3.511465991919429*^9, 3.5114660075173206`*^9}, {3.511466080794512*^9, 
   3.5114661085430994`*^9}, {3.511466179834177*^9, 3.511466192357893*^9}, {
   3.5114666850280724`*^9, 3.5114667265004444`*^9}, {3.5114667609114122`*^9, 
   3.5114669790538893`*^9}, 3.511467182428522*^9, {3.5114672310943055`*^9, 
   3.5114672372136555`*^9}, {3.5114673422786646`*^9, 3.511467358606599*^9}, {
   3.5114674452845564`*^9, 3.5114674803255606`*^9}, {3.511467690758597*^9, 
   3.511467734241084*^9}, {3.5114678143276644`*^9, 3.511467867821724*^9}, {
   3.5114682355977592`*^9, 3.5114682610142136`*^9}, {3.511469914575792*^9, 
   3.51146996681678*^9}, {3.5114700111283145`*^9, 3.5114700131494303`*^9}, {
   3.5114700940700583`*^9, 3.5114700948711042`*^9}, {3.5114701446229496`*^9, 
   3.5114702119498005`*^9}, {3.511470242624555*^9, 3.511470253326167*^9}, {
   3.511471805775962*^9, 3.5114720188521495`*^9}, {3.51147946019277*^9, 
   3.511479481069964*^9}, {3.5141228154827967`*^9, 3.5141228159458427`*^9}, {
   3.514240513664956*^9, 3.5142405243231525`*^9}, 3.5142429018709373`*^9, {
   3.514243005912125*^9, 3.51424305118624*^9}, {3.5142431733122406`*^9, 
   3.5142431941102405`*^9}, {3.5142464048678055`*^9, 3.514246417246805*^9}, {
   3.514246500026516*^9, 3.514246503147828*^9}, {3.5142465372452374`*^9, 
   3.5142465407285852`*^9}, {3.5142465876862807`*^9, 
   3.5142465953320456`*^9}, {3.5142466324647584`*^9, 
   3.5142466373192434`*^9}, {3.514248100036602*^9, 3.514248112352602*^9}, 
   3.514248188706602*^9, 3.5142484459746017`*^9, {3.514248503337841*^9, 
   3.51424853912842*^9}, {3.5142488730958133`*^9, 3.514248877957299*^9}, {
   3.5142814382298136`*^9, 3.5142814760795984`*^9}, {3.514281601836173*^9, 
   3.5142816210640955`*^9}, {3.514281705171505*^9, 3.5142817599899864`*^9}, {
   3.5142825418053293`*^9, 3.5142825744773293`*^9}, {3.514282760361329*^9, 
   3.514282852294329*^9}, {3.5142830122603292`*^9, 3.5142831749884815`*^9}, {
   3.514283214303413*^9, 3.514283247840766*^9}, {3.514283335497531*^9, 
   3.5142833635363345`*^9}, {3.5142834690008802`*^9, 3.514283506482628*^9}, {
   3.514283606482627*^9, 3.5142836420531836`*^9}, {3.514283832118188*^9, 
   3.5142838368456607`*^9}, {3.5142838783238077`*^9, 3.514283940679043*^9}, 
   3.514283990645039*^9, {3.51428410916389*^9, 3.5142841120281763`*^9}, {
   3.514284147877761*^9, 3.514284173679341*^9}, {3.5142842051704893`*^9, 
   3.5142842495609283`*^9}, {3.5142845971906776`*^9, 
   3.5142846865156775`*^9}, {3.514284735346678*^9, 3.5142847807516775`*^9}, {
   3.514284821226678*^9, 3.5142848282566776`*^9}, {3.514284883397678*^9, 
   3.5142848919656777`*^9}, {3.5142849264336777`*^9, 3.514284995148678*^9}, {
   3.514285062958678*^9, 3.514285071361678*^9}, {3.5142851576316776`*^9, 
   3.5142851762166777`*^9}, {3.514285296743678*^9, 3.514285297611678*^9}, {
   3.51428562052018*^9, 3.514285621139242*^9}, {3.5142858140865345`*^9, 
   3.514285856280754*^9}, {3.5142859176828938`*^9, 3.5142859850206265`*^9}, {
   3.5142860794790716`*^9, 3.5142861214032636`*^9}, {3.514286249916114*^9, 
   3.51428627898602*^9}, {3.514286319064028*^9, 3.5142863740395246`*^9}, {
   3.5142942691476707`*^9, 3.5142942855332227`*^9}, {3.5143038707848396`*^9, 
   3.514303882111512*^9}, {3.514303963042585*^9, 3.514304073408985*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`init$$ = {{
    0.404, -0.15}}, $CellContext`n2$$ = 20, $CellContext`pan$$ = {0, 
    0}, $CellContext`zoom$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n2$$], 20, ""}, 1, 20, 1}, {{
       Hold[$CellContext`zoom$$], 1, ""}, 1, 5}, {{
       Hold[$CellContext`pan$$], {0, 0}}, {-1, -1}, {1, 1}}, {
      Hold[
       Row[{
         Grid[{{"interation", 
            Manipulate`Place[1]}, {"", ""}, {"zoom", 
            Manipulate`Place[2]}}, Alignment -> {{Right, Left}, Baseline}], 
         Manipulate`Place[3]}]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`init$$], {{0.404, -0.15}}}, {-2, -2}, {2, 2}}}, 
    Typeset`size$$ = Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`n2$2814$$ = 
    0, $CellContext`zoom$2815$$ = 0, $CellContext`pan$2816$$ = {0, 
    0}, $CellContext`init$2817$$ = {0, 0}}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`init$$ = {{
         0.404, -0.15}}, $CellContext`n2$$ = 
        20, $CellContext`pan$$ = {0, 0}, $CellContext`zoom$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`n2$$, $CellContext`n2$2814$$, 0], 
        Hold[$CellContext`zoom$$, $CellContext`zoom$2815$$, 0], 
        Hold[$CellContext`pan$$, $CellContext`pan$2816$$, {0, 0}], 
        Hold[$CellContext`init$$, $CellContext`init$2817$$, {0, 0}]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Dynamic[
        Graphics[{
          Inset[
           Image[CompressedData["
1:eJzs3Ql4leWB9//f9ddWShFwR0UgrAEkC2QBoghCBOICiI0okkY0WkRR0aDF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            "], "Byte", ColorSpace -> 
            "RGB", Interleaving -> True], {-2, -2}, {Left, Bottom}, {4, 4}], {
          White, 
           Dashing[{0.02, 0.008}], 
           Dynamic[
            Line[{{{
                Part[$CellContext`init$$, 1, 1], -2}, 
               Offset[{0, -9}, 
                Part[$CellContext`init$$, 1]]}, {
               Offset[{0, 9}, 
                Part[$CellContext`init$$, 1]], {
                Part[$CellContext`init$$, 1, 1], 2}}, {{-2, 
                Part[$CellContext`init$$, 1, 2]}, 
               Offset[{-9, 0}, 
                Part[$CellContext`init$$, 1]]}, {
               Offset[{9, 0}, 
                Part[$CellContext`init$$, 1]], {2, 
                Part[$CellContext`init$$, 1, 2]}}}], 
            TrackedSymbols :> {$CellContext`init$$}]}, {
           Dynamic[
            $CellContext`mandelGraph[
            1, $CellContext`n2$$, $CellContext`init$$], 
            TrackedSymbols :> {$CellContext`n2$$, $CellContext`init$$}]}}, 
         PlotRangePadding -> Scaled[0.01], PlotRange -> 
         Dynamic[(
            1/$CellContext`zoom$$) {{-2, 2} + (2 ($CellContext`zoom$$ - 1)) 
              Part[$CellContext`pan$$, 1], {-2, 
              2} + (2 ($CellContext`zoom$$ - 1)) Part[$CellContext`pan$$, 2]},
            TrackedSymbols :> {$CellContext`zoom$$, $CellContext`pan$$}], 
         ImageSize -> {400, 400}, FrameTicks -> True, Frame -> True, Axes -> 
         False, PlotRangeClipping -> True, PlotLabel -> 
         Dynamic[Part[$CellContext`init$$, 1, 1] + 
           I Part[$CellContext`init$$, 1, 2], TrackedSymbols :> {}]], 
        TrackedSymbols :> {}], 
      "Specifications" :> {{{$CellContext`n2$$, 20, ""}, 1, 20, 1, Appearance -> 
         "Labeled", ImageSize -> Small, ControlPlacement -> 
         1}, {{$CellContext`zoom$$, 1, ""}, 1, 5, Appearance -> "Labeled", 
         ImageSize -> Small, ControlPlacement -> 
         2}, {{$CellContext`pan$$, {0, 0}}, {-1, -1}, {1, 1}, 
         ControlPlacement -> 3}, 
        Row[{
          Grid[{{"interation", 
             Manipulate`Place[1]}, {"", ""}, {"zoom", 
             Manipulate`Place[2]}}, Alignment -> {{Right, Left}, Baseline}], 
          Manipulate`Place[3]}], {{$CellContext`init$$, {{
          0.404, -0.15}}}, {-2, -2}, {2, 2}, ControlType -> Locator, 
         Appearance -> Graphics[{
            GrayLevel[1], 
            Circle[{0, 0}]}, ImageSize -> 18]}}, 
      "Options" :> {
       AppearanceElements -> None, SynchronousInitialization -> False}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{459., {270., 277.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`mandelbrot[
         Pattern[$CellContext`n, 
          Blank[Integer]], 
         Pattern[$CellContext`c, 
          Blank[]]] := 
       NestWhileList[#^2 + $CellContext`c& , 0, Abs[#] < 2& , 
         1, $CellContext`n]; $CellContext`mandelGraph[
         Pattern[$CellContext`nVec, 
          Blank[Integer]], 
         Pattern[$CellContext`nIt, 
          Blank[Integer]], 
         Pattern[$CellContext`init, 
          Blank[]]] := 
       Module[{$CellContext`tmp1 = 
          Map[$CellContext`mandelbrot[$CellContext`nIt, #]& , {
            Part[$CellContext`init, 1, 1] + 
             I Part[$CellContext`init, 1, 2]}]}, {
          AbsoluteThickness[1], 
          Arrowheads[Small], 
          RGBColor[0.8, 0.7, 0.3], 
          MapIndexed[{
            Arrow[#]}& , 
           Map[Partition[
             Map[{
               Re[#], 
               Im[#]}& , #], 2, 1]& , $CellContext`tmp1], {2}]}]; Null); 
     Typeset`initDone$$ = True),
    SynchronousInitialization->False,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5147468467738733`*^9}]
}, {2}]],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel",
  FontWeight->"Plain"],
 StyleBox["\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 ButtonBox["Based on an interactive applet by Felipe Dimer de Oliveira.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/IteratesForTheMandelbrotSet/"], 
    None},
  ButtonNote->
   "http://demonstrations.wolfram.com/IteratesForTheMandelbrotSet/"],
 StyleBox[" ", "FigureCaptionLabel"],
 "Change the number of \[LineSeparator]iterations or the color of the paths, \
and drag the locator to see the paths of different points."
}], "FigureCaption",
 CellChangeTimes->{{3.509219656680394*^9, 3.509219694547472*^9}, {
   3.509220005381826*^9, 3.509220038615546*^9}, {3.509981987713937*^9, 
   3.50998201548167*^9}, 3.510887493186824*^9, {3.51283449159807*^9, 
   3.512834497296721*^9}, 3.514287340792673*^9, 3.5147390751128955`*^9}],

Cell["\<\
The boundary between successive counts defines a series of \
\[OpenCurlyDoubleQuote]Mandelbrot set lemniscates\[CloseCurlyDoubleQuote] (or \
\[OpenCurlyDoubleQuote]equipotential curves\[CloseCurlyDoubleQuote]; Peitgen \
and Saupe 1988) defined by iterating the quadratic recurrence,\
\>", "Text",
 CellChangeTimes->{3.5108876717693624`*^9, 3.514287340792673*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["L", "n"], 
   RowBox[{"(", "C", ")"}], "\[LongEqual]", 
   SubscriptBox["z", "n"], "\[LongEqual]", 
   SubscriptBox["r", "max"], "."}], TraditionalForm]], "EquationNumbered",
 TaggingRules:>{"Punctuation" -> "."},
 CellChangeTimes->{3.5142873407936735`*^9}],

Cell["The first few lemniscates are therefore given by", "Text",
 CellChangeTimes->{3.5142873407936735`*^9}],

Cell[BoxData[
 FormBox[Cell[BoxData[
   FormBox[GridBox[{
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{
           SubscriptBox["L", "1"], 
           RowBox[{"(", "C", ")"}]}], "DisplayFormula"], TraditionalForm]]]]],
        Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox["C", "DisplayFormula"], TraditionalForm]]]]]},
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{
           SubscriptBox["L", "2"], 
           RowBox[{"(", "C", ")"}]}], "DisplayFormula"], TraditionalForm]]]]],
        Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{"C", 
           RowBox[{"(", 
            RowBox[{"C", "+", "1"}], ")"}]}], "DisplayFormula"], 
         TraditionalForm]]]]]},
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["\[Null]", "DisplayFormula"], TraditionalForm]]]]], Cell[
       TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["C", "2"], "+", "C"}], "DisplayFormula"], 
         TraditionalForm]]]]]},
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{
           SubscriptBox["L", "3"], 
           RowBox[{"(", "C", ")"}]}], "DisplayFormula"], TraditionalForm]]]]],
        Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{"C", "+", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"C", "+", 
              SuperscriptBox["C", "2"]}], ")"}], "2"]}], "DisplayFormula"], 
         TraditionalForm]]]]]},
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["\[Null]", "DisplayFormula"], TraditionalForm]]]]], Cell[
       TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["C", "4"], "+", "2", 
           SuperscriptBox["C", "3"], "+", 
           SuperscriptBox["C", "2"], "+", "C"}], "DisplayFormula"], 
         TraditionalForm]]]]]},
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{
           SubscriptBox["L", "4"], 
           RowBox[{"(", "C", ")"}]}], "DisplayFormula"], TraditionalForm]]]]],
        Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{"C", "+", 
           SuperscriptBox[
            RowBox[{"[", 
             RowBox[{"C", "+", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"C", "+", 
                 SuperscriptBox["C", "2"]}], ")"}], "2"]}], "]"}], "2"]}], 
          "DisplayFormula"], TraditionalForm]]]]]},
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["\[Null]", "DisplayFormula"], TraditionalForm]]]]], Cell[
       TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["C", "8"], "+", "4", 
           SuperscriptBox["C", "7"], "+", "6", 
           SuperscriptBox["C", "6"], "+", "6", 
           SuperscriptBox["C", "5"], "+", "5", 
           SuperscriptBox["C", "4"], "+", "2", 
           SuperscriptBox["C", "3"], "+", 
           SuperscriptBox["C", "2"], "+", "C"}], "DisplayFormula"], 
         TraditionalForm]]]]]}
     },
     GridBoxAlignment->{
      "Columns" -> {Right, Center, {Left}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]]], 
  TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.5142873407976775`*^9}],

Cell[TextData[{
 "(Sloane\[CloseCurlyQuote]s ",
 ButtonBox["A114448",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://oeis.org/A114448"], None}],
 ")."
}], "Text",
 CellChangeTimes->{3.5142873407986784`*^9}],

Cell[TextData[{
 "When writing ",
 Cell[BoxData[
  FormBox[
   RowBox[{"C", "\[LongEqual]", "x", "+", "i", "y"}], TraditionalForm]], 
  "InlineFormula"],
 " and taking the ",
 "absolute square",
 " of each side, the lemniscates can be plotted in the ",
 "complex plane",
 ", and the first few are given by"
}], "Text",
 CellChangeTimes->{{3.509124974873871*^9, 3.509124975061197*^9}, 
   3.5142873407986784`*^9}],

Cell[BoxData[
 FormBox[Cell[BoxData[
   FormBox[GridBox[{
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox[
          SuperscriptBox["r", "2"], "DisplayFormula"], TraditionalForm]]]]], 
       Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{
           SuperscriptBox["x", "2"], "+", 
           SuperscriptBox["y", "2"]}], "DisplayFormula"], 
         TraditionalForm]]]]]},
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox[
          SuperscriptBox["r", "2"], "DisplayFormula"], TraditionalForm]]]]], 
       Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], 
           RowBox[{"[", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"x", "+", "1"}], ")"}], "2"], "+", 
             SuperscriptBox["y", "2"]}], "]"}]}], "DisplayFormula"], 
         TraditionalForm]]]]]},
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox[
          SuperscriptBox["r", "2"], "DisplayFormula"], TraditionalForm]]]]], 
       Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], ")"}], 
           RowBox[{"(", 
            RowBox[{"1", "+", "2", "x", "+", "5", 
             SuperscriptBox["x", "2"], "+", "6", 
             SuperscriptBox["x", "3"], "+", "6", 
             SuperscriptBox["x", "4"], "+", "4", 
             SuperscriptBox["x", "5"], "+", 
             SuperscriptBox["x", "6"], "-", "3", 
             SuperscriptBox["y", "2"], "-", "2", "x", 
             SuperscriptBox["y", "2"], "+", "8", 
             SuperscriptBox["x", "2"], 
             SuperscriptBox["y", "2"], "+", "8", 
             SuperscriptBox["x", "3"], 
             SuperscriptBox["y", "2"], "+", "3", 
             SuperscriptBox["x", "4"], 
             SuperscriptBox["y", "2"], "+", "2", 
             SuperscriptBox["y", "4"], "+", "4", "x", 
             SuperscriptBox["y", "4"], "+", "3", 
             SuperscriptBox["x", "2"], 
             SuperscriptBox["y", "4"], "+", 
             SuperscriptBox["y", "6"]}], ")"}], "."}], "DisplayFormula"], 
         TraditionalForm]]]]]}
     },
     GridBoxAlignment->{
      "Columns" -> {Right, Center, {Left}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]]], 
  TraditionalForm]], "EquationNumbered",
 TaggingRules:>{"Punctuation" -> "."},
 CellChangeTimes->{3.514287340801681*^9}],

Cell[TextData[{
 "These are a ",
 "circle",
 ", an ",
 "oval",
 ", and a ",
 "pear curve",
 ". In fact, the second ",
 "Mandelbrot set lemniscate",
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]], "InlineFormula"],
 " can be written in terms of a new coordinate system with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["x", "\[Prime]"], "\[Congruent]", "x", "-", "1", "/", 
    "2"}], TraditionalForm]], "InlineFormula"],
 " as"
}], "Text",
 CellChangeTimes->{{3.50912500543923*^9, 3.509125010871684*^9}, 
   3.514287340802682*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]"], "-", 
        StyleBox[
         FractionBox["1", "2"],
         ScriptLevel->1]}], ")"}], "2"], "+", 
     SuperscriptBox["y", "2"]}], "]"}], 
   RowBox[{"[", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["x", "\[Prime]"], "+", 
        StyleBox[
         FractionBox["1", "2"],
         ScriptLevel->1]}], ")"}], "2"], "+", 
     SuperscriptBox["y", "2"]}], "]"}], "\[LongEqual]", 
   SuperscriptBox["r", "2"], ","}], TraditionalForm]], "EquationNumbered",
 TaggingRules:>{"Punctuation" -> ","},
 CellChangeTimes->{3.514287340803683*^9}],

Cell[TextData[{
 "which is just a ",
 "Cassini oval",
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"a", "\[LongEqual]", "1", "/", "2"}], TraditionalForm]], 
  "InlineFormula"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["b", "2"], "\[LongEqual]", "r"}], TraditionalForm]], 
  "InlineFormula"],
 ". The ",
 "Mandelbrot set lemniscates",
 " grow increasingly convoluted with higher ",
 "count",
 " and approach the Mandelbrot set as the ",
 "count",
 " tends to infinity."
}], "Text",
 CellChangeTimes->{{3.5091250244840403`*^9, 3.5091250259982586`*^9}, 
   3.5142873408046837`*^9}],

Cell["\<\
Another way to visualize the Mandelbrot set is to use height coordinate \
instead of coloring and plot the set in 3D. This is shown in the \
Demonstration below. Interact with the 3D graphics by rotating it with the \
cursor.\
\>", "Text",
 CellChangeTimes->{
  3.5091191252899313`*^9, {3.509119184835513*^9, 3.509119185116315*^9}, {
   3.5091196639771895`*^9, 3.5091196665979896`*^9}, {3.5091242036026163`*^9, 
   3.509124205700078*^9}, {3.5091242457360744`*^9, 3.509124248532896*^9}, {
   3.510888121817271*^9, 3.510888150115947*^9}, {3.5114805157691455`*^9, 
   3.511480517271231*^9}, {3.5116289179625487`*^9, 3.511628918398937*^9}, 
   3.5142873408046837`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ListPlot3D", "[", 
    RowBox[{
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"Norm", "/@", 
        RowBox[{"Transpose", "[", 
         RowBox[{"mandelbrotnest", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"x", ",", "y"}], "}"}], "+", "xy"}], ",", 
                RowBox[{"{", 
                 RowBox[{"y", ",", 
                  RowBox[{"-", "sca"}], ",", "sca", ",", 
                  RowBox[{"N", "[", 
                   FractionBox["sca", "aa"], "]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x", ",", 
                  RowBox[{"-", "sca"}], ",", "sca", ",", 
                  RowBox[{"N", "[", 
                   FractionBox["sca", "aa"], "]"}]}], "}"}]}], "]"}], ",", 
              "1"}], "]"}], "]"}], ",", "st"}], "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"2", " ", "aa"}], "+", "1"}]}], "]"}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", "da"}], ",", 
     RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "Automatic", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", ".5"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"ClippingStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{".5", ",", ".6", ",", ".7"}], "]"}], ",", 
        RowBox[{"Specularity", "[", 
         RowBox[{"White", ",", "80"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"SphericalRegion", "\[Rule]", "True"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Yellow", ",", 
        RowBox[{"Specularity", "[", 
         RowBox[{"White", ",", "80"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"ViewAngle", "\[Rule]", 
      RowBox[{"Dynamic", "[", "zo", "]"}]}], ",", 
     RowBox[{"ViewPoint", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.258"}], ",", "1.938", ",", "2.761"}], "}"}]}]}], 
    "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"zo", ",", 
       FractionBox["\[Pi]", "10"], ",", "\"\<zoom\>\""}], "}"}], ",", 
     FractionBox["\[Pi]", "6"], ",", 
     FractionBox["\[Pi]", "20"], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"aa", ",", "25", ",", "\"\<detail\>\""}], "}"}], ",", "1", ",", 
     "25", ",", "1", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"st", ",", "15", ",", "\"\<steps\>\""}], "}"}], ",", "0", ",", 
     "15", ",", "1", ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sca", ",", "1", ",", "\"\<scale\>\""}], "}"}], ",", ".01", ",", 
     FractionBox["3", "2"], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"da", ",", "3", ",", "\"\<\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0", "\[Rule]", "\"\<data\>\""}], ",", 
       RowBox[{"3", "\[Rule]", "\"\<interpolation\>\""}]}], "}"}]}], "}"}], 
   ",", "\[IndentingNewLine]", "Delimiter", ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"xy", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["1", "2"]}], ",", "0"}], "}"}], ",", "\"\<center\>\""}],
       "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["3", "2"]}], ",", 
       RowBox[{"-", 
        FractionBox["2", "2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", 
       FractionBox["2", "2"]}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Initialization", "\[RuleDelayed]", 
    RowBox[{"(", 
     RowBox[{"mandelbrotnest", "=", 
      RowBox[{"Compile", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"g", ",", "_Real", ",", "2"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "_Integer", ",", "0"}], "}"}]}], "}"}], ",", 
        RowBox[{"Module", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"a3", ",", "a4"}], "}"}], ",", 
          RowBox[{"Nest", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a3", "=", 
                SuperscriptBox[
                 RowBox[{
                 "#1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                  "2"]}], ";", 
               RowBox[{"a4", "=", 
                SuperscriptBox[
                 RowBox[{
                 "#1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
                  "2"]}], ";", 
               RowBox[{"Clip", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"a3", "-", "a4", "+", 
                    RowBox[{
                    "g", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], ",", 
                   RowBox[{
                    RowBox[{"2.", " ", 
                    RowBox[{
                    "#1", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], " ", 
                    RowBox[{
                    "#1", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "+", 
                    RowBox[{
                    "g", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "4"}], ",", "4"}], "}"}]}], "]"}]}], ")"}], 
             "&"}], ",", "g", ",", "s"}], "]"}]}], "]"}]}], "]"}]}], ")"}]}], 
   ",", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.35696210375764*^9, {3.36661823965539*^9, 3.36661827949387*^9}, 
   3.36662216666128*^9, {3.3666230097057*^9, 3.36662311386091*^9}, {
   3.36662315666379*^9, 3.36662316929765*^9}, {3.36662346741155*^9, 
   3.36662347035714*^9}, 3.36662351075228*^9, {3.36662357267911*^9, 
   3.36662357455458*^9}, {3.38416995763371*^9, 3.38416995944621*^9}, {
   3.3865260958335247`*^9, 3.3865261465360007`*^9}, 3.3869004739183702`*^9, {
   3.386937665624074*^9, 3.386937691298526*^9}, {3.386937773690229*^9, 
   3.386937804977378*^9}, {3.386938210138535*^9, 3.386938224607236*^9}, {
   3.386938286114315*^9, 3.386938301508358*^9}, {3.3869383427321053`*^9, 
   3.386938397787703*^9}, {3.3869385494450274`*^9, 3.386938586410707*^9}, {
   3.386938620753811*^9, 3.3869386589097157`*^9}, {3.386938886188345*^9, 
   3.386938889227149*^9}, {3.3869389597589293`*^9, 3.3869389766064577`*^9}, {
   3.386939063292472*^9, 3.3869390658587008`*^9}, {3.3869391455791473`*^9, 
   3.386939194464971*^9}, {3.386942140483741*^9, 3.386942190372117*^9}, {
   3.38694225964854*^9, 3.3869423801875553`*^9}, {3.386942413457397*^9, 
   3.386942454252701*^9}, {3.3869425317473097`*^9, 3.3869427609607677`*^9}, {
   3.386942846478158*^9, 3.3869430005643177`*^9}, {3.386943032229416*^9, 
   3.386943065465214*^9}, {3.3869431172660418`*^9, 3.386943226063352*^9}, {
   3.3869440357686462`*^9, 3.386944041643708*^9}, {3.3869441148786*^9, 
   3.386944115511546*^9}, 3.3869441680812693`*^9, {3.3869443583224573`*^9, 
   3.3869443689238586`*^9}, {3.386944403679165*^9, 3.386944405684834*^9}, {
   3.3869444359915667`*^9, 3.386944436661285*^9}, {3.386945325376807*^9, 
   3.386945328374749*^9}, {3.386945633608918*^9, 3.386945636019459*^9}, 
   3.386957632783066*^9, {3.3869576726310883`*^9, 3.386957677363162*^9}, {
   3.386962898855104*^9, 3.386962920340015*^9}, {3.386963019264468*^9, 
   3.3869630409373426`*^9}, 3.3869634870727634`*^9, {3.387033598103019*^9, 
   3.3870336169000483`*^9}, {3.387040843584515*^9, 3.387040846999814*^9}, 
   3.387040896352738*^9, 3.3871401588559504`*^9, 3.387140227228476*^9, {
   3.387140325469536*^9, 3.387140334850481*^9}, {3.3872130616979647`*^9, 
   3.387213064103091*^9}, {3.5054416665095916`*^9, 3.5054416748714275`*^9}, {
   3.5054417079857388`*^9, 3.505441832317428*^9}, {3.5054418652034283`*^9, 
   3.505441865810428*^9}, {3.505441941134428*^9, 3.505441945646428*^9}, {
   3.5054419936174283`*^9, 3.505442039233428*^9}, {3.505442098221428*^9, 
   3.505442127523428*^9}, {3.505442194118428*^9, 3.505442261587428*^9}, {
   3.505442693011241*^9, 3.505442701752115*^9}, {3.505442770527992*^9, 
   3.505442832982237*^9}, {3.505442874879426*^9, 3.505442933586296*^9}, 
   3.5054430111490517`*^9, {3.505446676753008*^9, 3.5054468061649437`*^9}, {
   3.5054469112659945`*^9, 3.5054469165560474`*^9}, {3.5054876299191465`*^9, 
   3.505487681017256*^9}, {3.5054878801605453`*^9, 3.50548789056528*^9}, {
   3.5091188086963205`*^9, 3.50911881339192*^9}, {3.5091188537179203`*^9, 
   3.5091188826247206`*^9}, {3.5091189132007203`*^9, 
   3.5091189173971205`*^9}, {3.5114769128150682`*^9, 
   3.5114769484741077`*^9}, {3.511477004074288*^9, 3.5114770300887756`*^9}, {
   3.511477129131441*^9, 3.5114771851866465`*^9}, {3.511477223416834*^9, 
   3.5114772959759836`*^9}, {3.511477333448127*^9, 3.511477415887842*^9}, {
   3.511477447056625*^9, 3.5114774723280706`*^9}, {3.511477510050228*^9, 
   3.5114775102642403`*^9}, 3.5114775988673077`*^9, {3.5114776514973183`*^9, 
   3.5114778165777607`*^9}, {3.511477850460698*^9, 3.5114778724419556`*^9}, {
   3.5114780381854353`*^9, 3.511478150704871*^9}, {3.511478229040352*^9, 
   3.511478263817341*^9}, {3.511478325455867*^9, 3.5114783352424264`*^9}, {
   3.5114783712074833`*^9, 3.511478371599506*^9}, {3.5114784390473633`*^9, 
   3.511478444489675*^9}, {3.511478499381815*^9, 3.511478622648865*^9}, {
   3.5114786563447924`*^9, 3.511478656441798*^9}, {3.511478709088809*^9, 
   3.5114788616005325`*^9}, 3.511479022490735*^9, {3.511479113987968*^9, 
   3.5114791156190615`*^9}, {3.5114791822818747`*^9, 3.511479190913368*^9}, {
   3.511479336400689*^9, 3.5114793387818255`*^9}, {3.5114803161417274`*^9, 
   3.5114804690814753`*^9}, 3.5142873408066854`*^9, {3.514304334515585*^9, 
   3.514304419338785*^9}},
 CellID->775079852],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`aa$$ = 25, $CellContext`da$$ = 
    3, $CellContext`sca$$ = 1, $CellContext`st$$ = 15, $CellContext`xy$$ = {
     Rational[-1, 2], 0}, $CellContext`zo$$ = Rational[1, 10] Pi, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`zo$$], Rational[1, 10] Pi, "zoom"}, Rational[1, 6] 
      Pi, Rational[1, 20] Pi}, {{
       Hold[$CellContext`aa$$], 25, "detail"}, 1, 25, 1}, {{
       Hold[$CellContext`st$$], 15, "steps"}, 0, 15, 1}, {{
       Hold[$CellContext`sca$$], 1, "scale"}, 0.01, 
      Rational[3, 2]}, {{
       Hold[$CellContext`da$$], 3, ""}, {
      0 -> "data", 3 -> "interpolation"}}, {{
       Hold[$CellContext`xy$$], {
        Rational[-1, 2], 0}, "center"}, {
       Rational[-3, 2], -1}, {
       Rational[1, 2], 1}}}, Typeset`size$$ = {360., {178., 182.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`zo$2901$$ = 0, $CellContext`aa$2902$$ = 
    0, $CellContext`st$2903$$ = 0, $CellContext`sca$2904$$ = 
    0, $CellContext`da$2905$$ = False, $CellContext`xy$2906$$ = {0, 0}}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`aa$$ = 25, $CellContext`da$$ = 
        3, $CellContext`sca$$ = 1, $CellContext`st$$ = 15, $CellContext`xy$$ = {
          Rational[-1, 2], 0}, $CellContext`zo$$ = Rational[1, 10] Pi}, 
      "ControllerVariables" :> {
        Hold[$CellContext`zo$$, $CellContext`zo$2901$$, 0], 
        Hold[$CellContext`aa$$, $CellContext`aa$2902$$, 0], 
        Hold[$CellContext`st$$, $CellContext`st$2903$$, 0], 
        Hold[$CellContext`sca$$, $CellContext`sca$2904$$, 0], 
        Hold[$CellContext`da$$, $CellContext`da$2905$$, False], 
        Hold[$CellContext`xy$$, $CellContext`xy$2906$$, {0, 0}]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ListPlot3D[
        Partition[
         Map[Norm, 
          Transpose[
           $CellContext`mandelbrotnest[
            Transpose[
             Flatten[
              
              Table[{$CellContext`x, $CellContext`y} + $CellContext`xy$$, \
{$CellContext`y, -$CellContext`sca$$, $CellContext`sca$$, 
                
                N[$CellContext`sca$$/$CellContext`aa$$]}, {$CellContext`x, \
-$CellContext`sca$$, $CellContext`sca$$, 
                N[$CellContext`sca$$/$CellContext`aa$$]}], 
              1]], $CellContext`st$$]]], 2 $CellContext`aa$$ + 1], 
        InterpolationOrder -> $CellContext`da$$, Boxed -> False, Axes -> 
        False, Mesh -> Automatic, 
        PlotRange -> {Automatic, Automatic, {-0.5, 3}}, ClippingStyle -> 
        Directive[
          RGBColor[0.5, 0.6, 0.7], 
          Specularity[White, 80]], SphericalRegion -> True, PlotStyle -> 
        Directive[Yellow, 
          Specularity[White, 80]], ViewAngle -> Dynamic[$CellContext`zo$$], 
        ViewPoint -> {-0.258, 1.938, 2.761}], 
      "Specifications" :> {{{$CellContext`zo$$, Rational[1, 10] Pi, "zoom"}, 
         Rational[1, 6] Pi, Rational[1, 20] Pi, ImageSize -> 
         Tiny}, {{$CellContext`aa$$, 25, "detail"}, 1, 25, 1, ImageSize -> 
         Tiny}, {{$CellContext`st$$, 15, "steps"}, 0, 15, 1, ImageSize -> 
         Tiny}, {{$CellContext`sca$$, 1, "scale"}, 0.01, 
         Rational[3, 2], ImageSize -> Tiny}, 
        Delimiter, {{$CellContext`da$$, 3, ""}, {
         0 -> "data", 3 -> "interpolation"}}, Delimiter, {{$CellContext`xy$$, {
           Rational[-1, 2], 0}, "center"}, {
          Rational[-3, 2], -1}, {
          Rational[1, 2], 1}}}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{562., {211., 218.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({{$CellContext`mandelbrotnest = 
         CompiledFunction[{8, 8., 5468}, {{
             Blank[Real], 2}, 
            Blank[Integer]}, {{3, 2, 0}, {2, 0, 0}, {3, 2, 
           8}}, {{0, {2, 0, 4}}, {2, {2, 0, 2}}, {
            1, {2, 0, 1}}, {{-4, 4}, {2, 1, 6}}, {0., {3, 0, 1}}, {
            2., {3, 0, 0}}}, {0, 6, 2, 0, 
           10}, {{41, 257, 3, 0, 1, 3, 2, 0, 3, 2, 8}, {6, 0, 5}, {6, 4, 3}, {
            3, 19}, {38, 8, 0, 1, 1, 3}, {40, 56, 3, 1, 3, 3, 1, 7}, {
            42, "CopyTensor", 3, 1, 7, 3, 1, 1}, {38, 8, 0, 2, 1, 7}, {40, 56,
             3, 1, 7, 3, 1, 3}, {42, "CopyTensor", 3, 1, 3, 3, 1, 5}, {40, 43,
             3, 1, 5, 3, 1, 3}, {38, 0, 0, 1, 1, 7}, {44, 1, 3, 7, 9}, {38, 8,
             0, 1, 1, 3}, {41, 259, 3, 0, 0, 3, 1, 3, 3, 1, 7}, {38, 8, 0, 2, 
            1, 3}, {45, 7, 3, 7}, {38, 0, 0, 2, 1, 3}, {44, 7, 3, 7}, {34, 9, 
            7, 0, 3}, {47, Clip, 3, 2, 3, 2, 1, 6, 3, 2, 9}, {
            42, "CopyTensor", 3, 2, 9, 3, 2, 8}, {4, 3, 5, -18}, {1}}, 
           Function[{$CellContext`g, $CellContext`s}, 
            Module[{$CellContext`a3, $CellContext`a4}, 
             
             Nest[($CellContext`a3 = Part[#, 1]^2; $CellContext`a4 = 
               Part[#, 2]^2; 
              Clip[{$CellContext`a3 - $CellContext`a4 + 
                 Part[$CellContext`g, 1], (2. Part[#, 1]) Part[#, 2] + 
                 Part[$CellContext`g, 2]}, {-4, 
                4}])& , $CellContext`g, $CellContext`s]]], 
           Evaluate]}; $CellContext`mandelbrotnest = Compile[{{$CellContext`g, 
            Blank[Real], 2}, {$CellContext`s, 
            Blank[Integer], 0}}, 
          Module[{$CellContext`a3, $CellContext`a4}, 
           
           Nest[($CellContext`a3 = Part[#, 1]^2; $CellContext`a4 = 
             Part[#, 2]^2; 
            Clip[{$CellContext`a3 - $CellContext`a4 + 
               Part[$CellContext`g, 1], (2. Part[#, 1]) Part[#, 2] + 
               Part[$CellContext`g, 2]}, {-4, 
              4}])& , $CellContext`g, $CellContext`s]]]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5147468612173176`*^9}]
}, {2}]],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel",
  FontWeight->"Plain"],
 StyleBox["\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 ButtonBox["Based on an interactive applet by Michael Schreiber.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://demonstrations.wolfram.com/MandelbrotSetPrint/"], None},
  ButtonNote->"http://demonstrations.wolfram.com/MandelbrotSetPrint/"],
 " Click and drag the graphic to rotate it, \[LineSeparator]or use the \
controls to change the viewing options."
}], "FigureCaption",
 CellChangeTimes->{{3.509219656680394*^9, 3.509219694547472*^9}, {
   3.509220005381826*^9, 3.509220038615546*^9}, {3.509981174833585*^9, 
   3.5099811803585253`*^9}, {3.509981288739472*^9, 3.509981294792078*^9}, 
   3.512834506843265*^9, 3.5142873408627357`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Area", "Subsection",
 CellChangeTimes->{3.514287340863737*^9}],

Cell["The area of the Mandelbrot set can be written exactly as", "Text",
 CellChangeTimes->{3.514287340863737*^9}],

Cell[BoxData[
 FormBox[
  RowBox[{"A", "\[LongEqual]", "\[Pi]", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"n", "\[LongEqual]", "1"}], "\[Infinity]"], "n", 
     SubsuperscriptBox["b", "n", "2"]}], ")"}]}], 
  TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.514287340863737*^9}],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "n"], TraditionalForm]], "InlineFormula"],
 " are the coefficients of the ",
 "Laurent series",
 " about infinity of the conformal map ",
 Cell[BoxData[
  FormBox["\[Psi]", TraditionalForm]], "InlineFormula"],
 " of the exterior of the ",
 "unit disk",
 " onto the exterior of the Mandelbrot set,"
}], "Text",
 CellChangeTimes->{3.5142873408647375`*^9}],

Cell[BoxData[
 FormBox[Cell[BoxData[
   FormBox[GridBox[{
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{"\[Psi]", 
           RowBox[{"(", "w", ")"}]}], "DisplayFormula"], TraditionalForm]]]]],
        Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{"w", "+", 
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"n", "\[LongEqual]", "0"}], "\[Infinity]",
            LimitsPositioning->True], 
           SubscriptBox["b", "n"], 
           SuperscriptBox["w", 
            RowBox[{"-", "n"}]]}], "DisplayFormula"], TraditionalForm]]]]]},
      {Cell[TextData[Cell[BoxData[
        FormBox[
         StyleBox["\[Null]", "DisplayFormula"], TraditionalForm]]]]], Cell[
       TextData[Cell[BoxData[
        FormBox[
         StyleBox["=", "DisplayFormula"], TraditionalForm]]]]], Cell[TextData[
       Cell[BoxData[
        FormBox[
         StyleBox[
          RowBox[{"w", "-", 
           StyleBox[
            FractionBox["1", "2"],
            ScriptLevel->1], "+", 
           StyleBox[
            FractionBox["1", "8"],
            ScriptLevel->1], 
           SuperscriptBox["w", 
            RowBox[{"-", "1"}]], "-", 
           StyleBox[
            FractionBox["1", "4"],
            ScriptLevel->1], 
           SuperscriptBox["w", 
            RowBox[{"-", "2"}]], "+", 
           StyleBox[
            FractionBox["15", "128"],
            ScriptLevel->1], 
           SuperscriptBox["w", 
            RowBox[{"-", "3"}]], "+", "0", 
           SuperscriptBox["w", 
            RowBox[{"-", "4"}]], "-", 
           StyleBox[
            FractionBox["47", "1024"],
            ScriptLevel->1], 
           SuperscriptBox["w", 
            RowBox[{"-", "5"}]], "+", "\[Ellipsis]"}], "DisplayFormula"], 
         TraditionalForm]]]]]}
     },
     GridBoxAlignment->{
      "Columns" -> {Right, Center, {Left}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], TraditionalForm]]], 
  TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{3.514287340865739*^9}],

Cell[TextData[{
 "(Sloane\[CloseCurlyQuote]s ",
 ButtonBox["A054670",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://oeis.org/A054670"], None}],
 " and ",
 ButtonBox["A054671",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://oeis.org/A054671"], None}],
 "; Ewing and Schober 1992). The recursion for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "n"], TraditionalForm]], "InlineFormula"],
 " is given by"
}], "Text",
 CellChangeTimes->{3.514287340865739*^9}],

Cell[BoxData[
 FormBox[GridBox[{
    {
     FormBox[
      StyleBox[
       SubscriptBox["b", "n"], "DisplayFormula"],
      TraditionalForm], "=", 
     RowBox[{"\[Piecewise]", GridBox[{
        {
         StyleBox[
          RowBox[{"-", 
           StyleBox[
            FractionBox["1", "2"],
            ScriptLevel->1]}], "DisplayFormula"], 
         FormBox[
          StyleBox[
           RowBox[{"for", " ", Cell[BoxData[
             FormBox[
              StyleBox[
               RowBox[{"n", "\[LongEqual]", "0"}], "DisplayFormula"], 
              TraditionalForm]]]}], "DisplayFormula"],
          TraditionalForm]},
        {
         FormBox[
          StyleBox[
           RowBox[{"-", 
            FractionBox[
             SubscriptBox["w", 
              RowBox[{"n", ",", "n", "+", "1"}]], "n"]}], "DisplayFormula"],
          TraditionalForm], 
         StyleBox["otherwise", "DisplayFormula"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}}]}]},
    {
     FormBox[
      StyleBox[
       SubscriptBox["w", 
        RowBox[{"n", ",", "m"}]], "DisplayFormula"],
      TraditionalForm], "=", 
     RowBox[{"\[Piecewise]", GridBox[{
        {
         StyleBox["0", "DisplayFormula"], 
         StyleBox[
          RowBox[{"for", " ", Cell[BoxData[
            FormBox[
             StyleBox[
              RowBox[{"n", "\[LongEqual]", "0"}], "DisplayFormula"], 
             TraditionalForm]]]}], "DisplayFormula"]},
        {
         FormBox[
          StyleBox[
           RowBox[{
            SubscriptBox["a", 
             RowBox[{"m", "-", "1"}]], "+", 
            SubscriptBox["w", 
             RowBox[{"n", "-", "1", ",", "m"}]], "+", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"j", "\[LongEqual]", "0"}], 
              RowBox[{"m", "-", "2"}],
              LimitsPositioning->True], 
             RowBox[{
              SubscriptBox["a", "j"], 
              SubscriptBox["w", 
               RowBox[{"n", "-", "1", ",", "m", "-", "j", "-", "1"}]]}]}]}], 
           "DisplayFormula"],
          TraditionalForm], 
         StyleBox["otherwise", "DisplayFormula"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}}]}]},
    {
     StyleBox[
      SubscriptBox["a", "j"], "DisplayFormula"], "=", Cell[TextData[Cell[
     BoxData[
      FormBox[
       StyleBox[
        SubscriptBox["u", 
         RowBox[{"0", ",", "j", "+", "1"}]], "DisplayFormula"], 
       TraditionalForm]]]]]},
    {
     StyleBox[
      SubscriptBox["u", 
       RowBox[{"n", ",", "k"}]], "DisplayFormula"], "=", 
     RowBox[{"\[Piecewise]", GridBox[{
        {
         StyleBox["1", "DisplayFormula"], Cell[TextData[Cell[BoxData[
          FormBox[
           StyleBox[
            RowBox[{"for", " ", Cell[BoxData[
              FormBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["2", "n"], "-", "1", "\[LongEqual]", "k"}], 
                "DisplayFormula"], TraditionalForm]]]}], "DisplayFormula"], 
           TraditionalForm]]]]]},
        {
         FormBox[
          StyleBox[
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"j", "\[LongEqual]", "0"}], "k",
             LimitsPositioning->True], 
            RowBox[{
             SubscriptBox["u", 
              RowBox[{"n", "-", "1", ",", "j"}]], 
             SubscriptBox["u", 
              RowBox[{"n", "-", "1", ",", "k", "-", "j"}]]}]}], 
           "DisplayFormula"],
          TraditionalForm], 
         FormBox[
          StyleBox[
           RowBox[{"for", " ", Cell[BoxData[
             FormBox[
              StyleBox[
               RowBox[{
                SuperscriptBox["2", "n"], "-", "1", ">", "k"}], 
               "DisplayFormula"], TraditionalForm]]]}], "DisplayFormula"],
          TraditionalForm]},
        {
         FormBox[
          StyleBox["0", "DisplayFormula"],
          TraditionalForm], Cell[TextData[Cell[BoxData[
          FormBox[
           StyleBox[
            RowBox[{"for", " ", Cell[BoxData[
              FormBox[
               StyleBox[
                RowBox[{
                 SuperscriptBox["2", 
                  RowBox[{"n", "+", "1"}]], "-", "1", ">", "k"}], 
                "DisplayFormula"], TraditionalForm]]]}], "DisplayFormula"], 
           TraditionalForm]]]]]},
        {
         StyleBox[
          RowBox[{
           FractionBox["1", "2"], 
           RowBox[{"(", 
            RowBox[{
             SubscriptBox["u", 
              RowBox[{"n", "+", "1", ",", "k"}]], "-", 
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"j", "\[LongEqual]", "1"}], 
              RowBox[{"k", "-", "1"}],
              LimitsPositioning->True], 
             SubscriptBox["u", 
              RowBox[{"n", ",", "j"}]], 
             SubscriptBox["u", 
              RowBox[{"n", ",", "k", "-", "j"}]]}], ")"}]}], "DisplayFormula"], 
         FormBox[
          StyleBox[
           RowBox[{"otherwise", "."}], "DisplayFormula"],
          TraditionalForm]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}}]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {Right, Center, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], 
  TraditionalForm]], "EquationNumbered",
 CellChangeTimes->{{3.514113769259536*^9, 3.5141137693949423`*^9}, {
   3.5141138264476748`*^9, 3.514113860453313*^9}, {3.514113903583218*^9, 
   3.514113993944607*^9}, 3.514287340871744*^9}],

Cell[TextData[{
 "These coefficients can be computed recursively, but a closed form is not \
known. Furthermore, the sum converges very slowly, so ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "118"], TraditionalForm]], "InlineFormula"],
 " terms are needed to get the first two digits, and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "1181"], TraditionalForm]], "InlineFormula"],
 " terms are needed to get three digits. Ewing and Schober (1992) computed \
the first ",
 Cell[BoxData[
  FormBox["240000", TraditionalForm]], "InlineFormula"],
 " values of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "n"], TraditionalForm]], "InlineFormula"],
 ", found that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "1"}], "<", "n", 
    SubscriptBox["b", "n"], "<", "1"}], TraditionalForm]], "InlineFormula"],
 " in this range, and conjectured that this inequality always holds. This \
calculation also provided the limit ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", "\[LessEqual]", "1.7274"}], TraditionalForm]], 
  "InlineFormula"],
 " and led the authors to believe that the true values lies between ",
 Cell[BoxData[
  FormBox["1.66", TraditionalForm]], "InlineFormula"],
 " and ",
 Cell[BoxData[
  FormBox["1.71", TraditionalForm]], "InlineFormula"],
 "."
}], "Text",
 CellChangeTimes->{3.5142873408727446`*^9}],

Cell[TextData[{
 "The area of the set obtained by pixel counting is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1.50659177", "\[PlusMinus]", "0.00000008"}], TraditionalForm]], 
  "InlineFormula"],
 " (Sloane\[CloseCurlyQuote]s ",
 ButtonBox["A098403",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://oeis.org/A098403"], None}],
 "; Munafo; Lesmoir\[Hyphen]Gordon ",
 StyleBox["et al. ",
  FontSlant->"Italic"],
 "2000, p.\[NonBreakingSpace]97) and by statistical sampling is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"1.506484", "\[PlusMinus]", "0.000004"}], TraditionalForm]], 
  "InlineFormula"],
 " with 95% confidence (Mitchell 2001), both of which are significantly \
smaller than the estimate of Ewing and Schober (1992)."
}], "Text",
 CellChangeTimes->{3.514287340873746*^9}],

Cell[TextData[{
 "The following code takes advantage of a multicore system (if present) and \
runs the evaluation of ",
 Cell[BoxData[
  SubscriptBox["A", "n"]],
  CellChangeTimes->{{3.509104269132216*^9, 3.5091043128344088`*^9}, {
   3.5091043731284375`*^9, 3.5091044264707713`*^9}, {3.5091053852926483`*^9, 
   3.5091053911322327`*^9}, {3.50910548071719*^9, 3.5091054986499834`*^9}, {
   3.509105657596876*^9, 3.509105662781395*^9}, {3.509106499803093*^9, 
   3.5091065010972223`*^9}, {3.5091066077248845`*^9, 3.5091066556956806`*^9}}],
 " in parallel on all available cores. The evaluation times may vary \
depending on computer system. On an Intel dual-core 2.5 GHz CPU with 4G of \
memory it takes a few minutes."
}], "Text",
 CellChangeTimes->{{3.5060340149819965`*^9, 3.5060340164201403`*^9}, {
   3.509106559820094*^9, 3.5091065620803204`*^9}, {3.5091066768307943`*^9, 
   3.5091066798040915`*^9}, {3.5091251527555184`*^9, 3.509125158141141*^9}, {
   3.509125192078368*^9, 3.509125199040651*^9}, 3.514287340873746*^9}],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJzt2ftXlHUeB/DH8d66SgG6keIICIrKXUQxeItIIsodkfvMwAxo5iUF0VIe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   "], {{{}, {}, {}, {}, 
     {RGBColor[
       NCache[
        Rational[2, 3], 0.6666666666666666], 0.33333333333333337`, 0], 
      LineBox[{2, 1}], LineBox[{3, 10}], LineBox[{4, 11}], LineBox[{5, 12}], 
      LineBox[{6, 13}], LineBox[{7, 14}], LineBox[{8, 15}], LineBox[{9, 16}], 
      LineBox[{202, 17}], LineBox[{203, 18}], LineBox[{204, 19}], 
      LineBox[{205, 20}], LineBox[{206, 21}], LineBox[{207, 22}], 
      LineBox[{208, 23}], LineBox[{209, 24}], LineBox[{210, 25}], 
      LineBox[{211, 26}], LineBox[{212, 27}], LineBox[{213, 28}], 
      LineBox[{214, 29}], LineBox[{215, 30}], LineBox[{216, 31}], 
      LineBox[{217, 32}], LineBox[{218, 33}], LineBox[{219, 34}], 
      LineBox[{220, 35}], LineBox[{221, 36}], LineBox[{222, 37}], 
      LineBox[{223, 38}], LineBox[{224, 39}], LineBox[{225, 40}], 
      LineBox[{226, 41}], LineBox[{227, 42}], LineBox[{228, 43}], 
      LineBox[{229, 44}], LineBox[{230, 45}], LineBox[{231, 46}], 
      LineBox[{232, 47}], LineBox[{233, 48}], LineBox[{234, 49}], 
      LineBox[{235, 50}], LineBox[{236, 51}], LineBox[{237, 52}], 
      LineBox[{238, 53}], LineBox[{239, 54}], LineBox[{240, 55}], 
      LineBox[{241, 56}], LineBox[{242, 57}], LineBox[{243, 58}], 
      LineBox[{244, 59}], LineBox[{245, 60}], LineBox[{246, 61}], 
      LineBox[{247, 62}], LineBox[{248, 63}], LineBox[{249, 64}], 
      LineBox[{250, 65}], LineBox[{251, 66}], LineBox[{252, 67}], 
      LineBox[{253, 68}], LineBox[{254, 69}], LineBox[{255, 70}], 
      LineBox[{256, 71}], LineBox[{257, 72}], LineBox[{258, 73}], 
      LineBox[{259, 74}], LineBox[{260, 75}], LineBox[{261, 76}], 
      LineBox[{262, 77}], LineBox[{263, 78}], LineBox[{264, 79}], 
      LineBox[{265, 80}], LineBox[{266, 81}], LineBox[{267, 82}], 
      LineBox[{268, 83}], LineBox[{269, 84}], LineBox[{270, 85}], 
      LineBox[{271, 86}], LineBox[{272, 87}], LineBox[{273, 88}], 
      LineBox[{274, 89}], LineBox[{275, 90}], LineBox[{276, 91}], 
      LineBox[{277, 92}], LineBox[{278, 93}], LineBox[{279, 94}], 
      LineBox[{280, 95}], LineBox[{281, 96}], LineBox[{282, 97}], 
      LineBox[{283, 98}], LineBox[{284, 99}], LineBox[{285, 100}], 
      LineBox[{286, 101}], LineBox[{287, 102}], LineBox[{288, 103}], 
      LineBox[{289, 104}], LineBox[{290, 105}], LineBox[{291, 106}], 
      LineBox[{292, 107}], LineBox[{293, 108}], LineBox[{294, 109}], 
      LineBox[{295, 110}], LineBox[{296, 111}], LineBox[{297, 112}], 
      LineBox[{298, 113}], LineBox[{299, 114}], LineBox[{300, 115}], 
      LineBox[{301, 116}], LineBox[{302, 117}], LineBox[{303, 118}], 
      LineBox[{304, 119}], LineBox[{305, 120}], LineBox[{306, 121}], 
      LineBox[{307, 122}], LineBox[{308, 123}], LineBox[{309, 124}], 
      LineBox[{310, 125}], LineBox[{311, 126}], LineBox[{312, 127}], 
      LineBox[{313, 128}], LineBox[{314, 129}], LineBox[{315, 130}], 
      LineBox[{316, 131}], LineBox[{317, 132}], LineBox[{318, 133}], 
      LineBox[{319, 134}], LineBox[{320, 135}], LineBox[{321, 136}], 
      LineBox[{322, 137}], LineBox[{323, 138}], LineBox[{324, 139}], 
      LineBox[{325, 140}], LineBox[{326, 141}], LineBox[{327, 142}], 
      LineBox[{328, 143}], LineBox[{329, 144}], LineBox[{330, 145}], 
      LineBox[{331, 146}], LineBox[{332, 147}], LineBox[{333, 148}], 
      LineBox[{334, 149}], LineBox[{335, 150}], LineBox[{336, 151}], 
      LineBox[{337, 152}], LineBox[{338, 153}], LineBox[{339, 154}], 
      LineBox[{340, 155}], LineBox[{341, 156}], LineBox[{342, 157}], 
      LineBox[{343, 158}], LineBox[{344, 159}], LineBox[{345, 160}], 
      LineBox[{346, 161}], LineBox[{347, 162}], LineBox[{348, 163}], 
      LineBox[{349, 164}], LineBox[{350, 165}], LineBox[{351, 166}], 
      LineBox[{352, 167}], LineBox[{353, 168}], LineBox[{354, 169}], 
      LineBox[{355, 170}], LineBox[{356, 171}], LineBox[{357, 172}], 
      LineBox[{358, 173}], LineBox[{359, 174}], LineBox[{360, 175}], 
      LineBox[{361, 176}], LineBox[{362, 177}], LineBox[{363, 178}], 
      LineBox[{364, 179}], LineBox[{365, 180}], LineBox[{366, 181}], 
      LineBox[{367, 182}], LineBox[{368, 183}], LineBox[{369, 184}], 
      LineBox[{370, 185}], LineBox[{371, 186}], LineBox[{372, 187}], 
      LineBox[{373, 188}], LineBox[{374, 189}], LineBox[{375, 190}], 
      LineBox[{376, 191}], LineBox[{377, 192}], LineBox[{378, 193}], 
      LineBox[{379, 194}], LineBox[{380, 195}], LineBox[{381, 196}], 
      LineBox[{382, 197}], LineBox[{383, 198}], LineBox[{384, 199}], 
      LineBox[{385, 200}]}}, {{}, 
     {RGBColor[0.8, 0, 0], PointSize[0.008], PointBox[CompressedData["
1:eJwV0ddazwEAgOFfGRmpzJDS38zeWzLKOHUJLoB7MELZOyspm6yQvckI2StC
ysheifA6eJ/nO/9CU6ZNnhoWBEER08UMZjKLdGYzh7lkkMk85rOAhSxiMUtY
yjKWs4KVrCKL1axhLetYTzYbyGEjueSxic1sYSvb2M4OdrKLfHazh73sYz8F
HOAghyjkMEc4yjGOc4KTnOI0ZzjLOc5zgYsUcYnLXOEqxVzjOjco4Sa3uM0d
7nKP+zzgIY94TClPeEoZz3jOC8p5SQWVvOI1b3hLFe94zwc+8onPfOEr3/jO
D6r5SQ2/+E0tf/j7f354EIQRTh3qUo/6RNCAhjSiMZE0IYpoYmhKM5rTgpa0
IpbWtKEtcbQjngTak0iIDnSkE53pQleS6EZ3etCTXvSmD33pR38GMJBBDGYI
QxnGcEYwkmRGkcJoxjCWcaSSxngmMJFJ/APKLWza
       "]]}, {}}}],
  AspectRatio->0.4,
  AxesOrigin->{10., 2.},
  Frame->True,
  FrameLabel->{
    FormBox["n", TraditionalForm], 
    FormBox[
     SubscriptBox["A", "n"], TraditionalForm]},
  ImageSize->600,
  LabelStyle->Directive[FontSize -> 15],
  PlotRange->{{1, 200}, {2., 2.423175390374891}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, 
    Scaled[0.02]}]], "Text",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{
  3.509106549094022*^9, {3.5091066155776696`*^9, 3.5091066566047716`*^9}, {
   3.5108878081257977`*^9, 3.5108878341263933`*^9}, {3.510888760648636*^9, 
   3.5108888026448307`*^9}, {3.510888850660617*^9, 3.510888866533265*^9}, 
   3.5114830995569296`*^9, 3.511483222317951*^9, {3.511483254436788*^9, 
   3.5114833824421096`*^9}, {3.511483427824705*^9, 3.5114834485618916`*^9}, {
   3.511483480739732*^9, 3.511483495360568*^9}, 3.5114835913480587`*^9, 
   3.511483628821202*^9, 3.5114836607710295`*^9, 3.5114837102228575`*^9, {
   3.511483753489332*^9, 3.511483789042366*^9}, {3.511483823254323*^9, 
   3.511483900562744*^9}, {3.5114839694676857`*^9, 3.5114839927940197`*^9}, {
   3.5114841204773226`*^9, 3.511484136347231*^9}, {3.5114851315141506`*^9, 
   3.511485152667361*^9}, 3.514287340881753*^9, 3.514747825094104*^9}],

Cell[TextData[{
 StyleBox["Figure ", "FigureCaptionLabel"],
 StyleBox[
 CounterBox["FigureCaption"], "FigureCaptionLabel"],
 StyleBox[".", "FigureCaptionLabel",
  FontWeight->"Plain"],
 StyleBox["\[ThickSpace]\[ThickSpace]", "FigureCaptionLabel"],
 "Recursive calculations of the Mandelbrot set area."
}], "FigureCaption",
 CellChangeTimes->{{3.509219656680394*^9, 3.509219694547472*^9}, {
   3.509220005381826*^9, 3.509220038615546*^9}, {3.5099811562996902`*^9, 
   3.509981166625554*^9}, {3.5100571462440357`*^9, 3.510057153185749*^9}, {
   3.5108775001566353`*^9, 3.510877511335162*^9}, 3.514287340774657*^9, {
   3.514297234559276*^9, 3.5142972653953595`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Generalizations", "Subsection",
 CellChangeTimes->{3.514287340881753*^9}],

Cell[TextData[{
 "The term Mandelbrot set can also be applied to generalizations of \
\[OpenCurlyDoubleQuote]the\[CloseCurlyDoubleQuote] Mandelbrot set in which \
the function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}], "\[LongEqual]", 
    SuperscriptBox["z", "2"], "+", "C"}], TraditionalForm]], 
  "InlineFormula"],
 " is replaced by some other function. For example ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", 
    RowBox[{"(", "z", ")"}], "\[LongEqual]", "sin", 
    RowBox[{"(", 
     RowBox[{"z", "/", "c"}], ")"}]}], TraditionalForm]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["z", "0"], "\[LongEqual]", "c"}], TraditionalForm]], 
  "InlineFormula"],
 ", and ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]], "InlineFormula"],
 " is allowed to vary in the complex plane. Note that completely different \
sets (that are not Mandelbrot sets) can be obtained for choices of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "0"], TraditionalForm]], "InlineFormula"],
 " that do not lie in the fractal attractor. Also generalizations of the \
Mandelbrot set can be constructed by replacing ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["z", "n", "2"], TraditionalForm]], "InlineFormula"],
 " with ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["z", "n", "k"], TraditionalForm]], "InlineFormula"],
 " or ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     SubscriptBox[
      OverscriptBox["z", "_"], "n"], ")"}], "k"], TraditionalForm]], 
  "InlineFormula"],
 ", where ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]], "InlineFormula"],
 " is a ",
 "positive integer",
 " and ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["z", "_"], TraditionalForm]], "InlineFormula"],
 " denotes the ",
 "complex conjugate",
 " of ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]], "InlineFormula"],
 "."
}], "Text",
 CellChangeTimes->{{3.5091279508713675`*^9, 3.509127968900257*^9}, {
   3.509128033884365*^9, 3.509128058219493*^9}, 3.5142873408837547`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell[TextData[{
 "Alfeld, P. \[OpenCurlyDoubleQuote]The Mandelbrot Set.\
\[CloseCurlyDoubleQuote] ",
 ButtonBox["http://www.math.utah.edu/~alfeld/math/mandelbrot/mandelbrot.html",
  
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.math.utah.edu/~alfeld/math/mandelbrot/mandelbrot.html"], 
    None}],
 "."
}], "Reference"],

Cell[TextData[{
 "Branner, B. \[OpenCurlyDoubleQuote]The Mandelbrot Set.\
\[CloseCurlyDoubleQuote] In ",
 StyleBox["Chaos and Fractals: The Mathematics Behind the Computer Graphics, \
Proc. Sympos. Appl. Math., Vol.\[NonBreakingSpace]39",
  FontSlant->"Italic"],
 " (Ed. R.\[NonBreakingSpace]L.\[NonBreakingSpace]Devaney and L.\
\[NonBreakingSpace]Keen). Providence, RI: Amer. Math. Soc., 75\[Dash]105, \
1989."
}], "Reference",
 TaggingRules:>{"ISBN" -> "0821801376"},
 CellChangeTimes->{{3.514739532885186*^9, 3.5147395577916555`*^9}}],

Cell[TextData[{
 "Devaney, R. \[OpenCurlyDoubleQuote]The Mandelbrot Set and the Farey Tree, \
and the Fibonacci Sequence.\[CloseCurlyDoubleQuote] ",
 StyleBox["Amer. Math. Monthly",
  FontSlant->"Italic"],
 " ",
 StyleBox["106",
  FontWeight->"Bold"],
 ", 289\[Dash]302, 1999."
}], "Reference",
 CellChangeTimes->{{3.5091144208500233`*^9, 3.5091144208500233`*^9}}],

Cell[TextData[{
 "Dickau, R.\[NonBreakingSpace]M. \[OpenCurlyDoubleQuote]Mandelbrot (and \
Similar) Sets.\[CloseCurlyDoubleQuote] ",
 ButtonBox["http://mathforum.org/advanced/robertd/mandelbrot.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathforum.org/advanced/robertd/mandelbrot.html"], None}],
 "."
}], "Reference"],

Cell[TextData[{
 "Dickau, R.\[NonBreakingSpace]M. \[OpenCurlyDoubleQuote]Julia Sets.\
\[CloseCurlyDoubleQuote] ",
 ButtonBox["http://mathforum.org/advanced/robertd/julias.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathforum.org/advanced/robertd/julias.html"], None}],
 "."
}], "Reference"],

Cell[TextData[{
 "Dickau, R.\[NonBreakingSpace]M. \[OpenCurlyDoubleQuote]Another Method for \
Calculating Julia Sets.\[CloseCurlyDoubleQuote] ",
 ButtonBox["http://mathforum.org/advanced/robertd/inversejulia.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://mathforum.org/advanced/robertd/inversejulia.html"], None}],
 "."
}], "Reference"],

Cell[TextData[{
 "Douady, A. \[OpenCurlyDoubleQuote]Julia Sets and the Mandelbrot Set.\
\[CloseCurlyDoubleQuote] In ",
 StyleBox["The Beauty of Fractals: Images of Complex Dynamical Systems",
  FontSlant->"Italic"],
 " (Ed. H.\[Hyphen]O.\[NonBreakingSpace]Peitgen and D.\[NonBreakingSpace]H.\
\[NonBreakingSpace]Richter). Berlin: Springer\[Hyphen]Verlag, p.\
\[NonBreakingSpace]161, 1986."
}], "Reference",
 TaggingRules:>{"ISBN" -> "0387158510"},
 CellChangeTimes->{{3.514739744359609*^9, 3.514739753484346*^9}}],

Cell[TextData[{
 "Dufner, J.; Roser, A.; and Unseld, ",
 StyleBox["F. Fraktale und Julia-Mengen",
  FontSlant->"Italic"],
 ". Harri Deutsch, 1998."
}], "Reference",
 TaggingRules:>{"ISBN" -> "3817115644"},
 CellChangeTimes->{{3.514739771016604*^9, 3.514739787130437*^9}}],

Cell[TextData[{
 "Elenbogen, B. and Kaeding, T. \[OpenCurlyDoubleQuote]A Weak Estimate of the \
Fractal Dimension of the Mandelbrot Boundary.\[CloseCurlyDoubleQuote] ",
 StyleBox["Phys. Lett. A",
  FontSlant->"Italic"],
 " ",
 StyleBox["136",
  FontWeight->"Bold"],
 ", 358\[Dash]362, 1989."
}], "Reference"],

Cell[TextData[{
 "Eppstein, D. \[OpenCurlyDoubleQuote]Area of the Mandelbrot Set.\
\[CloseCurlyDoubleQuote] ",
 ButtonBox["http://www.ics.uci.edu/~eppstein/junkyard/mand\[Hyphen]area.html",
  
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.ics.uci.edu/~eppstein/junkyard/mand-area.html"], None}],
 "."
}], "Reference"],

Cell[TextData[{
 "Ewing, J.\[NonBreakingSpace]H. and Schober, G. \[OpenCurlyDoubleQuote]The \
Area of the Mandelbrot Set.\[CloseCurlyDoubleQuote] ",
 StyleBox["Numer. Math.",
  FontSlant->"Italic"],
 " ",
 StyleBox["61",
  FontWeight->"Bold"],
 ", 59\[Dash]72, 1992."
}], "Reference"],

Cell[TextData[{
 "Fisher, Y. and Hill, J. \[OpenCurlyDoubleQuote]Bounding the Area of the \
Mandelbrot Set.\[CloseCurlyDoubleQuote] Submitted to ",
 StyleBox["Numer. Math.",
  FontSlant->"Italic"]
}], "Reference"],

Cell[TextData[{
 "Gleick, J. ",
 StyleBox["Chaos: Making a New Science",
  FontSlant->"Italic"],
 ". New York: Penguin Books, center plate (following \
p.\[NonBreakingSpace]114), 1988."
}], "Reference",
 TaggingRules:>{"ISBN" -> "0140092501"},
 CellChangeTimes->{{3.5147398468553486`*^9, 3.5147398559980907`*^9}}],

Cell[TextData[{
 "Hill, J.\[NonBreakingSpace]R. \[OpenCurlyDoubleQuote]Fractals and the Grand \
Internet Parallel Processing Project.\[CloseCurlyDoubleQuote] Ch.\
\[NonBreakingSpace]15 in ",
 StyleBox["Fractal Horizons: The Future Use of Fractals",
  FontSlant->"Italic"],
 ". New York: St.\[NonBreakingSpace]Martin\[CloseCurlyQuote]s Press, pp.\
\[NonBreakingSpace]299\[Dash]323, 1996."
}], "Reference",
 TaggingRules:>{"ISBN" -> "0312125992"},
 CellChangeTimes->{{3.5147398723860054`*^9, 3.5147398808375406`*^9}}],

Cell[TextData[{
 "Lauwerier, H. Fractals: ",
 StyleBox["Endlessly Repeated Geometric Figures",
  FontSlant->"Italic"],
 ". Princeton, NJ: Princeton University Press, pp.\[NonBreakingSpace]124\
\[Dash]126, 138\[Dash]151 and 177\[Dash]180, 1991."
}], "Reference",
 TaggingRules:>{"ISBN" -> "0691024456"},
 CellChangeTimes->{{3.5091133833070307`*^9, 3.5091133919579067`*^9}, {
  3.514739907500537*^9, 3.5147399194441185`*^9}}],

Cell[TextData[{
 "Lei, T. (Ed.). ",
 StyleBox["The Mandelbrot Set, Theme and Variations",
  FontSlant->"Italic"],
 ". Cambridge, England: Cambridge University Press, 2000."
}], "Reference",
 TaggingRules:>{"ISBN" -> "0521774764"},
 CellChangeTimes->{{3.514739983161228*^9, 3.51473998946912*^9}}],

Cell[TextData[{
 "Lesmoir\[Hyphen]Gordon, N.; Rood, W.; and Edney, R. ",
 StyleBox["Introducing Fractal Geometry",
  FontSlant->"Italic"],
 ". Cambridge, England: Icon Books, p.\[NonBreakingSpace]97, 2000."
}], "Reference",
 TaggingRules:>{"ISBN" -> "1840461233"},
 CellChangeTimes->{{3.514740025882041*^9, 3.514740032633065*^9}}],

Cell[TextData[{
 "Mandelbrot, B.\[NonBreakingSpace]B. ",
 StyleBox["The Fractal Geometry of Nature",
  FontSlant->"Italic"],
 ". New York: W.\[NonBreakingSpace]H. Freeman, pp.\[NonBreakingSpace]188\
\[Dash]189, 1983."
}], "Reference",
 TaggingRules:>{"ISBN" -> "0716711869"},
 CellChangeTimes->{{3.514740058366783*^9, 3.514740065170824*^9}}],

Cell[TextData[{
 "Mendes\[Hyphen]France, M. \[OpenCurlyDoubleQuote]Nevertheless.\
\[CloseCurlyDoubleQuote] ",
 StyleBox["Math. Intell.",
  FontSlant->"Italic"],
 " ",
 StyleBox["10",
  FontWeight->"Bold"],
 ", 35, 1988."
}], "Reference"],

Cell[TextData[{
 "Mitchell, K. \[OpenCurlyDoubleQuote]A Statistical Investigation of the Area \
of the Mandelbrot Set.\[CloseCurlyDoubleQuote] 2001. ",
 ButtonBox["http://www.fractalus.com/kerry/articles/area/mandelbrot\[Hyphen]\
area.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.fractalus.com/kerry/articles/area/mandelbrot-area.html"], 
    None}],
 "."
}], "Reference"],

Cell[TextData[{
 "Munafo, R. \[OpenCurlyDoubleQuote]Mu\[Hyphen]Ency\[LongDash]The \
Encyclopedia of the Mandelbrot Set.\[CloseCurlyDoubleQuote] ",
 ButtonBox["http://www.mrob.com/pub/muency.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.mrob.com/pub/muency.html"], None}],
 "."
}], "Reference"],

Cell[TextData[{
 "Munafo, R. \[OpenCurlyDoubleQuote]Area of the Mandelbrot Set.\
\[CloseCurlyDoubleQuote] ",
 ButtonBox["http://www.mrob.com/pub/muency/areaofthemandelbrotset.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.mrob.com/pub/muency/areaofthemandelbrotset.html"], None}],
 "."
}], "Reference"],

Cell[TextData[{
 "Munafo, R. \[OpenCurlyDoubleQuote]Pixel Counting.\[CloseCurlyDoubleQuote] ",
 ButtonBox["http://www.mrob.com/pub/muency/pixelcounting.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.mrob.com/pub/muency/pixelcounting.html"], None}],
 "."
}], "Reference",
 CellChangeTimes->{{3.5091144003939805`*^9, 3.5091144003939805`*^9}, {
  3.509115379723135*^9, 3.509115379723135*^9}}],

Cell[TextData[{
 "Peitgen, H.\[Hyphen]O. and Saupe, D. (Eds.). ",
 StyleBox["The Science of Fractal Images",
  FontSlant->"Italic"],
 ". New York: Springer\[Hyphen]Verlag, pp.\[NonBreakingSpace]152-163 and 178\
\[Dash]179, 1988."
}], "Reference",
 CellChangeTimes->{{3.5091153804102087`*^9, 3.509115388967393*^9}, {
  3.5147401068543253`*^9, 3.5147401139784613`*^9}}],

Cell[TextData[{
 "Schroeder, M. ",
 StyleBox["Fractals, Chaos, Power Laws",
  FontSlant->"Italic"],
 ". New York: W.\[NonBreakingSpace]H. Freeman, p.\[NonBreakingSpace]39, \
1991."
}], "Reference",
 TaggingRules:>{"ISBN" -> "0716723573"},
 CellChangeTimes->{{3.5147401290429797`*^9, 3.514740142177919*^9}}],

Cell[TextData[{
 "Shishikura, M. \[OpenCurlyDoubleQuote]The Boundary of the Mandelbrot Set \
has Hausdorff Dimension Two.\[CloseCurlyDoubleQuote] ",
 StyleBox["Ast\[EAcute]risque",
  FontSlant->"Italic"],
 ", No.\[NonBreakingSpace]222, ",
 StyleBox["7",
  FontWeight->"Bold"],
 ", 389\[Dash]405, 1994."
}], "Reference"],

Cell[TextData[{
 "Sloane, N.\[NonBreakingSpace]J.\[NonBreakingSpace]A. Sequences ",
 ButtonBox["A054670",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://oeis.org/A054670"], None}],
 ", ",
 ButtonBox["A054671",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://oeis.org/A054671"], None}],
 ", ",
 ButtonBox["A098403",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://oeis.org/A098403"], None}],
 ", and ",
 ButtonBox["A114448",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://oeis.org/A114448"], None}],
 " in \[OpenCurlyDoubleQuote]The On\[Hyphen]Line Encyclopedia of Integer \
Sequences.\[CloseCurlyDoubleQuote]"
}], "Reference",
 CellChangeTimes->{3.514738950313467*^9}],

Cell[TextData[{
 "Wagon, S. \[OpenCurlyDoubleQuote]Julia Sets.\[CloseCurlyDoubleQuote] \
\[Section]5.4 in ",
 StyleBox["Mathematica in Action",
  FontSlant->"Italic"],
 ". New York: W.\[NonBreakingSpace]H. Freeman, pp.\[NonBreakingSpace]163\
\[Dash]178, 1991."
}], "Reference",
 TaggingRules:>{"ISBN" -> "071672202X"},
 CellChangeTimes->{{3.5147401710315723`*^9, 3.5147401763091555`*^9}}],

Cell[TextData[{
 "Wells, D. ",
 StyleBox["The Penguin Dictionary of Curious and Interesting Geometry",
  FontSlant->"Italic"],
 ". London: Penguin, pp. 126\[Dash]127 and\[NonBreakingSpace]146\[Dash]148, \
1991."
}], "Reference",
 TaggingRules:>{"ISBN" -> "0140118136"},
 CellChangeTimes->{{3.509113478372977*^9, 3.5091134805278883`*^9}, {
  3.514740193434291*^9, 3.5147401996811647`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{860, Automatic},
WindowMargins->Automatic,
WindowElements->{"MagnificationPopUp", "StatusArea", "VerticalScrollBar"},
WindowTitle->"CDF InfoKit - Mandelbrot & Julia Sets",
PrintingCopies->1,
PrintingPageRange->{1, 1},
PrivateNotebookOptions->{"PluginToolbarEnabled"->False},
ShowCellBracket->False,
ShowSelection->True,
Deployed->False,
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData[StyleDefinitions -> "StyleMenuClear.nb"]], 
   Cell[
    CellGroupData[{
      Cell["Style Environment Names", "Section"], 
      Cell[
       StyleData[All, "Working"], PageWidth -> 800]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Notebook Options Settings", "Section"], 
      Cell[
       StyleData["Notebook"], ShowCellBracket -> False, FontFamily -> "Times",
        FontSize -> 18, FontWeight -> "Plain", FontSlant -> "Plain"]}, 
     Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Title and Section Cells", "Section"], 
      Cell[
       StyleData["Title"], CellMargins -> {{60, 0}, {2, 60}}, 
       LineSpacing -> {0, 48}, FontFamily -> "Georgia", FontSize -> 36, 
       FontWeight -> "Plain", FontSlant -> "Plain", 
       FontVariations -> {"CapsType" -> "SmallCaps"}, FontColor -> 
       RGBColor[
        0.07290760662241551, 0.42914473182269014`, 0.5300068665598535]], 
      Cell[
       StyleData["Subtitle"], 
       CellMargins -> {{60, Inherited + 100}, {Inherited, Inherited}}, 
       FontFamily -> "Arial", FontSize -> 20, FontWeight -> "Plain", 
       FontSlant -> "Plain", FontColor -> GrayLevel[0.2]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Author"], CellMargins -> {{60, 0}, {8, 16}}, 
          CellFrameMargins -> 10, CellFrameColor -> 
          RGBColor[0.53, 0.22, 0.14], FontFamily -> "Verdana", FontSize -> 18,
           FontWeight -> "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[1], Background -> 
          RGBColor[
           0.07290760662241551, 0.42914473182269014`, 0.5300068665598535]], 
         Cell[
          StyleData["Author", "Printout"], 
          CellMargins -> {{24, 120}, {8, 20}}, FontColor -> GrayLevel[1]]}, 
        Closed]], 
      Cell[
       StyleData["Abstract"], CellMargins -> {{71, 100}, {8, 8}}, 
       TextJustification -> 0., LineSpacing -> {1, 6}, FontFamily -> 
       "Georgia", FontSize -> 12, FontWeight -> "Plain", FontSlant -> "Plain",
        FontColor -> GrayLevel[0.25]], 
      Cell[
       StyleData["Section"], CellFrame -> {{0, 0}, {0.5, 0}}, 
       CellMargins -> {{60, Inherited}, {8, 36}}, CellFrameColor -> 
       GrayLevel[0.5], 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Subsubsubsection", 0}, {"Item1", 0}, {"Item2", 0}, {"Item3", 0}, {
         "Item1Numbered", 0}, {"Item2Numbered", 0}, {"Item3Numbered", 0}}, 
       FontFamily -> "Arial", FontSize -> 20, FontWeight -> "Plain", 
       FontSlant -> "Plain", FontColor -> 
       RGBColor[
        0.07290760662241551, 0.42914473182269014`, 0.5300068665598535]], 
      Cell[
       StyleData["Subsection"], CellMargins -> {{75, Inherited}, {8, 12}}, 
       CounterAssignments -> {{"Subsubsection", 0}, {"Subsubsubsection", 0}, {
         "Item1", 0}, {"Item2", 0}, {"Item3", 0}, {"Item1Numbered", 0}, {
         "Item2Numbered", 0}, {"Item3Numbered", 0}}, FontFamily -> "Arial", 
       FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", FontColor -> 
       RGBColor[0.1202410925459678, 0.2980392156862745, 0.3167467765316243]]},
      Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Body Text", "Section"], 
      Cell[
       StyleData["Text"], CellMargins -> {{60, 10}, {7, 7}}, 
       LineSpacing -> {1, 4}, FontFamily -> "Georgia", FontSize -> 13, 
       FontWeight -> "Plain", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0.2]], 
      Cell[
       StyleData["Reference"], CellMargins -> {{60, 10}, {2, 4}}, Hyphenation -> 
       True, LineSpacing -> {1, 1}, ParagraphIndent -> -18, 
       TabSpacings -> {0.1, 1, 1.5}, FontFamily -> "Georgia", FontSize -> 12, 
       FontColor -> GrayLevel[0.2]]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Formulas and Programming", "Section"], 
      Cell[
       StyleData["Figure"], Editable -> True, 
       CellMargins -> {{56, Inherited}, {Inherited, 20}}, CellGroupingRules -> 
       "InputGrouping", CounterIncrements -> "Figure", 
       GraphicsBoxOptions -> {ImageSize -> 350}, 
       Graphics3DBoxOptions -> {ImageSize -> 350}], 
      Cell[
       StyleData["FigureCaption"], CellMargins -> {{60, Inherited}, {20, 4}}, 
       CellGroupingRules -> "NormalGrouping", PageBreakAbove -> False, 
       Hyphenation -> True, CounterIncrements -> "FigureCaption", 
       CounterAssignments -> {{"Nil", 0}}, FontFamily -> "Arial", FontSize -> 
       11, FontWeight -> "Plain", FontSlant -> "Plain", FontColor -> 
       GrayLevel[0.33]], 
      Cell[
       StyleData["FigureCaptionLabel"], FontWeight -> "Bold"], 
      Cell[
       StyleData["EquationNumbered"], 
       CellMargins -> {{85, 40}, {Inherited, Inherited}}, 
       CellFrameLabels -> {{None, 
          Cell[
           TextData[{"(", 
             CounterBox["EquationNumbered"], ")"}]]}, {None, None}}, 
       DefaultFormatType -> TraditionalForm, CounterIncrements -> 
       "EquationNumbered", FontSize -> 13, FontColor -> 
       RGBColor[0.23076218814374, 0.23076218814374, 0.23076218814374], 
       ButtonBoxOptions -> {Appearance -> {Automatic, None}}]}, Open]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Input and Output Cells", "Section"], 
      Cell[
       StyleData["Input"], ShowCellBracket -> True, 
       CellMargins -> {{56, 10}, {5, 10}}, FontSize -> 12], 
      Cell[
       StyleData["Output"], ShowCellBracket -> True, 
       CellMargins -> {{60, 10}, {10, 5}}]}, Open]]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Microsoft Windows (64-bit) (February 23, 2011)",
   StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[623, 23, 568, 7, 103, "Title"],
Cell[1194, 32, 275, 3, 31, "Subtitle"],
Cell[1472, 37, 229, 3, 66, "Author"],
Cell[1704, 42, 819, 13, 157, "Abstract"],
Cell[CellGroupData[{
Cell[2548, 59, 31, 0, 71, "Section"],
Cell[2582, 61, 739, 11, 110, "Text"],
Cell[3324, 74, 559, 8, 90, "Text"],
Cell[3886, 84, 314, 5, 50, "Text"],
Cell[4203, 91, 528, 9, 90, "Text"],
Cell[CellGroupData[{
Cell[4756, 104, 20552, 586, 1223, "Input",
 CellID->1388044557],
Cell[25311, 692, 33551, 827, 572, "Output"]
}, {2}]],
Cell[58874, 1522, 800, 17, 53, "FigureCaption"],
Cell[59677, 1541, 1331, 20, 150, "Text"],
Cell[CellGroupData[{
Cell[61033, 1565, 12886, 329, 654, "Input"],
Cell[73922, 1896, 39206, 987, 540, "Output"]
}, {2}]],
Cell[113140, 2886, 776, 16, 53, "FigureCaption"]
}, Open  ]],
Cell[CellGroupData[{
Cell[113953, 2907, 192, 7, 71, "Section"],
Cell[114148, 2916, 179, 8, 30, "Text"],
Cell[114330, 2926, 287, 9, 44, "EquationNumbered"],
Cell[114620, 2937, 1556, 54, 90, "Text"],
Cell[116179, 2993, 75, 0, 30, "Text"],
Cell[116257, 2995, 194, 6, 27, "EquationNumbered"],
Cell[116454, 3003, 597, 15, 30, "Text"],
Cell[117054, 3020, 86367, 1086, 225, "Text"],
Cell[203424, 4108, 911, 22, 38, "FigureCaption"],
Cell[204338, 4132, 1901, 59, 110, "Text"],
Cell[CellGroupData[{
Cell[206264, 4195, 17763, 397, 798, "Input",
 CellID->7775854],
Cell[224030, 4594, 6528, 131, 516, "Output"]
}, {2}]],
Cell[230570, 4728, 538, 12, 38, "FigureCaption"],
Cell[231111, 4742, 930, 19, 70, "Text"],
Cell[232044, 4763, 1215, 39, 90, "Text"],
Cell[233262, 4804, 291, 12, 30, "Text"],
Cell[233556, 4818, 458, 12, 45, "EquationNumbered"],
Cell[234017, 4832, 294, 13, 30, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[234348, 4850, 75, 1, 71, "Section"],
Cell[CellGroupData[{
Cell[234448, 4855, 133, 2, 36, "Subsection"],
Cell[234584, 4859, 341, 6, 70, "Text"],
Cell[234928, 4867, 192, 4, 30, "Text"],
Cell[235123, 4873, 238, 7, 27, "EquationNumbered"],
Cell[235364, 4882, 1559, 42, 70, "Text"],
Cell[236926, 4926, 78985, 1301, 515, "Text"],
Cell[315914, 6229, 577, 12, 38, "FigureCaption"],
Cell[316494, 6243, 687, 18, 70, "Text"],
Cell[317184, 6263, 1432, 38, 47, "EquationNumbered"],
Cell[318619, 6303, 1130, 32, 90, "Text"],
Cell[319752, 6337, 575, 9, 90, "Text"],
Cell[320330, 6348, 1280, 27, 110, "Text"],
Cell[321613, 6377, 215846, 2703, 442, "Text"],
Cell[537462, 9082, 500, 11, 38, "FigureCaption"]
}, Open  ]],
Cell[CellGroupData[{
Cell[537999, 9098, 77, 1, 36, "Subsection"],
Cell[538079, 9101, 2062, 49, 130, "Text"],
Cell[CellGroupData[{
Cell[540166, 9154, 212975, 3580, 916, "Input"],
Cell[753144, 12736, 199952, 3310, 564, "Output"]
}, {2}]],
Cell[953108, 16049, 1015, 21, 53, "FigureCaption"],
Cell[954126, 16072, 372, 6, 50, "Text"],
Cell[954501, 16080, 309, 8, 23, "EquationNumbered"],
Cell[954813, 16090, 108, 1, 30, "Text"],
Cell[954924, 16093, 4313, 119, 165, "EquationNumbered"],
Cell[959240, 16214, 217, 8, 30, "Text"],
Cell[959460, 16224, 412, 13, 50, "Text"],
Cell[959875, 16239, 3094, 81, 102, "EquationNumbered"],
Cell[962972, 16322, 575, 22, 50, "Text"],
Cell[963550, 16346, 750, 25, 34, "EquationNumbered"],
Cell[964303, 16373, 607, 23, 50, "Text"],
Cell[964913, 16398, 674, 12, 50, "Text"],
Cell[CellGroupData[{
Cell[965612, 16414, 10888, 235, 601, "Input",
 CellID->775079852],
Cell[976503, 16651, 6503, 124, 446, "Output"]
}, {2}]],
Cell[983018, 16778, 900, 18, 53, "FigureCaption"]
}, Open  ]],
Cell[CellGroupData[{
Cell[983955, 16801, 68, 1, 36, "Subsection"],
Cell[984026, 16804, 114, 1, 30, "Text"],
Cell[984143, 16807, 337, 9, 52, "EquationNumbered"],
Cell[984483, 16818, 427, 14, 50, "Text"],
Cell[984913, 16834, 2211, 62, 84, "EquationNumbered"],
Cell[987127, 16898, 483, 17, 30, "Text"],
Cell[987613, 16917, 5751, 167, 304, "EquationNumbered"],
Cell[993367, 17086, 1339, 38, 110, "Text"],
Cell[994709, 17126, 787, 22, 70, "Text"],
Cell[995499, 17150, 1026, 17, 71, "Text"],
Cell[996528, 17169, 9423, 156, 276, "Text"],
Cell[1005954, 17327, 664, 13, 38, "FigureCaption"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1006655, 17345, 79, 1, 36, "Subsection"],
Cell[1006737, 17348, 2049, 65, 114, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1008835, 17419, 29, 0, 71, "Section"],
Cell[1008867, 17421, 336, 10, 21, "Reference"],
Cell[1009206, 17433, 537, 11, 37, "Reference"],
Cell[1009746, 17446, 364, 10, 37, "Reference"],
Cell[1010113, 17458, 338, 8, 21, "Reference"],
Cell[1010454, 17468, 311, 8, 21, "Reference"],
Cell[1010768, 17478, 354, 8, 21, "Reference"],
Cell[1011125, 17488, 513, 10, 37, "Reference"],
Cell[1011641, 17500, 271, 7, 21, "Reference"],
Cell[1011915, 17509, 308, 9, 37, "Reference"],
Cell[1012226, 17520, 333, 9, 21, "Reference"],
Cell[1012562, 17531, 284, 9, 21, "Reference"],
Cell[1012849, 17542, 213, 5, 21, "Reference"],
Cell[1013065, 17549, 313, 8, 21, "Reference"],
Cell[1013381, 17559, 515, 10, 37, "Reference"],
Cell[1013899, 17571, 423, 9, 37, "Reference"],
Cell[1014325, 17582, 295, 7, 21, "Reference"],
Cell[1014623, 17591, 330, 7, 21, "Reference"],
Cell[1014956, 17600, 341, 8, 21, "Reference"],
Cell[1015300, 17610, 237, 9, 21, "Reference"],
Cell[1015540, 17621, 396, 10, 37, "Reference"],
Cell[1015939, 17633, 316, 8, 21, "Reference"],
Cell[1016258, 17643, 324, 8, 21, "Reference"],
Cell[1016585, 17653, 411, 9, 21, "Reference"],
Cell[1016999, 17664, 367, 8, 37, "Reference"],
Cell[1017369, 17674, 306, 8, 21, "Reference"],
Cell[1017678, 17684, 319, 9, 21, "Reference"],
Cell[1018000, 17695, 710, 24, 21, "Reference"],
Cell[1018713, 17721, 388, 9, 21, "Reference"],
Cell[1019104, 17732, 388, 9, 21, "Reference"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)(* NotebookSignature yKNEenyi2guCZJkscZkIGvXm *)
